#include "TPhSensorMapDBFECItem.h"

#include <string.h>

ClassImp(TPhSensorMapDBFECItem)

  /////////////////////////////////////////////////////////////////////////
  //
  // TPhSensorMapDBFECItem stores the (Sensor, Row, Col) lookup map for  
  // a given FEC. This class is used by TPhSensorMapDB, which does the
  // actual lookup. 
  //
  // $Id: TPhSensorMapDBFECItem.cxx,v 1.4 1999/02/25 00:45:11 olszewsk Exp $
  //
  /////////////////////////////////////////////////////////////////////////

TPhSensorMapDBFECItem::TPhSensorMapDBFECItem()
{
  // Default constructor

  Int_t i;

  fFEC = 0;
  for(i = 0; i < kNumStrings; i++) {
    fStringLength[i] = 0;
    fString[i] = NULL;
  }
}

TPhSensorMapDBFECItem::TPhSensorMapDBFECItem(Int_t FEC) 
{
  // Normal constructor
  // Allocate maximum number of channels storage for the strings. In the 
  // Streamer we will then only write out as many channels as we have
  // actually used.

  Int_t i;

  fFEC = FEC;
  for(i = 0; i < kNumStrings; i++) {
    fStringLength[i] = 0;
    fString[i] = new SensorMap_t[kMaxLength];
  }  
}

TPhSensorMapDBFECItem::~TPhSensorMapDBFECItem()
{
  // Default destructor

  Int_t i;
  for(i = 0; i < kNumStrings; i++) {
    if(fString[i])
      delete [] fString[i];
    fStringLength[i] = 0;
  }
}

void TPhSensorMapDBFECItem::Store(Int_t String, Int_t ChPos, 
				  Char_t *Sensor, Int_t Row, Int_t Col, 
				  Int_t BondPat)
{
  // Store the (Sensor, Row, Col) + BondPattern information 
  // 
  // This routine is called when the table is initially populated

  SensorMap_t data;

  if(String >= kNumStrings) {
    Error("Store", "String is larger than allowed!");
    return;
  }
  if(ChPos >= kMaxLength) {
    Error("Store", "Channel is larger than allowed!");
    return;
  }

  strcpy(data.Sensor, Sensor);
  data.Row = Short_t(Row);
  data.Column = Short_t(Col);
  data.BondPat = Char_t(BondPat);

  fString[String][ChPos] = data;

  // Remember largest channel position
  if(fStringLength[String] <= ChPos)
    fStringLength[String] = ChPos+1;

}

Bool_t TPhSensorMapDBFECItem::Lookup(Int_t String, Int_t ChPos, 
		Char_t *Sensor, Int_t *Row, Int_t *Col, Int_t *BondPat)
{
  // The Sensor, Row and Column are looked up for a given String and Channel
  // position. The calling routine is responsible for sufficient storage
  // allocation.
  // 
  // Return: kTRUE if this is a valid entry and kFALSE if an error occured. 

  SensorMap_t data;

  // Check if this is a valid entry
  if(String > kNumStrings || String < 0)
    return kFALSE;
  if(ChPos >= fStringLength[String] || ChPos < 0)
    return kFALSE;

  data = fString[String][ChPos];

  strcpy(Sensor, data.Sensor);
  *Row = data.Row;
  *Col = data.Column;
  *BondPat = data.BondPat;

  return kTRUE;
}

void TPhSensorMapDBFECItem::Print(Option_t *option)
{
  // Print all the stored maps in this FEC
  
  Int_t String, ChPos;
  SensorMap_t MapItem;

  printf("Dump of FEC# = %d\n", fFEC);
  for(String = 0; String < kNumStrings; String++) {
    for(ChPos = 0; ChPos < fStringLength[String]; ChPos++) {
      MapItem = fString[String][ChPos];
      printf("String = %d, ChPos = %d --> %s (%d, %d)\n", 
	     String, ChPos, MapItem.Sensor, MapItem.Row, MapItem.Column);
    }
  }
}

//------------------------------------------------------------------------
Int_t TPhSensorMapDBFECItem::GetNStrings()
{
  Int_t String;
  Int_t NString = 0;
  for(String=0; String<kNumStrings; String++)
    {
     if(fStringLength[String]==0) return NString;
     NString++; 
    }
}

//__________________________________________________________________________
void TPhSensorMapDBFECItem::Streamer(TBuffer &R__b)
{
  // Stream an object of class TPhSensorMapDBFECItem.
  // Hand modified.

  Int_t i, j;
  if (R__b.IsReading()) {
    Version_t R__v = R__b.ReadVersion(); if (R__v) { }
    TObject::Streamer(R__b);
    R__b >> fFEC;
    R__b.ReadStaticArray(fStringLength);

    for (i = 0; i < kNumStrings; i++) {
      fString[i] = new SensorMap_t[fStringLength[i]];
      for (j = 0; j < fStringLength[i]; j++) {
	R__b.ReadStaticArray(fString[i][j].Sensor);
	R__b >> fString[i][j].Row;
	R__b >> fString[i][j].Column;
	R__b >> fString[i][j].BondPat;
      }
    }

  } else {
    R__b.WriteVersion(TPhSensorMapDBFECItem::IsA());
    TObject::Streamer(R__b);
    R__b << fFEC;
    R__b.WriteArray(fStringLength, kNumStrings);
  
    for (i = 0; i < kNumStrings; i++) {
      for (j = 0; j < fStringLength[i]; j++) {
	R__b.WriteArray(fString[i][j].Sensor, strlen(fString[i][j].Sensor));
	R__b << fString[i][j].Row;
	R__b << fString[i][j].Column;
	R__b << fString[i][j].BondPat;
      }
    }
  }
}
