// Made by A.O. on 4.11.1997
// Converts .AOU or .APX ascii output files from Phobos MC Geant based program
// to root format, creating MCTracks, MCHits, MCHitArrays and 
// MCRawDataBuffers data containers for each data event.
//main()
{
  gROOT.Reset();

  TStopwatch timer;      // create a timer
  TPhEvent *event;

  Char_t PathName[150];
  Char_t FileName[200];
  Char_t EventName[20];

  const Char_t *phathome = gSystem->Getenv("PHATHOME");
  sprintf(PathName, "%s/data/",phathome); 
  // Prompt for file to be opened. Depending on navigation in
  // dialog the current working directory can be changed.
  // The returned file name is always with respect to the
  // current directory.
  const char *gOpenAsTypes[] = {
    "AOU files",   "*.aou",
    "APX files",  "*.apx",
    0, 0
  };

  static TGFileInfo fi;
  fi.fFileTypes = gOpenAsTypes;
  fi.fIniDir = PathName;
  if(!gROOT->IsBatch()) {
    new TGFileDialog(gClient->GetRoot(), gClient->GetRoot(), kFDOpen, &fi);
    strcpy(FileName, fi.fFilename);
  } else {
    sprintf(FileName, "%s/data/hijing_2cen.aou",phathome);
  }

  // Attention!, now pointer to TPhDetector object is known only after
  // first event has been converted (AOU header has been read).
  // So only then the pointer value is known.
  TPhDetector *detector;

  // TPhASCIIData has been tested to work with one file, 
  // then new objects should be created to handle next (if any) files
  TPhASCIIData *data = new TPhASCIIData(FileName,1,1);
  if( !data || !data->IsOpen() ) {
    fprintf(stderr,
	    "AouToRoot: problems creating TPhASCIIData object - exiting.");
    exit(0);
  }
  TPhRun *run;
  run = data->GetRun();

  // Output goes into data subdirectory of the Phat home directory
  strcat(FileName,".root");
  TFile *out = new TFile(FileName,"RECREATE");
  if( !out ) {
    fprintf(stderr,
	    "AouToRoot: could not create %s output file - exiting.",
	    FileName);
    exit(0);
    }
  
  int cnt = 0;
  TPhDataObject *cont;
  timer.Start();
  while( event = data->GetNextEvent() ) {
    out.cd();
    // New mapping of electronics is used here to produce raw data container
    detector = TPhDetector::GetInstance();
    if( !detector ) {
      fprintf(stderr,
         "AouToRoot: could not obtain TPhDetector object - exiting.");
       exit(0);
    }
    detector->SetEvent(event);
    // Works for APX type files
    if(((TPhHashContainer *) 
	event->GetObject("MCHitArrays"))->GetEntries()) {
      //detector->MakeRawHitFECn0("MCHitArrays", "MCRawHitFECn0s");
    } 
    else if(((TPhHashContainer *) 
	     event->GetObject("MCHits"))->GetEntries()) {
      // In case of AOU file the following two lines replace the above 
      detector->MakeHitArraysOutOfHits("MCHits","HitArraysFromHits");
      //detector->MakeRawHitFECn0("HitArraysFromHits", "MCRawHitFECn0s");
    } 
    // the MCHits and MCTracks containers can be deleted for faster      //
    // access and smaller files                                          //
    // cont = (TPhDataObject *) event->GetObject("MCHits");              //  
    // event->RemoveObject(cont);                                        //   
    // delete cont;                                                      // cleaning   
    // cont = (TPhDataObject *) event->GetObject("MCTracks");            //   
    // event->RemoveObject(cont);                                        //  
    // delete cont;                                                      // 
      /////////////////////////////////////////////////////////////////////

    event->Write();
    event->Print("1");
    delete event;
    timer.Stop();
    timer.Print();
    timer.Continue();
    cnt++;
  }
  timer.Stop();
  timer.Print();
  
  run->Write();
  detector->Write();
  data->Close();
  delete data;
  out->Close();
}

