// Create templates for a set of px and pz 
{
    gROOT->Reset();
    gROOT->Time();

    Float_t x;
    Float_t z;
    Float_t dist;
    Int_t num = 0;
    Int_t i;
   
    Float_t chi2;
    Float_t ndof;
    Float_t p;
    
    // Step sizes in Px and Pz
    const Float_t kMinP   = 0.1;
    const Float_t kMaxP   = 0.25;
    const Float_t kPStep  = 0.0025;

    TPhHit *hit;
    TPhStuff *stuff = new TPhStuff();

    // Get the PHATHOME environmental.
    const Char_t *phathome = gSystem->Getenv("PHATHOME");
    printf("Found PHAT home at %s\n",phathome);
    Char_t fname[256];

    printf("Create Magnet\n");
//    TPhIdealMagnet *magnet = new TPhIdealMagnet();
    sprintf(fname,"%s/init/magnet/PhobosMagnet.root",phathome);
    printf("Get magnet object from %s \n",fname);
    TFile f(fname);
    TPhToscaMagnet *magnet = (TPhToscaMagnet *) f.Get("magnet");
    f.Close();

    sprintf(fname,"%s/init/test/Detector.root", phathome);
    printf("Get detector object from %s \n",fname);
    TFile f2(fname);
    // Get the latest geometry from the detector database.
    TPhDetector *det = f2.Get("LatestGeometry");
    f2.Close();

    printf("Create Simulator\n");

    TPhSwim   *swim = new TPhSwim();
    swim->SetMagnet(magnet);
    swim->SetDetector(det);
    swim->SetMS(kFALSE);
    swim->SetPixelize(kFALSE);
    swim->SetVerbose(kFALSE);

    TObjArray *TemplateList = new TObjArray();

    printf("Create templates between %g %g, %g stepsize\n",kMinP,kMaxP,kPStep);

    Float_t p;
    Float_t px;
    Float_t py;
    Float_t pz;
    Float_t oop;
    Float_t vec[13];
    Int_t cnt;

// Open a TCanvas and draw the detector
    Bool_t drawflag = kFALSE;
    if(drawflag) {
      TCanvas c1("view");
      TView v(1);
      v.SetRange(-5, -5, -5, 80, 20, 80);
      det->Draw(3, kFALSE);
    }

    for(px = kMinP ;px < kMaxP ; px += kPStep)
      for(pz = kMinP ;pz<kMaxP ; pz += kPStep)
	{
	  py = 0;

	  TrueTrack = new TPhTrack();
	  TrueTrack->SetPx(px);
	  TrueTrack->SetPy(py);
	  TrueTrack->SetPz(pz);
	  TrueTrack->SetMass(0.139);
	  // Only positive charge for now
	  TrueTrack->SetCharge(1);
	  swim->SwimTrack(TrueTrack);
	  if(drawflag) 
	    TrueTrack->Draw(4);

	  TObjArray *list = TrueTrack->GetHitList();
	  printf("Template %g %g %g: %d hits\n",px,py,pz,list->GetEntries());
	  // Only save templates going through at least 10 Si layers.
	  if(list->GetEntries() > 10)
	    {
	      printf("Create Template\n");
         
	      TPhTrackTemplate *t = new TPhTrackTemplate(16);
    
	      printf("Fill track to template\n");
	      t->FillTrack(TrueTrack,kFALSE);
    
	      swim->SetMS(kTRUE);
	      swim->SetPixelize(kTRUE);
	      swim->SetVerbose(0);      
        
// First, fill tracks with multiple scattering into the track
// template to determine average distance from the template
// in each plane. 
// The full covariance matrix is then filled in the next step
// with the normalized errors. That's done to make the inter-
// polation of missing rows easier.

	      for(i = 0; i < 2000; i++) 
		{
		  if(!(i%500)) 
		    {
		      printf("Add track %d\n",i);
		    }
		  track = new TPhTrack();
		  track->SetPx(px);
		  track->SetPy(py);
		  track->SetPz(pz);
		  track->SetMass(0.139);
		  track->SetCharge(1);
		  swim->SwimTrack(track);
		  if(track->GetNHits() == t->GetNRows())
		    {
		      // Don't add track to covariance mtx
		      t->AddTrack(track,kFALSE);
		    }
		  //		  return;
		  delete track;
		  det->ClearHits();
		}
	      t->NormEntries();
	      
// This time fill the full covariance matrix with normalized
// errors

	      for(i=0;i<2000;i++)
		{
		  track = new TPhTrack();
		  track->SetPx(px);
		  track->SetPy(py);
		  track->SetPz(pz);
		  track->SetMass(0.139);
		  track->SetCharge(1);
		  swim->SwimTrack(track);
		  if(track->GetNHits() == t->GetNRows())
		    {
		      // add track to covariance mtx
		      t->AddTrack(track,kTRUE);
		    }
		  if(!(i%500))
		    {
		      printf("Add track %d\n",i);
		    }
		  delete track;
		  det->ClearHits();
		}
	      t->NormCovar();
	      t->InvertCovar();
	      TemplateList->Add(t);
	    }
	}
    TemplateList->Print();
    TFile f1("templates.root","RECREATE");
    f1.cd();
    TemplateList->Write();
    f1.Close();
}


