// macro is using the data manager TPhTB98DST class to read Test Beam 98 run data 
// and produce TPhEvents with RawHitFECn0 objects, 
// uses pedestal histograms to remove pedestal and obtain a signal
main (Char_t *inputfilename=0, Char_t *pedfilename=0, Int_t skipevents = 0, Int_t runno = 0)
{
  gROOT->Reset();

  //  inputfilename = "run001.dat"; 
  //  pedfilename   = "ped005.dat.root";
  
  const Int_t kMaxEvents = 100;
  const Int_t kSigMult = 0;       // kSigMult * (pedestal RMS) noise removal
  const Int_t sig_bound = 50;     // signal found if ADC > sig_bound
  Int_t runno = 0;
  Int_t verbose = 2;
  
  // Histogram booking
  TH2D *histA00ADC = new TH2D("A00","Plane NA00 - ADCs",70, -0.5, 69.5, 22, -0.5, 21.5);
  TH2D *histA01ADC = new TH2D("A01","Plane NA01 - ADCs",70, -0.5, 69.5, 22, -0.5, 21.5);
  TH2D *histB00ADC = new TH2D("B00","Plane NB00 - ADCs",70, -0.5, 69.5, 22, -0.5, 21.5);
  TH2D *histB01ADC = new TH2D("B01","Plane NB01 - ADCs",70, -0.5, 69.5, 22, -0.5, 21.5);
  TH2D *histC00ADC = new TH2D("C00","Plane NC00 - ADCs",70, -0.5, 69.5, 22, -0.5, 21.5);
  TH2D *histC01ADC = new TH2D("C01","Plane NC01 - ADCs",70, -0.5, 69.5, 22, -0.5, 21.5);
  TH2D *histD00ADC = new TH2D("D00","Plane ND00 - ADCs",70, -0.5, 69.5, 22, -0.5, 21.5);
  TH2D *histD01ADC = new TH2D("D01","Plane ND01 - ADCs",70, -0.5, 69.5, 22, -0.5, 21.5);

  histA00ADC->SetMaximum(100);
  histA01ADC->SetMaximum(100);
  histB00ADC->SetMaximum(100);
  histB01ADC->SetMaximum(100);
  histC00ADC->SetMaximum(100);
  histC01ADC->SetMaximum(100);
  histD00ADC->SetMaximum(100);
  histD01ADC->SetMaximum(100);

  histA00ADC->SetMinimum(-50);
  histA01ADC->SetMinimum(-50);
  histB00ADC->SetMinimum(-50);
  histB01ADC->SetMinimum(-50);
  histC00ADC->SetMinimum(-50);
  histC01ADC->SetMinimum(-50);
  histD00ADC->SetMinimum(-50);
  histD01ADC->SetMinimum(-50);

  Char_t *ctitle[100];
  sprintf(ctitle,"Left sensor ADC histograms for file %s",inputfilename);
  TCanvas *c1 = new TCanvas("c1",ctitle,20,20,800,800);
  c1->Divide(2,2);
  c1->cd(1);
  histA00ADC->Draw("lego");

  sprintf(ctitle,"Right sensor ADC histogram for file %s",inputfilename);
  TCanvas *c2 = new TCanvas("c2",ctitle,20,20,800,800);
  c2->Divide(2,2);
  c2->cd(1);
  histA01ADC->Draw("lego");

  c1->cd(2);
  histB00ADC->Draw("lego");

  c2->cd(2);
  histB01ADC->Draw("lego");

  c1->cd(3);
  histC00ADC->Draw("lego");

  c2->cd(3);
  histC01ADC->Draw("lego");

  c1->cd(4);
  histD00ADC->Draw("lego");

  c2->cd(4);
  histD01ADC->Draw("lego");

  // INPUT file
  //-----------
  if(!inputfilename) {
     printf("Call main(filename) with the input file name as a parameter\n");
     return;
  }
  TPhBT98DST *bt = NULL;
  bt = new TPhBT98DST(inputfilename,skipevents,runno);
  bt->SetVerbose(verbose);
  if( !bt->IsInitialized() ) return;

  // file with histograms of mean and sig of pedestal
  TFile *pedfile;
  if(!(pedfile = new TFile(pedfilename,"READ","Test Beam 98 data"))) {
     printf("Error: Output file %s could not be opened.\n",pedfilename);
     return;
  }

  TH2D *histA00mADC = (TH2D *) pedfile->Get("A00m");
  TH2D *histA01mADC = (TH2D *) pedfile->Get("A01m");
  TH2D *histB00mADC = (TH2D *) pedfile->Get("B00m");
  TH2D *histB01mADC = (TH2D *) pedfile->Get("B01m");
  TH2D *histC00mADC = (TH2D *) pedfile->Get("C00m");
  TH2D *histC01mADC = (TH2D *) pedfile->Get("C01m");
  TH2D *histD00mADC = (TH2D *) pedfile->Get("D00m");
  TH2D *histD01mADC = (TH2D *) pedfile->Get("D01m");

  TH2D *histA00vADC = (TH2D *) pedfile->Get("A00v");
  TH2D *histA01vADC = (TH2D *) pedfile->Get("A01v");
  TH2D *histB00vADC = (TH2D *) pedfile->Get("B00v");
  TH2D *histB01vADC = (TH2D *) pedfile->Get("B01v");
  TH2D *histC00vADC = (TH2D *) pedfile->Get("C00v");
  TH2D *histC01vADC = (TH2D *) pedfile->Get("C01v");
  TH2D *histD00vADC = (TH2D *) pedfile->Get("D00v");
  TH2D *histD01vADC = (TH2D *) pedfile->Get("D01v");
  
  Char_t outputfilename[100];
  sprintf(outputfilename,"%s.root",inputfilename);
  printf("Converting TB98 file %s to %s ROOT format\n",inputfilename,outputfilename);
  // output file
  TFile *outputfile;
  if(!(outputfile = new TFile(outputfilename,"RECREATE","Test Beam 98 data"))) {
     printf("Error: Output file %s could not be opened.\n",outputfilename);
     return;
  }

  // Get TB98 detector
  const Char_t *phathome = gSystem->Getenv("PHATHOME");
  Char_t *detpath[100];
  sprintf(detpath,"%s/init/Detector_TB98.root",phathome);
  TFile *detfile = new TFile(detpath);
  TPhDetector *detector = detfile->Get("PMC_TB98_V4.30");
  
  // prepare for conversion and read the raw byte stream from TB98 data file
  Int_t xpix=0,ypix=0,adc=0,sig=0,eventcounter=0;
  Bool_t sigfound = kFALSE;
  TPhBoxSiSensor *plane=NULL;
  TPhHitArray *ha=NULL;
  TPhEvent *event = NULL;
  TPhObjectContainer *rawcont = NULL;
  
  outputfile->cd();
  while( (eventcounter <= kMaxEvents) && (event = bt->GetNextEvent()) ) {
    eventcounter++;
    
    histA00ADC->Reset();
    histA01ADC->Reset();
    histB00ADC->Reset();
    histB01ADC->Reset();
    histC00ADC->Reset();
    histC01ADC->Reset();
    histD00ADC->Reset();
    histD01ADC->Reset();

    detector->SetEvent(event);
    detector->MakeHitArrays("RawHitFECn0s","HitArraysTB98");
    detector->FillWithEventHitArrays("HitArraysTB98");
    //NA00
    plane = (TPhBoxSiSensor *) detector->GetSensor("NA00");
    plane->MakeHitList("RawHitFECn0s", "HitsTB98");
    ha = plane->GetHitArray();
    for(xpix=0;xpix<70;xpix++) {
      for(ypix=0;ypix<22;ypix++) {
	adc = ha->GetADC(ypix,xpix);
	sig =     adc
	  -   histA00mADC->GetCellContent(xpix+1,ypix+1)
	  - kSigMult*histA00vADC->GetCellContent(xpix+1,ypix+1);
	histA00ADC->Fill(xpix,ypix,sig);
	if(sig>sig_bound) sigfound = kTRUE;
      }
    }
    //NA01
    plane = (TPhBoxSiSensor *) detector->GetSensor("NA01");
    plane->MakeHitList("RawHitFECn0s", "HitsTB98");
    ha = plane->GetHitArray();
    for(xpix=0;xpix<70;xpix++) {
      for(ypix=0;ypix<22;ypix++) {
	adc = ha->GetADC(ypix,xpix);
	sig =     adc
	  -   histA01mADC->GetCellContent(xpix+1,ypix+1)
	  - kSigMult*histA01vADC->GetCellContent(xpix+1,ypix+1);
	histA01ADC->Fill(xpix,ypix,sig);
	if(sig>sig_bound) sigfound = kTRUE;
      }
    }
    //NB00
    plane = (TPhBoxSiSensor *) detector->GetSensor("NB00");
    plane->MakeHitList("RawHitFECn0s", "HitsTB98");
    ha = plane->GetHitArray();
    for(xpix=0;xpix<70;xpix++) {
      for(ypix=0;ypix<22;ypix++) {
	adc = ha->GetADC(ypix,xpix);
	sig =     adc
	  -   histB00mADC->GetCellContent(xpix+1,ypix+1)
	  - kSigMult*histB00vADC->GetCellContent(xpix+1,ypix+1);
	histB00ADC->Fill(xpix,ypix,sig);
	if(sig>sig_bound) sigfound = kTRUE;
      }
    }
    //NB01
    plane = (TPhBoxSiSensor *) detector->GetSensor("NB01");
    plane->MakeHitList("RawHitFECn0s", "HitsTB98");
    ha = plane->GetHitArray();
    for(xpix=0;xpix<70;xpix++) {
      for(ypix=0;ypix<22;ypix++) {
	adc = ha->GetADC(ypix,xpix);
	sig =     adc
	  -   histB01mADC->GetCellContent(xpix+1,ypix+1)
	  - kSigMult*histB01vADC->GetCellContent(xpix+1,ypix+1);
	histB01ADC->Fill(xpix,ypix,sig);
	if(sig>sig_bound) sigfound = kTRUE;
      }
    }
    //NC00
    plane = (TPhBoxSiSensor *) detector->GetSensor("NC00");
    plane->MakeHitList("RawHitFECn0s", "HitsTB98");
    ha = plane->GetHitArray();
    for(xpix=0;xpix<70;xpix++) {
      for(ypix=0;ypix<22;ypix++) {
	adc = ha->GetADC(ypix,xpix);
	sig =     adc
	  -   histC00mADC->GetCellContent(xpix+1,ypix+1)
	  - kSigMult*histC00vADC->GetCellContent(xpix+1,ypix+1);
	histC00ADC->Fill(xpix,ypix,sig);
	if(sig>sig_bound) sigfound = kTRUE;
      }
    }
    //NC01
    plane = (TPhBoxSiSensor *) detector->GetSensor("NC01");
    plane->MakeHitList("RawHitFECn0s", "HitsTB98");
    ha = plane->GetHitArray();
    for(xpix=0;xpix<70;xpix++) {
      for(ypix=0;ypix<22;ypix++) {
	adc = ha->GetADC(ypix,xpix);
	sig =     adc
	  -   histC01mADC->GetCellContent(xpix+1,ypix+1)
	  - kSigMult*histC01vADC->GetCellContent(xpix+1,ypix+1);
	histC01ADC->Fill(xpix,ypix,sig);
	if(sig>sig_bound) sigfound = kTRUE;
      }
    }
    //ND00
    plane = (TPhBoxSiSensor *) detector->GetSensor("ND00");
    plane->MakeHitList("RawHitFECn0s", "HitsTB98");
    ha = plane->GetHitArray();
    for(xpix=0;xpix<70;xpix++) {
      for(ypix=0;ypix<22;ypix++) {
	adc = ha->GetADC(ypix,xpix);
	sig =     adc
	  -   histD00mADC->GetCellContent(xpix+1,ypix+1)
	  - kSigMult*histD00vADC->GetCellContent(xpix+1,ypix+1);
	histD00ADC->Fill(xpix,ypix,sig);
	if(sig>sig_bound) sigfound = kTRUE;
      }
    }
    //ND01
    plane = (TPhBoxSiSensor *) detector->GetSensor("ND01");
    plane->MakeHitList("RawHitFECn0s", "HitsTB98");
    ha = plane->GetHitArray();
    for(xpix=0;xpix<70;xpix++) {
      for(ypix=0;ypix<22;ypix++) {
	adc = ha->GetADC(ypix,xpix);
	sig =     adc
	  -   histD01mADC->GetCellContent(xpix+1,ypix+1)
	  - kSigMult*histD01vADC->GetCellContent(xpix+1,ypix+1);
	histD01ADC->Fill(xpix,ypix,sig);
	if(sig>sig_bound) sigfound = kTRUE;
      }
    }
    // display interesting events
    if(sigfound) {
      for(Int_t ipad=1;ipad<5;ipad++) {
	c1->cd(ipad);
	gPad->Modified();
	gPad->Update();
	c2->cd(ipad);
	gPad->Modified();
	gPad->Update();
      }
      sigfound = kFALSE;
      Char_t dummy;
      // wait for return ..
      printf("Hit return to continue ...\n");
      gets(&dummy);
      if(dummy=='s') return 0;
    }
    delete event;
  }
  bt->Close();
  pedfile->Close();
}
