//  macro that reads Test Beam 98 data and produces TPhEvents with 
//  RawHitFECn0 objects, and more. This macro uses TPhBT98DST data manager
//  with compiled methods for reading data from file.
main (Char_t *inputfilename=0, Int_t runno=0)
{
  gROOT->Reset();

  //  Char_t *inputfilename = "ped005.dat";
  const kMaxEvents = 1000000;
  Int_t skipevents = 0;
  Int_t runno = 0;
  Int_t verbose = 1;

  // INPUT file
  //-----------
  if(!inputfilename) {
     printf("Call main(filename) with the input file name as a parameter\n");
     return;
  }
  TPhBT98DST *bt = NULL;
  bt = new TPhBT98DST(inputfilename,skipevents,runno);
  bt->SetVerbose(verbose);
  if( !bt->IsInitialized() ) return;

  // OUTPUT file
  //------------
  Char_t outputfilename[100];
  sprintf(outputfilename,"%s.root",inputfilename);
  printf("Converting TB98 file %s to %s ROOT format\n",inputfilename,outputfilename);
  TFile *outputfile;
  if(!(outputfile = new TFile(outputfilename,"RECREATE","Test Beam 98 data"))) {
     printf("Error: Output file %s could not be opened.\n",outputfilename);
     return;
  }

  // Get TB98 detector
  //------------------
  const Char_t *phathome = gSystem->Getenv("PHATHOME");
  Char_t *detpath[100];
  sprintf(detpath,"%s/init/Detector_TB98.root",phathome);
  TFile *detfile = new TFile(detpath);
  TPhDetector *detector = detfile->Get("PMC_TB98_V4.30");
  
  // prepare for conversion and read the raw byte stream from TB98 data file
  Int_t xpix=0,ypix=0,adc=0,eventcounter=0;
  TPhSiSensor *plane=NULL;
  TPhHitArray *ha=NULL;
  TPhEvent *event = NULL;
  TPhObjectContainer *rawcont = NULL;
  
  outputfile->cd();
  while( (event = bt->GetNextEvent()) ) {
    eventcounter++;
    detector->SetEvent(event);
    // make hit arrays outof raw hits
    detector->MakeHitArrays("RawHitFECn0s","HitArraysTB98");
    // attach them to the sensors
    detector->FillWithEventHitArrays("HitArraysTB98");
    plane = (TPhSiSensor *) detector->GetSensor("NA00");
    ha = plane->GetHitArray();
    //NA00 for example
    for(xpix=0;xpix<70;xpix++) {
      for(ypix=0;ypix<22;ypix++) {
        // do with them what you need
        // ypix - rows - first, 
        adc = ha->GetADC(ypix,xpix);
      }
    }

    outputfile->cd();
    event->Write();
    delete event;
    if(eventcounter >= kMaxEvents) break;
  }
  // save information on the results of the run
  bt->Write();
  outputfile->Close();
}
