//  File mdcdst.C      Macro version of mdcdst.cxx   D McLeod 2/24/99
//     This is an adaptation of MDC1 macros RROCC.C, rchwdst.C etc. as a
//     "skeleton" to be filled in for various data mining tests in MDC2.

//////////////////////////////////////////////////////////////////////////////
//   "Operating instructions":  This macro may be edited as you wish; it
// is intended to be a "skeleton" with existing examples to follow in filling
// in code for any study you wish to make on the MDC2 "mock" reconstruction.

//     With this macro you may plot any quantities of interest in the MDC2
// analysis output or output a micro-DST of some or all branches with any 
// selection that you program into it.  This routine takes care of the 
// "infrastructure".  The Tree analyzed here is that specified by Out.C 
// in the MDC2 analysis (see Phat/macros/mdc2).

//    This version has the /disk20000 MDC2 mock analysis output file locations
// hardcoded.  Six subsets or any combination may be chosen.  For this reason
// it is intended to be run on rlnx03, and for long (batch) jobs on rcas0134 or
// other nodes as they become available; after MDC2 we may use rsun00 also.
// Adaptation to any other locations that can hold many gigabytes e.g. ABACUS
// should be clear.  A useful improvement might be an automatic file name
// read such as in rchwdst_ach.C (9/98) with matching of characters to allow
// selection as an added feature.  It would be less brutal than this solution!
// Another idea we've discussed is storage of file names in a container with
// an iterator and methods for filtering the names.
//
//    The BNL rules are that rlnx03 should not be used for "long" jobs, which
// restricts use of mdcdst to chain->Draw for which the macro may be more 
// convenient. It will usually be run as batch i.e. mdcdstprog -b -q on 
// rcas; you may wish to output any plots to postscript in this case.

//     In general, edit to change the macro's behavior.  
// But some common alterations may be done externally: You may curtail the 
// number of events in the event loop to e.g. 50 by setenv MDCLIM 50 before 
// running the program.  setenv MDCPICK LDr would set to do the event loop
// and write a mDST using data set r i.e. random central hijing events.  
// Here is the keyletter translation:
//        L means run the explicit loop over events.
//        D means write a DST.
//        C means do the implicit loop chain->Draw operations
//        A means make the TPhMapSet branches active also i.e. All branches.
// Lower case letters choose one or more sets of data:
//        c = fixed central hijing (hg fc)
//        r = random vertex central hijing (hg rc)
//        p = central hg with plasma added (hg pl)
//        f = fixed inclusive hijing (hg fi)
//        i = random vertex inclusive (hg ri)
//        v = fixed central venus (ve fc)
// MDCPICK can contain any combination of these letters in any order, 
// up to 10 letters. If MDCPICK and/or MDCLIM do not exist, the 
// corresponding defaults below are taken.  You may alter the microDST
// file name from its default local mDST.root by setenv MDCMDST filename.
//////////////////////////////////////////////////////////////////////////////
{
  gROOT->Reset("a");
  Int_t j = 0;
/////////////////////// End of setup, start user code ////////////////////////
//  Set the default running conditions for this execution:
  Int_t Nevents = 10;    // cutoff on explicit loop over events.
  Bool_t wDST  = kFALSE;  // To switch on/off mDST write
  Bool_t eLOOP = kTRUE;  // Run the event loop over the chain
  Bool_t aLLBR = kFALSE;  // Activate all branches
  Bool_t cHAIN = kTRUE;  // Run the chain->Draw plots
  Char_t mDSTname[100];  // Output microDST file name
  strcpy(mDSTname,"mDST.root");
  Char_t pick[15];       // Input data set control
  strcpy(pick,"r");
  Int_t modulo = 100;

  //  Added 3/1/99:
  Char_t vzlc[10];
  Char_t vzhc[10];
  Float_t vzl = -10.0;  // Lower cut on vertex location
  Float_t vzh = 10.0;   // Upper cut

//  Override the default conditions above if environment parameters exist:
  if(gSystem->Getenv("MDCPICK")) {
    strcpy(pick,gSystem->Getenv("MDCPICK"));
    printf("MDCPICK run options = %s\n",pick);
    wDST = kFALSE;
    if(strstr(pick,"D")) wDST = kTRUE;
    eLOOP = kFALSE;
    if(strstr(pick,"L")) eLOOP = kTRUE;
    cHAIN = kFALSE;
    if(strstr(pick,"C")) cHAIN = kTRUE;
    aLLBR = kFALSE;
    if(strstr(pick,"A")) aLLBR = kTRUE;
    if(wDST) eLOOP = kTRUE;  // covers user blunders
  }
  if(gSystem->Getenv("MDCLIM"))  {
    Nevents = atoi(gSystem->Getenv("MDCLIM"));
    printf("Event loop number of events limit from MDCLIM = %d\n",Nevents);
  }
  if(gSystem->Getenv("MDCMDST")) {
    strcpy(mDSTname,gSystem->Getenv("MDCMDST"));
    printf("Output DST name chosen by MDCMDST = %s\n",mDSTname);
  }
  if(gSystem->Getenv("MDCMODUL")) {
    modulo = atoi(gSystem->Getenv("MDCMODUL"));
    printf("The event # is printed every %d events (MDCMODUL)\n",modulo);
  }
 
//////////////////////////////////////////////////////////////////////////////
//  Some example histograms, change these as you wish:
  TH1F *histoZv = new TH1F("histoZv"   ,"z vertex",220,-11.,11.);
  TH1F *histoEvnum = new TH1F("histoEvnum","event numbers",100,0.,10000.);
  TH1D *histoMult1 = new TH1D("histoMult1","chain multiplicity",100,0.,10000.);
  TH1D *histoMult2 = new TH1D("histoMult2" ,"loop multiplicity",100,0.,10000.);
  TH1F *histoNtrks = new TH1F("histoNtrks"   ,"Ntracks found",10,0.,10.);
  TH2F *MulRvsT = new TH2F("MulRvsT", "Recon vs True Mult",100,5900.,6200.,100,5900.,6200.);

//   "Generic" 4 canvases made available:
  TCanvas* c1 = new TCanvas("c1", "Phobos MDC2 output 1", 0, 0, 600, 400);
  TCanvas* c2 = new TCanvas("c2", "Phobos MDC2 output 2", 0, 430, 600, 400);
  TCanvas* c3 = new TCanvas("c3", "Phobos MDC2 output 3", 630, 0, 600, 400);
  TCanvas* c4 = new TCanvas("c4", "Phobos MDC2 output 4", 630, 430, 600, 400);

///////////////////////////////////////////////////////////////////////////////
////////////////// A few pages with all our MDC2 reconstructions!//////////////
  //// Note that these files are each about 655K bytes & 200 events (central)
  //// or 410K and 1000 events (peripheral) for a total of 72 GB, 52K events.
  printf("Define DST chain\n");
  TChain* chain = new TChain("DST");
  if(strstr(pick,"c")) {
    printf(" chain c (hg fc) to be added\n");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg0100fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg0102fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg0104fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg0106fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg0108fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg0110fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg0112fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg0114fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg0116fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg0118fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg0200fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg0202fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg0204fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg0206fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg0208fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg0210fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg0212fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg0214fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg0216fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg0218fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg0300fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg0302fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg0304fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg0306fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg0308fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg0310fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg0312fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg0314fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg0316fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg0318fc51.root");
      printf(" chain hg fc added; 30 files, 5974 events, 19.6 GB\n");
  }
  if(strstr(pick,"r")) {  
    printf(" chain r (hg rc) to be added\n");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg1000rc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg1002rc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg1004rc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg1006rc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg1008rc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg1010rc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg1012rc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg1014rc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg1016rc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg1018rc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg1100rc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg1102rc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg1104rc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg1106rc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg1108rc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg1110rc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg1112rc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg1114rc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg1116rc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg1118rc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg1200rc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg1202rc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg1204rc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg1206rc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg1208rc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg1210rc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg1212rc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg1214rc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg1216rc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981212hg1218rc51.root");
    printf(" chain hg rc added; 30 files, 5970 events, 19.6 GB\n");
  }
  if(strstr(pick,"p")) {  
    printf(" chain p (hg pl) to be added\n");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981216hg0100pl51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981216hg0102pl51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981216hg0104pl51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981216hg0106pl51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981216hg0108pl51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981216hg0110pl51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981216hg0112pl51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981216hg0114pl51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981216hg0118pl51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981216hg0200pl51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981216hg0202pl51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981216hg0204pl51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981216hg0206pl51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981216hg0208pl51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981216hg0210pl51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981216hg0212pl51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981216hg0214pl51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981216hg0216pl51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981216hg0218pl51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981216hg0300pl51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981216hg0302pl51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981216hg0304pl51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981216hg0306pl51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981216hg0308pl51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981216hg0310pl51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981216hg0312pl51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981216hg0314pl51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981216hg0316pl51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51981216hg0318pl51.root");
    printf(" chain hg pl added; 29 files, 5771 events, 19.0 GB\n");
  }
  if(strstr(pick,"f")) {  
    printf(" chain f (hg fi) to be added\n");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg0100fi51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg0110fi51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg0200fi51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg0210fi51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg0300fi51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg0310fi51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg0400fi51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg0410fi51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg0600fi51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg0610fi51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg1000fi51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg1010fi51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg2500fi51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg2510fi51.root");
    printf(" chain hg fi added; 14 files, 13986 events, 5.74 GB\n");
    }
  if(strstr(pick,"i")) {  
    printf(" chain i (hg ri) to be added\n");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg1100ri51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg1110ri51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg1200ri51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg1210ri51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg1300ri51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg1310ri51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg1400ri51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg1410ri51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg1500ri51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg1510ri51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg1600ri51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg1610ri51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg1700ri51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg1710ri51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg1800ri51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg1810ri51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg1900ri51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg1910ri51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg2000ri51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119hg2010ri51.root");
    printf(" chain hg ri added; 20 files, 19980 events, 8.2 GB\n");
  }
  if(strstr(pick,"v")) {  
    printf(" chain v (ve fc) to be added\n");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119ve0100fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119ve0104fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119ve0200fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119ve0202fc51.root");
    chain->Add("/disk20000/phobos/disk0/mdc2/krakow/rec/phod51990119ve0204fc51.root");
  printf(" chain ve fc added; 5 files, 795 events, 0.4 GB\n");
  }
  printf("Done building file chain\n");
/////////////////////////////////////////////////////////////////////////////  
/////////////////////////////////////////////////////////////////////////////  

  chain->SetBranchStatus("*",0);  // disable all branches
  if(aLLBR) {
    chain->SetBranchStatus("*",1);       // all branches of input
  }
  else {
    chain->SetBranchStatus("header",1);  // Omit the TPhMapSet objects
    chain->SetBranchStatus("vertex",1);
    chain->SetBranchStatus("trkhead",1);
    chain->SetBranchStatus("VtxObject",1);
    chain->SetBranchStatus("mhisthr-1",1);
    chain->SetBranchStatus("mhistin-1",1);
    chain->SetBranchStatus("mulgraf0",1);
    chain->SetBranchStatus("mulgraf1",1);
  }
//  chain->Print();   // Uncomment if you want to check contents

  printf("Setting up structures as in DST write for MDC2:\n");
  typedef struct {Float_t runnum,evnum,mult,dmult,multru,dmultru;} Header;
  typedef struct {Float_t xv,yv,zv; Bool_t vtxval; Int_t vtxerr;} Vertex;
  typedef struct {Float_t Ntracks,Ntemplates;} TPhtrkhd;
  Header h;
  Vertex v;
  TPhtrkhd trkhd;
  TPhVertex *v1 = new TPhVertex();
  TH2F *hidNdetadphi = new TH2F();
  TH2F *dNdetadphi   = new TH2F();
  TGraphErrors *mGraphs0 = new TGraphErrors();  //pointers to plots
  TGraphErrors *mGraphs1 = new TGraphErrors();  //pointers to plots
  
  TPhMapSet *sms1 = new TPhMapSet();   // Sensor mapset pointer
  TPhMapSet *dms1 = new TPhMapSet();    // Display mapset pointer

  printf("Set Branch Addresses\n");
  chain->SetBranchAddress("header", &h);
  chain->SetBranchAddress("vertex", &v);
  chain->SetBranchAddress("trkhead", &trkhd);
  chain->SetBranchAddress("VtxObject", &v1);
  chain->SetBranchAddress("mhistin-1", &dNdetadphi);
  chain->SetBranchAddress("mhisthr-1", &hidNdetadphi);
  chain->SetBranchAddress("mulgraf0", &mGraphs0);
  chain->SetBranchAddress("mulgraf1", &mGraphs1);
  if(aLLBR) {
    chain->SetBranchAddress("mulsmap", &sms1);
    chain->SetBranchAddress("muldmap", &dms1);
  }
  printf("Branch Addresses are set\n");

  gSystem->Exec("date");
  gBenchmark->Reset();

///////////////////////////////////////////////////////////////////////////////
  if(cHAIN) {
    gBenchmark->Start("Chain draw");

//    Here are some examples of TChain draws; you may change 
//    these to examples you find more interesting:
    c1->cd();
    chain->Draw("vertex.zv>>histoZv"); 
    c1->Update();
    c2->cd();
    chain->Draw("header.mult>>histoMult1",
                      "header.mult<10000 && header.mult>=0");
    c2->Update();
    if(!eLOOP) {     // We have two more canvases to draw on
      c3->cd();
      chain->Draw("trkhead.Ntracks>>histoNtrks");
      c3->Update();
      c4->cd();
      chain->Draw("header.mult:header.multru>>MulRvsT","","BOX");
      c4->Update();
    }
    gBenchmark->Show("Chain draw");
  }
///////////////////////////////////////////////////////////////////////////////
  if(eLOOP) {
    printf("Before output tree\n");
    TFile* fout;
    TTree* otree;
    if(wDST)
    {
      // Add an output tree.  This can be independent of the input structure.
      // Here we attach the branches to the same objects as the input tree.
      //    Edit in the output file name & path below, or use MDCMDST:
      fout = new TFile(mDSTname,"RECREATE","A miniDST",0);
      fout->SetCompressionLevel(1);
      printf("Output compression level set to 1\n");
      otree = new TTree("mDST","PHOBOS Output miniDST Tree",32000000);
      otree->SetAutoSave(50000000);
      printf("miniDST Tree created\n");

      // Comment out branches not wanted
      otree->Branch("header",&h,"runnum:evnum:mult:dmult:multru:dmultru");
      otree->Branch("trkhead",&trkhd,"Ntracks:Ntemplates");
      otree->Branch("vertex",&v,"xv:yv:zv:vtxval:vtxerr");
      otree->Branch("VtxObject","TPhVertex",&v1,32000,0);
      otree->Branch("mhisthr-1","TH2F",&dNdetadphi,128000,0);
      otree->Branch("mhistin-1","TH2F",&hidNdetadphi,128000,0);
      otree->Branch("mulgraf0","TGraphErrors",&mGraphs0,128000,0);
      otree->Branch("mulgraf1","TGraphErrors",&mGraphs1,128000,0);
      if(aLLBR) {
        otree->Branch("mulsmap","TPhMapSet",&sms1,128000,0);
        otree->Branch("muldmap","TPhMapSet",&dms1,128000,0);
      }
      // Set up convenient means to cut output according to vertex 3/1/99:
      if(gSystem->Getenv("MDCVL")) {
         strcpy(vzlc,gSystem->Getenv("MDCVL"));
         vzl = atof(vzlc);
         printf("Lower vertex cut on DST out (MDCVL) = %f\n",vzl);
      }
      if(gSystem->Getenv("MDCVH")) {
         strcpy(vzhc,gSystem->Getenv("MDCVH"));
         vzh = atof(vzhc);
         printf("Upper vertex cut on DST out (MDCVH) = %f\n",vzh);
      }
    }
////////////////////////////////////////////////////////////////////////////
    gBenchmark->Start("Event loop");
    Int_t nevent;
    nevent = (Int_t)chain->GetEntries();
    printf("Total number of events available : %d \n",nevent);
    if(Nevents <= nevent) {nevent = Nevents;}
    printf("Total number of events to be analyzed : %d \n",nevent);

    Float_t tt;
    for (Int_t i=0;i<nevent;i++) 
    {
      chain->GetEvent(i,0);        //read active branches of  event in memory
      if(i%modulo==0) {
        printf("Event# %d\n",i);
         if(strstr(pick,"M")) gSystem->Exec("free");  //get memory use
      }  
      tt = h.mult;
      if(tt>=0 && tt<10000)
      {
        //  Example plot filling, edit as you wish
        histoMult2->Fill(h.mult);  //Fill histogram with number of ptls
        histoEvnum->Fill(h.evnum); // and event number
      }
  
// Conditions for filling output tree from this event:
// Here is an example including only the tail of (inclusive) multiplicity
      //if(wDST && (h.mult >= 6200.0) && (h.mult <= 10000.0))
//  Select a vertex range, -10 to 10 default (3/1/99):
      if(wDST && (v.zv <= vzh) && (v.zv >= vzl))
      {            // Fill the output tree with current branch states
        fout->cd(); 
        otree->Fill();
        j++;    // output event counter
      }
    }
    gBenchmark->Show("Event loop");
///////////////////////////////////////////////////////////////////////////////

    //  Example plots; edit in whatever you want to see
    c3->cd();
    histoMult2->Draw();
    c4->cd();
    histoEvnum->Draw();

    gSystem->Exec("date");

    if(wDST)
    {
      fout->cd();   
      if(strstr(pick,"P")) {
        printf("Output tree contents:\n");
        fout->Print();
      }
      fout->Write();
      fout->Close();
      printf("mdcdst: Wrote mDST tree %s, %d events\n",mDSTname,j);
      Char_t lister[100];
      sprintf(lister,"ls -l %s",mDSTname);
      gSystem->Exec(lister);
    }
  }

  ////  End of mdcdst.C
}
