//tmp
// Read events made by write_events.C from a root file and show some 
// info about the events.
//
//Begin_Html <A HREF="mailto:decowski@mit.edu">decowski@mit.edu</A>
//End_Html
{
    gROOT->Reset();

    Int_t      i;

    TPhHit    *hit;
    TPhEvent  *event;
    TPhObjectContainer *TrackContainer;

    TObjArray *HitList;
    TObjArray *TrackList;
    TPhTrack  *track;

    // Open the data file. File can be generated by the write_events.C macro
    // As with all Phat stuff, PHATHOME envrionment has to be defined and 
    // pointing to the main Phat directory
    Char_t FileName[200];
    sprintf(FileName, "%s/data/pmc100ev89.hijet.aou.root", 
	    gSystem->Getenv("PHATHOME"));
    TPhDST *dst = new TPhDST(FileName);

    // Get the detector object. This is only needed by TPhSwim, to trace the 
    // tracks through the detector
    Char_t FileName[256];
    sprintf(FileName,"%s/init/test/Detector.root", 
	    gSystem->Getenv("PHATHOME"));
    TFile f(FileName);
    TPhDetector *det = f.Get("PMC_V3.80");
    f.Close();

    // TPhSwim also needs a magnet object.
    TPhIdealMagnet *magnet = new TPhIdealMagnet();

    // Instantiate TPhSwim and connect the detector and magnet objects to it.
    TPhSwim *swim  = new TPhSwim();
    swim->SetDetector(det);
    swim->SetMagnet(magnet);

    // We will histogram some silly hit parameters.
    TCanvas c1("Show Hits in Spectrometer");
    TH1F *xvsz = new TH1F("xvsz","X vs Z (cm)",250, 0, 80);

    TPhSpectSensor *sensor = det->GetSensor("SPA1");

    // This loop loops over all events. 
    while(event = dst->GetNextEvent()) {
      printf("Found %d %d \n",event->GetNRun(), event->GetNEvent());

      // Our generated tracks are in a TPhObjectContainer, named 'MCTracks'
      // in the event object. We first need to receive it. 
      TrackContainer = (TPhObjectContainer*) event->GetObject("MCTracks");

      // Now we get the tracks in the TrackContainer. Note that CINT
      // seems to have trouble getting it directly. Eg. 
      // TrackList = (TObjArray*) event->GetObject("MCTracks")->GetObjectList()
      // does not seem to work, while it is legal C++.
      TrackList = TrackContainer->GetObjectList();
      printf("%d tracks in event\n", TrackList->GetEntries());

      // Here we create an iterator over all Tracks in the event.
      TIter TrackIter(TrackList);
      while(track = (TPhTrack*) TrackIter()) {

	// Swim the track through the detector.
	swim->SwimTrack(track);

	// TPhSwim fills the HitList of the track.
	HitList = track->GetHitList();

        //Loop over all tracks (we could have used an iterator) and 
	//fill our histogram.
       	for(i = 0; i < HitList->GetEntries(); i++) {
	  hit = (TPhHit *) HitList->At(i);

	  if (hit->GetSensorLabel() == sensor->GetLabel())
	    xvsz->Fill(hit->GetEnergy());

 	  if(i%1000) {
 	    xvsz->Draw();
 	    c1.Update();
	  }
	}
      }
    }
}
