//  Reconstruction of particles in spectrometer based on template algorithm
//  input data: root file with data in "raw data" format 
//              containing "MCRawHitFECn0s" HitArray
//  author: A.Olszewski, K.Wozniak
{
// Clean the ROOT environment 
    gROOT->Reset();
    gROOT->Time(); 
   
//========================
//  General initialization
//========================

   Int_t fVerbose=0;

// Get the directory where we sit in
   const Char_t *phathome = gSystem->Getenv("PHATHOME");
   printf("Found PHAT home at %s\n",phathome);

   // Get detector object from ROOT raw data file 
   TPhDetector *det = NULL;
   Char_t InputFileName[512];

   //   sprintf(InputFileName,"s1p45pipPIXDE_NOSCAT.aou.root","");
   printf("File with raw data: ");
   scanf("%s", InputFileName);

   TPhDST *inputdata = new TPhDST();
   if(!inputdata->Open(InputFileName)) {
      if(fVerbose>0) 
         fprintf(stderr,"rsFromRaw: can not open %s input file - exiting.",FileName);
      exit(0);
   }

   if( !det ) {
      det = inputdata->GetDetector();
      if(det) {
         printf("TPhDetector ver.%f found in %s\n", det->GetVersion(), InputFileName);
      } else {
         printf("rsFromRaw: Can't find/create a TPhDetector object\n");
         exit(0);
      }
   }


   Int_t num = 0;
   Int_t i;
   Int_t j;

// Create some histograms

   TH1F mom("mom","tot. momentum of reconstructed ptls",200,0.350,0.550);

// Create a few important objects

  TPhTemplateManager *tman  = new TPhTemplateManager();
  TPhTrackSelector   *tsel  = new TPhTrackSelector();

  printf("Templates from file: ");
  Char_t TemplFileName[256];
  scanf("%s", TemplFileName);

  tman->SetVerbose(1);
  tman->ReadTemplateList(TemplFileName);

  Int_t neventsmax;
  Int_t ncandidates, ntrfound;
  Int_t nevent0, nevent1, nevent2, nevent3;
  Float_t templtested; 
  Float_t x, z;
  
  TPhSubDetector *spectP, *spectN;
  TIter          *NextHit;
  TIterator      *spectPIter, *spectNIter;
  TPhSpectSensor *ssens;
  TPhEvent   *event;
  TObjArray  *tracklist;
  TObjArray  *hitlist;
  TPhTrack   *track;
  TPhHit     *hit;
  Int_t       nhitarr;
  Char_t     *name;

  tman->SetVerbose(0);
  tsel->SetVerbose(0);
  
  printf("Maximal number of events:");
  scanf("%d", &neventsmax);

  printf("...Start processing events\n");

  nevent0 = 0;
  nevent1 = 0;
  nevent2 = 0;
  nevent3 = 0;

//=================
//  Main event loop
//=================
    while(event = inputdata->GetNextEvent() && num < neventsmax)
    {

//================================
// Prepare hits for reconstruction
//================================
 	printf("new Event %d \n\n",num);
        det->ClearHits();
        det->SetEvent(event);

        nhitarr = det->MakeHitArrays("MCRawHitFECn0s","MCHitArraysFromFECn0s");
        printf("Raw data have been converted to %d hit arrays.\n", nhitarr);
#ifdef DEBUG
        THashTable *hacon = (THashTable *) event->GetObject("MCHitArraysFromFECn0s");
        hacon->Print("1");
#endif

        det->FillWithEventHitArrays("MCHitArraysFromFECn0s");

        if( !(spectP = det->GetSubDetector("SpectP")) ) 
           printf("rsFromRaw: Positive spectrometer arm not found, shall not be processed.\n");
        if( !(spectN = det->GetSubDetector("SpectN")) )
           printf("rsFromRaw: Negative spectrometer arm not found, shall not be processed.\n");

        spectPIter = spectP->GetSensorIter();
        spectNIter = spectN->GetSensorIter();

        spectPIter->Reset();
        while( ssens = (TPhSpectSensor *) spectPIter->Next() ) {
#ifdef DEBUG
	  TPhHitArray *hap = NULL;
	  if( hap = ssens->GetHitArray() ) hap->Print();
#endif
	  if( ssens->MakeHitList("dummy","HitsFromFECn0sHitArrays") ) {
              ssens->ClearHitArray();
#ifdef DEBUG
              printf("Found %d hits in sensor %s.\n", 
                      ssens->GetHitList()->GetEntriesFast(),ssens->GetName());
              ssens->GetHitList()->Print();
#endif

	      hitlist = NULL;
              if( hitlist = ssens->GetHitList() ) {
		NextHit = new TIter(hitlist);
		while( hit = (TPhHit *) NextHit() ) 
                { 
                  x = hit->GetX();
                  z = hit->GetZ();
//    ===============================================
//    selection criterion for hits for reconstruction
//    ===============================================
                  if(x>5.0 && x<80.0 && z>0.0 && z<80.0 && x<0.9*z )   
                  {
                     hitlist->Remove(hit);
  //                   printf("Remove x,z:  %11.4f  %11.4f\n", x, z);
                  }
                }
	      }
	      delete NextHit;
		  
#ifdef DEBUG
              printf("Found %d hits in sensor %s after cleaning.\n", 
                      ssens->GetHitList()->GetEntriesFast(),ssens->GetName());
              ssens->GetHitList()->Print();
#endif
	  }
	}
        spectNIter->Reset();
        while( ssens = (TPhSpectSensor *) spectNIter->Next() ) {
#ifdef DEBUG
          TPhHitArray *han = NULL;
          if( han = ssens->GetHitArray() ) han->Print();
#endif
	  if( ssens->MakeHitList("dummy","HitsFromFECn0sHitArrays") ) {
              ssens->ClearHitArray();
#ifdef DEBUG
              printf("Found %d hits in sensor %s.\n", 
                      ssens->GetHitList()->GetEntriesFast(),ssens->GetName());
              ssens->GetHitList()->Print();
#endif

	      hitlist = NULL;
              if( hitlist = ssens->GetHitList() ) {
		NextHit = new TIter(hitlist);
		while( hit = (TPhHit *) NextHit() ) 
		  if( hit->GetZ() > 2000.0 ) hitlist->Remove(hit);
	      }
	      delete NextHit;
		  
#ifdef DEBUG
              printf("Found %d hits in sensor %s after cleaning.\n", 
                      ssens->GetHitList()->GetEntriesFast(),ssens->GetName());
              ssens->GetHitList()->Print();
#endif
	  }
	}

//===============
// Reconstruction
//===============

//        CPU time limit 60 s
	templtested = tman->CreateTrackCandidates(60.0);
        ncandidates = tman->GetCandidateList()->GetEntries();

	tsel->SelectTracks(tman->GetCandidateList());
	
	tracklist = tsel->GetTrackList();
        ntrfound = tracklist->GetEntries();

//===============
// Results:
//  templtested - fraction of templates tested up to CPU time limit
//  ncandidates - number of track candidates
//  ntrfound    - number of tracks after selection 
//  tracklist   - list of tracks found
// summarized:
//  nevent0     - number of events with 0 tracks found
//  nevent1     - number of events with 1 track found
//   ..
//  nevent3     - number of events with 3 or more tracks found
//===============
        if(ntrfound == 0)  nevent0++;
        if(ntrfound == 1)  nevent1++;
        if(ntrfound == 2)  nevent2++;
        if(ntrfound >= 3)  nevent3++;

	printf("Found %d candidates   and %d tracks in the fraction of templates %f \n", ncandidates, ntrfound, templtested);
	for(i=0;i<tracklist->GetEntries();i++)
	{
	    track = (TPhTrack *) tracklist->At(i);
	    mom->Fill(track->GetP());
	    printf("Found track %g (%g , %g , %d)\n",
                track->GetP(),track->GetPx(),track->GetPz(),track->GetCharge());
	}

        tman->GetCandidateList()->Delete();
        delete event;
	num++;
    }


//==========================================
// display histogram and make final cleaning
//==========================================

    delete det;

    printf(" Events with  0  tracks found: %8d\n", nevent0);
    printf(" Events with  1  tracks found: %8d\n", nevent1);
    printf(" Events with  2  tracks found: %8d\n", nevent2);
    printf(" Events with  >2 tracks found: %8d\n", nevent3);


    mom.DrawCopy();

   c1->Modified();
   c1->cd();
}
