#ifndef _PhEvent_INCLUDED_
#define _PhEvent_INCLUDED_

///////////////////////////////////////////////////////////////////////
//                                                                   //
//    TPhEvent                                                       //
//                                                                   //
//    Phobos event class                                             //
//                                                                   //
//    TPhEvent manages access to the raw and reconstructed data      //
//    for one event in the PHAT environment.                         // 
//    environment                                                    //
//                                                                   //
//    Author  : Gunther Roland (rolandg@vxcern.cern.ch)              //
//    Created : 01/12/95                                             //
//    Version : 1.0                                                  //
//    Changed : July 12 1997                                         //
//              Add TPhEventHeader                                   //
//              Add HashTable for TPhDataBuffers                     //
//                                                                   //
//              Andrzej Olszewski December 3 1998                    //
//              Access to parameters added                           //
//                                                                   //
// $Id: TPhEvent.h,v 1.5 1998/12/15 23:19:46 decowski Exp $          //
//                                                                   //
///////////////////////////////////////////////////////////////////////

// Root Classes


#include "TNamed.h"
#include "THashTable.h"
#include "TH1.h"

// Phobos Classes

#include "TPhEventHeader.h"
#include "TPhDataObject.h"

class TPhVertex;
class TPhParKey;

class TPhEvent : public TPhDataObject {

public:
  TPhEvent();
  TPhEvent(Int_t run, Int_t event);
    
  virtual ~TPhEvent();

    
  virtual void      SetVerbose(Int_t i){ fVerbose = i;  }

  virtual Int_t     GetNRun()       { return fEventHeader->GetNRun(); }
  virtual Int_t     GetNEvent()     { return fEventHeader->GetNEvent(); }
  virtual Int_t     GetTriggerMask(){ return fEventHeader->GetTriggerMask();}
  virtual Int_t     GetDate()       { return fEventHeader->GetDate(); }
  virtual Int_t     GetTime()       { return fEventHeader->GetTime(); }
  virtual Int_t     GetDetStatus()  { return fEventHeader->GetDetStatus(); }

  virtual Int_t     GetNPars()                   
    { return fEventHeader->GetNPars(); }
  virtual TPhParKey* GetParameter(Int_t pos)     
    { return fEventHeader->GetParameter(pos); }
  virtual void      AddParameter(TPhParKey *par) 
    { fEventHeader->AddParameter(par); }

  virtual TPhEventHeader   *GetEventHeader()  { return fEventHeader;  }
  virtual THashTable       *GetObjectList()   { return fObjectList;   }
  virtual TPhDataObject    *GetObject(Char_t *ObjectName);
  virtual Int_t             AddObject(TPhDataObject *Object);
  virtual Int_t             RemoveObject(TPhDataObject *Object);

  virtual void       ls(Option_t *option="");
  virtual void       Print(Option_t *option="0");
  virtual void       PrintPars(Option_t *) 
    { GetEventHeader()->Print(); }
  virtual void       ListObjects() { ls(); };

  virtual TPhVertex *FindVertex(Bool_t Force = kFALSE);
  virtual void       DisplayVertex();

private:

    Int_t           fVerbose;      // Controls debugging/monitoring output
    TPhEventHeader *fEventHeader;  // Event header with general event info
    THashTable     *fObjectList;   // List of data objects
    TH1F           *fFineVertex;   //! Fine Histogram to calc vertex
    TH1F           *fCoarseVertex; //! Coarse Histogram to calc vertex

public:

    ClassDef(TPhEvent,1) // PHOBOS event data class

};

#endif




