#ifndef _PhHit_INCLUDED_
#define _PhHit_INCLUDED_

///////////////////////////////////////////////////////////////////////
//                                                                   //
//    TPhHit                                                         //
//                                                                   //
//    Phobos Hit class                                               //
//                                                                   //
//    TPhHit is the standard PHOBOS hit class used in the PR         //
//    programs                                                       // 
//                                                                   //
//    Author  : Gunther Roland (rolandg@vxcern.cern.ch)              //
//    Created : 01/16/96                                             //
//    Version : 1.0                                                  //
//    Changed : 30.09.1997 Andrzej Olszewski                         //
//              11.11.1998 Andrzej Olszewski & Krzysztof Wozniak     //
//                                                                   //
///////////////////////////////////////////////////////////////////////

// Root Classes

#include "TObject.h"
#include "TPolyMarker3D.h"
#include "TClass.h"

// Phobos Classes

class TPhSensor;

class TPhHit : public TObject {

public:
    TPhHit();
    
    virtual ~TPhHit();

    virtual Int_t     GetLabel()        { return fLabel;      }
    virtual Int_t     GetSensorLabel()  { return fSensorLabel;}
    virtual Int_t     GetLayer()        { return fLayer;      }
    virtual Float_t   GetX()            { return fX;          }
    virtual Float_t   GetY()            { return fY;          }
    virtual Float_t   GetZ()            { return fZ;          }
    virtual Int_t     GetPadX()         { return fPadX;       }
    virtual Int_t     GetPadY()         { return fPadY;       }
    virtual Float_t   GetDe()           { return fDe;         }
    virtual Float_t   GetDt()           { return fDt;         }
    virtual Float_t   GetField()        { return fField;      }

    virtual TPhSensor* GetSensor();

    virtual Float_t   CalcDist45();

    virtual TPolyMarker3D *GetMarker()  { return fMarker; }

    virtual void     SetLabel(Int_t n)      { fLabel = n;        } 
    virtual void     SetSensorLabel(Int_t n){ fSensorLabel = n;  }
    virtual void     SetLayer(Int_t n)      { fLayer = n;        }
    virtual void     SetX(Float_t x)        { fX = x;            }
    virtual void     SetY(Float_t x)        { fY = x;            }
    virtual void     SetZ(Float_t x)        { fZ = x;            }
    virtual void     SetPadX(Int_t n)       { fPadX = n;         }
    virtual void     SetPadY(Int_t n)       { fPadY = n;         }
    virtual void     SetDe(Float_t x)       { fDe = x;           }
    virtual void     SetDt(Float_t x)       { fDt = x;           }
    virtual void     SetField(Float_t x)    { fField  = x;       }

    virtual void     ls(Option_t *option = "");
    virtual void     Print(Option_t *option = "");
    virtual void     Draw(Option_t *option = "");

protected:

    Int_t     fLabel;       // Hit label
    Int_t     fSensorLabel; // Hit sensor label
    Int_t     fLayer;       // Hit layer number  
    Float_t   fX;           // X position                
    Float_t   fY;           // Y position
    Float_t   fZ;           // Z position
    Int_t     fPadX;        // number of the pad hit in local X direction
    Int_t     fPadY;        // number of the pad hit in local Y direction
    Float_t   fDe;          // Energy deposition
    Float_t   fDt;          // Time when the particle entered the sensor
    Float_t   fField ;      // Magnetic Field at X,Y,Z    

    TPolyMarker3D *fMarker; //! Marker

public:

    ClassDef(TPhHit,2)  // PHOBOS hit data class

};

#endif
