#ifndef _TPhHitArray_INCLUDED_
#define _TPhHitArray_INCLUDED_

///////////////////////////////////////////////////////////////////////
//                                                                   //
//    TPhHitArray                                                    //
//                                                                   //
//    PHOBOS container class for unpacked hits                       //
//                                                                   //
//    Author  : Gunther Roland (gunter.roland@cern.ch)               //
//    Created : July 14 1997                                         //
//    Version : 1.0                                                  //
//    Changed : 30.09.1997 Andrzej Olszewski                         //
//                                                                   //
// $Id: TPhHitArray.h,v 1.8 1999/02/24 23:12:43 olszewsk Exp $       //
//                                                                   //
///////////////////////////////////////////////////////////////////////

// Root Classes
class TH2S;

// PHOBOS Classes

#include "TPhDataObject.h"

// forward declaration

class TPhSensor;        

class TPhHitArray : public TPhDataObject {

public:

  TPhHitArray();
  TPhHitArray(const Char_t *Name, const Char_t *Title = NULL);
  TPhHitArray(TPhSensor *Sensor, const Char_t *Name, 
	      const Char_t *Title = NULL);

  virtual ~TPhHitArray();
  
  virtual void     DrawHistogram(Option_t *Option = "LEGO2");

  virtual Char_t  *GetSensorName()    { return fSensorName;    }
  virtual Int_t    GetNHits()    { return fHits;    }
  virtual Int_t    GetRows()    { return fRows;    }
  virtual Int_t    GetColumns()    { return fColumns;    }
  virtual Short_t  GetADC(Int_t row, Int_t column);

  virtual void     CalcNHits();
  virtual void     SetNHits(Int_t nhits) { fHits = nhits; }
  virtual void     SetRows(Int_t rows) { fRows = rows; }
  virtual void     SetColumns(Int_t columns) { fColumns = columns; }
  virtual void     SetADC(Int_t row, Int_t column, Int_t val);

          void     Print(Option_t *option = "");

private:

  virtual Int_t    GetIndex(Int_t row,Int_t column);
  virtual void     MakeArrays(TPhSensor *Sensor);

  Char_t           fSensorName[32]; // Name of TPhSensor object 'owning' this array of hits
  Int_t         fHits;           // Number of hits in the array       
  Int_t         fRows;           // X size of raw hit buffer           
  Int_t         fColumns;        // Y size of raw hit buffer           
  Short_t      *fADC;            // Array of unpacked ADC values
  TH2S         *fHist;           //! Histogram to store values

public:

  ClassDef(TPhHitArray,1)      // Sensor hit array (2D structure)

};

#endif


