#ifndef _PhMomentumVector_INCLUDED_
#define _PhMomentumVector_INCLUDED_

///////////////////////////////////////////////////////////////////////
//                                                                   //
//    TPhMomentumVector                                              //
//                                                                   //
//    Phobos momentum vector class                                   //
//                                                                   //
//    Standard class for storing momentum vectors. Z is the beam     //
//    direction                                                      // 
//                                                                   //
//    Author  : Gunther Roland (rolandg@vxcern.cern.ch)              //
//    Created : 01/09/96                                             //
//    Version : 1.0                                                  //
//    Changed :                                                      //
//                                                                   //
// $Id: TPhMomentumVector.h,v 1.2 1998/09/17 16:49:38 decowski Exp $
//                                                                   //
///////////////////////////////////////////////////////////////////////

#include "math.h"

// Root Classes

#include "TObject.h"
#include "TMath.h"

// Phobos Classes

class TPhMomentumVector : public TObject {

public:
    TPhMomentumVector();
    virtual ~TPhMomentumVector() { };

    virtual Double_t  GetPsi() const 
      { return TMath::ACos(fPy/TMath::Sqrt(fPx*fPx+fPy*fPy));   }

// Return the angle with respect to the beamline
    virtual Double_t  GetTheta() const
      { return TMath::Sign(fPx, fPx)*TMath::ATan2(fPx, fPz); }

    virtual Int_t     GetCharge() const 
      { return fCharge; }

// Return total P
    virtual Double_t  GetP() const 
      { return TMath::Sqrt(fPx*fPx+fPy*fPy+fPz*fPz); }
// Return P in the XZ plane
    virtual Double_t  GetPxz() const
      { return TMath::Sqrt(fPx*fPx + fPz*fPz); }
    virtual Double_t  GetPx() const    { return fPx;                  }
    virtual Double_t  GetPy() const    { return fPy;                  }
    virtual Double_t  GetPz() const    { return fPz;                  }
    virtual Double_t  GetPt() const    
      { return TMath::Sqrt(fPx*fPx+fPy*fPy); }

    virtual Double_t  GetSlopeXZ() const { return fPx/fPz;              }
    virtual Double_t  GetSlopeYZ() const { return fPy/fPz;              }
 
    virtual void     SetPx(Double_t x)  { fPx = x;      }
    virtual void     SetPy(Double_t x)  { fPy = x;      }
    virtual void     SetPz(Double_t x)  { fPz = x;      }
    virtual void     SetCharge(Int_t i){ fCharge = i;  }
  
private:

    Double_t fPx;            // Momentum in X-direction
    Double_t fPy;            // Momentum in Y-direction
    Double_t fPz;            // Momentum in Z-direction
    Char_t  fCharge;         // Charge 

public:
    ClassDef(TPhMomentumVector,1)  // Momentum vector storage and manipulation

};

#endif


