#ifndef _TPhObjectContainer_INCLUDED_
#define _TPhObjectContainer_INCLUDED_

////////////////////////////////////////////////////////////////////////
//                                                                    //
//    TPhObjectContainer                                              //
//                                                                    //
//    Phobos data container class. Raw data and the results of        //
//    calibration and reconstruction operations are stored in         //
//    TPhObjectContainer objects, which in turn are managed and       //
//    stored using the TPhEvent class.                                // 
//                                                                    //
//    Author  : Gunther Roland (gunter.roland@cern.ch)                //
//    Created : July 13 1997                                          //
//    Version : 1.0                                                   //
//    Changed : 980309 mpd: TPhObjectContainer inherits now from      //
//              TPhAbsDataContainer, also added GetIterator()         //
//                                                                    //
////////////////////////////////////////////////////////////////////////

// Root Classes

#include "TObjArray.h"
#include "TIterator.h"

// PHOBOS Classes

#include "TPhAbsDataContainer.h"

class TPhObjectContainer : public TPhAbsDataContainer {

public:

  TPhObjectContainer();
  TPhObjectContainer(Char_t *Name,Char_t *Title = NULL);
    
  virtual ~TPhObjectContainer();
  
  virtual void Add(TObject *object);

  virtual Int_t     GetEntries() { return fObjectList->GetEntries(); }
  virtual TObjArray *GetObjectList()   { return fObjectList; }
  virtual TIterator *GetIterator(Bool_t dir = kIterForward)
                                       { return fObjectList->MakeIterator(dir); }

  virtual void ls(Option_t *option = "");
  virtual void Draw(Option_t *option = "");
  virtual void Print(Option_t *option = "99");

private:

    TObjArray *fObjectList;     // List of objects stored in container

public:

    ClassDef(TPhObjectContainer,1)    // Data container for objects NOT inheriting from TNamed

};

#endif




