#ifndef __TPhRawHitFECn0__
#define __TPhRawHitFECn0__


/////////////////////////////////////////////////////////////////////
// 
// Class implementing the data from a NON-zerosuppressed FEC
// data.
//
//
// The data looks like the following (as of March 23, 1998):
//
// |-----trailer info--------|-------------data--------------------|
//
// -------------------     -----     -----             -----     --- ---
// | 1 | 1 | 1 | 1 | 1 ... 1 | 0 ... 0 | 0 ........... 0 | 0 ... 0 |  |
// -------------------     -----     -----             -----     ---  |
// |   |   |   |   |         |                                     |  |
// | T |   |   |   |  16x    |     3bit String Number              |  |
// | O |   |   |   |  7bit   |                                     |  |
// | T |   |   |   |         |---    ----- ........... ------    --|  |
// | A |   |   |   | Analog  |                                     |  |
// | L |   |   |---|  Values |                                     |  |
// |   |   |   |Mo |         |                                     |  |
// | # |   |   |de |         |                                     | 16-bit
// |   |--------------     ---          8 Strings                  |  |
// | o | S | F |   |         |                                     |  |
// | f | h | I | F |  8bit   |      each ADC value is 12bits       |  |
// |   | i | F | E |         |                                     |  |
// | W | f | O | C | Analog  |                                     |  |
// | O | t |   |   |  Values |                                     |  |
// | R | E | E | # |         |                                     |  |
// | D | r | r |   |         |                                     |  |
// | S | r | r |   |         |                                     |  |
// -------------------     ---     ---     --     --     ---     --- ---
//
//                                                        Start ---^
//
// $Id: TPhRawHitFECn0.h,v 1.6 1999/02/24 23:27:08 olszewsk Exp $
//
///////////////////////////////////////////////////////////////////////


// Root classes
#include "TObjArray.h"

// Phobos classes
#include "TPhAbsRawHitFEC.h"
#include "TPhString.h"

class TPhRawHitFECn0 : public TPhAbsRawHitFEC {

protected:
  void                 Pack();
  void                 UnPack();

public:

  TPhRawHitFECn0();
  TPhRawHitFECn0(Int_t FECNum);
  virtual ~TPhRawHitFECn0();

  virtual UInt_t        GetTotalWords() { return fTrailer[kTotalWordsPos]; }

// Debugging
  virtual void          PrintPacked(Option_t *option = "");
  virtual void          PrintPacked(Option_t *option, Int_t Line);

protected:

  UChar_t*     fRawHitsPacked;     // Packed 16-bit RawHits
    					
public:

  ClassDef(TPhRawHitFECn0,1)	// NON zero-suppressed FEC data storage
};


#endif // __TPhRawHitFECn0__
