#ifndef _TPhVertex_INCLUDED_
#define _TPhVertex_INCLUDED_


// Root classes

#include "TObjArray.h"
#include "TArrayF.h"

// PHOBOS classes

#include "TPhDataObject.h"

class TPhTrack;

class TPhVertex : public TPhDataObject {

public:

  enum EVtxStatus { 
    kValidVtx = 0, 
    kNotValidVtx,
    kUnknownVtx, 
    kOutsideRangeVtx, 
    kStatSmallVtx,
    kBadChi2Vtx
  };

  TPhVertex();
 
  TPhVertex(Char_t *Name, Char_t *Title = NULL, 
	    EVtxStatus Status = kUnknownVtx);
  
  virtual ~TPhVertex();

// Setters
  
  virtual void SetStatus(EVtxStatus Flag)    { fStatus   = Flag;       }
  virtual void SetIdDet(UChar_t DetectorId)  { fDetId    = DetectorId; }
  virtual void SetIdVtx(UChar_t VertexId)    { fVertexId = VertexId;   }
  virtual void SetX(Double_t X)               { fX        = X;          }
  virtual void SetY(Double_t Y)               { fY        = Y;          }
  virtual void SetZ(Double_t Z)               { fZ        = Z;          }

  virtual void SetSigX(Double_t X)            { fSigX        = X;       }
  virtual void SetSigY(Double_t Y)            { fSigY        = Y;       }
  virtual void SetSigZ(Double_t Z)            { fSigZ        = Z;       }

  virtual void SetPchi2(Double_t FitProb)     { fProb     = FitProb;    }

  // Test
  virtual Bool_t IsValid() { return (fStatus == kValidVtx) ? kTRUE : kFALSE; }
  
// Getters
  
  virtual EVtxStatus GetStatus()   {    return fStatus;     }
  virtual UChar_t GetIdDet()       {    return fDetId;      }
  virtual UChar_t GetIdVtx()       {    return fVertexId;   }
  
  virtual Double_t GetX()           {    return fX;          }
  virtual Double_t GetY()           {    return fY;          }
  virtual Double_t GetZ()           {    return fZ;          }
  
  virtual Double_t GetSigX()        {    return fSigX;       }
  virtual Double_t GetSigY()        {    return fSigY;       }
  virtual Double_t GetSigZ()        {    return fSigZ;       }

  virtual Double_t GetPchi2()       {    return fProb;       }
  
  virtual TObjArray    *GetParticleList()  {   return fParticleList;   }

  virtual void          Print(Option_t * /* Option */);

  virtual void          AddParticle(TPhTrack *t);

  ClassDef(TPhVertex,1)   // Vertex DST Class

protected:

  EVtxStatus fStatus;           // Vertex Status flag
  UChar_t fDetId;               // Id of Detector containing vertex
  UChar_t fVertexId;            // Id of Vertex type                
  Double_t fX;                  // Vertex position, X               
  Double_t fY;                  // Vertex position, Y               
  Double_t fZ;                  // Vertex position, Z               
  Double_t fSigX;               // Error on vertex position, X               
  Double_t fSigY;               // Error on vertex position, Y               
  Double_t fSigZ;               // Error on vertex position, Z               
  Double_t fProb;               // Vertex fit probability                    
  TObjArray *fParticleList;     // List of particles originating at vertex
    
};


#endif




