#include <iostream.h>
#include "TPhEventHeader.h"

ClassImp(TPhEventHeader)


//////////////////////////////////////////////////////////////////
//                                                              //
// TPhEventHeader is a PHOBOS data containing basic information //
// about the data events.                                       //
//                                                              //
// $Id: TPhEventHeader.cxx,v 1.4 1998/12/14 07:27:52 olszewsk Exp $
//                                                              //
//////////////////////////////////////////////////////////////////

TPhEventHeader::TPhEventHeader()
{
// Constructor. Set counter and list data members to zero.
// Don't use this constructor unless you have to and know
// what you are doing
// Use TPhEventHeader(Int_t run, Int_t event) instead

  fNRun = 0;
  fNEvent = 0;
  fTriggerMask = 0;
  fDate = 0;
  fTime = 0;
  fDetStatus = 0;
  fParMgr = NULL;
}

TPhEventHeader::TPhEventHeader(Int_t run, Int_t event)
{
// Constructor. Create the event header and the hash table
// for storing the data objects for this event. Set the 
// event name.

  SetNRun(run);
  SetNEvent(event);
  fTriggerMask = 0;
  fDate = 0;
  fTime = 0;
  fDetStatus = 0;
  fParMgr = NULL;
}

TPhEventHeader::~TPhEventHeader()
{
// Destructor. 

   SafeDelete(fParMgr);
}

Int_t TPhEventHeader::GetNPars()
{
  // Get number of parameters in the list

  if(!fParMgr) return 0;
  return fParMgr->GetNPars();
}

void TPhEventHeader::AddParameter(TPhParKey *par)
{
  // Add TPhParKey object to the list
  Char_t name[20];

  if(!fParMgr) {
    sprintf(name,"PARS_%d_%d",fNRun,fNEvent);
    fParMgr = new TPhParManager(name,"Event parameters");
  }
  fParMgr->AddParameter(par);
}

TPhParKey *TPhEventHeader::GetParameter(Int_t pos)
{
  // Get TPhParKey parameter object at pos position

  if(!fParMgr) return NULL;
  return fParMgr->GetParameter(pos);
}

void TPhEventHeader::Print()
{
  // Print data members 

   IndentLevel();
   cout << IsA()->GetName() << " Run: " << GetNRun() << " Event: " << GetNEvent() 
        << " Trig: " << GetTriggerMask() << " Date: " << GetDate() << " " << GetTime() 
        << " Detector: " << GetDetStatus() << endl;
   cout << "Parameters:" << endl; 
   fParMgr->PrintAll();
   return;
}

//______________________________________________________________________________
void TPhEventHeader::Streamer(TBuffer &R__b)
{
  // Stream an object of class TPhEventHeader.
  // Version 1 had no parameters accessed by name

   if (R__b.IsReading()) {
      Version_t R__v = R__b.ReadVersion(); if (R__v) { }
      TObject::Streamer(R__b);
      R__b >> fNRun;
      R__b >> fNEvent;
      R__b >> fTriggerMask;
      R__b >> fDate;
      R__b >> fTime;
      if(R__v>1) {
	R__b >> fDetStatus;
	R__b >> fParMgr;
      }
   } else {
      R__b.WriteVersion(TPhEventHeader::IsA());
      TObject::Streamer(R__b);
      R__b << fNRun;
      R__b << fNEvent;
      R__b << fTriggerMask;
      R__b << fDate;
      R__b << fTime;
      R__b << fDetStatus;
      R__b << fParMgr;
   }
}
