#include <math.h>
#include "TPhMCHit.h"
#include <iostream.h>
#include "TClass.h"
#include "TMath.h"

ClassImp(TPhMCHit)

///////////////////////////////////////////////////////////////////////
//                                                                   //
//    TPhMCHit                                                       //
//                                                                   //
//    TPhMCHit is the PHOBOS hit class used to store "real"          //
//    information about hits as received from PMC MC program.        // 
//                                                                   //
///////////////////////////////////////////////////////////////////////

TPhMCHit::TPhMCHit()
{
  // Defaulf constructor
   fDx = 0.0;
   fDy = 0.0;
   fDz = 0.0;
   fTrackNo = -1;  // negative number for undefined hit
   fPsi = 0.0;
   fLength = 0.0;
}

Float_t TPhMCHit::CalcPsi()
{
  // Calculate and set fPsi value using  fDx, fDy, fDz

    if(fabs(fDx) + fabs(fDz) > 0.0)
           fPsi =  TMath::ATan2(fDx, fDz);
    return fPsi;
}

Float_t TPhMCHit::CalcDLength()
{
  // Calculate length of the track inside the sensor

  Double_t d;

  d = fDx*fDx;
  d += fDy*fDy;
  d += fDz*fDz;

  return sqrt(d);
}

void TPhMCHit::Print(Option_t *option)
{
  // List the hit object info
  // Use "number" as an option to indicate how many sublevels should be listed

  printf("-------------------------------------------------------------------------------\n");
  printf("TPhMCHit: dx dy dz in sensor: %8.4f %8.4f %8.4f \n" \
         "on track no: %6d track length %8.3e  angle %8.4e\n", 
          fDx, fDy, fDz, fTrackNo, fLength, fPsi);
  TPhHit::Print(option);
}

void TPhMCHit::ls(Option_t *option)
{
  // List Object. option is still unused.

  TObject::IncreaseDirLevel();
  IndentLevel();
  cout << "Class:" << IsA()->GetName() << " is a hit in Sensor " 
       << GetSensorLabel() << " at " << GetX() << "," << GetY() 
       << "," << GetZ() << endl;
  TObject::DecreaseDirLevel();
}
