#include "TPhParKey.h"

ClassImp(TPhParKey)

/////////////////////////////////////////////////////////////////////////////
//                                                                         //
// TPhParKey is a class to store user notes on a ROOT TFile file.          //
//                                                                         //
// $Id: TPhParKey.cxx,v 1.2 1998/12/15 21:49:00 decowski Exp $
//                                                                         //
/////////////////////////////////////////////////////////////////////////////

TPhParKey::TPhParKey() 
{
  // default constructor
  fParValueType = 0;
}

TPhParKey::TPhParKey(Char_t *source, Char_t *parname, Char_t *value, Char_t partype)
{
  // building constructor
  fSource = source;  
  fParName = parname; 
  fParValue = value; 
  fParValueType = partype; 
}

Bool_t TPhParKey::GetParNumValue(Float_t *values, Int_t *numpars)
{
  // Try to extract numeric value of the parameter 
  Float_t ftemp[9];

  if(fParValueType==0) return kFALSE;
  if(!values) {
    Warning("GetParNumValue",
            "NULL pointer to a float given! \n");
    return kFALSE;
  }

  *numpars = sscanf(fParValue.Data(),"%f %f %f %f %f %f %f %f %f", 
		    ftemp,ftemp+1,ftemp+2,ftemp+3,ftemp+4,ftemp+5,ftemp+6,ftemp+7,ftemp+8);
  for(Int_t i=0;i<fParValueType;i++) 
    if(i<*numpars) 
      values[i]=ftemp[i];

  if(*numpars<fParValueType) return kFALSE;
  return kTRUE;
}

Bool_t TPhParKey::GetParTextValue(Char_t *value)
{
  // Extract value of the parameter in the text form
  // storage buffer must be provided externally

  if(!value) {
    Warning("GetParTextValue",
            "NULL pointer to a string given! \n");
    return kFALSE;
  }

  strncpy(value,fParValue.Data(),119);
  return kTRUE;
}

void TPhParKey::ls() 
{
  // Print the key

  Print();
  return;
}

void TPhParKey::Print() 
{
  // Print the key contents
  // in the: Source Name Type Value format
  // unless this is a definition or a comment
  
  if( HasName("DEFR") || HasName("DEFE") ) {
    PrintNoKey();
    return;
  }

  printf(" %s %15s %4d  %s \n", 
           fSource.Data(), fParName.Data(), fParValueType, fParValue.Data());
  return;
}

void TPhParKey::PrintNoKey() 
{
  // Print the key contents
  // in the: Source Name Type Value format
  // unless this is a definition or a comment
  Char_t tempname[120], tempvalue[120];    

  sscanf(fParValue.Data(),"%s %[ -~]", tempname, tempvalue);
  printf(" %s %15s (def) %s\n", 
           fSource.Data(), tempname, tempvalue);
  return;
}

