#include <iostream.h>
#include "TClass.h"
#include "TPhHit.h"
#include "TPhMCHit.h"
#include "TPhRecMCHit.h"
#include "TPhTrack.h"

ClassImp(TPhRecMCHit)

////////////////////////////////////////////////////////////////////////
//                                                                    //
//    TPhRecMCHit                                                     //
//                                                                    //
//    TPhRecMCHit is the PHOBOS hit class used to store "true"        //
//    MC hits (merged signals in neighbour pixels)                    // 
//    This class has some (but not all) functions of TPhRecHit        //
//                                                                    //
////////////////////////////////////////////////////////////////////////

TPhRecMCHit::TPhRecMCHit()
{
  // Default constructor

  fDist45 = 0.0;
  fNPads  = 0;
  fLabel  = 0;
}

TPhRecMCHit::TPhRecMCHit(TPhHit *rawhit)
{
  // Constructor copying information from an existing hit

  fSensorLabel = rawhit->GetSensorLabel();
  fLayer = rawhit->GetLayer();
  fLabel = rawhit->GetLabel();
  fX = rawhit->GetX();
  fY = rawhit->GetY();
  fZ = rawhit->GetZ();
  fPadX = rawhit->GetPadX();
  fPadY = rawhit->GetPadY();
  fDe = rawhit->GetDe();
  fDt = rawhit->GetDt();
  fField = rawhit->GetField();  

  fDist45 = 0.0;
  fNPads  = 0;
  fLabel  = 0;
}

TPhRecMCHit::TPhRecMCHit(TPhMCHit *mchit)
{
  // Constructor copying information from an existing hit

  fSensorLabel = mchit->GetSensorLabel();
  fLayer = mchit->GetLayer();
  fLabel = mchit->GetLabel();
  fX = mchit->GetX();
  fY = mchit->GetY();
  fZ = mchit->GetZ();
  fPadX = mchit->GetPadX();
  fPadY = mchit->GetPadY();
  fDe = mchit->GetDe();
  fDt = mchit->GetDt();
  fField = mchit->GetField();
  fDx = mchit->GetDx();
  fDy = mchit->GetDy();
  fDz = mchit->GetDz();
  fTrackNo = mchit->GetTrackNo();
  fPsi = mchit->CalcPsi();
  fLength = mchit->GetLength();

  fDist45 = 0.0;
  fNPads  = 0;
  fLabel  = 0;
}


Float_t TPhRecMCHit::CalcDist45()
{
  // Calculate distance from the hit to the 45 deg. line
  // Dist45 is equal 2*distance**2, but is negative for Z > abs(X)

  Float_t x, z;

  if(fDist45 != 0.0)  return  fDist45;

  x = GetX();
  z = GetZ();

  if(fabs(x) == fabs(z))  return 0.0;

  if(x > 0.0)
  {
     fDist45 = z-x;
     fDist45 *= fDist45;
     if(z > x)  fDist45 = -fDist45;
  }
  else
  {
     fDist45 = z+x;
     fDist45 *= fDist45;
     if(z > -x)  fDist45 = -fDist45;
  }
  return fDist45;
}


void TPhRecMCHit::Print(Option_t *option)
{
  // List the hit object info
  // Use "number" as an option to indicate how many sublevels should be listed

  printf("-------------------------------------------------------------------------------\n");
  printf("RecMCHit: merged %d pads\n", fNPads);
  TPhHit::Print(option);
}

void TPhRecMCHit::ls(Option_t *option)
{
  // List Object. option is still unused.

  TObject::IncreaseDirLevel();
  IndentLevel();
  cout << "Class:" << IsA()->GetName() << " is a merged MC hit in Sensor " 
       << GetSensorLabel() << " at " << GetX() << "," << GetY() 
       << "," << GetZ() << endl;
  TObject::DecreaseDirLevel();
}
