#include "TPhVertex.h"
#include "TPhTrack.h"

ClassImp(TPhVertex)

/////////////////////////////////////////////////////////////////////////
//
// TPhVertex provides the storage for the vertex in the Phobos 
// datastructure. The actual Vertex finding occurs in TPhEvent::FindVertex
//
// $Id: TPhVertex.cxx,v 1.2 1999/02/10 04:33:21 decowski Exp $
//
//////////////////////////////////////////////////////////////////////////

TPhVertex::TPhVertex()
{
// Default Constructor. Do not use.
// Use TPhVertex(Char_t *) instead.

  fStatus = kUnknownVtx;
  fDetId = 0;
  fVertexId = 0;
  fX = 0;
  fY = 0;
  fZ = -66666; // we default to close to the PHENIX vertex position ;->  
  fSigX = 0;
  fSigY = 0;
  fSigZ = 0;  
  fProb = 0;
  fParticleList = NULL;
}

TPhVertex::TPhVertex(Char_t *name, Char_t *title, EVtxStatus Status)
  : TPhDataObject(name,title)
{
// Constructor. Create vertex object and call TPhDataObject constructor
// with name argument
//
// The vertex status is passed in Status

  fStatus = Status;

  fDetId = 0;
  fVertexId = 0;
  fX = 0;
  fY = 0;
  fZ = -66666; // we default to close to the PHENIX vertex position ;->  
  fSigX = 0;
  fSigY = 0;
  fSigZ = 0;  
  fProb = 0;
  fParticleList = NULL;
}

TPhVertex::~TPhVertex()
{
// Destructor. 

  if(fParticleList)
    fParticleList->Clear();
  delete fParticleList;

}

void TPhVertex::AddParticle(TPhTrack *Track)
{
// Add a pointer to a TPhTrack object to the fTrackList
// array. For the first track, fTrackList is allocated 
// here.

  if(!fParticleList) {
    fParticleList = new TObjArray();
  }
  fParticleList->Add((TObject *) Track);
}

void TPhVertex::Print(Option_t * /* Option */)
{
  // Print some info about the vertex

  printf("Vertex %s: ", GetName());
  if(fStatus == kValidVtx)
    printf("Is Valid, at (%f, %f, %f)\n", GetX(), GetY(), GetZ());
  else if(fStatus == kStatSmallVtx)
    printf("Too little statistics to make a vertex!\n");
  else if(fStatus == kOutsideRangeVtx)
    printf("Outside of geometrical range!\n");
  else if(fStatus == kBadChi2Vtx) 
    printf("Vertex fit has very low Chi2!\n");
  else
    printf("Unknown status\n");

  // silliness
  if(fZ == -66666 && fStatus == kUnknownVtx) 
    printf("This vertex is at the PHENIX IP !\n");
}
