#ifndef _TPhBoxSiSensor_INCLUDED_
#define _TPhBoxSiSensor_INCLUDED_

/////////////////////////////////////////////////////////////////////////////
// 
//  TPhBoxSiSensor 
// 
// TPhBoxSiSensor is the base class for all Phobos BOX shaped Silicon sensors 
//
// Created 971219 by P. Decowski
//
// Changed 980414 mpd: All the boxed shaped Si sensors now inherit from this 
// class. TPhTOFSensor specifically does not inherit from this. 
//
// Changed: 15.07.98  A.Olszewski 
//                    Use rotation matrices to calculate sensor outer points,
//                    coordinates of pixel centers.
//
// $Id
// 
/////////////////////////////////////////////////////////////////////////////

// Root classes
#include "TBRIK.h"
#include "TRotMatrix.h"

// Phobos classes
#include "TPhSiSensor.h"

class TPhHit;

const Double_t kMrgFak        = 1.05;

class TPhBoxSiSensor : public TPhSiSensor {

public:

  TPhBoxSiSensor();
  TPhBoxSiSensor(const Char_t* Name, Int_t Label, Int_t Layer, 
                 Double_t X0, Double_t X1, Double_t Y0, Double_t Y1, 
                 Double_t Z0, Double_t Z1);

  virtual ~TPhBoxSiSensor();

//  virtual void       Paint(Option_t *option) { TNode::Paint(option); }
  virtual void       CalcAlpha();
  virtual TPhHit*    Pixelize(TPhHit *hit);
  virtual Int_t      MakeHitsOutOfHitArray(Char_t *HitArrayConName,
					   Char_t *HitConName);
  virtual Bool_t     MakeHitList(/* const */ Char_t *HitConName);
  virtual Bool_t     GetCoords(Int_t Row, Int_t Column, 
			       Double_t *X, Double_t *Y, Double_t *Z); 

  virtual void       Print();   // *MENU*

  virtual Double_t     GetX0()          { return fX0;         }
  virtual Double_t     GetX1()          { return fX1;         }
  virtual Double_t     GetY0()          { return fY0;         }
  virtual Double_t     GetY1()          { return fY1;         }
  virtual Double_t     GetZ0()          { return fZ0;         }
  virtual Double_t     GetZ1()          { return fZ1;         }

  virtual Float_t      GetDx()          { return fDx;         }
  virtual Float_t      GetDy()          { return fDy;         }
  virtual Float_t      GetDz()          { return fDz;         }
  
  virtual Double_t     GetAlpha()       { return fAlpha;      }

  virtual void       SetX0(Double_t x)        { fX0    = x;       }
  virtual void       SetX1(Double_t x)        { fX1    = x;       }
  virtual void       SetY0(Double_t x)        { fY0    = x;       }
  virtual void       SetY1(Double_t x)        { fY1    = x;       }
  virtual void       SetZ0(Double_t x)        { fZ0    = x;       }
  virtual void       SetZ1(Double_t x)        { fZ1    = x;       }
  virtual void       SetAlpha(Double_t x)     { fAlpha     = x;   }

  void SetDim(Float_t dx, Float_t dy, Float_t dz);
  void CalcBoxPoints();

protected:
  Double_t      fX0;            //  Sensor position X0
  Double_t      fX1;            //  Sensor position X1
  Double_t      fY0;            //  Sensor position Y0 
  Double_t      fY1;            //  Sensor position Y1
  Double_t      fZ0;            //  Sensor position Z0
  Double_t      fZ1;            //  Sensor position Z1
  Double_t      fAlpha;         //  (Normal) of the sensor angle with respect 
                                //  to beam axis (in rad)

  Float_t       fDx;            // Sensor half-length
  Float_t       fDy;            // Sensor half-length
  Float_t       fDz;            // Sensor half-length

public:
  ClassDef(TPhBoxSiSensor,1)      // Base class for BOX shaped sensors

};

#endif /* _TPhBoxSiSensor_INCLUDED_ */
