#ifndef __TPhChannelCalAbs__
#define __TPhChannelCalAbs__


///////////////////////////////////////////////////////////////////////////
//                                                                       //
//    TPhChannelCalAbs                                                   //
//                                                                       //
//    Phobos class to store calibration data for a single channel        //
//                                                                       //
//    TPhChannelCalAbs is an abstract class for classes storing          //
//    calibration information for a single channel.                      //
//                                                                       //
//    Author  : Andrzej Olszewski (andrzej.olszewski@ifj.edu.pl)         //
//    Created : 1/02/99                                                  //
//    Version : 1.0                                                      //
//    Changed :                                                          //
//                                                                       //
// $Id: TPhChannelCalAbs.h,v 1.1 1999/02/24 22:26:02 olszewsk Exp $
//                                                                       //
///////////////////////////////////////////////////////////////////////////

// ROOT classes
#include "TObject.h"
#include "TArrayF.h"

// Phat classes

class TPhChannelCalAbs : public TObject {

  friend class TPhStringCalAbs;

public:

  TPhChannelCalAbs();
  TPhChannelCalAbs(Int_t parno, Int_t parpointsno, Float_t boardlinearity,
		   Float_t *pars, Float_t *calpoints, 
		   Float_t *parerrors=NULL, Float_t *relerrors=NULL);
  virtual ~TPhChannelCalAbs();

  virtual Bool_t Calibrate(Float_t &ADC)=0;

  virtual void   ls(Option_t *option = "");
  virtual void   Print(Option_t *option = "");

  virtual void   SetVerbose(Int_t verbose)   { fVerbose = verbose;             }
  virtual Int_t  GetVerbose()                { return fVerbose;                }

  Float_t        GetCalLinearity()           { return fCalLinearity;           }
  Char_t         GetParNo()                  { return fParNo;                  } 
  Char_t         GetParPointsNo()            { return fParPointsNo;            }
  Float_t        GetPar(Int_t no)            { return fPars[no];               }
  Float_t        GetParError(Int_t no)       { return fParErrors[no];          }
  Float_t        GetCalPoint(Int_t no)       { return fCalPoints[no];          }
  Float_t        GetRelError(Int_t no)       { return fRelErrors[no];          }

protected:

  TArrayF       *GetPars()            { return &fPars;                         }
  TArrayF       *GetParErrors()       { return &fParErrors;                    }
  TArrayF       *GetCalPoints()       { return &fCalPoints;                    }
  TArrayF       *GetRelErrors()       { return &fRelErrors;                    }

  Float_t        fCalLinearity;       // Calibration board linearity
  Char_t         fParNo;              // Number of calibration method parameters
  Char_t         fParPointsNo;        // Number of calibration points
  TArrayF        fPars;               // Array of calibration parameters
  TArrayF        fParErrors;          // Errors of calibration parameters
  TArrayF        fCalPoints;          // ADC points where calibration was done
  TArrayF        fRelErrors;          // Relative errors
  Int_t          fVerbose;            //!Verbose flag

public:

  ClassDef(TPhChannelCalAbs,1)	// Calibrate ADC for each channel
};


#endif // __TPhChannelCalAbs__
