#ifndef __TPhFEC__
#define __TPhFEC__

//////////////////////////////////////////////////////////////////////////////
//                                                                          //
//    TPhFEC                                                                //
//                                                                          //
//    Phobos FEC class                                                      //
//                                                                          //
//    TPhFEC is a class storing information on properties of electronic     //
//    channels withing one FEC.                                             //
//    FEC is divided into strings of channels, that may come from different //
//    sensors. A string may come from from several chips, each of them      //
//    may be connected to a various number of pads.                         //
//                                                                          //
//    Author  : Andrzej Olszewski (andrzej.olszewski@ifj.edu.pl)            //
//    Created : 29/12/98                                                    //
//    Version : 1.0                                                         //
//    Changed :                                                             //
//                                                                          //
// $Id: TPhFEC.h,v 1.2 1999/03/05 11:30:05 olszewsk Exp $   
//                                                                          //
//////////////////////////////////////////////////////////////////////////////

// ROOT classes
#include "TNamed.h"
#include "TObjArray.h"

// Phat classes
#include "TPhRawHitFECn0.h"
#include "TPhString.h"

class TPhFEC : public TNamed {

public:

  TPhFEC();
  TPhFEC(Int_t FECNum, 
	 Int_t numstrings, Int_t *stringsizes, Int_t *chipnos, Int_t *chipsizes);
  virtual ~TPhFEC();

  UShort_t           GetFECNo()        { return fFECNo;      }
  UShort_t           GetNumStrings()   { return fNumStrings; }   
  TPhString         *GetString(Int_t i);  

  Bool_t             PedPreProcess(TPhRawHitFECn0 *fecevent);
  Bool_t             PedProcess(TPhRawHitFECn0 *fecevent);
  Bool_t             CMNProcess(TPhRawHitFECn0 *fecevent);
  Bool_t             NoiseProcess(TPhRawHitFECn0 *fecevent);
  Bool_t             ZeroSuppress(TPhRawHitFECn0 *fecevent);
  void               Calibrate(Bool_t &status);
  Bool_t             Calibrate(TPhAbsRawHitFEC *fecevent);
  Bool_t             CalibrateOnStrings(TPhAbsRawHitFEC *fecevent);

  void               MakeHitArrays(TPhHashContainer *HitArrayCont)
                           { fStrings->ForEach(TPhString,MakeHitArrays)(HitArrayCont);   }
  void               DeleteCalChannelArrays()
                           { fStrings->ForEach(TPhString,DeleteCalChannelArray)();       }
  void               DeleteCalStringObjects()
                           { fStrings->ForEach(TPhString,DeleteCalStringObject)();       }

  void               RemovePedArrays();
  void               RemoveCMNArrays();
  void               RemoveNoiseArrays();
  void               RemoveZZArrays();
  void               RemoveSuppArrays();

  void               SetDoHistograms(Bool_t onoff) 
                                 { fStrings->ForEach(TPhString,SetDoHistograms)(onoff);    }
  void               DeleteHistograms()
                                 { fStrings->ForEach(TPhString,DeleteHistograms)();        }

  //                 Setting/getting parameters for pedestal/noise string routines 
  void               SetMIN_NUM_PED_EVENTS(Int_t value) 
                            { fStrings->ForEach(TPhString,SetMIN_NUM_PED_EVENTS)(value);   }
  void 	             SetMIPADC_CUTOFF(Int_t value)             
                            { fStrings->ForEach(TPhString,SetMIPADC_CUTOFF)(value);        }
  void               SetMIN_CHANNELS_CMN_EST(Int_t value) 
                            { fStrings->ForEach(TPhString,SetMIN_CHANNELS_CMN_EST)(value); }
  void               SetMIN_NUM_NOISE_EVENTS(Int_t value) 
                            { fStrings->ForEach(TPhString,SetMIN_NUM_NOISE_EVENTS)(value); }
  void               SetTHRESH_CMN(Float_t value)  
                            { fStrings->ForEach(TPhString,SetTHRESH_CMN)(value);           }
  void               SetTHRESH_MULTIPLIER(Float_t value)  
                            { fStrings->ForEach(TPhString,SetTHRESH_MULTIPLIER)(value);    }

  void               ls(Option_t *option = "");
  void               Print(Option_t *option = "");

  Int_t              GetVerbose() const        { return fVerbose; }
  void               SetVerbose(Int_t verbose) { fVerbose = verbose; }
  void               SetVerboseDown(Int_t verbose) 
			    { fVerbose = verbose;
			      fStrings->ForEach(TPhString,SetVerboseDown)(verbose); }

protected:

  UShort_t      fFECNo;                        // FEC number
  UShort_t      fNumStrings;                   // No of strings in this FEC
  TObjArray    *fStrings;                      // List of string objects
  Int_t         fVerbose;                      //! verbose flag
public:

  ClassDef(TPhFEC,1)	// FEC and FEC channel's properties
};


#endif // __TPhFEC__
