#ifndef _PhGufldMagnet_INCLUDED_
#define _PhGufldMagnet_INCLUDED_

///////////////////////////////////////////////////////////////////////
//                                                                   //
//    TPhGufldMagnet                                                 //
//                                                                   //
//    PHOBOS Magnet information class via Gufld routine              //
//                                                                   //
//    TPhGufldMagnet define the interface for the PHOBOS Magnet      //
//    objects                                                        //
//                                                                   //
//    Author  : K.Wozniak, A.Olszewski                               //
//    Created : 25.03.97                                             //
//    Version : 2.0                                                  //
//    Changed : 26.09.1997                                                    //
//                                                                   //
///////////////////////////////////////////////////////////////////////

#include "TPhMagnet.h"

/***********************************************************************     */
/*Start_Verbatim                                                       *     */
/*                                                                     *     */
/*  Created:  02-MAR-1993   K. Wozniak                                 *     */
/*                                                                     *     */
/*                 Cylindrical magnetic field map                      *     */
/*                 ------------------------------                      *     */
/*                                                                     *     */
/*  NNRMAX   Parameter - maximal size of the map in radial direction   *     */
/*  NNVMAX   Parameter - maximal size of the map in vertical direction *     */
/*  NNR      actual size of the map in radial direction                *     */
/*  NNV      actual size of the map in vertical direction              *     */
/*  XTAB     radial (XTAB[0]..XTYAB[NNR-1]  and vertical (XTAB[NNR]..  *     */
/*           XTAB[NNR+NNV-1])  coordiantes of the grid points of the map*    */
/*  BRTAB    table of the radial compoments of the field               *     */
/*  BVTAB    table of the vertical components of the field             *     */
/*           Field value at the point  (XTAB(I), XTAB(NNR+K) is:       *     */
/*             (BRTAB(I+K*NNR), BVTAB(I+K*NNR))                        *     */
/*                                                                     *     */
/*                                                                     *     */
/*End_Verbatim                                                         *     */
/***********************************************************************     */
/*End_Documentation                                                          */

// 
// $Id: TPhGufldMagnet.h,v 1.2 1998/09/24 15:56:21 decowski Exp $
//

const Int_t NNRMAX = 200;
const Int_t NNVMAX = 150;

const Int_t MAXMAP = 520000;    /*   for  several maps  */
const Int_t MAXGRID = 400;
const Int_t NMAPMAX = 20;

class TPhGufldMagnet : public TPhMagnet {

public:

    TPhGufldMagnet();
//mpd Had to put in a dummy copy constructor, because the SunOS compiler seems to have
//mpd problems compiling it. 
    TPhGufldMagnet(class TPhGufldMagnet& magnet) { 
      Warning("TPhGufldMagnet copy constructor", 
	      "The copy constructor is not implemented!"); } 
    TPhGufldMagnet(Char_t *filename, Int_t *type, Double_t *bfldmax, 
         Double_t *zmagx, Double_t *zmagz, Double_t *zmoff, Double_t *zrfld, 
         Double_t *version); // Constructor with every possible Gufld parameter setting.

    virtual ~TPhGufldMagnet();

    Bool_t  InitFieldMap(Char_t *filename, Int_t *type, Double_t *bfldmax, 
                Double_t *zmagx, Double_t *zmagz, Double_t *zmoff, Double_t *zrfld, 
                Double_t *version);
    void    GetFieldParameters(Char_t *filename, Int_t *type, Double_t *bfldmax, 
                Double_t *zmagx, Double_t *zmagz, Double_t *zmoff, Double_t *zrfld, 
                Double_t *version);
    Bool_t  ReadFieldMap(Char_t *filename, Int_t *type, 
                Float_t *version);
    Bool_t  ReadFieldMap(Char_t *filename, Int_t *type, 
                Double_t *version);
    Bool_t  GetField(Float_t *vect, Float_t *b);
    Bool_t  GetField(Double_t *vect, Double_t *b);
    void    ls();


private:

    Int_t   keyword(Char_t *c, Char_t *k, Char_t *kk, Int_t n);
    Int_t   addnumber(Char_t *c, Int_t n);
    void     cyfld(Double_t r, Double_t v, Double_t *br, Double_t *bv);
    void     stoper(Char_t *funct, Char_t *mess, Int_t errnum);
    Bool_t   gufld(Double_t *vect, Double_t *b);
    Double_t fint(Int_t dim, Double_t *x, Int_t *na, Double_t *a, Double_t *b);
    Double_t fint(Int_t dim, Double_t *x, Int_t *na, Double_t *a, Double_t *b,
                  Int_t ig, Int_t im);

protected:

   Double_t bfld;          // Magnetic field strength                      
   Double_t magx,magz;     // Coordinates of field center
   Double_t moff[3];       // offset of the field                               
   Double_t rfld;          // Radius of field (perfect dipole only)             
   Int_t   magt;          // Field type: 0 = no field, 1 = dipole, 2,3 = ASCII map 
   Char_t FileName[100];    // General map file name                              
   Char_t MapFileName[100]; // Actual submap file name                              
   Double_t magv;   // Map version number                               


private:
   
    Int_t gufldinit;
    Int_t gufldread;
 
    Int_t nnr, nnv;

    Double_t xtab[NNRMAX+NNVMAX], brtab[NNRMAX*NNVMAX], bvtab[NNRMAX*NNVMAX];

/*   ---- ASCII (MTYP=2) MAP DECLARATIONS --------------                    */

    Int_t nmap;   //  number of submaps
    Int_t iphoind[NMAPMAX];  //  1 - map movable (PHOBOS magnet);
                              //  0 - fixed map (Beam magnet)
    Int_t impos[NMAPMAX];    //  position of data in bx, by, bz tables
    Int_t igpos[NMAPMAX];    //  position of data in grid table a
    Int_t nax[NMAPMAX];      //  number of grid values in  x
    Int_t nay[NMAPMAX];      //  number of grid values in  y
    Int_t naz[NMAPMAX];      //  number of grid values in  z
    Double_t bmax2[NMAPMAX];  //  maximal field at y=0 

    Double_t a[MAXGRID];
    Double_t bx[MAXMAP],by[MAXMAP],bz[MAXMAP];

/*  -------- End of ASCII map declarations -------------                      */

    Int_t isaou;

public:

    ClassDef(TPhGufldMagnet,1)     // PHOBOS magnetic field interface

};

#endif

