#ifndef _TPhRingSensor_
#define _TPhRingSensor_

/////////////////////////////////////////////////////////////////////////////
//                                                                         //
// TPhRingSensor                                                           //
//                                                                         //
// This class is the description of the Ring sensor elements.              //
//                                                                         //
// Created 971219 by P. Decowski                                           //
// Changed 980414 mpd: The inheritance structure of the sensors changed.   //
//                     TPhRingSensor now inherits from TPhSiSensor only.   //
// Changed 980501 A.O. Pixelization parameters introduced                  //
//                                                                         //
// $Id: TPhRingSensor.h,v 1.3 1998/05/02 18:05:16 olszewsk Exp $                                                                    //
//                                                                         //
/////////////////////////////////////////////////////////////////////////////

#include "TPhSiSensor.h"

class TPhRingSensor : public TPhSiSensor {

public:

  TPhRingSensor(); 
  virtual ~TPhRingSensor();

  virtual void Paint(Option_t *option) { TNode::Paint(option); }
  virtual void Draw(Option_t *option="");

  virtual void SetParameters(Float_t Rmin, Float_t Rmax, Float_t Dz, 
			     Float_t Phi1, Float_t Phi2);
  virtual void SetParameters(Float_t *pars);

  virtual void SetPadParameters(Float_t Dphi, Float_t R0, Float_t R1, Float_t R2, Float_t R3, 
                                  Float_t R4, Float_t R5, Float_t R6, Float_t R7, Float_t R8);
  virtual void SetPadParameters(Float_t *ppars);

protected:
  Float_t fRmin;        // inside radius
  Float_t fRmax;        // outside radius
  Float_t fDz;          // half length in z
  Float_t fPhi1;        // first phi limit
  Float_t fPhi2;        // second phi limit
  Float_t fDphi;        // pixel phi width
  Float_t fRs[9];       // pixel (9) boundaries in radial direction (8 ranges)
public:
  
  ClassDef(TPhRingSensor,1) // Ring Sensor class

};

#endif /*  _TPhRingSensor_ */
