#ifndef _TPhSiSensor_INCLUDED_
#define _TPhSiSensor_INCLUDED_

////////////////////////////////////////////////////////////////////////////
//                                                                        //
//  TPhSiSensor                                                           //
//                                                                        //
// TPhSiSensor is the base class of all Phobos Silicon sensors.           //
// It is meant to handle all the general silicon stuff.                   //
//                                                                        //
// Created 971219 by P. Decowski                                          //
//                                                                        //
// Changed 980414 mpd: changed the inheritance of TPhSiSensor. It is no   // 
// longer a Mixin class, but fully derives from TPhSensor.                //
//                                                                        //
// $Id: TPhSiSensor.h,v 1.10 1999/03/10 12:46:34 decowski Exp $                
//
//HitDisplay() method added for online monitoring purpose (J.Katzy may 98)//
//                                                                        //
////////////////////////////////////////////////////////////////////////////

// ROOT classes
#include "Rtypes.h"

// Phobos classes
#include "TPhSensor.h"

class TPhHitArray;
class TPhSensor;
class TCanvas;
class TPad;
class TPaveLabel;

// conversion from ADC to charge: ADC after calibration=0.01fC*6242e-/fC*3.62eV
// 990318 HP change precision in calibration to 0.01fC
const Float_t kChargeToEnergy = 0.00000022596;

class TPhSiSensor : public TPhSensor {

public:
  TPhSiSensor();
  virtual ~TPhSiSensor();

  virtual Int_t        MakeHitsOutOfHitArray(Char_t *HitArrayConName, 
					     Char_t *HitConName);
  virtual Int_t        MakeHitArraysOutOfHits(Char_t *HitConName, 
					      Char_t *HitArrayConName);

  virtual void         AddHitArray(TPhHitArray *HitArray) 
    { fHitArray = HitArray; }
  virtual void         ClearHitArray();

  virtual TPhHitArray* GetHitArray() { return fHitArray; }

  virtual Int_t        GetRows()                 { return fRows;       }
  virtual Int_t        GetColumns()              { return fColumns;    }
  virtual void         SetRows(Int_t num)      { fRows  = num;   }
  virtual void         SetColumns(Int_t num)   { fColumns  = num;   }

  virtual Double_t     GetPadWidthX()   { return fPadWidthX;   }
  virtual Double_t     GetPadWidthY()   { return fPadWidthY;  }
  virtual Double_t     GetPxlWidth()    { return fPadWidthX;   } //OBSOLETE
  virtual Double_t     GetPxlHeight()   { return fPadWidthY;  }  //OBSOLETE
  virtual Double_t     GetThickness()   { return fThickness; }

  virtual void         SetPxlWidth(Double_t x)  { fPadWidthX = x;   } //OBSOLETE
  virtual void         SetPxlHeight(Double_t x) { fPadWidthY = x;   } //OBSOLETE
  virtual void         SetThickness(Double_t x) { fThickness = x;   }
  void                 HitDisplay();

protected:
  Double_t      fPadWidthX;     //  Sensor padX width
  Double_t      fPadWidthY;     //  Sensor padY width
  Double_t      fThickness;     //  Si thickness  
  Int_t         fRows;          //  # of 'vertical' segments;
  Int_t         fColumns;       //  # of 'horizontal' segments;
  TPhHitArray *fHitArray;       //! The HitArray
 
public:
  ClassDef(TPhSiSensor,2) // Silicon Sensor base class

};

#endif /* _TPhSiSensor_INCLUDED_ */



