#ifndef _TPhSubDetector_
#define _TPhSubDetector_

/////////////////////////////////////////////////////////////////////////////
//                                                                         //
//    TPhSubDetector                                                       //
//                                                                         //
// The SubDetector class gives access to the various pieces of the Phobos  // 
// layers.                                                                 //
// The following SubDetectors are valid:                                   //
//                                                                         //
//         "RingMult"   Ring Multiplicity detectors                        //
//         "Octagon"    Octagon Mult detector detector                     //
//         "Vertex"     Vertex detector                                    //
//         "SpectP"     Positive Spectrometer arm                          //
//         "SpectN"     Negative Spectrometer arm                          //
//         "TOFP"       Positive Time of flight detector                   //
//         "TOFN"       Positive Time of flight detector                   //
//         "Trigger"    Trigger detector                                   //
//                                                                         //
//   Author  : Patrick Decowski                                            // 
//   Created :  21 Jan. 1998                                               //
//                                                                         //
// $Id: TPhSubDetector.h,v 1.8 1999/02/25 00:35:04 olszewsk Exp $
//                                                                         //
/////////////////////////////////////////////////////////////////////////////

// ROOT classes
#include "TNamed.h"
#include "TObjArray.h"
#include "THashTable.h"

// Phobos classes
class TPhLayer;
class TPhHit;
class TPhSensor;

class TPhSubDetector : public TNamed {

private:
  TObjArray   *fLayerList;    // List of all the Layers inside the subdetector
  THashTable  *fSensorList;    //! List of all the sensors (build dynamically)
  Float_t     fMaxSensorHeight;// Max Height of the sensor inside
  Bool_t      fTurnedOn;      //! flag to indicate if subdetector is ON or OFF

public:
  TPhSubDetector();
  TPhSubDetector(const Char_t *Name);
  virtual ~TPhSubDetector();

  TObjArray* GetLayerList() const { return fLayerList; }
  TPhLayer*  GetLayer(const Int_t i) const;
  TIterator* GetSensorIter(const Bool_t dir = kIterForward);

  Float_t    GetMaxSensorHeight() const { return fMaxSensorHeight; }

  void       AddLayer(TPhLayer *Layer);
  void       AddHit(TPhHit *Hit);
  void       AddSensor(TPhSensor *sensor); 

  Int_t      MakeHitArraysOutOfHits(Char_t *HitConName, 
				    Char_t *HitArrayConName);
  Int_t      MakeHitsOutOfHitArrays(Char_t *HitArrayConName,
				    Char_t *HitConName);

  void       BuildSensorList();
  Bool_t     IsThere(const Char_t *Name);
  
  void       Draw(Option_t *option = "");

  void       CalcMaxSensorHeight();
  void       Print() const;
  void       ls(Option_t *Option = "") const;

  void       DeleteHits();
  void       ClearHits();
  
  void       TurnOn();
  void       TurnOff();
  Bool_t     IsOn() const { return fTurnedOn; }

  ClassDef(TPhSubDetector,1)  // SubDetectors containing detector layers

};

#endif // _TPhSubDetector_
