#ifndef _TPhToscaMagnet_
#define _TPhToscaMagnet_

/////////////////////////////////////////////////////////////////////////
//
// TPhToscaMagnet
// 
// This is the class that provides access to the simulated magnetic 
// field. The way it works is that the field map is generated using a 
// tool like TOSCA 3D and then processed by this class. The TPhToscaMagnet
// object is then written out to a Root file. This class actually 
// encapsulates two field maps: 
// 1. a fine grid that takes care of the magnetic field inside the
// spectrometer.
// 2. a coarser grid that extends the grid to the outer parts of the
// magnet.
//
// Author: Patrick Decowski
//
// $Id: TPhToscaMagnet.h,v 1.3 1999/01/11 19:03:07 decowski Exp $
//
/////////////////////////////////////////////////////////////////////////

#include "TObject.h"
#include "TObjArray.h"
#include "TPhMagnet.h"

class TPhToscaMagnet : public TPhMagnet {

public:
  Char_t fVersion[30];         // version of the field map
  UInt_t fDate;                // date when the map was made

  Char_t fFNameFine[50];       // file name of the fine mesh grid
  Char_t fFNameCoarse[50];     // file name of the coarse mesh grid

  Float_t fDeltaFine[3];       // distance between grid points in fine mesh 
  Float_t fDeltaCoarse[3];     // distance between grid points in coarse mesh 

  Float_t fMinFine[3];         // minimum limits on fine grid
  Float_t fMaxFine[3];         // maximum limits on fine grid
  Float_t fMinCoarse[3];       // minimum limits on coarse grid
  Float_t fMaxCoarse[3];       // maximum limits on coarse grid

  Int_t fNPointsFine[3];       // number of grid points along X, Y, Z
  Int_t fNPointsCoarse[3];     // number of grid points along X, Y, Z

  Float_t *fGridNodesFine;     // defines the distance between gridnodes
  Float_t *fGridNodesCoarse;   // needed by Fint. 

  Float_t *fFineGrid[3];       // data points for the fine grid
  Int_t fFineNGridPoints;      // total number of gridpoints. 

  Float_t *fCoarseGrid[3];     // data points for the coarse grid
  Int_t fCoarseNGridPoints;    // number of gridpoints. 

  TObjArray *fPolyLine3D;      // Array of the PolyLines for 3D drawing.
			       // This object will not be streamed!

private:
  Int_t ReadGrid(const Char_t*, Float_t**, Float_t*, Float_t*, Float_t*);
  void Interpolate(Float_t*, Float_t*, Int_t*, Float_t*, Float_t**);
  Float_t Fint(Int_t, Float_t*, Int_t*, Float_t*, Float_t*);

public:
  
  TPhToscaMagnet();

  virtual ~TPhToscaMagnet();

  void MakeFieldMap(const Char_t*, const Char_t*, const Char_t*);

  Bool_t GetField(Float_t*, Float_t*);
  Bool_t GetField(Float_t, Float_t, Float_t, Float_t*, Float_t*, Float_t*);

  void Print(Float_t, Float_t, Float_t);
  void ls();

  void Draw3D(Float_t Lenght = 4, Float_t Normalization = 0.8, 
	      Float_t Rib = 8);
  void MakeVRML(Float_t Length = 4, Float_t Normalization = 0.8,
		Float_t Rib = 8);

  const Char_t* GetVersion()    { return fVersion; };
  const UInt_t  GetDate()       { return fDate; };

  const Char_t* GetFileNameFine()   { return fFNameFine; };
  const Char_t* GetFileNameCoarse() { return fFNameCoarse; };

  ClassDef(TPhToscaMagnet, 1) // Class containing the TOSCA magnet field

};

#endif /* end of class _TPhToscaMagnet_ */
