#include "math.h"

#include "TPhIdealMagnet.h"

ClassImp(TPhIdealMagnet)

//////////////////////////////////////////////////////////////////
//
// PHOBOS Toy Magnet class. Represents a field that only has a 
// verticla component of strength fFieldMax in a cylinder
// of radius fFieldRadius around fFieldCenter. 
// Access to the field is provided via the GetField() member 
// function. 
// The field  can be rescaled with SetFieldMax() and moved 
// with SetFieldOffset()
// All variables should  be in cm and Tesla (and GeV/c)
//
// $Id: TPhIdealMagnet.cxx,v 1.2 1999/03/12 07:25:57 decowski Exp $
//
/////////////////////////////////////////////////////////////////

TPhIdealMagnet::TPhIdealMagnet()
{
// Constructor
// Default constructor sets everything to some initial value

    fFieldMax    = 2;
    fFieldRadius2 = 45*45;
    fFieldCenter[0] = 48;
    fFieldCenter[1] = 0; 
    fFieldCenter[2] = 48;

}

TPhIdealMagnet::~TPhIdealMagnet()
{
// Default destructor. Does nothing in this case    

}
    
Bool_t TPhIdealMagnet::ReadFieldMap(Char_t *filename, 
				    Int_t *type, Float_t *version)
{
// dummy function to allow class be non-abstract
   
   printf("There is nothing to be initialized from a file %s" \
	  " in this class\n", filename);
   *type = 0;
   *version = 0;
   return kTRUE;
}

Bool_t  TPhIdealMagnet::GetField(Float_t *pos, Float_t *field)
{
// Check positions in pos[3] for validity and then 
// retrieve 3 field components from field map. 
// Parameters are x,y,z coordinates, field is bx,by,bz,
// as usual

// Return kTRUE if proper field value is returned in field[3], else
// return kFALSE

    Float_t r;
    Float_t dx,dz;

    dx = pos[0] - fFieldCenter[0] - fFieldOffset[0];
    dz = pos[2] - fFieldCenter[2] - fFieldOffset[2];

    r = dx*dx+dz*dz;
    if(r < fFieldRadius2)
    {
        field[0] = 0;
        field[1] = fFieldMax;
        field[2] = 0;
    }
    else
    {
        field[0] = 0;
        field[1] = 0;
        field[2] = 0;
    }

    return kTRUE;
}


