#include "math.h"

#include "TPhMagnet.h"

ClassImp(TPhMagnet)

/////////////////////////////////////////////////////////////////////
// PHOBOS Magnet class. Provides access to the magnetic 
// field map via the GetField() member function. 
// Field maps can be rescaled with SetFieldMax() 
// and an offset can be set to the field center to move it
// from the default location.
// In case of field maps calculated during the run 
// their center can be set with SetCenter().
// More complicated field map classes should inherit from
// TPhMagnet and provide same interface. All variables should 
// be in cm and Tesla (and GeV/c)
//
// $Id: TPhMagnet.cxx,v 1.2 1999/01/11 18:48:53 decowski Exp $
//
/////////////////////////////////////////////////////////////////////

TPhMagnet::TPhMagnet()
{
// Constructor
// Default constructor sets everything to 0.

    fFieldMax       = 0;
    fFieldType      = 0;
    fFieldVersion   = 0;
    fFieldCenter[0] = 0; 
    fFieldCenter[1] = 0; 
    fFieldCenter[2] = 0; 
    fFieldOffset[0] = 0; 
    fFieldOffset[1] = 0; 
    fFieldOffset[2] = 0; 
}

TPhMagnet::TPhMagnet(Int_t fFT, Float_t fFM, Float_t *fFO)
{
// Constructor that sets all the class data members.

    fFieldMax       = fFM;
    fFieldType      = fFT;
    fFieldVersion   = 0;
    fFieldCenter[0] = 0; 
    fFieldCenter[1] = 0; 
    fFieldCenter[2] = 0; 
    fFieldOffset[0] = fFO[0]; 
    fFieldOffset[1] = fFO[1]; 
    fFieldOffset[2] = fFO[2]; 
}

TPhMagnet::~TPhMagnet()
{
// Default destructor. Don't forget to release space
// for field map if it has been allocated. 

}

Bool_t TPhMagnet::GetField(Float_t */* x */, Float_t* /* field */)
{
  // Return the field value (3-vector) in field (in Tesla) for a 
  // given point x (in cm)
  AbstractMethod("GetField");

  return kFALSE;
}

Bool_t TPhMagnet::ReadFieldMap(Char_t* /* FileName */, Int_t* /* type */, 
			       Float_t* /* version */)
{
  // Read the field from some file. 
  // Note that this method might not be implemented, since the 
  // field might be stored in some *.root object DB file
  
  return kFALSE;
}

void TPhMagnet::GetFieldCenter(Float_t *x)
{
// Extract current location of the center of the magnetic field. 

   x[0] = fFieldCenter[0];
   x[1] = fFieldCenter[1];
   x[2] = fFieldCenter[2];
}

void TPhMagnet::SetFieldCenter(Float_t *x)
{
// Set the field map center when creating the field.

   fFieldCenter[0] = x[0];
   fFieldCenter[1] = x[1];
   fFieldCenter[2] = x[2];
}

void TPhMagnet::SetFieldOffset(Float_t *x)
{
// Set offset to the field map center away from default.

   fFieldOffset[0] = x[0];
   fFieldOffset[1] = x[1];
   fFieldOffset[2] = x[2];
}

void TPhMagnet::GetFieldOffset(Float_t *x)
{
// Extract current setting of the offset from the center 
// of magnetic field

   x[0] = fFieldOffset[0];
   x[1] = fFieldOffset[1];
   x[2] = fFieldOffset[2];
}


void TPhMagnet::ls()
{
  printf("\n --> TPhMagnet parameters: <--\n");
  printf("  fFieldVersion  = %f\n", fFieldVersion);
  printf("  fFieldType     = %d\n", fFieldType);
  printf("  fFieldMax      = %f\n", fFieldMax);
  printf("  fFieldCeter[]  = %f %f %f\n", fFieldCenter[0], fFieldCenter[1], fFieldCenter[2]);
  printf("  fFieldOffset[] = %f %f %f\n", fFieldOffset[0], fFieldOffset[1], fFieldOffset[2]);
  printf(" --> TPhMagnet parameters: <--\n");
}

