// Default display definitions for Phobos class TPhDispDef
// File: TPhDispDefV.h
// Date     Vers  Description
// 13-Feb-99 3.0  Remove duplicate MPC*-1 display (RV)
// $Id: TPhDispDefV.h,v 1.5 1999/02/13 23:19:49 verdier Exp $
//////////////////////////////////////////////////////////////

// 05-Feb-99 3.0  Change hr displays to .1 in Eta x pi/16 in phi (RV)
// 16-Dec-98 3.0  Use syntax {{...},{...},...} to avoid compiler warnings (RV)
// 28-Aug-98: Complete detectors, clean up, add \n (RV)
// 20-Jun-98: Add all vertex sensors (RV)
// 03-Jun-98: Add '-1' for 1-event displays; change declaration syntax (RV)
// 20-May-98: Correct type in MOG* (RV)
// 09-May-98: Group sensors into planes (RV)
// 11-Feb-98: Id field -> # events, rename *M for TPhPadMap::select (RV)
// 19-Jan-98: Make names unique (RV)
// 03-Nov-97: Creation using values from mulcontrol.nml (Robin Verdier)

static Float_t c225 = 0.92388; //! NO STREAMER
static Float_t s225 = 0.38268; //! NO STREAMER
static Float_t c45  = 0.70711; //! NO STREAMER

// The variables here are pseudorapidity eta and angle phi (degrees)
// The display name specifies which sensors are included, using the 
// wildcard syntax defined by TPhPadMap::Select.  By convention, displays
// ending in "-1" are cleared on every event, but the actual definition
// comes from the second field, formerly called the Id, which specifies 
// the number of events to be accumulated, with 0 for none, and -1 for all.
// The geometry definitions could be replaced by references to a small set 
// of displays.

static TPhSensGeo gMulDisplays[] =
{
 { "MNC*-1",   1,  2,  10, -5.4, 0.1,  8,   0.0, 45.00,  -504.8, 
    {0, 0, 0}, {{ c225,  s225, 0}, {-s225,  c225, 0}, {0, 0, 1}}, 0.1 },

 { "MNC0-1",   1,  2,  10, -5.4, 0.1,  8,   0.5,  5.50,  -504.8, 
    {0, 0, 0}, {{ c225,  s225, 0}, {-s225,  c225, 0}, {0, 0, 1}}, 0.1 },
 { "MNC1-1",   1,  2,  10, -5.4, 0.1,  8,  45.5,  5.50,  -504.8, 
    {0, 0, 0}, {{ s225,  c225, 0}, {-c225,  s225, 0}, {0, 0, 1}}, 0.1 },
 { "MNC2-1",   1,  2,  10, -5.4, 0.1,  8,  90.5,  5.50,  -504.8, 
    {0, 0, 0}, {{-s225,  c225, 0}, { c225,  s225, 0}, {0, 0, 1}}, 0.1 },
 { "MNC3-1",   1,  2,  10, -5.4, 0.1,  8, 135.5,  5.50,  -504.8, 
    {0, 0, 0}, {{-c225,  s225, 0}, { s225,  c225, 0}, {0, 0, 1}}, 0.1 },
 { "MNC4-1",   1,  2,  10, -5.4, 0.1,  8, 180.5,  5.50,  -504.8, 
    {0, 0, 0}, {{-c225, -s225, 0}, { s225, -c225, 0}, {0, 0, 1}}, 0.1 },
 { "MNC5-1",   1,  2,  10, -5.4, 0.1,  8, 225.5,  5.50,  -504.8, 
    {0, 0, 0}, {{-s225, -c225, 0}, { c225, -s225, 0}, {0, 0, 1}}, 0.1 },
 { "MNC6-1",   1,  2,  10, -5.4, 0.1,  8, 270.5,  5.50,  -504.8, 
    {0, 0, 0}, {{ s225, -c225, 0}, {-c225, -s225, 0}, {0, 0, 1}}, 0.1 },
 { "MNC7-1",   1,  2,  10, -5.4, 0.1,  8, 315.5,  5.50,  -504.8, 
    {0, 0, 0}, {{ c225, -s225, 0}, {-s225, -c225, 0}, {0, 0, 1}}, 0.1 },

 { "MNB*-1",   1,  2,  12, -4.7, 0.1,  8,   0.0, 45.00,  -234.9, 
    {0, 0, 0}, {{ c225,  s225, 0}, {-s225,  c225, 0}, {0, 0, 1}}, 0.1 },

 { "MNB0-1",   1, 2,  12, -4.7, 0.1,    8,  0.5,  5.50,  -234.9, 
    {0, 0, 0}, {{ c225,  s225, 0}, {-s225,  c225, 0}, {0, 0, 1}}, 0.1 },
 { "MNB1-1",   1, 2,  12, -4.7, 0.1,    8,  45.5, 5.50,  -234.9, 
    {0, 0, 0}, {{ s225,  c225, 0}, {-c225,  s225, 0}, {0, 0, 1}}, 0.1 },
 { "MNB2-1",   1, 2,  12, -4.7, 0.1,    8,  90.5, 5.50,  -234.9, 
    {0, 0, 0}, {{-s225,  c225, 0}, { c225,  s225, 0}, {0, 0, 1}}, 0.1 },
 { "MNB3-1",   1, 2,  12, -4.7, 0.1,    8, 135.5, 5.50,  -234.9, 
    {0, 0, 0}, {{-c225,  s225, 0}, { s225,  c225, 0}, {0, 0, 1}}, 0.1 },
 { "MNB4-1",   1, 2,  12, -4.7, 0.1,    8, 180.5, 5.50,  -234.9, 
    {0, 0, 0}, {{-c225, -s225, 0}, { s225, -c225, 0}, {0, 0, 1}}, 0.1 },
 { "MNB5-1",   1, 2,  12, -4.7, 0.1,    8, 225.5, 5.50,  -234.9, 
    {0, 0, 0}, {{-s225, -c225, 0}, { c225, -s225, 0}, {0, 0, 1}}, 0.1 },
 { "MNB6-1",   1, 2,  12, -4.7, 0.1,    8, 270.5, 5.50,  -234.9, 
    {0, 0, 0}, {{ s225, -c225, 0}, {-c225, -s225, 0}, {0, 0, 1}}, 0.1 },
 { "MNB7-1",   1, 2,  12, -4.7, 0.1,    8, 315.5, 5.50,  -234.9, 
    {0, 0, 0}, {{ c225, -s225, 0}, {-s225, -c225, 0}, {0, 0, 1}}, 0.1 },

 { "MNA*-1",   1, 2,  11, -3.9, 0.1,    8,   0.,  45.0,  -112.8, 
    {0, 0, 0}, {{ c225,  s225, 0}, {-s225,  c225, 0}, {0, 0, 1}}, 0.1 },

 { "MNA0-1",   1, 2,  11, -3.9, 0.1,    8,  0.5,  5.50,  -112.8, 
    {0, 0, 0}, {{ c225,  s225, 0}, {-s225,  c225, 0}, {0, 0, 1}}, 0.1 },
 { "MNA1-1",   1, 2,  11, -3.9, 0.1,    8,  45.5, 5.50,  -112.8, 
    {0, 0, 0}, {{ s225,  c225, 0}, {-c225,  s225, 0}, {0, 0, 1}}, 0.1 },
 { "MNA2-1",   1, 2,  11, -3.9, 0.1,    8,  90.5, 5.50,  -112.8, 
    {0, 0, 0}, {{-s225,  c225, 0}, { c225,  s225, 0}, {0, 0, 1}}, 0.1 },
 { "MNA3-1",   1, 2,  11, -3.9, 0.1,    8, 135.5, 5.50,  -112.8, 
    {0, 0, 0}, {{-c225,  s225, 0}, { s225,  c225, 0}, {0, 0, 1}}, 0.1 },
 { "MNA4-1",   1, 2,  11, -3.9, 0.1,    8, 180.5, 5.50,  -112.8, 
    {0, 0, 0}, {{-c225, -s225, 0}, { s225, -c225, 0}, {0, 0, 1}}, 0.1 },
 { "MNA5-1",   1, 2,  11, -3.9, 0.1,    8, 225.5, 5.50,  -112.8, 
    {0, 0, 0}, {{-s225, -c225, 0}, { c225, -s225, 0}, {0, 0, 1}}, 0.1 },
 { "MNA6-1",   1, 2,  11, -3.9, 0.1,    8, 270.5, 5.50,  -112.8, 
    {0, 0, 0}, {{ s225, -c225, 0}, {-c225, -s225, 0}, {0, 0, 1}}, 0.1 },
 { "MNA7-1",   1, 2,  11, -3.9, 0.1,    8, 315.5, 5.50,  -112.8, 
    {0, 0, 0}, {{ c225, -s225, 0}, {-s225, -c225, 0}, {0, 0, 1}}, 0.1 },

 { "MO*-1",  1,  1,  28,  -3.50,  0.25,   8,  -22.5,  45.0,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },

 { "MOA*-1",   1,  1,  18,  -3.60,  0.40,   2,  -21.9,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },

 { "MOA0-1",   1,  1,   8,  -3.50,  0.10,   2,  -21.9,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOA1-1",   1,  1,  13,  -3.40,  0.10,   2,  -21.9,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOA2-1",   1,  1,  18,  -3.25,  0.10,   2,  -21.9,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOA3-1",   1,  1,  27,  -3.10,  0.10,   2,  -21.9,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOA4-1",   1,  1,  39,  -2.90,  0.10,   2,  -21.9,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOA5-1",   1,  1,  46,  -2.70,  0.10,   2,  -21.9,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOA9-1",   1,  1,  27,   0.30,  0.10,   2,  -21.9,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOAA-1",   1,  1,  18,   1.50,  0.10,   2,  -21.9,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOAB-1",   1,  1,  13,   2.10,  0.10,   2,  -21.9,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOAC-1",   1,  1,   8,   2.70,  0.10,   2,  -21.9,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },

 { "MOB*-1",   1,  1,  18,  -3.60,  0.4,    2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, -c45, 0}, { c45, c45, 0}},  0.1 },

 { "MOB0-1",   1,  1,  10,  -3.24,  0.024,  2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, -c45, 0}, { c45, c45, 0}},  0.1 },
 { "MOB1-1",   1,  1,  10,  -3.09,  0.030,  2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, -c45, 0}, { c45, c45, 0}},  0.1 },
 { "MOB2-1",   1,  1,  10,  -2.90,  0.036,  2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, -c45, 0}, { c45, c45, 0}},  0.1 },
 { "MOB3-1",   1,  1,  10,  -2.68,  0.050,  2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, -c45, 0}, { c45, c45, 0}},  0.1 },
 { "MOB4-1",   1,  1,  10,  -2.39,  0.074,  2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, -c45, 0}, { c45, c45, 0}},  0.1 },
 { "MOB5-1",   1,  1,  10,  -2.00,  0.136,  2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, -c45, 0}, { c45, c45, 0}},  0.1 },
 { "MOB6-1",   1,  1,  10,  -1.30,  0.260,  2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, -c45, 0}, { c45, c45, 0}},  0.1 },
 { "MOB7-1",   1,  1,  10,   0.64,  0.136,  2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, -c45, 0}, { c45, c45, 0}},  0.1 },
 { "MOB8-1",   1,  1,  10,   1.65,  0.074,  2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, -c45, 0}, { c45, c45, 0}},  0.1 },
 { "MOB9-1",   1,  1,  10,   2.18,  0.050,  2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, -c45, 0}, { c45, c45, 0}},  0.1 },
 { "MOBA-1",   1,  1,  10,   2.54,  0.036,  2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, -c45, 0}, { c45, c45, 0}},  0.1 },
 { "MOBB-1",   1,  1,  10,   2.79,  0.030,  2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, -c45, 0}, { c45, c45, 0}},  0.1 },
 { "MOBC-1",   1,  1,  10,   3.00,  0.024,  2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, -c45, 0}, { c45, c45, 0}},  0.1 },

 { "MOC*-1",   1,  1,   18,  -3.60,  0.4,     2,  68.1, 21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },

 { "MOC0-1",   1,  1,   10,  -3.50,  0.075,   2,  68.1, 21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "MOC1-1",   1,  1,   10,  -3.40,  0.13,    2,  68.1, 21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "MOC2-1",   1,  1,   10,  -3.25,  0.18,    2,  68.1, 21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "MOC3-1",   1,  1,   10,  -3.10,  0.27,    2,  68.1, 21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "MOC4-1",   1,  1,   10,  -2.90,  0.40,    2,  68.1, 21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "MOC8-1",   1,  1,   10,  -1.10,  0.40,    2,  68.1, 21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "MOC9-1",   1,  1,   10,  +0.40,  0.27,    2,  68.1, 21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "MOCA-1",   1,  1,   10,   1.50,  0.18,    2,  68.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "MOCB-1",   1,  1,   10,   2.10,  0.13,    2,  68.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "MOCC-1",   1,  1,   10,   2.75,  0.075,   2,  68.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },

 { "MOD*-1",  -1,  1,   18,  -3.60,  0.4,     2, 113.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, c45, 0}, { -c45, c45, 0}},  0.1 },

 { "MOD0-1",   1,  1,   10,  -3.50,  0.075,   2, +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, c45, 0}, { -c45, c45, 0}},  0.1 },
 { "MOD1-1",   1,  1,   10,  -3.40,  0.13,    2, +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, c45, 0}, { -c45, c45, 0}},  0.1 },
 { "MOD2-1",   1,  1,   10,  -3.25,  0.18,    2, +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, c45, 0}, { -c45, c45, 0}},  0.1 },
 { "MOD3-1",   1,  1,   10,  -3.10,  0.27,    2, +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, c45, 0}, { -c45, c45, 0}},  0.1 },
 { "MOD4-1",   1,  1,   10,  -2.90,  0.40,    2, +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, c45, 0}, { -c45, c45, 0}},  0.1 },
 { "MOD5-1",   1,  1,   10,  -2.70,  0.46,    2, +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, c45, 0}, { -c45, c45, 0}},  0.1 },
 { "MOD6-1",   1,  1,   10,  -2.40,  0.48,    2, +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, c45, 0}, { -c45, c45, 0}},  0.1 },
 { "MOD7-1",   1,  1,   10,  -1.90,  0.46,    2, +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, c45, 0}, { -c45, c45, 0}},  0.1 },
 { "MOD8-1",   1,  1,   10,  -1.10,  0.40,    2, +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, c45, 0}, { -c45, c45, 0}},  0.1 },
 { "MOD9-1",   1,  1,   10,  +0.40,  0.27,    2, +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, c45, 0}, { -c45, c45, 0}},  0.1 },
 { "MODA-1",   1,  1,   10,   1.50,  0.18,    2, +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, c45, 0}, { -c45, c45, 0}},  0.1 },
 { "MODB-1",   1,  1,   10,   2.10,  0.13,    2, +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, c45, 0}, { -c45, c45, 0}},  0.1 },
 { "MODC-1",   1,  1,   10,   2.75,  0.075,   2, +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, c45, 0}, { -c45, c45, 0}},  0.1 },

 { "MOE*-1",   1,  1,   18,  -3.60,   0.4,    2, 158.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },

 { "MOE0-1",   1,  1,   10,  -3.50,  0.075,   2, 158.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOE1-1",   1,  1,   10,  -3.40,  0.13,    2, 158.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOE2-1",   1,  1,   10,  -3.25,  0.18,    2, 158.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOE3-1",   1,  1,   10,  -3.10,  0.27,    2, 158.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOE4-1",   1,  1,   10,  -2.90,  0.40,    2, 158.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOE5-1",   1,  1,   10,  -2.70,  0.46,    2, 158.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },

 { "MOE9-1",   1,  1,   10,  +0.40,  0.27,    2, 158.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOEA-1",   1,  1,   10,   1.50,  0.18,    2, 158.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOEB-1",   1,  1,   10,   2.10,  0.13,    2, 158.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOEC-1",   1,  1,   10,   2.75,  0.075,   2, 158.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },

 { "MOF*-1",   1,  1,   18,  -3.50,  0.4,     2, 203.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, c45, 0}, {-c45, -c45, 0}},  0.1 },

 { "MOF0-1",   1,  1,   10,  -3.50,  0.075,   2, 203.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, c45, 0}, {-c45, -c45, 0}},  0.1 },
 { "MOF1-1",   1,  1,   10,  -3.40,  0.13,    2, 203.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, c45, 0}, {-c45, -c45, 0}},  0.1 },
 { "MOF2-1",   1,  1,   10,  -3.25,  0.18,    2, 203.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, c45, 0}, {-c45, -c45, 0}},  0.1 },
 { "MOF3-1",   1,  1,   10,  -3.10,  0.27,    2, 203.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, c45, 0}, {-c45, -c45, 0}},  0.1 },
 { "MOF4-1",   1,  1,   10,  -2.90,  0.40,    2, 203.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, c45, 0}, {-c45, -c45, 0}},  0.1 },
 { "MOF5-1",   1,  1,   10,  -2.70,  0.46,    2, 203.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, c45, 0}, {-c45, -c45, 0}},  0.1 },
 { "MOF6-1",   1,  1,   10,  -2.40,  0.48,    2, 203.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, c45, 0}, {-c45, -c45, 0}},  0.1 },
 { "MOF7-1",   1,  1,   10,  -1.90,  0.46,    2, 203.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, c45, 0}, {-c45, -c45, 0}},  0.1 },
 { "MOF8-1",   1,  1,   10,  -1.10,  0.40,    2, 203.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, c45, 0}, {-c45, -c45, 0}},  0.1 },
 { "MOF9-1",   1,  1,   10,  +0.40,  0.27,    2, 203.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, c45, 0}, {-c45, -c45, 0}},  0.1 },
 { "MOFA-1",   1,  1,   10,   1.50,  0.18,    2, 203.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, c45, 0}, {-c45, -c45, 0}},  0.1 },
 { "MOFB-1",   1,  1,   10,   2.10,  0.13,    2, 203.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, c45, 0}, {-c45, -c45, 0}},  0.1 },
 { "MOFC-1",   1,  1,   10,   2.75,  0.075,   2, 203.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, c45, 0}, {-c45, -c45, 0}},  0.1 },

 { "MOG*-1",   1,  1,   18,  -3.60,  0.4,     2, 248.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, { 0, -1, 0}},  0.1 },

 { "MOG0-1",   1,  1,   10,  -3.50,  0.075,   2, 248.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, { 0, -1, 0}},  0.1 },
 { "MOG1-1",   1,  1,   10,  -3.40,  0.13,    2, 248.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, { 0, -1, 0}},  0.1 },
 { "MOG2-1",   1,  1,   10,  -3.25,  0.18,    2, 248.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, { 0, -1, 0}},  0.1 },
 { "MOG3-1",   1,  1,   10,  -3.10,  0.27,    2, 248.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, { 0, -1, 0}},  0.1 },
 { "MOG4-1",   1,  1,   10,  -2.90,  0.40,    2, 248.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, { 0, -1, 0}},  0.1 },
 { "MOG8-1",   1,  1,   10,  -1.10,  0.40,    2, 248.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, { 0, -1, 0}},  0.1 },
 { "MOG9-1",   1,  1,   10,  +0.40,  0.27,    2, 248.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, { 0, -1, 0}},  0.1 },
 { "MOGA-1",   1,  1,   10,   1.50,  0.18,    2, 248.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, { 0, -1, 0}},  0.1 },
 { "MOGB-1",   1,  1,   10,   2.10,  0.13,    2, 248.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, { 0, -1, 0}},  0.1 },
 { "MOGC-1",   1,  1,   10,   2.75,  0.075,   2, 248.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, { 0, -1, 0}},  0.1 },

 { "MOH*-1",   1,  1,   18,  -3.60,  0.4,     2, 293.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, -c45, 0}, { c45, -c45, 0}},  0.1 },

 { "MOH0-1",   1,  1,   10,  -3.50,  0.075,   2, 293.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, -c45, 0}, { c45, -c45, 0}},  0.1 },
 { "MOH1-1",   1,  1,   10,  -3.40,  0.13,    2, 293.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, -c45, 0}, { c45, -c45, 0}},  0.1 },
 { "MOH2-1",   1,  1,   10,  -3.25,  0.18,    2, 293.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, -c45, 0}, { c45, -c45, 0}},  0.1 },
 { "MOH3-1",   1,  1,   10,  -3.10,  0.27,    2, 293.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, -c45, 0}, { c45, -c45, 0}},  0.1 },
 { "MOH4-1",   1,  1,   10,  -2.90,  0.40,    2, 293.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, -c45, 0}, { c45, -c45, 0}},  0.1 },
 { "MOH5-1",   1,  1,   10,  -2.70,  0.46,    2, 293.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, -c45, 0}, { c45, -c45, 0}},  0.1 },
 { "MOH6-1",   1,  1,   10,  -2.40,  0.48,    2, 293.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, -c45, 0}, { c45, -c45, 0}},  0.1 },
 { "MOH7-1",   1,  1,   10,  -1.90,  0.46,    2, 293.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, -c45, 0}, { c45, -c45, 0}},  0.1 },
 { "MOH8-1",   1,  1,   10,  -1.10,  0.40,    2, 293.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, -c45, 0}, { c45, -c45, 0}},  0.1 },
 { "MOH9-1",   1,  1,   10,  +0.40,  0.27,    2, 293.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, -c45, 0}, { c45, -c45, 0}},  0.1 },
 { "MOHA-1",   1,  1,   10,   1.50,  0.18,    2, 293.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, -c45, 0}, { c45, -c45, 0}},  0.1 },
 { "MOHB-1",   1,  1,   10,   2.10,  0.13,    2, 293.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, -c45, 0}, { c45, -c45, 0}},  0.1 },
 { "MOHC-1",   1,  1,   10,   2.75,  0.075,   2, 293.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, -c45, 0}, { c45, -c45, 0}},  0.1 },

 { "MPA*-1", 1, 2,  10,  2.9, 0.1,    8,   0.0, 45.0,  +112.8, 
    {0, 0, 0}, {{ c225,  s225, 0}, {-s225,  c225, 0}, {0, 0, 1}}, 0.1 },

 { "MPA0-1", 1, 2,  10,  2.9, 0.1,    8,   0.5, 5.50,  +112.8, 
    {0, 0, 0}, {{ c225,  s225, 0}, {-s225,  c225, 0}, {0, 0, 1}}, 0.1 },
 { "MPA1-1", 1, 2,  10,  2.9, 0.1,    8,  45.5, 5.50,  +112.8, 
    {0, 0, 0}, {{ s225,  c225, 0}, {-c225,  s225, 0}, {0, 0, 1}}, 0.1 },
 { "MPA2-1", 1, 2,  10,  2.9, 0.1,    8,  90.5, 5.50,  +112.8, 
    {0, 0, 0}, {{-s225,  c225, 0}, { c225,  s225, 0}, {0, 0, 1}}, 0.1 },
 { "MPA3-1", 1, 2,  10,  2.9, 0.1,    8, 135.5, 5.50,  +112.8, 
    {0, 0, 0}, {{-c225,  s225, 0}, { s225,  c225, 0}, {0, 0, 1}}, 0.1 },
 { "MPA4-1", 1, 2,  10,  2.9, 0.1,    8, 180.5, 5.50,  +112.8, 
    {0, 0, 0}, {{-c225, -s225, 0}, { s225, -c225, 0}, {0, 0, 1}}, 0.1 },
 { "MPA5-1", 1, 2,  10,  2.9, 0.1,    8, 225.5, 5.50,  +112.8, 
    {0, 0, 0}, {{-s225, -c225, 0}, { c225, -s225, 0}, {0, 0, 1}}, 0.1 },
 { "MPA6-1", 1, 2,  10,  2.9, 0.1,    8, 270.5, 5.50,  +112.8, 
    {0, 0, 0}, {{ s225, -c225, 0}, {-c225, -s225, 0}, {0, 0, 1}}, 0.1 },
 { "MPA7-1", 1, 2,  10,  2.9, 0.1,    8, 315.5, 5.50,  +112.8, 
    {0, 0, 0}, {{ c225, -s225, 0}, {-s225, -c225, 0}, {0, 0, 1}}, 0.1 },

 { "MPB*-1", 1, 2,  10,  3.7, 0.1,    8,   0.0, 45.0,  +234.9, 
    {0, 0, 0}, {{ c225,  s225, 0}, {-s225,  c225, 0}, {0, 0, 1}}, 0.1 },

 { "MPB0-1", 1, 2,  10,  3.7, 0.1,    8,   0.5, 45.0,  +234.9, 
    {0, 0, 0}, {{ c225,  s225, 0}, {-s225,  c225, 0}, {0, 0, 1}}, 0.1 },
 { "MPB1-1", 1, 2,  10,  3.7, 0.1,    8,  45.5, 5.50,  +234.9, 
    {0, 0, 0}, {{ s225,  c225, 0}, {-c225,  s225, 0}, {0, 0, 1}}, 0.1 },
 { "MPB2-1", 1, 2,  10,  3.7, 0.1,    8,  90.5, 5.50,  +234.9, 
    {0, 0, 0}, {{-s225,  c225, 0}, { c225,  s225, 0}, {0, 0, 1}}, 0.1 },
 { "MPB3-1", 1, 2,  10,  3.7, 0.1,    8, 135.5, 5.50,  +234.9, 
    {0, 0, 0}, {{-c225,  s225, 0}, { s225,  c225, 0}, {0, 0, 1}}, 0.1 },
 { "MPB4-1", 1, 2,  10,  3.7, 0.1,    8, 180.5, 5.50,  +234.9, 
    {0, 0, 0}, {{-c225, -s225, 0}, { s225, -c225, 0}, {0, 0, 1}}, 0.1 },
 { "MPB5-1", 1, 2,  10,  3.7, 0.1,    8, 225.5, 5.50,  +234.9, 
    {0, 0, 0}, {{-s225, -c225, 0}, { c225, -s225, 0}, {0, 0, 1}}, 0.1 },
 { "MPB6-1", 1, 2,  10,  3.7, 0.1,    8, 270.5, 5.50,  +234.9, 
    {0, 0, 0}, {{ s225, -c225, 0}, {-c225, -s225, 0}, {0, 0, 1}}, 0.1 },
 { "MPB7-1", 1, 2,  10,  3.7, 0.1,    8, 315.5, 5.50,  +234.9, 
    {0, 0, 0}, {{ c225, -s225, 0}, {-s225, -c225, 0}, {0, 0, 1}}, 0.1 },

 { "MPC*-1", 1, 2,  10,  4.4, 0.1,    8,   0.0,  45.0,  +504.8, 
    {0, 0, 0}, {{ c225,  s225, 0}, {-s225,  c225, 0}, {0, 0, 1}}, 0.1 },

 { "MPC0-1", 1, 2,  10,  4.4, 0.1,    8,   0.5,  5.50,  +504.8, 
    {0, 0, 0}, {{ c225,  s225, 0}, {-s225,  c225, 0}, {0, 0, 1}}, 0.1 },
 { "MPC1-1", 1, 2,  10,  4.4, 0.1,    8,  45.5,  5.50,  +504.8, 
    {0, 0, 0}, {{ s225,  c225, 0}, {-c225,  s225, 0}, {0, 0, 1}}, 0.1 },
 { "MPC2-1", 1, 2,  10,  4.4, 0.1,    8,  90.5,  5.50,  +504.8, 
    {0, 0, 0}, {{-s225,  c225, 0}, { c225,  s225, 0}, {0, 0, 1}}, 0.1 },
 { "MPC3-1", 1, 2,  10,  4.4, 0.1,    8, 135.5,  5.50,  +504.8, 
    {0, 0, 0}, {{-c225,  s225, 0}, { s225,  c225, 0}, {0, 0, 1}}, 0.1 },
 { "MPC4-1", 1, 2,  10,  4.4, 0.1,    8, 180.5,  5.50,  +504.8, 
    {0, 0, 0}, {{-c225, -s225, 0}, { s225, -c225, 0}, {0, 0, 1}}, 0.1 },
 { "MPC5-1", 1, 2,  10,  4.4, 0.1,    8, 225.5,  5.50,  +504.8, 
    {0, 0, 0}, {{-s225, -c225, 0}, { c225, -s225, 0}, {0, 0, 1}}, 0.1 },
 { "MPC6-1", 1, 2,  10,  4.4, 0.1,    8, 270.5,  5.50,  +504.8, 
    {0, 0, 0}, {{ s225, -c225, 0}, {-c225, -s225, 0}, {0, 0, 1}}, 0.1 },
 { "MPC7-1", 1, 2,  10,  4.4, 0.1,    8, 315.5,  5.50,  +504.8, 
    {0, 0, 0}, {{ c225, -s225, 0}, {-s225, -c225, 0}, {0, 0, 1}}, 0.1 },

 { "V*-1",   1,  1,  10,  -2.0,  0.40,  2,  0.,  180.,  9., 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },

 { "VB*-1",  1, 1,  20, -2.5, 0.25,   4, 246.9, 11.55,  9., 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },

 { "VBA*-1", 1, 1,  10, -2.0, 0.4,    4, 246.9, 11.55,  5.64, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },

 { "VBA0-1", 1, 1,  10, -2.4, 0.4,    4, 246.9, 11.55,  5.64, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },
 { "VBA1-1", 1, 1,  11, -2.2, 0.4,    4, 246.9, 11.55,  5.64, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },
 { "VBA2-1", 1, 1,  11, -2.0, 0.4,    4, 246.9, 11.55,  5.64, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },
 { "VBA3-1", 1, 1,  10, -1.6, 0.4,    4, 246.9, 11.55,  5.64, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },

 { "VBB*-1", 1, 1,  10, -2.0, 0.4,    4, 247.9, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },

 { "VBB0-1", 1, 1,   7, -1.8, 0.4,    2, 247.9, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },
 { "VBB1-1", 1, 1,   8, -1.6, 0.4,    2, 247.9, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },
 { "VBB2-1", 1, 1,   8, -1.3, 0.4,    2, 247.9, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },
 { "VBB3-1", 1, 1,   7, -1.0, 0.4,    2, 247.9, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },
 { "VBB4-1", 1, 1,   7, -1.8, 0.4,    2, 270.8, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },
 { "VBB5-1", 1, 1,   8, -1.6, 0.4,    2, 270.8, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },
 { "VBB6-1", 1, 1,   8, -1.3, 0.4,    2, 270.8, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },
 { "VBB7-1", 1, 1,   7, -1.0, 0.4,    2, 270.8, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },

 { "VT*-1",  1, 1,  20, -2.5, 0.25,   4,  66.9, 11.55,  5.64, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },

 { "VTA*-1", 1, 1,  10, -2.0, 0.4,    4,  66.9, 11.55,  5.64, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },

 { "VTA0-1", 1, 1,  10, -2.4, 0.4,    4,  66.9, 11.55,  5.64, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "VTA1-1", 1, 1,  11, -2.2, 0.4,    4,  66.9, 11.55,  5.64, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "VTA2-1", 1, 1,  11, -2.0, 0.4,    4,  66.9, 11.55,  5.64, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "VTA3-1", 1, 1,  10, -1.6, 0.4,    4,  66.9, 11.55,  5.64, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },

 { "VTB*-1", 1, 1,  10, -2.0, 0.4,    4,  67.1, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },

 { "VTB0-1", 1, 1,   7, -1.8, 0.4,    2,  67.1, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "VTB1-1", 1, 1,   8, -1.6, 0.4,    2,  67.1, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "VTB2-1", 1, 1,   8, -1.3, 0.4,    2,  67.1, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "VTB3-1", 1, 1,   7, -1.0, 0.4,    2,  67.1, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "VTB4-1", 1, 1,   7, -1.8, 0.4,    2,  90.8, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "VTB5-1", 1, 1,   8, -1.6, 0.4,    2,  90.8, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "VTB6-1", 1, 1,   8, -1.3, 0.4,    2,  90.8, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "VTB7-1", 1, 1,   7, -1.0, 0.4,    2,  90.8, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },

 { "*-1",    1, 3,  48, -6.0, 0.25,   8,  0.,   45.0,   0.,
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },

 { "*+in-1", 1, 3,  48, -6.0, 0.25,   1,  0.,  360.0,   0.,
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },

 { "*+hr-1", 1, 3, 120, -6.0, 0.10,  32,   0.,  11.25,  0.,
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },

 { "MN*",   -1, 2,  14, -5.4, 0.2,    8,   0.,  45.0,  -504.8, 
    {0, 0, 0}, {{ c225,  s225, 0}, {-s225,  c225, 0}, {0, 0, 1}}, 0.1 },

 { "MNC*",  -1, 2,  10, -5.4, 0.1,    8,   0.,  45.0,  -504.8, 
    {0, 0, 0}, {{ c225,  s225, 0}, {-s225,  c225, 0}, {0, 0, 1}}, 0.1 },

 { "MNC0",  -1, 2,  10, -5.4, 0.1,    8,   0.5, 5.50,  -504.8, 
    {0, 0, 0}, {{ c225,  s225, 0}, {-s225,  c225, 0}, {0, 0, 1}}, 0.1 },
 { "MNC1",  -1, 2,  10, -5.4, 0.1,    8,  45.5, 5.50,  -504.8, 
    {0, 0, 0}, {{ s225,  c225, 0}, {-c225,  s225, 0}, {0, 0, 1}}, 0.1 },
 { "MNC2",  -1, 2,  10, -5.4, 0.1,    8,  90.5, 5.50,  -504.8, 
    {0, 0, 0}, {{-s225,  c225, 0}, { c225,  s225, 0}, {0, 0, 1}}, 0.1 },
 { "MNC3",  -1, 2,  10, -5.4, 0.1,    8, 135.5, 5.50,  -504.8, 
    {0, 0, 0}, {{-c225,  s225, 0}, { s225,  c225, 0}, {0, 0, 1}}, 0.1 },
 { "MNC4",  -1, 2,  10, -5.4, 0.1,    8, 180.5, 5.50,  -504.8, 
    {0, 0, 0}, {{-c225, -s225, 0}, { s225, -c225, 0}, {0, 0, 1}}, 0.1 },
 { "MNC5",  -1, 2,  10, -5.4, 0.1,    8, 225.5, 5.50,  -504.8, 
    {0, 0, 0}, {{-s225, -c225, 0}, { c225, -s225, 0}, {0, 0, 1}}, 0.1 },
 { "MNC6",  -1, 2,  10, -5.4, 0.1,    8, 270.5, 5.50,  -504.8, 
    {0, 0, 0}, {{ s225, -c225, 0}, {-c225, -s225, 0}, {0, 0, 1}}, 0.1 },
 { "MNC7",  -1, 2,  10, -5.4, 0.1,    8, 315.5, 5.50,  -504.8, 
    {0, 0, 0}, {{ c225, -s225, 0}, {-s225, -c225, 0}, {0, 0, 1}}, 0.1 },

 { "MNB*",  -1, 2,  12, -4.7, 0.1,    8,   0.,  45.0,  -234.9, 
    {0, 0, 0}, {{ c225,  s225, 0}, {-s225,  c225, 0}, {0, 0, 1}}, 0.1 },

 { "MNB0",  -1, 2,  12, -4.7, 0.1,    8,   0.5, 5.50,  -234.9, 
    {0, 0, 0}, {{ c225,  s225, 0}, {-s225,  c225, 0}, {0, 0, 1}}, 0.1 },
 { "MNB1",  -1, 2,  12, -4.7, 0.1,    8,  45.5, 5.50,  -234.9, 
    {0, 0, 0}, {{ s225,  c225, 0}, {-c225,  s225, 0}, {0, 0, 1}}, 0.1 },
 { "MNB2",  -1, 2,  12, -4.7, 0.1,    8,  90.5, 5.50,  -234.9, 
    {0, 0, 0}, {{-s225,  c225, 0}, { c225,  s225, 0}, {0, 0, 1}}, 0.1 },
 { "MNB3",  -1, 2,  12, -4.7, 0.1,    8, 135.5, 5.50,  -234.9, 
    {0, 0, 0}, {{-c225,  s225, 0}, { s225,  c225, 0}, {0, 0, 1}}, 0.1 },
 { "MNB4",  -1, 2,  12, -4.7, 0.1,    8, 180.5, 5.50,  -234.9, 
    {0, 0, 0}, {{-c225, -s225, 0}, { s225, -c225, 0}, {0, 0, 1}}, 0.1 },
 { "MNB5",  -1, 2,  12, -4.7, 0.1,    8, 225.5, 5.50,  -234.9, 
    {0, 0, 0}, {{-s225, -c225, 0}, { c225, -s225, 0}, {0, 0, 1}}, 0.1 },
 { "MNB6",  -1, 2,  12, -4.7, 0.1,    8, 270.5, 5.50,  -234.9, 
    {0, 0, 0}, {{ s225, -c225, 0}, {-c225, -s225, 0}, {0, 0, 1}}, 0.1 },
 { "MNB7",  -1, 2,  12, -4.7, 0.1,    8, 315.5, 5.50,  -234.9, 
    {0, 0, 0}, {{ c225, -s225, 0}, {-s225, -c225, 0}, {0, 0, 1}}, 0.1 },

 { "MNA*",  -1, 2,  11, -3.9, 0.1,    8,   0.,  45.0,  -112.8, 
    {0, 0, 0}, {{ c225,  s225, 0}, {-s225,  c225, 0}, {0, 0, 1}}, 0.1 },

 { "MNA0",  -1, 2,  11, -3.9, 0.1,    8,   0.5, 5.50,  -112.8, 
    {0, 0, 0}, {{ c225,  s225, 0}, {-s225,  c225, 0}, {0, 0, 1}}, 0.1 },
 { "MNA1",  -1, 2,  11, -3.9, 0.1,    8,  45.5, 5.50,  -112.8, 
    {0, 0, 0}, {{ s225,  c225, 0}, {-c225,  s225, 0}, {0, 0, 1}}, 0.1 },
 { "MNA2",  -1, 2,  11, -3.9, 0.1,    8,  90.5, 5.50,  -112.8, 
    {0, 0, 0}, {{-s225,  c225, 0}, { c225,  s225, 0}, {0, 0, 1}}, 0.1 },
 { "MNA3",  -1, 2,  11, -3.9, 0.1,    8, 135.5, 5.50,  -112.8, 
    {0, 0, 0}, {{-c225,  s225, 0}, { s225,  c225, 0}, {0, 0, 1}}, 0.1 },
 { "MNA4",  -1, 2,  11, -3.9, 0.1,    8, 180.5, 5.50,  -112.8, 
    {0, 0, 0}, {{-c225, -s225, 0}, { s225, -c225, 0}, {0, 0, 1}}, 0.1 },
 { "MNA5",  -1, 2,  11, -3.9, 0.1,    8, 225.5, 5.50,  -112.8, 
    {0, 0, 0}, {{-s225, -c225, 0}, { c225, -s225, 0}, {0, 0, 1}}, 0.1 },
 { "MNA6",  -1, 2,  11, -3.9, 0.1,    8, 270.5, 5.50,  -112.8, 
    {0, 0, 0}, {{ s225, -c225, 0}, {-c225, -s225, 0}, {0, 0, 1}}, 0.1 },
 { "MNA7",  -1, 2,  11, -3.9, 0.1,    8, 315.5, 5.50,  -112.8, 
    {0, 0, 0}, {{ c225, -s225, 0}, {-s225, -c225, 0}, {0, 0, 1}}, 0.1 },

 { "MO*",   -1,  1,   28,  -3.50,  0.25,    8, -22.5,  45.0,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },

 { "MOA*",  -1,  1,   28,  -3.50,  0.25,   2,  -21.9,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },

 { "MOA0",  -1,  1,   10,  -3.50,  0.075,  2,  -21.9,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOA1",  -1,  1,   10,  -3.40,  0.13,   2,  -21.9,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOA2",  -1,  1,   10,  -3.25,  0.18,   2,  -21.9,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOA3",  -1,  1,   10,  -3.10,  0.27,   2,  -21.9,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOA4",  -1,  1,   10,  -2.90,  0.40,   2,  -21.9,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOA5",  -1,  1,   10,  -2.70,  0.46,   2,  -21.9,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOA9",  -1,  1,   10,   0.40,  0.27,   2,  -21.9,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOAA",  -1,  1,   10,   1.50,  0.18,   2,  -21.9,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOAB",  -1,  1,   10,   2.10,  0.13,   2,  -21.9,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOAC",  -1,  1,   10,   2.75,  0.075,  2,  -21.9,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },

 { "MOB*",  -1,  1,   28,  -3.50,  0.25,   2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, -c45, 0}, { c45, c45, 0}},  0.1 },

 { "MOB0",  -1,  1,   10,  -3.50,  0.075,  2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, -c45, 0}, { c45, c45, 0}},  0.1 },
 { "MOB1",  -1,  1,   10,  -3.40,  0.13,   2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, -c45, 0}, { c45, c45, 0}},  0.1 },
 { "MOB2",  -1,  1,   10,  -3.25,  0.18,   2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, -c45, 0}, { c45, c45, 0}},  0.1 },
 { "MOB3",  -1,  1,   10,  -3.10,  0.27,   2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, -c45, 0}, { c45, c45, 0}},  0.1 },
 { "MOB4",  -1,  1,   10,  -2.90,  0.40,   2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, -c45, 0}, { c45, c45, 0}},  0.1 },
 { "MOB5",  -1,  1,   10,  -2.70,  0.46,   2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, -c45, 0}, { c45, c45, 0}},  0.1 },
 { "MOB6",  -1,  1,   10,  -2.40,  0.48,   2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, -c45, 0}, { c45, c45, 0}},  0.1 },
 { "MOB7",  -1,  1,   10,  -1.90,  0.46,   2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, -c45, 0}, { c45, c45, 0}},  0.1 },
 { "MOB8",  -1,  1,   10,  -1.10,  0.40,   2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, -c45, 0}, { c45, c45, 0}},  0.1 },
 { "MOB9",  -1,  1,   10,  +0.40,  0.27,   2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, -c45, 0}, { c45, c45, 0}},  0.1 },
 { "MOBA",  -1,  1,   10,   1.50,  0.18,   2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, -c45, 0}, { c45, c45, 0}},  0.1 },
 { "MOBB",  -1,  1,   10,   2.10,  0.13,   2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, -c45, 0}, { c45, c45, 0}},  0.1 },
 { "MOBC",  -1,  1,   10,   2.75,  0.075,  2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, -c45, 0}, { c45, c45, 0}},  0.1 },

 { "MOC*",  -1,  1,   28,  -3.50,  0.25,    2,  68.1, 21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },

 { "MOC0",  -1,  1,   10,  -3.50,  0.075,   2,  68.1, 21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "MOC1",  -1,  1,   10,  -3.40,  0.13,    2,  68.1, 21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "MOC2",  -1,  1,   10,  -3.25,  0.18,    2,  68.1, 21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "MOC3",  -1,  1,   10,  -3.10,  0.27,    2,  68.1, 21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "MOC4",  -1,  1,   10,  -2.90,  0.40,    2,  68.1, 21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "MOC8",  -1,  1,   10,  -1.10,  0.40,    2,  68.1, 21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "MOC9",  -1,  1,   10,  +0.40,  0.27,    2,  68.1, 21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "MOCA",  -1,  1,   10,   1.50,  0.18,   2,   68.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "MOCB",  -1,  1,   10,   2.10,  0.13,   2,   68.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "MOCC",  -1,  1,   10,   2.75,  0.075,  2,   68.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },

 { "MOD*",  -1,  1,   16,  -3.2,   0.4,    2,  113.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, c45, 0}, { -c45, c45, 0}},  0.1 },

 { "MOD0",  -1,  1,   10,  -3.50,  0.075,  2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, c45, 0}, { -c45, c45, 0}},  0.1 },
 { "MOD1",  -1,  1,   10,  -3.40,  0.13,   2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, c45, 0}, { -c45, c45, 0}},  0.1 },
 { "MOD2",  -1,  1,   10,  -3.25,  0.18,   2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, c45, 0}, { -c45, c45, 0}},  0.1 },
 { "MOD3",  -1,  1,   10,  -3.10,  0.27,   2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, c45, 0}, { -c45, c45, 0}},  0.1 },
 { "MOD4",  -1,  1,   10,  -2.90,  0.40,   2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, c45, 0}, { -c45, c45, 0}},  0.1 },
 { "MOD5",  -1,  1,   10,  -2.70,  0.46,   2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, c45, 0}, { -c45, c45, 0}},  0.1 },
 { "MOD6",  -1,  1,   10,  -2.40,  0.48,   2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, c45, 0}, { -c45, c45, 0}},  0.1 },
 { "MOD7",  -1,  1,   10,  -1.90,  0.46,   2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, c45, 0}, { -c45, c45, 0}},  0.1 },
 { "MOD8",  -1,  1,   10,  -1.10,  0.40,   2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, c45, 0}, { -c45, c45, 0}},  0.1 },
 { "MOD9",  -1,  1,   10,  +0.40,  0.27,   2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, c45, 0}, { -c45, c45, 0}},  0.1 },
 { "MODA",  -1,  1,   10,   1.50,  0.18,   2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, c45, 0}, { -c45, c45, 0}},  0.1 },
 { "MODB",  -1,  1,   10,   2.10,  0.13,   2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, c45, 0}, { -c45, c45, 0}},  0.1 },
 { "MODC",  -1,  1,   10,   2.75,  0.075,  2,  +23.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, { c45, c45, 0}, { -c45, c45, 0}},  0.1 },

 { "MOE*",  -1,  1,   16,  -3.2,   0.4,    2,  158.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },

 { "MOE0",  -1,  1,   10,  -3.50,  0.075,  2,  158.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOE1",  -1,  1,   10,  -3.40,  0.13,   2,  158.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOE2",  -1,  1,   10,  -3.25,  0.18,   2,  158.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOE3",  -1,  1,   10,  -3.10,  0.27,   2,  158.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOE4",  -1,  1,   10,  -2.90,  0.40,   2,  158.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOE5",  -1,  1,   10,  -2.70,  0.46,   2,  158.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },

 { "MOE9",  -1,  1,   10,  +0.40,  0.27,   2,  158.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOEA",  -1,  1,   10,   1.50,  0.18,   2,  158.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOEB",  -1,  1,   10,   2.10,  0.13,   2,  158.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },
 { "MOEC",  -1,  1,   10,   2.75,  0.075,  2,  158.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, { 0, 1, 0}, {-1, 0, 0}},  0.1 },

 { "MOF*",  -1,  1,   16,  -3.2,   0.4,    2,  203.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, c45, 0}, {-c45, -c45, 0}},  0.1 },

 { "MOF0",  -1,  1,   10,  -3.50,  0.075,  2,  203.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, c45, 0}, {-c45, -c45, 0}},  0.1 },
 { "MOF1",  -1,  1,   10,  -3.40,  0.13,   2,  203.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, c45, 0}, {-c45, -c45, 0}},  0.1 },
 { "MOF2",  -1,  1,   10,  -3.25,  0.18,   2,  203.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, c45, 0}, {-c45, -c45, 0}},  0.1 },
 { "MOF3",  -1,  1,   10,  -3.10,  0.27,   2,  203.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, c45, 0}, {-c45, -c45, 0}},  0.1 },
 { "MOF4",  -1,  1,   10,  -2.90,  0.40,   2,  203.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, c45, 0}, {-c45, -c45, 0}},  0.1 },
 { "MOF5",  -1,  1,   10,  -2.70,  0.46,   2,  203.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, c45, 0}, {-c45, -c45, 0}},  0.1 },
 { "MOF6",  -1,  1,   10,  -2.40,  0.48,   2,  203.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, c45, 0}, {-c45, -c45, 0}},  0.1 },
 { "MOF7",  -1,  1,   10,  -1.90,  0.46,   2,  203.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, c45, 0}, {-c45, -c45, 0}},  0.1 },
 { "MOF8",  -1,  1,   10,  -1.10,  0.40,   2,  203.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, c45, 0}, {-c45, -c45, 0}},  0.1 },
 { "MOF9",  -1,  1,   10,  +0.40,  0.27,   2,  203.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, c45, 0}, {-c45, -c45, 0}},  0.1 },
 { "MOFA",  -1,  1,   10,   1.50,  0.18,   2,  203.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, c45, 0}, {-c45, -c45, 0}},  0.1 },
 { "MOFB",  -1,  1,   10,   2.10,  0.13,   2,  203.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, c45, 0}, {-c45, -c45, 0}},  0.1 },
 { "MOFC",  -1,  1,   10,   2.75,  0.075,  2,  203.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, c45, 0}, {-c45, -c45, 0}},  0.1 },

 { "MOG*",  -1,  1,   16,  -3.2,   0.4,    2,  248.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, { 0, -1, 0}},  0.1 },

 { "MOG0",  -1,  1,   10,  -3.50,  0.075,  2,  248.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, { 0, -1, 0}},  0.1 },
 { "MOG1",  -1,  1,   10,  -3.40,  0.13,   2,  248.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, { 0, -1, 0}},  0.1 },
 { "MOG2",  -1,  1,   10,  -3.25,  0.18,   2,  248.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, { 0, -1, 0}},  0.1 },
 { "MOG3",  -1,  1,   10,  -3.10,  0.27,   2,  248.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, { 0, -1, 0}},  0.1 },
 { "MOG4",  -1,  1,   10,  -2.90,  0.40,   2,  248.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, { 0, -1, 0}},  0.1 },
 { "MOG8",  -1,  1,   10,  -1.10,  0.40,   2,  248.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, { 0, -1, 0}},  0.1 },
 { "MOG9",  -1,  1,   10,  +0.40,  0.27,   2,  248.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, { 0, -1, 0}},  0.1 },
 { "MOGA",  -1,  1,   10,   1.50,  0.18,   2,  248.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, { 0, -1, 0}},  0.1 },
 { "MOGB",  -1,  1,   10,   2.10,  0.13,   2,  248.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, { 0, -1, 0}},  0.1 },
 { "MOGC",  -1,  1,   10,   2.75,  0.075,  2,  248.1,  21.9,  4.50, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, { 0, -1, 0}},  0.1 },

 { "MOH*",  -1,  1,   16,  -3.2,   0.4,    2,  293.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, -c45, 0}, { c45, -c45, 0}},  0.1 },

 { "MOH0",  -1,  1,   10,  -3.50,  0.075,  2,  293.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, -c45, 0}, { c45, -c45, 0}},  0.1 },
 { "MOH1",  -1,  1,   10,  -3.40,  0.13,   2,  293.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, -c45, 0}, { c45, -c45, 0}},  0.1 },
 { "MOH2",  -1,  1,   10,  -3.25,  0.18,   2,  293.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, -c45, 0}, { c45, -c45, 0}},  0.1 },
 { "MOH3",  -1,  1,   10,  -3.10,  0.27,   2,  293.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, -c45, 0}, { c45, -c45, 0}},  0.1 },
 { "MOH4",  -1,  1,   10,  -2.90,  0.40,   2,  293.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, -c45, 0}, { c45, -c45, 0}},  0.1 },
 { "MOH5",  -1,  1,   10,  -2.70,  0.46,   2,  293.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, -c45, 0}, { c45, -c45, 0}},  0.1 },
 { "MOH6",  -1,  1,   10,  -2.40,  0.48,   2,  293.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, -c45, 0}, { c45, -c45, 0}},  0.1 },
 { "MOH7",  -1,  1,   10,  -1.90,  0.46,   2,  293.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, -c45, 0}, { c45, -c45, 0}},  0.1 },
 { "MOH8",  -1,  1,   10,  -1.10,  0.40,   2,  293.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, -c45, 0}, { c45, -c45, 0}},  0.1 },
 { "MOH9",  -1,  1,   10,  +0.40,  0.27,   2,  293.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, -c45, 0}, { c45, -c45, 0}},  0.1 },
 { "MOHA",  -1,  1,   10,   1.50,  0.18,   2,  293.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, -c45, 0}, { c45, -c45, 0}},  0.1 },
 { "MOHB",  -1,  1,   10,   2.10,  0.13,   2,  293.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, -c45, 0}, { c45, -c45, 0}},  0.1 },
 { "MOHC",  -1,  1,   10,   2.75,  0.075,  2,  293.1,  21.9,  4.40, 
    {0, 0, 0}, {{ 0, 0, 1}, {-c45, -c45, 0}, { c45, -c45, 0}},  0.1 },

 { "MP*",   -1, 2,  14,  2.6, 0.2,    8,   0.,  45.0,  +112.8, 
    {0, 0, 0}, {{ c225,  s225, 0}, {-s225,  c225, 0}, {0, 0, 1}}, 0.1 },

 { "MPA*",  -1, 2,  10,  2.9, 0.1,    8,   0.,  45.0,  +112.8, 
    {0, 0, 0}, {{ c225,  s225, 0}, {-s225,  c225, 0}, {0, 0, 1}}, 0.1 },

 { "MPA0",  -1, 2,  10,  2.9, 0.1,    8,   0.5, 5.50,  +112.8, 
    {0, 0, 0}, {{ c225,  s225, 0}, {-s225,  c225, 0}, {0, 0, 1}}, 0.1 },
 { "MPA1",  -1, 2,  10,  2.9, 0.1,    8,  45.5, 5.50,  +112.8, 
    {0, 0, 0}, {{ s225,  c225, 0}, {-c225,  s225, 0}, {0, 0, 1}}, 0.1 },
 { "MPA2",  -1, 2,  10,  2.9, 0.1,    8,  90.5, 5.50,  +112.8, 
    {0, 0, 0}, {{-s225,  c225, 0}, { c225,  s225, 0}, {0, 0, 1}}, 0.1 },
 { "MPA3",  -1, 2,  10,  2.9, 0.1,    8, 135.5, 5.50,  +112.8, 
    {0, 0, 0}, {{-c225,  s225, 0}, { s225,  c225, 0}, {0, 0, 1}}, 0.1 },
 { "MPA4",  -1, 2,  10,  2.9, 0.1,    8, 180.5, 5.50,  +112.8, 
    {0, 0, 0}, {{-c225, -s225, 0}, { s225, -c225, 0}, {0, 0, 1}}, 0.1 },
 { "MPA5",  -1, 2,  10,  2.9, 0.1,    8, 225.5, 5.50,  +112.8, 
    {0, 0, 0}, {{-s225, -c225, 0}, { c225, -s225, 0}, {0, 0, 1}}, 0.1 },
 { "MPA6",  -1, 2,  10,  2.9, 0.1,    8, 270.5, 5.50,  +112.8, 
    {0, 0, 0}, {{ s225, -c225, 0}, {-c225, -s225, 0}, {0, 0, 1}}, 0.1 },
 { "MPA7",  -1, 2,  10,  2.9, 0.1,    8, 315.5, 5.50,  +112.8, 
    {0, 0, 0}, {{ c225, -s225, 0}, {-s225, -c225, 0}, {0, 0, 1}}, 0.1 },

 { "MPB*",  -1, 2,  10,  3.7, 0.1,    8,   0.0,  45.0,  +234.9, 
    {0, 0, 0}, {{ c225,  s225, 0}, {-s225,  c225, 0}, {0, 0, 1}}, 0.1 },

 { "MPB0",  -1, 2,  10,  3.7, 0.1,    8,   0.5, 5.50,  +234.9, 
    {0, 0, 0}, {{ c225,  s225, 0}, {-s225,  c225, 0}, {0, 0, 1}}, 0.1 },
 { "MPB1",  -1, 2,  10,  3.7, 0.1,    8,  45.5, 5.50,  +234.9, 
    {0, 0, 0}, {{ s225,  c225, 0}, {-c225,  s225, 0}, {0, 0, 1}}, 0.1 },
 { "MPB2",  -1, 2,  10,  3.7, 0.1,    8,  90.5, 5.50,  +234.9, 
    {0, 0, 0}, {{-s225,  c225, 0}, { c225,  s225, 0}, {0, 0, 1}}, 0.1 },
 { "MPB3",  -1, 2,  10,  3.7, 0.1,    8, 135.5, 5.50,  +234.9, 
    {0, 0, 0}, {{-c225,  s225, 0}, { s225,  c225, 0}, {0, 0, 1}}, 0.1 },
 { "MPB4",  -1, 2,  10,  3.7, 0.1,    8, 180.5, 5.50,  +234.9, 
    {0, 0, 0}, {{-c225, -s225, 0}, { s225, -c225, 0}, {0, 0, 1}}, 0.1 },
 { "MPB5",  -1, 2,  10,  3.7, 0.1,    8, 225.5, 5.50,  +234.9, 
    {0, 0, 0}, {{-s225, -c225, 0}, { c225, -s225, 0}, {0, 0, 1}}, 0.1 },
 { "MPB6",  -1, 2,  10,  3.7, 0.1,    8, 270.5, 5.50,  +234.9, 
    {0, 0, 0}, {{ s225, -c225, 0}, {-c225, -s225, 0}, {0, 0, 1}}, 0.1 },
 { "MPB7",  -1, 2,  10,  3.7, 0.1,    8, 315.5, 5.50,  +234.9, 
    {0, 0, 0}, {{ c225, -s225, 0}, {-s225, -c225, 0}, {0, 0, 1}}, 0.1 },

 { "MPC*",  -1, 2,  10,  4.4, 0.1,    8,   0.0,  45.0,  +504.8, 
    {0, 0, 0}, {{ c225,  s225, 0}, {-s225,  c225, 0}, {0, 0, 1}}, 0.1 },

 { "MPC0",  -1, 2,  10,  4.4, 0.1,    8,   0.5,  5.50,  +504.8, 
    {0, 0, 0}, {{ c225,  s225, 0}, {-s225,  c225, 0}, {0, 0, 1}}, 0.1 },
 { "MPC1",  -1, 2,  10,  4.4, 0.1,    8,  45.5,  5.50,  +504.8, 
    {0, 0, 0}, {{ s225,  c225, 0}, {-c225,  s225, 0}, {0, 0, 1}}, 0.1 },
 { "MPC2",  -1, 2,  10,  4.4, 0.1,    8,  90.5,  5.50,  +504.8, 
    {0, 0, 0}, {{-s225,  c225, 0}, { c225,  s225, 0}, {0, 0, 1}}, 0.1 },
 { "MPC3",  -1, 2,  10,  4.4, 0.1,    8, 135.5,  5.50,  +504.8, 
    {0, 0, 0}, {{-c225,  s225, 0}, { s225,  c225, 0}, {0, 0, 1}}, 0.1 },
 { "MPC4",  -1, 2,  10,  4.4, 0.1,    8, 180.5,  5.50,  +504.8, 
    {0, 0, 0}, {{-c225, -s225, 0}, { s225, -c225, 0}, {0, 0, 1}}, 0.1 },
 { "MPC5",  -1, 2,  10,  4.4, 0.1,    8, 225.5,  5.50,  +504.8, 
    {0, 0, 0}, {{-s225, -c225, 0}, { c225, -s225, 0}, {0, 0, 1}}, 0.1 },
 { "MPC6",  -1, 2,  10,  4.4, 0.1,    8, 270.5,  5.50,  +504.8, 
    {0, 0, 0}, {{ s225, -c225, 0}, {-c225, -s225, 0}, {0, 0, 1}}, 0.1 },
 { "MPC7",  -1, 2,  10,  4.4, 0.1,    8, 315.5,  5.50,  +504.8, 
    {0, 0, 0}, {{ c225, -s225, 0}, {-s225, -c225, 0}, {0, 0, 1}}, 0.1 },

 { "V*",    -1, 1,  10, -2.0, 0.4,    2,   0.,   180.,  9., 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },

 { "VB*",   -1, 1,  20, -2.5, 0.25,   4, 246.9, 11.55,  9., 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },

 { "VBA*",  -1, 1,  20, -2.5, 0.25,   4, 246.9, 11.55,  5.64, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },

 { "VBA0",  -1, 1,  10, -2.4, 0.4,    4, 246.9, 11.55,  5.64, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },
 { "VBA1",  -1, 1,  11, -2.2, 0.4,    4, 246.9, 11.55,  5.64, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },
 { "VBA2",  -1, 1,  11, -2.0, 0.4,    4, 246.9, 11.55,  5.64, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },
 { "VBA3",  -1, 1,  10, -1.6, 0.4,    4, 246.9, 11.55,  5.64, 
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },

 { "VBB*",  -1, 1,  16, -2.0, 0.25,   4, 247.9, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },

 { "VBB0",  -1, 1,   7, -1.8, 0.4,    2, 247.9, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },
 { "VBB1",  -1, 1,   8, -1.6, 0.4,    2, 247.9, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },
 { "VBB2",  -1, 1,   8, -1.3, 0.4,    2, 247.9, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },
 { "VBB3",  -1, 1,   7, -1.0, 0.4,    2, 247.9, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },
 { "VBB4",  -1, 1,   7, -1.8, 0.4,    2, 270.8, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },
 { "VBB5",  -1, 1,   8, -1.6, 0.4,    2, 270.8, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },
 { "VBB6",  -1, 1,   8, -1.3, 0.4,    2, 270.8, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },
 { "VBB7",  -1, 1,   7, -1.0, 0.4,    2, 270.8, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, {-1, 0, 0}, {0, -1, 0}},  0.1 },

 { "VT*",   -1, 1,  20, -2.5, 0.25,   4,  66.9, 11.55,  5.64, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },

 { "VTA*",  -1, 1,  20, -2.5, 0.25,   4,  66.9, 11.55,  5.64, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },

 { "VTA0",  -1, 1,  10, -2.4, 0.4,    4,  66.9, 11.55,  5.64, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "VTA1",  -1, 1,  11, -2.2, 0.4,    4,  66.9, 11.55,  5.64, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "VTA2",  -1, 1,  11, -2.0, 0.4,    4,  66.9, 11.55,  5.64, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "VTA3",  -1, 1,  10, -1.6, 0.4,    4,  66.9, 11.55,  5.64, 
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },

 { "VTB*",  -1, 1,  10, -2.0, 0.4,    4,  67.1, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },

 { "VTB0",  -1, 1,   7, -1.8, 0.4,    2,  67.1, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "VTB1",  -1, 1,   8, -1.6, 0.4,    2,  67.1, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "VTB2",  -1, 1,   8, -1.3, 0.4,    2,  67.1, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "VTB3",  -1, 1,   7, -1.0, 0.4,    2,  67.1, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "VTB4",  -1, 1,   7, -1.8, 0.4,    2,  90.8, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "VTB5",  -1, 1,   8, -1.6, 0.4,    2,  90.8, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "VTB6",  -1, 1,   8, -1.3, 0.4,    2,  90.8, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },
 { "VTB7",  -1, 1,   7, -1.0, 0.4,    2,  90.8, 11.04, 11.78,
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },

 { "*",     -1, 3,  48, -6.0, 0.25,   8,  0.,   45.0,   0.,
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },

 { "*+in",  -1, 3,  48, -6.0, 0.25,   1,  0.,  360.0,   0.,
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 },

 { "*+hr",  -1, 3, 120, -6.0, 0.10,  32,   0.,  11.25,  0.,
    {0, 0, 0}, {{ 0, 0, 1}, { 1, 0, 0}, { 0, 1, 0}},  0.1 }
};
