#ifndef _TPhOpts_INCLUDED_
#define _TPhOpts_INCLUDED_

////////////////////////////////////////////////////////////////////////
// TPhOpts is a Phobos class that provides access to ASCII files 
// containing embedded numerical fields specifying analysis options.
//
// File: TPhOpts.h
//
// Date     Vers  Description
// 04-Jun-98 1.0  Update comments (RV)
////////////////////////////////////////////////////////////////////////
// 28-Apr-98 0.2  Add GetField, GetLine, GetFloat, GetText, ... (RV)
// 28-Mar-98 0.1  Creation (Robin Verdier)

// Enumerated indices and flag bits for text and numeric variables

enum { eText = 0, eNumb = 1 }; // Indices for fFields[] and others
enum { eTextBit = 1, eNumbBit = 2 }; // Flag bits in search target and status

// PHOBOS Classes

class TObject;

class TPhOpts : public TObject 
{
public:
  TPhOpts                        // Constructor arguments:
  ( const Char_t *inFile,        // Name of input options file
    const Char_t *outFile = "",  // Name of output file, "" if none
    const Int_t   repLev = 1,    // Report level, 0=none, 1=only fatal, ...
    const Int_t   maxChars = 96  // Maximum line length
  );
  TPhOpts();                     // For delayed opens
  ~TPhOpts();                    // Destructor
  Float_t ConvFloat();           // Return current field converted to float
  Char_t *CurrField(Int_t type); // Pointer to current field of type specified
                                 // by bits in arg
  Int_t   Find(Int_t target);    // Find next fields in inFile of types 
                                 // specified by bits in target;
                                 // return fStatus for result of search
  Int_t   GetField               // Get a field, return index of found key
         (Char_t * const keys[], // List of search keys
          Int_t nKeys,           // Number of search keys to use
          Char_t *& chars,       // REFERENCE to char array to search
          const Char_t *charLim);// Pointer to last character + 1
/*
  Int_t   GetFloat               // Find next decimal number and return fStatus
           (Int_t   nStartDec,    // # keys in startDec
            Char_t *startDec[],   // Keys for start of decimal number field
            Int_t   nEndDec,      // # keys in endDec
            Char_t *endDec[],     // Keys for end of decimal number field
            Int_t   nLines        // # of lines to search, 0 = all
           );
*/
  Int_t   GetLine();               // Get next line and return fStatus
  Int_t   GetNum();                // Get numeric field, return found key index
  Int_t   GetStatus()
          { return fStatus; }
  Int_t   GetText                  // Get next text field, return key index
           (Char_t *keys[],        // Keys identifying text
            Int_t nKeys            // # of keys
           );
  Char_t *InFileName();            // Pointer to input template file name
  Int_t   InitLine();              // Set pointers to start of new line
  void    Open                     // Open input or output copy file
          (const Char_t *file,
           const Char_t *mode = "r"
          ); 
  Char_t *OutFileName();           // Pointer to output file name if non-0
  void    SetDecKeys               // Set current numeric start keys
           (Int_t nDecKeys,
            Char_t *decKeys[]
           );
  void    SetDecEnd                // Set numeric field end keys
           (Int_t nEndKeys,
            Char_t *endKeys[]
           );
  void    SetEOLKeys               // Set current end-of-line keys
           (Int_t type,
            Int_t nKeys,
            Char_t *keys[]
           );
  void    SetTextKeys              // Set current text keys
           (Int_t nTextKeys,
            Char_t *textKeys[]
           );
  void    SetField(Float_t value); // Set current data field in outFile
  Int_t   SetFloat(Float_t value); // Set current float field in outFile--
                                   // new version
  Int_t   SetLineRange(Int_t limit); // Set line range for searches

// Public class variables for help in debugging

  Int_t iprint;
  Int_t Nprint;
  Int_t ReportLevel;

// private: During development, these variables are also public

  Char_t  *fBufLims[2]; //! Pointer to one character past end of buffer.
  Char_t  *fBufp;       //! Pointer to start of buffer, NO STREAMER
  Int_t    fDecOffs;    // Offset to decimal point in num. field, < 0 if none
  Int_t    fExpOffs;    // Offset to exponent part of num. field, < 0 if none
  Int_t    fFlags[2];   // Special action flags for text & num searches
                        // fFlags[eText] == 1 to get only one text key / line
  Int_t    fLineFields[2]; // Number of current field in line
  Char_t  *fFields[2];  //! Pointers to start of current fields
  Int_t    fFileFields[2]; // Number of current field in file
  Int_t    fIEnd;       // Key for current end-of-buffer
  FILE    *fIn;         //! Input file handle, NO STREAMER
  Char_t  *fInFile;     //! Input file name, NO STREAMER
  Int_t    fKeyIndex[2]; // Indices of current found keys
  Int_t    fKeys[2];    // Keys for start of current fields
  Int_t    fLengths[2]; // Lengths of current fields
  Int_t    fLine;       // Number of current line in file
  Int_t    fLinesPerCall; // Maximum # lines to read in one call
  Int_t    fLinesRead;  // # lines read in current call
  Int_t    fMaxChars;   // Line buffer size, characters, incl. terminal 0
  Float_t  fNumValue;   // Value of found numeric field
  Int_t    fOffsets[2]; // Offsets to start of current fields
  FILE    *fOut;        //! Output file handle, 0 if none, NO STREAMER
  Char_t  *fOutFile;    //! Output file name, NO STREAMER
  Int_t    fStatus;     // Status of current buffer:
                        // -2 = error, e.g. too many keys specified
                        // -1 = end of file reached;
                        // >= 0: set bits indicate found field types

public:
ClassDef(TPhOpts,1)    // Phobos options class
};

#endif
