#ifndef _TPhSensDef_INCLUDED_
#define _TPhSensDef_INCLUDED_

////////////////////////////////////////////////////////////////////////
// TPhSensDef is a sensor geometry definition class for Phobos multiplicity
// reconstruction.
//
// File: TPhSensDef.h
//
// 16-Dec-98 v3  Unused constructors commented out until needed (RV)
// $Id: TPhSensDef.h,v 1.4 1998/12/21 21:45:47 verdier Exp $
//
////////////////////////////////////////////////////////////////////////

// 08-Dec-98 v2  Update copy creator and Set methods (RV)
// 19-Jun-98 1.0  Change fSensors initializer for OSF1 (cf. TPhDispDef) (RV)
// 23-May-98 0.1  Added GetIndex and List methods (RV)
// 12-Mar-98 0.1  Defs of c225, ... moved to TPhSensDef.v for Abacus (RV)
// 10-Jan-98 0.1  Implement access methods (RV)
// 30-Oct-97 0.1  Creation, R. Verdier

#include "TPhMul.h"  // defines kNSensMax

// forward declarations

class TObject;        
class TPhSensGeo; // defines EnameSize

class TPhSensDef : public TObject

{ 

public:

  TPhSensDef();

/* Comment-out So-far unused special creators to avoid compiler warnings:

  TPhSensDef(TPhSensDef *orig);

  TPhSensDef(Float_t Version, Char_t name[], Int_t id, Int_t type,
    Int_t nxcells, Float_t xmin, Float_t xsize,
    Int_t nycells, Float_t ymin, Float_t ysize,
    Float_t o1, Float_t o2, Float_t o3,
    Float_t a11, Float_t a12, Float_t a13,
    Float_t a21, Float_t a22, Float_t a23,
    Float_t a31, Float_t a32, Float_t a33 );

*/  // End of commented-out constructors

  virtual ~TPhSensDef();

// Copy from a SensDef's SensGeo to a SensGeo
  Int_t    Copy(TPhSensDef *source, Int_t isens, TPhSensGeo *copy);

  Float_t  GetAxis(Int_t isens, Int_t ixyz);

  Int_t    GetId(Int_t isens);

// Get index of named sensor
  Int_t    GetIndex(Char_t *sensorName);

  Float_t  GetMin(Int_t isens, Int_t ixy);

// Get name of indexed sensor
  Char_t  *GetName(Int_t isens);

  Int_t    GetNCells(Int_t isens, Int_t ixy);

  Int_t    GetNDefsAct(); // Number of active sensor definitions

  Int_t    GetNDefsMax() { return kNSensMax; } // Storage limit on # sens defs

  Float_t *GetOrig(Int_t isens);

  Float_t  GetSize(Int_t isens, Int_t ixy);

  Int_t    GetType(Int_t isens);

  void     List(Int_t isMin, Int_t isMax); // Display active sensor names

  void     SetAxis(Int_t isens, Int_t ixyz, Float_t val); // UNIMPLEMENTED

  void     SetId(Int_t isens, Int_t id);

  void     SetMin(Int_t isens, Int_t ixy, Float_t min);

  void     SetName(Int_t isens, Char_t *name);

  void     SetNCells(Int_t isens, Int_t ixy, Int_t ncells);

  void     SetOrig(Int_t isens, Float_t x, Float_t y, Float_t z);

  void     SetSize(Int_t isens, Int_t ixy, Float_t size);

  void     SetType(Int_t isens, Int_t type);

  void     Show(Int_t isens, Int_t reportLevel);

private:

  TPhSensGeo *fSensors; //! Defaults- NO STREAMER

public:

ClassDef(TPhSensDef,3)      // PHOBOS sensor geometry defaults class

};

#endif
