{
// runmul.C: basic script to reconstruct multiplicities using data 
// from a root "dst" file.
// Use: with $PHATHOME and phat correctly defined, execute
//   % phat $PHATHOME/phatmul/macros/runmul.C
// and follow prompts.
// At present you should do gROOT->Reset() before re-executing this
// macro.
// 10-Feb-99 Use MDC-2 interfaces defined in Mul.h (RV)
// 09-Feb-99: Add dialogue and call for output macro (RV)
// 27-Jan-99: Expand filenames for existence check; delete/create det (RV)
// 21-Jan-99: Delete vertex object before deleting event (RV)
// 13-Jan-99: More askmes, prevent crash on non-existent data file (RV)
// $Id: runmul.C,v 1.17 1999/02/11 19:55:33 verdier Exp $
//
  Int_t iev; // Event loop index

// Start of MDC2 interface //////////////////////////////////////////
// Additions for MDC2, from Mul.h, R.Verdier, 9-Feb-99.
TPhMul     mp;             // The Mul object
Char_t    *mMacroName = "$PHATHOME/phatmul/macros/writemul.C";
Int_t      dataSource = 2; // 0 = data, 1 = MC data, 2 = MCHits;
// The following names are used by writemul.C and must be changed here,
// and in writemul.C, if they conflict with other names.
TPhMapSet *dms1 = 0;       // Display mapset pointer
TPhMapSet *sms1 = 0;       // Sensor mapset pointer
// Bits set in mOpts to write histos, multi and single event maps:
Int_t      EnCh = 1, Ehists = 2, EdispNEv = 4, Edisp1Ev = 8, Esens1Ev = 16;
Int_t      mOpts = 3;      // 1 + 2 + 4 + 8 + 16;
Int_t     &mEvIndex = iev; // Event-loop index for identifying objects
TFile     *outFile = (TFile *)0; // If non-null, specified objects will be
//                                  streamed directly to this file.
// Reconstructed and generated total charged multiplicity
Float_t    nChRec = 0;     // Reconstructed from *+in 
Float_t    nChRecRMS = 0;  // RMS error in ""
Float_t    nChGen = 0;     // Generated (if MC tracks and hits used)
Float_t    nChGenRMS = 0;  // RMS error in ""
// 2-d histograms.  Selectors must begin with 's' to specify a SensMap;
// anything else means a display
Int_t      nMHists = 2;    // Number of 2-d histograms filled on each event
TH2F      *mHists[nMHists] = {0, 0};// Array of pointers to histograms
Char_t    *histSelect[2]  = {"*+hr-1", "*+in-1"};
Char_t    *hTypeNames[2]  = {   "hr1",    "nr1"};
// 1-d plots
Int_t      nMGraphs = 2;   // Number of 1-d plots filled on each event
TGraphErrors *mGraphs[nMGraphs] = {0, 0}; // Array of pointers to plots
Char_t    *graphSelect[2] = {"*+hr", "*+in"};
Char_t    *gTypeNames[2]  = { "hrn",  "nrn"};
// End of MDC2 interface ////////////////////////////////////////////

  Int_t   MaxReply = 131;
  Char_t  reply[MaxReply];
  Int_t   reportLevel = 4; // 1 = fatal, 2 = warning, 3 = summary, ...

  printf ("Enter h for a brief help note, cr to bypass it: ");
  if (fgets(reply, MaxReply, stdin) && (reply[0] == 'h') || (reply[0] == 'H'))
  {
 printf (
 "\n Since you've gotten this far, you have correctly defined \$PHATHOME.\n"
 " First you\'ll need the name of a .root file with events to analyze.\n");
 printf (
 " The current standard event file is cv0_all_containers.root, which is in\n"
 " /data04/phobos/olszewsk/exports/pre-mdc2 on abacus.mit.edu and \n");
 printf (
 " /home/phobos/PHOBOS-data/pre-mdc2/root/full on nighthawk.chm.bnl.gov.\n"
 " For others, you'll have to search. If you can find .apx files such as\n");
 printf (
 " /data02/sim/sim42/cv0_00000.apx on abacus, you can use the script\n"
 " \$PHATHOME/phatmul/macros/apxtoroot.C to convert them to .root form.\n");
 printf (
 " The .apx files use 3 MB per event, the .root files about half that.\n\n"
 " You may also want a setup script to define options.  The standard one,\n");
 printf (
 " \$PHATHOME/phatmul/macros/setmul.C, enables only the option to use MC\n"
 " tracks as a source, to see reconstructed / generated comparisons; you\n");
 printf (
 " can copy and edit it for other options.\n\n");
 printf (
 " Once the run completes, you can view the results in an X-window (if you\n"
 " have defined the environment variable DISPLAY) by executing the script\n");
 printf (
 "   .x \$PHATHOME/phatmul/macros/plotmul.C\n"
 " and following the prompts.\n\n");
 printf (
 " More possibilities are described in the users\' guide, muluser.doc.\n\n");
  }

// Allow use of a previously instantiated and modified multiplicity processor

//  printf ("Enter cr to create a new TPhMul processor, anything else to use"
//    " an existing\none created with 'TPhMul mp'? ");
//  if (fgets(reply, MaxReply, stdin))
//    if (reply[0] == '\n') TPhMul mp;

// Define a sample list of DST files.
// These examples are from ppcln.mit.edu; for abacus.mit.edu, remove the 
// leading '/mnt'.  For other platforms, you may have to run the 
// $PHATHOME/phatmul/macros/apxtoroot.C script to convert .apx files such 
// as /mnt/data02/sim/sim42/cv0_00000.apx on abacus to .root form, or
// specify them as direct input here, which is very slow.

  Char_t  dataFile[MaxReply+2]; // +1 for terminal null + \n

// If nFiles is enum or const, Cint will crash on reentry; but you'll
// have to change it to an enum if you want to compile it.
  Int_t nFiles = 6;
  Char_t *dataFiles[nFiles] =
  { "/mnt/data04/phobos/pre-mdc2-2/hijing_c.root",
    "/mnt/data04/phobos/olszewsk/exports/pre-mdc2/cv0_all_containers.root",
    "/mnt/data04/phobos/olszewsk/exports/pre-mdc2/cvr_all_containers.root",
    "/mnt/data04/phobos/olszewsk/exports/pre-mdc2/iv0_all_containers.root",
    "$PHATHOME/data/hijing_2cen.adat.root",
    "~/dat/cv0_10.root"
  };

// Get data file name

  TPhDST *dst;
  if (dst) delete dst; // for re-executing runmul
  if (!dst)
  { printf ("Enter name of root- or apx-format DST file, space for none,"
            " or\n");
    for (Int_t nn = 0; nn < nFiles; nn++)
    { Char_t *eol = ",";
      if (nn == nFiles-2) eol = ", or";
      if (nn == nFiles-1) eol = ":";
      Char_t *def = "";
      if (nn == 0) def = " or cr";
      printf (" %d%s = %s%s\n", nn+1, def, dataFiles[nn], eol);
    }
    if (fgets (reply, MaxReply, stdin))
// The following won't work if nFiles > 9.
    { Int_t iName = (reply[0] == '\n')? 0 : reply[0] - '1';
      if ((iName >= 0 && iName < nFiles && reply[1] == '\n')
         || reply[0] == '\n') strcpy (dataFile, dataFiles[iName]);
      else
      { strcpy (dataFile, reply);
        dataFile[strlen(reply)-1] = 0; // cut newline
      } 
    }

// Try to avoid later segment violations by checking that datafile exists.
// Unlike ROOT, fopen can't expand environmentals in names.
    Char_t *expName = gSystem->ExpandPathName(dataFile);
    FILE *dataExists = fopen (expName, "r");
    if (!dataExists && reportLevel) 
      printf ("Can't open file %s [%s]; use ^C to abort.\n", dataFile,
        expName);
    expName->Delete();
    
// Ask file format (use name-parsing only for default)
// The default seems to fail for the $PHATHOME file

    Int_t dataFormat = 0; // -1 = none, 0 = .root, 1 = .apx, 2 = user's .root
    Int_t len = strlen(dataFile);
    if (len >= 4 && dataFile[len-4] == '.' && dataFile[len-3] == 'a' &&
        dataFile[len-2] == 'p' && dataFile[len-1] == 'x') dataFormat = 1; 
    if (dataFile[0] == '~') dataFormat = 2; 
    if (!dataExists) dataFormat = -1;
    printf ("File type (0 = .root, 1 = .apx, 2 = user-created .root? "
      "[cr = %d]): ", dataFormat);
    if (fgets(reply, MaxReply, stdin))
      if (reply[0] != '\n') sscanf (reply, "%d", &dataFormat);
    if (dataExists) dataExists->fclose();

// Ask whether to process MC truth information if present

    Bool_t useMCHits = kTRUE;
    printf ("Use MC information if present (n | y)? [cr = y]: ");
    if (fgets(reply, MaxReply, stdin))
      useMCHits = (reply[0] == 'y') || (reply[0] == 'Y') || (reply[0] == '\n');

// Ask whether to find vertex.

    TPhVertex *v1;
    Bool_t findVertex = kTRUE;
    printf ("Use standard vertex finder (y | n)? [cr = y]: ");
    if (fgets(reply, MaxReply, stdin))
      findVertex = (reply[0] != 'n') && (reply[0] != 'N');

// If not, ask for a fixed vertex Z.

    Float_t zVertex = 0.;
    if (!findVertex)
    { printf ("Please enter vertex Z, in cm. [cr = %5.2f]: ", zVertex);
      if (fgets(reply, MaxReply, stdin))
        if (reply[0] != '\n') sscanf (reply, "%f", &zVertex);
    }

// Ask what set of names to use for the MC hits and hit arrays-- we may 
// have to do ask individually if they keep being changed.  This is 
// the reason for the most common Mul crash.

    Int_t nameSet = 0;
    printf ("Use current [0] or pre 30-Dec-98 [1] array names [cr = %d]: ",
      nameSet);
    if (fgets(reply, MaxReply, stdin))
      if (reply[0] == '1') nameSet = 1;

// Set TPhMul switch for special data object names (see
// mp.fHitArrayName[fHitArrayId])

    if (dataFormat > 0) mp.fHitArrayId = 1;

// Set TPhMul switch for processing MC (truth) information if present
// ( 0 = data, 1 = MC data, 2 = MC hits, 3 = diagnostic)

    if (useMCHits) mp.fDataSource = 2;

// Specify TPhEvent names of TPhHitArray and TPhVertex objects.  As
// they are often changed capriciously, we must specify them at a highly
// visible level.

    Char_t *HitArraysName = "PMCHitArraysFromHits";
    if (nameSet == 0)
    { mp.fMCHitsName   = "PMCHits";
      mp.fMCTracksName = "PMCTracks";
    }
    else
    { HitArraysName    = "HitArraysFromHits";
      mp.fMCHitsName   = "MCHits";
      mp.fMCTracksName = "MCTracks";
    }
    mp.fHitArrayName[0] = HitArraysName;
    Char_t *vertexName = (findVertex)? "MainVertex" : "";

    if (dataFormat == 1) TPhASCIIData *asd;

    TPhEvent *ev;

    if (dataFormat >= 0)
    { if (reportLevel >= 8) printf ("Reading %s:\n", dataFile);
      if (dataFormat != 1) dst = new TPhDST(dataFile);
      else asd = new TPhASCIIData(dataFile);
    }
    else if (fDataSource == 3)
// Create an empty event to satisfy calls in diagnostic mode with
// fDataSource = EDiagnostic (3)
      ev = new TPhEvent();
    else
      ev = (TPhEvent *) 0;

// Create the detector object.  This is a problem because LatestGeometry
// may not be what it claims, whereas the dst may not contain geometry.
// Go figure.

    TPhDetector *det = TPhDetector::GetInstance();
//   if (!det) det = TPhDetector::ReadLatestGeometry();
// For this macro, delete and recreate a detector each time through:
    if (det) TPhDetector::DeleteInstance();
    det = dst->GetDetector();
    if (!det) printf ("No TPhDetector object is available; expect a crash.\n");
// If the following statement is omitted, mp::Process will find a detector
//  mp.fDet = det;

    Int_t nEvents = 999999; // This should be generalized to use -1
    printf ("Number of events to process (cr = all): ");
    if (fgets(reply, MaxReply, stdin))
      if (reply[0] != '\n') sscanf (reply, "%d", &nEvents);

    Int_t nEvSkip = 0;
    printf ("Number of events to skip initially (cr = %d): ", nEvSkip);
    if (fgets(reply, MaxReply, stdin))
      if (reply[0] != '\n') sscanf (reply, "%d", &nEvSkip);

    Char_t modFile[MaxReply];
    strncpy (modFile, "$PHATHOME/phatmul/macros/setmul.C", MaxReply);
    printf ("Setup script filename (cr for none, 1 = %s)\n: ", modFile);
    if (fgets(reply, MaxReply, stdin))
    { reply[strlen(reply)-1] = 0; // Kill \n
      if (strcmp(reply, "1"))
        strncpy(modFile, reply, MaxReply);
    }

// Output file specification dialogue

    TFile *outFile = 0;
    Char_t outMacro[MaxReply];
    strncpy (outMacro, mMacroName, MaxReply);
    printf ("Output script filename (cr for none, 1 = %s)\n: ", outMacro);
    if (fgets(reply, MaxReply, stdin))
    { reply[strlen(reply)-1] = 0; // Kill \n
      if (strcmp(reply, "1"))
        strncpy(outMacro, reply, MaxReply);
    }

    Char_t outFileName[MaxReply];
    if (strcmp(outMacro, ""))
    { strncpy (outFileName, "muldst.root", MaxReply);
      printf ("Output filename (cr for none, 1 = %s)\n: ", outFileName);
      if (fgets(reply, MaxReply, stdin))
      { reply[strlen(reply)-1] = 0; // Kill \n
        if (strcmp(reply, "1"))
          strncpy(outFileName, reply, MaxReply);
      }
    }

// Loop over events in the file using Phat's event numbering 0, 1, ...
    for (iev = 0; iev < nEvents + nEvSkip; iev++)
    { if ((dataFormat != 1 && dst) || (dataFormat == 1 && asd))
      { if (reportLevel >= 4) printf ("Reading event %d...\n", iev);
// Delete previous event if it exists
        if (ev) delete ev;
// Get an event from the TPhDST (.root format) or TPhASCIIData (.apx)
        if (dataFormat != 1) ev = dst->GetNextEvent();
        else ev = asd->GetNextEvent();
        if (ev)
        { det->SetEvent(ev);
// If .root format, fill the HitArrays with hits
          if (dataFormat != 1) det->FillWithEventHitArrays(HitArraysName);
// Issue a warning if the hitarrays have an unknown name
          if (reportLevel >= 1)
          { TPhHashContainer *hitarrays 
              = (TPhHashContainer *) ev->GetObject(HitArraysName);
            Int_t nHA = (hitarrays)? hitarrays->GetEntries() : 0;
            if (!nHA || reportLevel >= 5)
              printf ("runmul.C: event contains %d %s\n", nHA, HitArraysName);
          }
          if (strcmp(vertexName, ""))
          { ev->FindVertex();
            v1 = (TPhVertex *) ev->GetObject(vertexName);
            if (v1)
            { mp.SetVertex(v1);
              if (reportLevel >= 4) 
                printf ("Found vertex \"%s\" at Z = %6.2f cm.\n",
                  vertexName, v1->GetZ());
            }
          }
          else
          { if (!v1) v1 = new TPhVertex("vZero");
            v1->SetZ(zVertex);
          }
        } // if (ev
      } // if (dst

      if (ev && iev >= nEvSkip)
      { if (reportLevel >= 4) printf ("Reconstructing multiplicity...\n");
// Reconstruct multiplicity if not already done)
        if (iev == nEvSkip && strcmp(modFile, ""))
// Optionally modify the multiplicity processor after initialization.
// The modifier file should refer to the TPhMul object through the pointer mp.
        { mp.Process(ev, -1);
          gROOT->Macro(modFile);
          mp.Process(ev, 1);
        }
        else
          mp.Process(ev);

// Execute macro to write output into DST outFileName

        if (strcmp(outMacro, ""))
	{ if (iev == nEvSkip && strcmp(outFileName, ""))
          { Char_t *outFileMode = "recreate";
            outFile = new TFile(outFileName, outFileMode);
          }
          if (outFile) outFile->cd();
          gROOT->Macro(outMacro);
        }

// Delete the vertex while the event exists

        if (v1) delete v1;
      } // if (ev && iev
      if (!ev && reportLevel >= 3)
      { printf ("EOF found after %d events.\n", iev);
        break;
      }
    } // for (Int_t iev
  }
}
