#include "TObject.h"
#include "TPhSensGeo.h"
#include "TPhDispDef.h"
#include "TPhDispDefV.h" // Default values

ClassImp(TPhDispDef)

////////////////////////////////////////////////////////////////////////////
//
// TPhDispDef is a display geometry definition class for Phobos multiplicity
// reconstruction.  It is structurally identical with TPhSensDef (q.v.) and 
// both may evolve into derived classes.
//
// 13-Jan-99 v3  NXcells, NYcells -> NXCells, NYCells for consistency (RV)
// $id$
//
////////////////////////////////////////////////////////////////////////////

// 16-Dec-98 v3  Unused constructors commented out until needed (RV)
// 08-Dec-98 v3  Strengthen parallelism with TPhSensDef, implement Sets (RV)
// 15-Aug-98 1.0  Change default values filename from .v to V.h (RV)
// 08-Jul-98 1.0  ixy = 0, 1 for x, y (RV)
// 03-Jun-98 1.0  Get max name size from EnameSize in TPhSensGeo.h;
//                change syntax of fDisplays declaration (RV)
// 12-Mar-98 0.3  Correct syntax errors for Abacus (RV)
// 15-Feb-98 0.2  Add GetNDefs methods (RV)
// 29-Oct-97: DispDef copy not restricted to id < kNSensMax (RV)
// 13-Oct-97: Creation (Robin Verdier)

// Return flags EOK, EbadArg, and Eunimplemented are enumerated in TPhMul.h
//  enum { EOK = 0, EbadArg = -999991, Eunimplemented = -999992 };

TPhDispDef::TPhDispDef()
{ fDisplays = gMulDisplays;
  return;
} 

/* Comment-out So-far unused special creators to avoid compiler warnings:

TPhDispDef::TPhDispDef(TPhDispDef *orig)
{ fDisplays = gMulDisplays;
  return;
} 

TPhDispDef::TPhDispDef(Float_t Version, Char_t name[], Int_t id, Int_t type,
    Int_t nxcells, Float_t xmin, Float_t xsize,
    Int_t nycells, Float_t ymin, Float_t ysize,
    Float_t o1, Float_t o2, Float_t o3,
    Float_t a11, Float_t a12, Float_t a13,
    Float_t a21, Float_t a22, Float_t a23,
    Float_t a31, Float_t a32, Float_t a33 )
{ fDisplays = gMulDisplays;
  return;
} 

*/  // End of commented-out constructors

TPhDispDef::~TPhDispDef() { return; } 

Int_t TPhDispDef::Copy(TPhDispDef *source, Int_t idisp, TPhSensGeo *copy)
{
// idisp is the display index = 0, 1, 2, ..., kNDispMax-1.
// Returns 0 if successful, else EbadArg.
// This is a primitive implementation to be replaced by byte copy
// operations and, possibly, an overloaded = operator

  if (idisp < 0 || idisp >= kNDispMax || source == 0 || copy == 0)
    return EbadArg;
  else
  { copy->Version = source->fDisplays[idisp].Version;
    Int_t nn; // Avoids DEC / GNU disagreement about scope
    strncpy (copy->Name, source->fDisplays[idisp].Name, EnameSize);
    copy->Id      = source->fDisplays[idisp].Id;
    copy->Type    = source->fDisplays[idisp].Type;
    copy->NXCells = source->fDisplays[idisp].NXCells;
    copy->Xmin    = source->fDisplays[idisp].Xmin;
    copy->Xsize   = source->fDisplays[idisp].Xsize;
    copy->NYCells = source->fDisplays[idisp].NYCells;
    copy->Ymin    = source->fDisplays[idisp].Ymin;
    copy->Ysize   = source->fDisplays[idisp].Ysize;
    for (nn=0; nn<3; copy->Orig[nn]=source->fDisplays[idisp].Orig[nn++]);
    for (nn=0; nn<3; nn++)
      for (int mm=0; mm<3;
        copy->Axes[nn][mm]=source->fDisplays[idisp].Axes[nn][mm++]);
    copy->Dist = source->fDisplays[idisp].Dist;
  }
  return EOK;
}

Float_t TPhDispDef::GetAxis(Int_t ixyz, Int_t idisp)
        { return (float) fDisplays[idisp].Axes[0][ixyz]; } 

Int_t   TPhDispDef::GetId(Int_t idisp) { return fDisplays[idisp].Id; }

Int_t   TPhDispDef::GetIndex(Char_t *displayName)
// Return sequential index of named active display, used in all Mul lists,
// or EbadArg (<< 0) if name is not in active list
{ Int_t idisp;
  for (idisp = kNDispMax-1; idisp >= 0; idisp--)
  { if ((fDisplays[idisp].Name[0]) 
    && !strcmp (displayName, fDisplays[idisp].Name)) break;
  }
  return (idisp >= 0)? idisp : EbadArg;
}

Float_t TPhDispDef::GetMin(Int_t idisp, Int_t ixy)
        { return (ixy == 0)? fDisplays[idisp].Xmin : fDisplays[idisp].Ymin; }

Char_t *TPhDispDef::GetName(Int_t idisp) { return fDisplays[idisp].Name; }

Int_t TPhDispDef::GetNCells(Int_t idisp, Int_t ixy)
      { return (ixy == 0)? fDisplays[idisp].NXCells : fDisplays[idisp].NYCells;
      }

Int_t TPhDispDef::GetNDefsAct()
// GetNDefsAct returns the number of active display definitions.
// The # of definitions is determined by the contents of TPhDispDefV.h, but 
// we need to define the meaning of kNDispMax, say to allocate space so
// that users can add new definitions without recompiling.
{ Int_t geoSize = sizeof(TPhSensGeo);
  Int_t dispSize = sizeof(gMulDisplays);
  Int_t nDefsAct = dispSize / geoSize;
  return nDefsAct; 
}

Float_t *TPhDispDef::GetOrig(Int_t idisp)
         { return fDisplays[idisp].Orig; }

Float_t TPhDispDef::GetSize(Int_t idisp, Int_t ixy)
        { return (ixy == 0)? fDisplays[idisp].Xsize : fDisplays[idisp].Ysize; }

Int_t  TPhDispDef::GetType(Int_t idisp) { return fDisplays[idisp].Type; }

void  TPhDispDef::List(Int_t idMin = 0, Int_t idMax = kNDispMax-1)
       { for (Int_t id = idMin; id <= idMax; id++)
         { printf ("%3d:%5s ", id, fDisplays[id].Name);
           if (!((id-idMin+1)%8) || id == idMax) printf ("\n");
         }
       }

void   TPhDispDef::SetAxis(Int_t idisp, Int_t ixyz, Float_t val)
       { fDisplays[idisp].Axes[0][ixyz] = val; }

void  TPhDispDef::SetId(Int_t idisp, Int_t id) {fDisplays[idisp].Id = id; }

void  TPhDispDef::SetMin(Int_t idisp, Int_t ixy, Float_t min)
       { if (ixy == 0) fDisplays[idisp].Xmin = min;
         if (ixy == 1) fDisplays[idisp].Ymin = min;
       }

void  TPhDispDef::SetName(Int_t idisp, Char_t *name)
       { strncpy(fDisplays[idisp].Name, name, EnameSize); }

void  TPhDispDef::SetNCells(Int_t idisp, Int_t ixy, Int_t ncells)
       { if (ixy == 0) fDisplays[idisp].NXCells = ncells;
         if (ixy == 1) fDisplays[idisp].NYCells = ncells;
       }

void  TPhDispDef::SetOrig(Int_t idisp, Float_t x, Float_t y, Float_t z)
       { fDisplays[idisp].Orig[0] = x;
         fDisplays[idisp].Orig[1] = y;
         fDisplays[idisp].Orig[2] = z; 
       }

void  TPhDispDef::SetSize(Int_t idisp, Int_t ixy, Float_t size)
       { if (ixy == 0) fDisplays[idisp].Xsize = size;
         if (ixy == 1) fDisplays[idisp].Ysize = size;
       }

void  TPhDispDef::SetType(Int_t idisp, Int_t type)
       { fDisplays[idisp].Type = type; }

void  TPhDispDef::Show(Int_t idisp, Int_t reportLevel)
        { if (reportLevel == 1) printf ("DispDef: display%3d = %s\n",
            idisp, fDisplays[idisp].Name);
          if (reportLevel == 2) printf (" #  Name Type nXCells  Xmin  "
            "Xcell  nYCells   Ymin  Ycell    Dist\n");
          if (reportLevel == 3) printf (
            "%3d %s %3d %6d%8.3f%7.3f%7d%8.3f%7.3f%9.3f\n",
            fDisplays[idisp].Id, fDisplays[idisp].Name, fDisplays[idisp].Type,
            fDisplays[idisp].NXCells, fDisplays[idisp].Xmin, 
            fDisplays[idisp].Xsize, fDisplays[idisp].NYCells, 
            fDisplays[idisp].Ymin, fDisplays[idisp].Ysize, 
            fDisplays[idisp].Dist);
        }

// End TPhDispDef implementation
