#include "TObject.h"
#include "TPhFsec.h"
#include "TPhFsecV.h" // Default values
#include "TPhSensDef.h"

ClassImp(TPhFsec)

////////////////////////////////////////////////////////////////////////////
//
// TPhFsec is a secondary track fraction calculation class for Phobos 
// analysis.
// GetFsec returns the global value of the total / primary track 
// ratio for a particular detector pad by interpolating in a table 
// using  values obtained from Phobos simulation.
// At present it returns only the phi-averaged value.
//
// File: TPhFsec.cxx
//
// Date     Vers  Description
// 16-Dec-98 1.0  Comment-out unused args for inimplemented Fit method (RV)
//
// $id$
//
////////////////////////////////////////////////////////////////////////////

// 15-Aug-98 1.0  Change default values filename from .v to V.h (RV)
// 22-May-98 0.3  Implement GetPar and SetPar methods, add TPhSensDef
//                argument to constructor (RV)
// 12-Dec-97 0.1  Add ReportLevel and Npring (Robin Verdier)
// 04-Nov-97 0.1  Creation based on TPhDept (Robin Verdier)

TPhFsec::TPhFsec(TPhSensDef &sd) {fSensDefs = &sd; }

// TPhFsec::TPhFsec(FILE *values) {} // UNIMPLEMENTED

Int_t TPhFsec::Fit (/*Char_t *sensorName, TPhFsec *fsec, TPhPadMap **disps, 
                    Int_t varIndex, Int_t varRMSIndex, Char_t *outFileName*/)
{ return Eunimplemented; } // UNIMPLEMENTED, see TPhDept

Int_t TPhFsec::GetFitSensorId ()
{ return fFitSensId; // Id of sensor being fitted
}

Int_t   TPhFsec::GetFitType (Char_t *sensorName)
// A specific fit type is not yet associated with each sensor
{ return (sensorName)? 1 : 1; }

// Double_t TPhFsec::GetFitValue (Double_t *x, Double_t *pars) {} UNIMPLE-
// MENTED, see TPhDept

Float_t TPhFsec::GetFsec(Int_t isens, Float_t Eta)
{
  static Int_t iprint = 0;
  Int_t Nprint = 10;
  Int_t ReportLevel = 1;

// Set iseg to the index of the first segment whose eta is <= the 
// requested eta

//  for (int iseg = 0, int nn = 1; nn < kNSeg-1; nn++) *** fails ***?
  Int_t iseg = 0;
  for (Int_t nn = 1; nn < kNSeg-1; nn++)
    if (Eta >= fF[isens][nn][1]) iseg = nn;

// Return value obtained by linear interpolation

  Float_t dFdE = (fF[isens][iseg+1][0] - fF[isens][iseg][0])
    / (fF[isens][iseg+1][1] - fF[isens][iseg][1]);
  Float_t Fsec = fF[isens][iseg][0] + dFdE * (Eta - fF[isens][iseg][1]);

  if (ReportLevel >= 3 && iprint < Nprint 
      && isens == 28 && Eta < -1.88 && Eta > -1.900) 
  { printf ("TPhFsec: for sensor %d and Eta = %8.3f, Edep =%12.4e.\n",
      isens, Eta, Fsec);
    iprint++;
  }

  return Fsec;
}

Int_t   TPhFsec::GetNPars (Int_t sensorId)
{ return (sensorId)? kNSeg : kNSeg; } // Individual fits not yet available

Float_t TPhFsec::GetPar (Int_t sensorId, Int_t parIndex)
{ return fF[sensorId][0][parIndex];
}

Float_t TPhFsec::GetPar (Char_t *sensorName, Int_t parIndex) 
{ const Float_t FlError = -9.99e20; // Note there's no provision for error
  Int_t is = fSensDefs->GetIndex(sensorName);
  return (is >= 0)? fF[is][0][parIndex] : FlError;
}

void TPhFsec::SetFitSensorId (Int_t sensorId)
{ // Select sensor to be fitted.  This is non-reentrant and should be changed.
  fFitSensId = (sensorId < kNSensMax)? sensorId : -1;
}

void TPhFsec::SetPar (Int_t sensorId, Int_t parIndex, Float_t value)
{ fF[sensorId][0][parIndex] = value;
}

void TPhFsec::SetPar (Char_t *sensorName, Int_t parIndex, Float_t value) 
{ Int_t is = fSensDefs->GetIndex(sensorName);
  if (is >= 0) fF[is][0][parIndex] = value;
}

// void TPhDept::SetupFit() {} UNIMPLEMENTED, see TPhDept
 
