#include "math.h"
#include "TPhPIDSpect.h"
#include "TPhMCTrack.h"
#include "TPhMCHit.h"
#include "TPhDetector.h"
#include "TPhSensor.h"

#include "TH2.h"
#include "TGraph.h"

ClassImp(TPhPIDSpect)

TPhPIDSpect::TPhPIDSpect()
{
}
TPhPIDSpect::~TPhPIDSpect() 
{
}
 
TPhPIDSpect::TPhPIDSpect(Char_t *FileName)
{
  // Constructor
  // Like TPhPIDSpect(), but also calls ReadBandPara()
  
  ReadBandPara(FileName);
}

Bool_t TPhPIDSpect::ReadBandPara(Char_t *FileName)
{
  //
  // The file with parameters of PID bands is opened and read into arrays:
  // fPiBandLo, fPiBandHi, fKBandLo, fKBandHi,fPBandLo, fPBandHi, fEBandLo, fEBandHi. 
  //
  // Parameters of the profile(Landau) functions are read into arrays:  
  // fPiBandMe, fPiBandRM, fKBandMea, fKBandRMS, fPBandMea, fPBandRMS, fEBandMea, fEBandRMS.
  // 

  Char_t str[150];
  Float_t suma=0.;
    FILE *Fcalka;
  if(fVerbose==1){
    Fcalka = fopen("calka","w");
  }  
  FILE *Fp;
  Fp = fopen(FileName,"r");
  
  if(Fp == NULL){
    printf("Couldn't open %s\n",FileName);
    return kFALSE;
  }
  else {
    printf("Opened file %s and reads PID band parameters \n",FileName);
  }
  
  // data for pions

  fgets (str, 150, Fp);
  if(fVerbose==1)printf("%s ",str);
  sscanf(str,"%d ",&nbinsx_pi);

  if(fVerbose==1)fprintf(Fcalka,"%d  \n",nbinsx_pi+1);
  if(fVerbose==1)fprintf(Fcalka,"%f %f \n",0.0,0.0);

  Int_t  nw;
  for(nw=0;nw<nbinsx_pi;nw++){
    fgets(str, 150, Fp);
    if(fVerbose==1)printf("%s ",str);
    sscanf(str,"%f %f %f %f %f %f %f  ",&fPiBandLo[nw],&fPiBandHi[nw],&fPiBandMe[nw],&fPiBandRM[nw],
	   &fPiMomentum1[nw],&fPiMomentum2[nw],&fPiMomentum3[nw]);
    suma = suma + 1.*exp(fPiBandMe[nw]*log(10.));

    if(nw<nbinsx_pi-1 && fVerbose==1)fprintf(Fcalka,"%f %f \n",fPiMomentum2[nw],suma);
  }

  if(fVerbose==1)fprintf(Fcalka,"%f %f \n",2.0,suma);

  p_pi =fPiMomentum1[0];
  p_tot=fPiMomentum3[nbinsx_pi-1];

  // data for kaons

  fgets (str, 150, Fp);
  if(fVerbose==1)printf("%s ",str);
  sscanf(str,"%d ",&nbinsx_k);
  for(nw=0;nw<nbinsx_k;nw++){
    fgets(str, 150, Fp);
    if(fVerbose==1)printf("%s ",str);
    sscanf(str,"%f %f %f %f %f  %f %f ",&fKBandLo[nw],&fKBandHi[nw],&fKBandMea[nw],&fKBandRMS[nw],
	   &fKMomentum1[nw],&fKMomentum2[nw],&fKMomentum3[nw]);
  }
  p_k=fKMomentum1[0];

  // data for protons

  fgets (str, 150, Fp);
  if(fVerbose==1)printf("%s ",str);
  sscanf(str,"%d ",&nbinsx_p);
  for(nw=0;nw<nbinsx_p;nw++){
    fgets(str, 150, Fp);
    if(fVerbose==1)printf("%s ",str);
    sscanf(str,"%f %f %f %f %f %f %f ",&fPBandLo[nw],&fPBandHi[nw],&fPBandMea[nw],&fPBandRMS[nw],
	   &fPMomentum1[nw],&fPMomentum2[nw],&fPMomentum3[nw]);
  }
  p_p=fPMomentum1[0];

  // data for electrons

  fgets (str, 150, Fp);
  if(fVerbose==1)printf("%s ",str);
  sscanf(str,"%d ",&nbinsx_e);
  for(nw=0;nw<nbinsx_e;nw++){
    fgets(str, 150, Fp);
    if(fVerbose==1)printf("%s ",str);
    sscanf(str,"%f %f %f %f %f %f %f ",&fEBandLo[nw],&fEBandHi[nw],&fEBandMea[nw],&fEBandRMS[nw],
	   &fEMomentum1[nw],&fEMomentum2[nw],&fEMomentum3[nw]);
  }
  p_e=fEMomentum1[0];

  // data for pions to be used in the reconstruction program

  fgets (str, 150, Fp);
  if(fVerbose==1)printf("%s ",str);
  for(nw=0;nw<nbinsx_pi;nw++){
    fgets(str, 150, Fp);
    if(fVerbose==1)printf("%s ",str);
    sscanf(str,"%f %f %f %f",&fPiBandLo_onehit[nw],&fPiBandHi_onehit[nw],
	   &fPiBandMe_onehit[nw],&fPiBandRM_onehit[nw]);
  }



  return kTRUE;
}


Int_t  TPhPIDSpect::DrawBands(Option_t *option) 
{ 
  TH2F *hframe1 = new TH2F("hframe1","dE/dx vs p - bands", 400., 0.0, 2.0,  400,0.0,1.6);
  hframe1->SetFillColor(0);
  hframe1->GetYaxis()->SetNdivisions(110);
  hframe1->GetXaxis()->SetLabelSize(0.06);
  hframe1->GetXaxis()->SetNdivisions(505);
  hframe1->Draw();
  TGraph *gr;

  // band for pions
    if(fVerbose==1)printf("%s \n",option);
  if(strstr(option,"1") || strstr(option,"0")){
    gr = new TGraph(nbinsx_pi,fPiMomentum2,fPiBandLo);
    gr->Draw("L");
    gr = new TGraph(nbinsx_pi,fPiMomentum2,fPiBandHi);
    gr->Draw("L");
  }
  // band for kaons
  if(strstr(option,"2") || strstr(option,"0")){
    gr = new TGraph(nbinsx_k,fKMomentum2,fKBandLo);
    gr->Draw("L");
    gr = new TGraph(nbinsx_k,fKMomentum2,fKBandHi);
    gr->Draw("L");
  }
  // band for protons
  if(strstr(option,"3") || strstr(option,"0")){
    gr = new TGraph(nbinsx_p,fPMomentum2,fPBandLo);
    gr->Draw("L");
    gr = new TGraph(nbinsx_p,fPMomentum2,fPBandHi);
    gr->Draw("L");
  }
  // band for electrons
  if((strstr(option,"4") || strstr(option,"0"))&& r4 != 0.){
    gr = new TGraph(nbinsx_e,fEMomentum2,fEBandLo);
    gr->Draw("L");
    gr = new TGraph(nbinsx_e,fEMomentum2,fEBandHi);
    gr->Draw("L");
  }

 return 1;
}

Int_t  TPhPIDSpect::DrawProfiles(Int_t k, Int_t gid) 
{ 
  Int_t i,j=0,kmax;
  Float_t p1,p2,yhig[4] = {0.8,1.5,1.7,0.3};
  if(gid==4)kmax=nbinsx_e;
  if(gid==3)kmax=nbinsx_p;
  if(gid==2)kmax=nbinsx_k;
  if(gid==1)kmax=nbinsx_pi;
  
  for(i=0;i<kmax;i++)
    {
      TF1* sqroot = new TF1("sqroot","[0]*exp(-(x-[1])*(x-[1])/[2]**2./2)",.0,yhig[gid-1]);
      if(gid==1){p1=fPiBandMe[i];p2=fPiBandRM[i];}
      if(gid==2){p1=fKBandMea[i];p2=fKBandRMS[i];}
      if(gid==3){p1=fPBandMea[i];p2=fPBandRMS[i];}
      if(gid==4){p1=fEBandMea[i];p2=fEBandRMS[i];}
      sqroot->SetParameters(1.,p1,p2);   
      if(j==0){j=1;sqroot->Draw();}
      if(j>0)sqroot->Draw("same");
    }
  
  return 1;
}

Float_t TPhPIDSpect::GetdEdxt(TPhMCTrack *track)
{

  Float_t dEdxt=6.2;
  Float_t g[nhitsMax];

  Float_t Dl;
  Int_t nhits=0,iarm;
  TPhMCHit *hit;

  iarm = Arm(track);
  //printf("%d \n",iarm);
  if(!iarm)  return dEdxt ;

  TIter NextHit(track->GetHitList());
  while((hit = (TPhMCHit *) NextHit()))
    { 
      Char_t  armind = (fDetector->GetSensor(hit->GetSensorLabel()))->GetName()[0];
      if((iarm == 1 && armind=='P') || (iarm == 2 && armind=='N' ))
	{	      
	  Dl = hit->GetDx() * hit->GetDx() + 
	    hit->GetDy() * hit->GetDy() +
	    hit->GetDz() * hit->GetDz();
	  if( Dl == 0.0)
	    {
	      printf("track with  Dl == 0.0: %f \n",Dl);
	      return dEdxt;
	    }
	  Dl = sqrt(Dl);
	  g[nhits] = hit->GetDe()/Dl;
	  nhits++;
	}
    }
  dEdxt = calc_truncmean(g,nhits,Ntrunt,nhits-Ntrunb);
  return  log10( dEdxt / ro_si ) + 3.;
  
}


Int_t TPhPIDSpect::GetBand(TPhMCTrack *track, Int_t *iBand)
{

  Float_t dedxtr = GetdEdxt( track ), p = track->GetP();
  
  iBand[0]=0;iBand[1]=0;iBand[2]=0;iBand[3]=0;
  
  Float_t PiBandH, PiBandL, KBandH, KBandL, PBandH, PBandL, EBandH, EBandL;
  
  if(p>p_p){ 
    PiBandH=Interpol(p,fPiBandHi,1);
    PiBandL=Interpol(p,fPiBandLo,1);
    KBandH =Interpol(p,fKBandHi, 2);
    KBandL =Interpol(p,fKBandLo, 2);
    PBandH =Interpol(p,fPBandHi, 3);
    PBandL =Interpol(p,fPBandLo, 3);
    EBandH =Interpol(p,fEBandHi, 4);
    EBandL =Interpol(p,fEBandLo, 4);
    if(dedxtr >PiBandL  && dedxtr <PiBandH)iBand[0] = 1; 
    if(dedxtr > KBandL  && dedxtr < KBandH)iBand[1] = 1; 
    if(dedxtr > PBandL  && dedxtr < PBandH)iBand[2] = 1;
    if(dedxtr > EBandL  && dedxtr < EBandH && r4 != 0. )iBand[3] = 1;
    return 5;
  }
  if(p>p_k && p<=p_p){ 
    PiBandH=Interpol(p,fPiBandHi,1);
    PiBandL=Interpol(p,fPiBandLo,1);
    KBandH =Interpol(p,fKBandHi, 2);
    KBandL =Interpol(p,fKBandLo, 2);
    EBandH =Interpol(p,fEBandHi, 4);
    EBandL =Interpol(p,fEBandLo, 4);
    if(dedxtr >PiBandL  && dedxtr <PiBandH)iBand[0] = 1; 
    if(dedxtr > KBandL  && dedxtr < KBandH)iBand[1] = 1; 
    if(dedxtr > EBandL  && dedxtr < EBandH && r4 != 0. )iBand[3] = 1;
    return 4;
  }
  if(p>p_pi && p<=p_k){ 
    PiBandH=Interpol(p,fPiBandHi,1);
    PiBandL=Interpol(p,fPiBandLo,1);
    EBandH =Interpol(p,fEBandHi, 4);
    EBandL =Interpol(p,fEBandLo, 4);
    if(dedxtr >PiBandL  && dedxtr <PiBandH)iBand[0] = 1; 
    if(dedxtr > EBandL  && dedxtr < EBandH && r4 != 0. )iBand[3] = 1;
    return 3;
  }
  if(p>p_e && p<=p_pi && r4 != 0. ){ 
    EBandH =Interpol(p,fEBandHi, 4);
    EBandL =Interpol(p,fEBandLo, 4);
    if(dedxtr > EBandL  && dedxtr < EBandH)iBand[3] = 1;
    return 2;
  }
  if(p < p_e)return 1;
  return 0;
}

Int_t  TPhPIDSpect::GetProb(TPhMCTrack *track, Float_t *PIDProb)
{
  Float_t w1,w2,w3,w4,w;

  Int_t iBand[4];

  PIDProb[0] = 0.0;PIDProb[1] = 0.0;PIDProb[2] = 0.0;PIDProb[3] = 0.0;
  
  Float_t dedxtr = GetdEdxt( track ), p = track->GetP();
  if( dedxtr == 0.0 || p > p_tot )return 0;
  if( dedxtr > 6.0 || dedxtr < 0.02 )return 0;
  
  // THE FIFTH INTERVAL

  if( p > p_p && p <= p_tot  )
    {
      w1 = ProfileFunction(1,dedxtr,p);
      w2 = ProfileFunction(2,dedxtr,p);
      w3 = ProfileFunction(3,dedxtr,p);
      w4 = ProfileFunction(4,dedxtr,p);
      w = w1 + r2 * w2 + r3 * w3 + r4 * w4;
      if(w > 0.)
	{
	  PIDProb[0] = w1/w;
	  PIDProb[1] = r2*w2/w;
	  PIDProb[2] = r3*w3/w;
	  PIDProb[3] = r4*w4/w;
	}
      return 5;
    }

  // THE FOURTH INTERVAL
  
  if( p >= p_k && p <= p_p  )
    {
      w1 = ProfileFunction(1,dedxtr,p);
      w2 = ProfileFunction(2,dedxtr,p);
      w4 = ProfileFunction(4,dedxtr,p);
      w = w1 + r2 * w2 + r4 * w4;
      if(w > 0.)
	{
	  PIDProb[0] =    w1/w;
	  PIDProb[1] = r2*w2/w;
	  PIDProb[3] = r4*w4/w;
	}
      return 4;
    }  

  // THE THIRD INTERVAL
  
  if( p >= p_pi && p <= p_k )
    {
      w1=ProfileFunction(1,dedxtr,p);  // weight for pion 
      w4=ProfileFunction(4,dedxtr,p);  // weight for electrons
      w=w1+r4*w4;
      if(w>0.)
	{
	  PIDProb[0] =    w1/w;
	  PIDProb[3] = r4*w4/w;
	}
      return 3;
    }
  
  // THE SECOND INTERVAL
  
  if( p > p_e && p <= p_pi)
    {
      GetBand(track,iBand);
      if(iBand[3]==1)PIDProb[3] = 1.; 
      return 2;
    }
  
  // THE FIRST INTERVAL
  if( p <= p_e )return  1;

  return  0;
  

}


Float_t TPhPIDSpect::ProfileFunction(Int_t pid, Float_t dedxtrm, Float_t p)
{
  Float_t mi,Mean,RMS;

  if(pid==1){Mean=Interpol(p,fPiBandMe,pid);RMS =Interpol(p,fPiBandRM,pid);}
  if(pid==2){Mean=Interpol(p,fKBandMea,pid);RMS =Interpol(p,fKBandRMS,pid);}
  if(pid==3){Mean=Interpol(p,fPBandMea,pid);RMS =Interpol(p,fPBandRMS,pid);}
  if(pid==4){Mean=Interpol(p,fEBandMea,pid);RMS =Interpol(p,fEBandRMS,pid);}

  mi=(dedxtrm-Mean)/RMS;
  if(fabs(mi)>Nsigma)
    return 0.;
  else
    return exp(-mi*mi/2);
}

// utility functions

Int_t TPhPIDSpect::Arm(TPhMCTrack *track)
{
  TPhMCHit *hit;

  if(!fDetector)
  {
      fDetector = TPhDetector::GetInstance();
      if(!fDetector)
      {
        printf("TPhPIDSpect::GetdEdxt : TPhDetector::Getinstance()  returnerd NULL\n");
        return  0;
      }
  }

  if(track->GetNHits() < nhitsMin)return 0;

  Int_t iarm=0,ilayer_old=0,ilayer,iok1[13],iok2[13];
  Int_t nhits1=0,nhits2=0;
  Int_t i;

  for(i=0;i<13;i++){iok1[i]=0;iok2[i]=0;}

  TIter NextHit(track->GetHitList());
  while((hit = (TPhMCHit *) NextHit()))
    { 
      ilayer = hit->GetLayer();
      if(ilayer>=ilayer_old)
	{
          Char_t  armind = (fDetector->GetSensor(hit->GetSensorLabel()))->GetName()[0];
	  if(armind == 'P')
          {
	    if(ilayer< 11)iok1[ilayer]=1;
	    if(ilayer==12)iok1[11]=1;
	    if(ilayer==14)iok1[12]=1;
	    ilayer_old=ilayer;
	    nhits1++;
	  }
	  if(armind == 'N')
          {
	    if(ilayer< 11)iok2[ilayer]=1;
	    if(ilayer==12)iok2[11]=1;
	    if(ilayer==14)iok2[12]=1;
	    ilayer_old=ilayer;
	    nhits2++;
	  }
	}
    }
  if(GetOK(iok1))iarm=1;
  if(GetOK(iok2))iarm=2;
  if(iarm==1 && nhits1>=nhitsMax)iarm=0;
  if(iarm==2 && nhits2>=nhitsMax)iarm=0;
  return iarm;
}

Float_t TPhPIDSpect::calc_truncmean(Float_t *g, Int_t nhits, Int_t start, Int_t stop)
{
  Float_t truncmean=0.;
  
  Sort(g,nhits);
  for(Int_t i = start; i < stop; i++)truncmean = truncmean + g[i];
  truncmean = truncmean/(stop - start);
  return   truncmean;
}

Int_t  TPhPIDSpect::GetOK(Int_t * iok) 
{ 
  Int_t ok=0;

  if (iok[6]==1 || iok[7]==1)ok=1;
  if(ok)
    {
      for(Int_t i=0;i<13;i++)
	{
	  if(i!=6 && i!=7)ok=ok*iok[i];
	}
    }
  return ok;
}

Float_t TPhPIDSpect::Interpol(Float_t p, Float_t a[], Int_t pid)
{
  Float_t *xl,*xc,*xh,k;
  Int_t nw,nbins,side2center;
  if(pid==1){xl=fPiMomentum1;xc=fPiMomentum2;xh=fPiMomentum3;nbins=nbinsx_pi;}
  if(pid==1 && p < p_pi || pid==1 && p > p_tot  ){
    if(fVerbose==1)printf("TPhPIDSpect::Interpol: momentum outside range 0.09-2GeV/c \n");
    return -777.;
  }
  if(pid==2){xl=fKMomentum1 ;xc=fKMomentum2 ;xh=fKMomentum3 ;nbins=nbinsx_k;}
  if(pid==3){xl=fPMomentum1 ;xc=fPMomentum2 ;xh=fPMomentum3 ;nbins=nbinsx_p;}
  if(pid==4){xl=fEMomentum1 ;xc=fEMomentum2 ;xh=fEMomentum3 ;nbins=nbinsx_e;}
  for(nw=0;nw<nbins;nw++)
    if( p>=xl[nw] && p <= xh[nw]){
      side2center=-1;
      if(p>xc[nw])side2center=1;
      break;
    }

  //printf("%d %d \n",nw,side2center);
  if((nw==nbins-1&&side2center==1) || (nw==0&&side2center==-1)){
    k=xc[nw] - xc[nw-side2center];
    k=(xc[nw]-p)/k;
    return a[nw] - k * (a[nw] - a[nw-side2center]);}
  else{
    k=xc[nw] - xc[nw+side2center];
    k=(xc[nw]-p)/k;
    return a[nw] - k * (a[nw] - a[nw+side2center]);}
}

void TPhPIDSpect::Sort(Float_t *v, Int_t n)
{
  Int_t gap, i, j;
  Float_t temp;
  for(gap=n/2;gap>0;gap/=2)
    for(i=gap;i<n;i++)
      for(j=i-gap;j>=0;j-=gap)
	{
	  if(v[j]<=v[j+gap])
	    break;
	  temp=v[j];
	  v[j]=v[j+gap];
	  v[j+gap]=temp;
	}
  for(i=0;i<n/2;i++)
    {
      temp=v[i];
      v[i]=v[n-1-i];
      v[n-1-i]=temp;
    }
}

void TPhPIDSpect::GetOneHitBand(Float_t p, Float_t *Mean_RMS)
{
  Mean_RMS[0] =  Interpol(p,fPiBandMe_onehit,1);
  Mean_RMS[1] =  Interpol(p,fPiBandRM_onehit,1);
  return;
}

