#include "math.h"
#include "TPhStop.h"
#include "TPhStopDisplay.h"
#include "TPhMCHit.h"
#include "TPhMCTrack.h"
#include "TPhDetector.h"
#include "TPhLayer.h"
#include "TPhSensor.h"
#include "TPhEvent.h"
#include "TPhVertex.h"
#include "TPhMomentumVector.h"
#include "TPolyLine.h"
#include "TPolyMarker.h"
#include "TH2.h"
#include "TNtuple.h"

#include "TPhObjectContainer.h"


ClassImp(TPhStopDisplay)


TPhStopDisplay::TPhStopDisplay()
{
  fStuckMCTracksBuffer   = new TPhObjectContainer("StuckMCTracks");
  //printf("DrawRawEvent: \n");
}

TPhStopDisplay::~TPhStopDisplay() 
{
}

void TPhStopDisplay::DrawRawEvent(TPhObjectContainer *fStuckTracksBuffer )
{
  TPhTrack *track;
  TPhMCHit   *hit;
  Float_t   theta,phi;
  Int_t num=0;

  if(fVerbose==1)printf("DrawRawEvent: %d \n",fStuckTracksBuffer->GetObjectList()->GetEntries());

  TIter NextTrack(fStuckTracksBuffer ->GetObjectList());  
  while((track = (TPhTrack *) NextTrack()) )
    { 
      TIter NextHit(track->GetHitList());
      while((hit = (TPhMCHit *) NextHit()))
	{
	  //GetMCTrack(hit->GetTrackNo())->Print("10");
	  if(fVerbose==1)printf("DrawRawEvent: %10.9f\n ",hit->GetDt());
      	  fStop->GetThetaPhi(hit,&theta,&phi);
	  if(fVerbose==1)printf("DrawRawEvent: %f %f \n",theta,phi);
	  xr[num]= new TMarker(theta,phi,20+hit->GetLayer());
	  xr[num]->Draw();
	  xr[num]->SetMarkerColor(1);
	  xr[num]->SetMarkerSize(0.8);
	  num++;
	}
    }
}

void TPhStopDisplay::DrawMCEvent(TPhObjectContainer *StuckMCTracksBuffer)
{
    TPhMCTrack *track;


  if(fVerbose==1)printf("DrawMCEvent: %d \n",StuckMCTracksBuffer->GetObjectList()->GetEntries());
  TIter NextTrack(StuckMCTracksBuffer->GetObjectList());  
  while( (track = (TPhMCTrack *) NextTrack()) )
    {
      DrawMCTrack(track);
    }

}
void TPhStopDisplay::DrawMCTrack(TPhMCTrack *track)
{
  Int_t   num;
  TPhMCHit *hit;
  TObjArray *HitList;
  Float_t theta,phi;
  
  HitList = track->GetHitList();
  if(HitList)
    {
      fPolyLine = new TPolyLine(track->GetNHits());
      num = 0;
      
      TIter NextHit(track->GetHitList());
      while( (hit = (TPhMCHit *) NextHit()))
	{
	  fStop->GetThetaPhi(hit,&theta,&phi);
	  fPolyLine->SetPoint(num,theta,phi); 
	  num++;
	}
      fPolyLine->SetLineColor(1);
      if(track->GetGPid()== 8||track->GetGPid()== 9) fPolyLine->SetLineColor(2);
      if(track->GetGPid()==11||track->GetGPid()==12) fPolyLine->SetLineColor(3);
      if(track->GetGPid()==14||track->GetGPid()==15) fPolyLine->SetLineColor(4);
      fPolyLine->Draw();
    }
}


  //one track reconstruction program testing
TPhObjectContainer *TPhStopDisplay::MethodEvl(TPhEvent *MCEvent, 
				              TPhObjectContainer *fStuckTracksBuffer, Int_t* Test)
{
  TPhObjectContainer *datMC  = (TPhObjectContainer *) MCEvent->GetObject("MCTracks");
  TPhMCTrack         *MCtrack;
  TPhMCTrack         *Rtrack;
  Int_t okr=0, okmc=0;

  if(fVerbose==1)printf("MethodEvl: 0\n");
  Int_t ncandM = fStuckTracksBuffer->GetEntries();

  if(fVerbose==1)printf("MethodEvl: 01 \n");


  fStuckMCTracksBuffer =  PickStpPtl(datMC);
  Int_t ncandMC= fStuckMCTracksBuffer->GetEntries();

  if(fVerbose==1)printf("MethodEvl: 1\n");

  //return fStuckMCTracksBuffer;

  if(ncandM == 0 && ncandMC== 0 )
    {
      return fStuckMCTracksBuffer;
    }
  if(fVerbose==1)printf("MethodEvl: %d 11\n",ncandM);
  if(ncandM){
    okr=1;
    PrintEvent(fStuckTracksBuffer);
    if(fVerbose==1)printf("MethodEvl: 2\n");
    
    TIter NextTrackR(fStuckTracksBuffer->GetObjectList());  
    while((Rtrack = (TPhMCTrack *) NextTrackR()))
      {
	if(Rtrack->GetGPid()== 8)Test[3]=Test[3]+1; 
	if(Rtrack->GetGPid()==11)Test[4]=Test[4]+1; 
	if(Rtrack->GetGPid()==14)Test[5]=Test[5]+1; 
	Int_t ok=1;
	if(fVerbose==1)printf("MethodEvl: 3\n");
	if(ncandMC)
	  {
	    TIter NextTrackMC1(datMC->GetObjectList());
	    while((MCtrack = (TPhMCTrack *) NextTrackMC1()))
	      {
		if(MC2R(MCtrack,Rtrack))ok=0;
	      }
	  }
	if(fVerbose==1)printf("MethodEvl: 4\n");
	if(ok == 1)
	  {
	    //not a stopping ptls 
	    if(Rtrack->GetGPid()== 8)Test[15]=Test[15]+1;
	    if(Rtrack->GetGPid()==11)Test[16]=Test[16]+1;
	    if(Rtrack->GetGPid()==14)Test[17]=Test[17]+1;
	    Int_t MCID = RID(Rtrack);
	    //no of nst. g pi in recon. pi, K, P
	    if(Rtrack->GetGPid()== 8 && (MCID == 8 || MCID == 9))Test[18]=Test[18]+1;
	    if(Rtrack->GetGPid()==11 && (MCID == 8 || MCID == 9))Test[19]=Test[19]+1;
	    if(Rtrack->GetGPid()==14 && (MCID == 8 || MCID == 9))Test[20]=Test[20]+1;
	    //no of nst. g K in recon. pi, K, P
	    if(Rtrack->GetGPid()== 8 && (MCID ==11 || MCID ==12))Test[21]=Test[21]+1;
	    if(Rtrack->GetGPid()==11 && (MCID ==11 || MCID ==12))Test[22]=Test[22]+1;
	    if(Rtrack->GetGPid()==14 && (MCID ==11 || MCID ==12))Test[23]=Test[23]+1;
	    //no of nst. g P in recon. pi, K, P
	    if(Rtrack->GetGPid()== 8 && (MCID ==14 || MCID ==15))Test[24]=Test[24]+1;
	    if(Rtrack->GetGPid()==11 && (MCID ==14 || MCID ==15))Test[25]=Test[25]+1;
	    if(Rtrack->GetGPid()==14 && (MCID ==14 || MCID ==15))Test[26]=Test[26]+1;
	    //no of random hit ptls K in recon. pi, K, P
	    if(Rtrack->GetGPid()== 8 && MCID == 0)Test[27]=Test[27]+1;
	    if(Rtrack->GetGPid()==11 && MCID == 0)Test[28]=Test[28]+1;
	    if(Rtrack->GetGPid()==14 && MCID == 0)Test[29]=Test[28]+1;
	  } 
      }
    
  }
  if(ncandMC==0)
    {
      if(fVerbose==1)printf("no stoping ptls in MC event\n");
    }
  else
    {
      okmc=1;
      if(fVerbose==1)printf("%d stoping ptls in MC event\n",datMC->GetObjectList()->GetEntries());
      if(fVerbose==1)PrintMCEvent(fStuckMCTracksBuffer);

      TIter NextTrack(datMC->GetObjectList());  
      while((MCtrack = (TPhMCTrack *) NextTrack()))
	{
	  if(MCtrack->GetGPid()== 8||MCtrack->GetGPid()== 9)Test[0]=Test[0]+1; 
	  if(MCtrack->GetGPid()==11||MCtrack->GetGPid()==12)Test[1]=Test[1]+1; 
	  if(MCtrack->GetGPid()==14||MCtrack->GetGPid()==15)Test[2]=Test[2]+1; 
	  if(MCtrack->GetGPid()== 8)Test[30]=Test[30]+1;
	  if(MCtrack->GetGPid()==11)Test[31]=Test[31]+1; 
	  if(MCtrack->GetGPid()==14)Test[32]=Test[32]+1; 
	  if(okr)
	    {
	      Int_t id;
	      TIter NextTrackR1(fStuckTracksBuffer->GetObjectList());
	      while((Rtrack = (TPhMCTrack *) NextTrackR1()))
		{
		  id=0;
		  id=MC2R(MCtrack,Rtrack);
		  if(id == 1)
		    {
		      //correct identyfication
		      if((MCtrack->GetGPid()== 8||MCtrack->GetGPid()== 9) && Rtrack->GetGPid()== 8)Test[6]=Test[6]+1;
		      if((MCtrack->GetGPid()==11||MCtrack->GetGPid()==12) && Rtrack->GetGPid()==11)Test[7]=Test[7]+1;
		      if((MCtrack->GetGPid()==14||MCtrack->GetGPid()==15) && Rtrack->GetGPid()==14)Test[8]=Test[8]+1;

		      // missidentification of a stopping pion
		      if((MCtrack->GetGPid()== 8||MCtrack->GetGPid()== 9) && Rtrack->GetGPid()==11)Test[ 9]=Test[ 9]+1;
		      if((MCtrack->GetGPid()== 8||MCtrack->GetGPid()== 9) && Rtrack->GetGPid()==14)Test[10]=Test[10]+1;

		      // missidentification of a stopping kaon
		      if((MCtrack->GetGPid()==11||MCtrack->GetGPid()==12) && Rtrack->GetGPid()== 8)Test[11]=Test[11]+1;
		      if((MCtrack->GetGPid()==11||MCtrack->GetGPid()==12) && Rtrack->GetGPid()==14)Test[12]=Test[12]+1;

		      // missidentification of a stopping proton
		      if((MCtrack->GetGPid()==14||MCtrack->GetGPid()==15) && Rtrack->GetGPid()== 8)Test[13]=Test[13]+1;
		      if((MCtrack->GetGPid()==14||MCtrack->GetGPid()==15) && Rtrack->GetGPid()==11)Test[14]=Test[14]+1;
		    } 
		}
	    }
	}
    }

  printf(" %10d %10d %10d - no of MC stopping ptls \n",                   Test[0] ,Test[1] ,Test[2] );
  printf(" %10d %10d %10d - no of MC stopping ptls with chge>0 \n",       Test[30],Test[31],Test[32]);
  printf(" %10d %10d %10d - no of reconstructed ptls\n",                  Test[3] ,Test[4] ,Test[5] );
  printf(" %10d %10d %10d - no of true(stopping) ptls in rec. ptls\n",    Test[6] ,Test[7] ,Test[8] );
  printf(" %10d %10d %10d - no of nst. ptls in rec. ptls\n",              Test[15],Test[16],Test[17]);
  printf(" %10d %10d %10d - no of nst. g pi in recon. pi, K, P\n",        Test[18],Test[19],Test[20]);
  printf(" %10d %10d %10d - no of nst. g K  in recon. pi, K, P\n",        Test[21],Test[22],Test[23]);
  printf(" %10d %10d %10d - no of nst. g P  in recon. pi, K, P\n",        Test[24],Test[25],Test[26]);
  printf(" %10d %10d %10d - no of random hit ptls K in recon. pi,K,P\n\n",Test[27],Test[28],Test[29]);

  return fStuckMCTracksBuffer;
}

TPhObjectContainer*  TPhStopDisplay::PickStpPtl(TPhObjectContainer* datMC)
{
  TPhMCTrack  *track;
  TPhMCHit    *hit,*hitlast;
  TObjArray   *HitList;
  Int_t ok,ihit;

  if(fVerbose==1)printf("PickStpPtl: \n");

  if(fVerbose==1)printf("PickStpPtl: %d \n",datMC->GetObjectList()->GetEntries());  

  TIter NextTrack(datMC->GetObjectList());  
  while((track = (TPhMCTrack *) NextTrack()))
    {
      
      if(fVerbose==1)printf("PickStpPtl: %d %d %d \n",track->GetNHits(),kNLayersStop,kNLayersStart );
      if(fVerbose==1)track->Print("10");
      if(track->GetNHits()-1<=kNLayersStop && track->GetNHits()-1>=kNLayersStart )
	{
	  if(fVerbose==1)printf("PickStpPtl: 1\n");
	  HitList = track->GetHitList();
	  if(fVerbose==1)printf("PickStpPtl: 2\n");
	  hitlast = (TPhMCHit *)HitList->Last();
      if(fVerbose==1){
	const Char_t *name=(fDetector->GetSensor(hitlast->GetSensorLabel()))->GetName();
	printf("PickStpPtl: %s 3\n",name);
      }
	  Float_t stop_index= hitlast->GetDt()*1000000000.;
	  if(fVerbose==1)printf("PickStpPtl: 4\n");

	  if(fVerbose==1)printf("PickStpPtl: %f  %f \n",stop_index,fStop->GetStopMass(track));

	  Float_t mass = 1000* fStop->GetStopMass(track);
	  if( stop_index > .5  )
	    {      
	      ok=1; 
	      ihit=0;
	      if( mass < 0.05 )ok=0;
	      TIter NextHit(track->GetHitList());
	      while((hit = (TPhMCHit *) NextHit()))
		{
		  if( ihit!=hit->GetLayer() || hit->GetX()<0.0 || hit->GetDe() < kdE )ok=0;
		  ihit++;
		}
	      if(ok==1)
		{
		  if(fVerbose==1)printf("MC stopping track\n");
		  fStuckMCTracksBuffer->Add(track);
		}
	    }
	}
    }

  if(fVerbose==1)printf("PickStpPtl: leaving %d \n",
			fStuckMCTracksBuffer->GetObjectList()->GetEntries());  

  return fStuckMCTracksBuffer;
}

void TPhStopDisplay::PrintEvent(TPhObjectContainer *fStuckTracksBuffer)
{
  TPhMCHit    *hit;
  TPhTrack    *track;
  Float_t      theta,phi;
  Int_t        itra=0;

  TIter NextTrack((fStuckTracksBuffer->GetObjectList()));
  while((track = (TPhTrack *) NextTrack()))
    {
      if(fVerbose==1)printf("reconstructed track with  %d hits: Stop mass %f, Eloss  %f \n",
	     track->GetNHits(),1000*fStop->GetStopMass(track),1000*fStop->GetEloss(track));
      itra++;
      Int_t ihit=0;
      
      TIter NextHit((track->GetHitList()));
      while((hit = (TPhMCHit *) NextHit()))
	{
	  ihit++;
	  fStop->GetThetaPhi(hit,&theta,&phi);
	  if(fVerbose==1){
	    const Char_t *name=(fDetector->GetSensor(hit->GetSensorLabel()))->GetName();
	    printf("PrintEvent:%s,th,ph,dE: %f %f %f,gPId,p: %d %f \n",
		   name,theta,phi,hit->GetDe(),
		   GetMCTrack(hit->GetTrackNo())->GetGPid(), GetMCTrack(hit->GetTrackNo())->GetP());
	  }
	}
    }
  return;
}

Int_t TPhStopDisplay::MC2R( TPhMCTrack *MCtrack,  TPhMCTrack *Rtrack )
{
  Int_t id=1;
  
  TPhMCHit  *MCHit,*RHit;
  TObjArray *MCHitList;
  TObjArray *RHitList;
  
  if(MCtrack->GetNHits()!=Rtrack->GetNHits())return 0;
  
  MCHitList = MCtrack->GetHitList();
  RHitList  = Rtrack->GetHitList();

  for(Int_t i=0;i< Rtrack->GetNHits();i++)
    {
      MCHit =  (TPhMCHit *) MCHitList->At(i);
      RHit  =  (TPhMCHit *) RHitList->At(i);
      if( MCHit->GetX()  !=  RHit->GetX()   )id=0;
      if( MCHit->GetY()  !=  RHit->GetY()   )id=0;
      if( MCHit->GetZ()  !=  RHit->GetZ()   )id=0;
      if( MCHit->GetDe() !=  RHit->GetDe()  )id=0;
    }
  return id;
}

Int_t TPhStopDisplay::RID( TPhTrack *Rtrack )
{
  Int_t ok=1;

  TPhMCHit  *RHit;
  TObjArray *RHitList;

  RHitList = Rtrack->GetHitList();

  RHit  =  (TPhMCHit *) RHitList->At(0);
  Int_t IdFirstHit = GetMCTrack(RHit->GetTrackNo())->GetGPid();
  Int_t IdNextHit;
  for(Int_t i=1;i< Rtrack->GetNHits();i++)
    {
      RHit  =  (TPhMCHit *) RHitList->At(i);
      IdNextHit = GetMCTrack(RHit->GetTrackNo())->GetGPid();
      if( IdNextHit != IdFirstHit )ok=0;
    }
  if(ok)ok=IdFirstHit;
  return ok;
}

void TPhStopDisplay::PrintMCEvent(TPhObjectContainer *fStuckTracksBuffer)
{
  TPhMCHit    *hit;
  TPhMCTrack  *track;
  Float_t     theta,phi;
  Int_t       itra=0;

  TIter NextTrack(fStuckTracksBuffer->GetObjectList());
  while((track = (TPhMCTrack *) NextTrack()))
    {
      itra++;
      if(fVerbose==1)printf("track %d with %d hits: mass  %f, p %f, Stop mass %f, Eloss %f\n",
			    itra,track->GetNHits(),track->GetMass(),track->GetP(),
			    1000*fStop->GetStopMass(track),1000*fStop->GetEloss(track));
      Int_t ihit=0;
      
      TIter NextHit(track->GetHitList());
      while((hit = (TPhMCHit *) NextHit()))
	{
	  ihit++;
	  fStop->GetThetaPhi(hit,&theta,&phi);
	  if(fVerbose==1) {
	    const Char_t *name=(fDetector->GetSensor(hit->GetSensorLabel()))->GetName();
	    printf("PrintMCEvent: %s th,ph,dE: %f %f %f\n",
		   name,theta,phi,hit->GetDe());
	  }
	}
    }
    
  return;
}



void TPhStopDisplay::Clear(TPhObjectContainer *StuckTracksBuffer)
{
  TPhTrack *track;

  if(StuckTracksBuffer)
    {
      
      if(0)printf("\n Clear 1 : \n");
      TIter NextTrack((StuckTracksBuffer->GetObjectList()));  
      while((track  =  (TPhTrack *) NextTrack()) )
	{ 
	  StuckTracksBuffer->GetObjectList()->Remove(track);
	  //delete track;
	} 
    }
  StuckTracksBuffer->Clear();
  if(0)printf("\n Clear 2 : \n");
}

void  TPhStopDisplay::MassvsEloss(TPhEvent *event, TH2F *h1, TH2F *h2, TH2F *h3)
{
  TPhMCTrack  *track;
  TPhMCHit    *hit;

  Int_t       ok,i;
  Float_t     stop_index;

  if(fVerbose==1)printf("MassvsEloss: \n");

  TPhObjectContainer *datMC  = (TPhObjectContainer *) event->GetObject("MCTracks");

  TIter NextTrack((datMC->GetObjectList()));  
  
  while((track = (TPhMCTrack *) NextTrack()))
    {
      if(track->GetNHits()-1<=kNLayersStop && track->GetNHits()-1>=kNLayersStart )
	{
	  i  = 0;
	  ok = 1;
	  TIter NextHit((track->GetHitList()));
	  while((hit = (TPhMCHit *) NextHit()))
	    {
	      if(fVerbose==1)printf("DAngle: %d %f %d \n",i,hit->GetDe(),hit->GetLayer() );
	      if( i!=hit->GetLayer() || hit->GetX()<0.0 || hit->GetDe() < kdE )ok=0;
	      stop_index = hit->GetDt()*1000000000.;
	      if( i == 4 &&  stop_index < 0.5 )ok=0;
	      i++;
	    }
	  if(fVerbose==1)printf("DAngle: %d %f \n",ok,stop_index);
	  	  
	  //Float_t mass =1000*fStop->GetStopMass(track);			
	  //Float_t Eloss=1000*fStop->GetEloss(track);			
	  if(ok==1)
	    {
	      Float_t mass  = 1000*fStop->GetStopMass(track);			
	      Float_t Eloss = 1000*fStop->GetEloss(track);			
	      if(track->GetGPid()== 8||track->GetGPid()== 9)h1->Fill(Eloss,mass);
	      if(track->GetGPid()==11||track->GetGPid()==12)h2->Fill(Eloss,mass);
	      if(track->GetGPid()==14||track->GetGPid()==15)h3->Fill(Eloss,mass);
	      if(fVerbose==1)printf("Mass Eloss: %f %f  \n",mass,Eloss);
	    }
	}
    }
  return;
}

void  TPhStopDisplay::DAngle_Theta(TPhEvent *event, TH1F *h0, TH1F *h1, TH1F *h2, TH1F *h3, TH1F *h4)
{
  TPhMCTrack  *track;
  TPhMCHit    *hit;
  Int_t        ok,i;
  Float_t      stop_index;
  Float_t      thetaprev,theta,phi;
  if(fVerbose==1)printf("DAngle: \n");
  
  TPhObjectContainer *datMC  = (TPhObjectContainer *) event->GetObject("MCTracks");
  
  TIter NextTrack(datMC->GetObjectList());  
  while((track = (TPhMCTrack *) NextTrack()))
    {
      if(track->GetNHits()-1<=kNLayersStop && track->GetNHits()-1>=kNLayersStart )
	{
	  i  = 0;
	  ok = 1;
	  TIter NextHit(track->GetHitList());
	  while((hit = (TPhMCHit *) NextHit()))
	    {
	      if(fVerbose==1)printf("DAngle: %d %f %d \n",i,hit->GetDe(),hit->GetLayer() );
	      if( i!=hit->GetLayer() || hit->GetX()<0.0 || hit->GetDe() < kdE )ok=0;
	      stop_index= hit->GetDt()*1000000000.;
	      if( i == 4 &&  stop_index < 0.5 )ok=0;
	      i++;
	    }
	  if(fVerbose==1)printf("DAngle: %d %f \n",ok,stop_index);
	  if(ok)
	    {
	      i  = 0;
	      TIter NextHit(track->GetHitList());
	      while((hit = (TPhMCHit *) NextHit()))
		{
		  fStop->GetThetaPhi(hit,&theta,&phi);
		  if(i>0)if(fVerbose==1)printf("DAngle: %f %f %f \n",
					       thetaprev,theta,track->GetTheta() );
		  if(i==0)h0->Fill(fabs(r2d*track->GetTheta() - theta));
		  if(i==1)h1->Fill(fabs(thetaprev - theta));
		  if(i==2)h2->Fill(fabs(thetaprev - theta));
		  if(i==3)h3->Fill(fabs(thetaprev - theta));
		  if(i==4)h4->Fill(fabs(thetaprev - theta));
		  i++;
		  thetaprev=theta;
		  //phiprev=phi;
		}
	    }
 	}
    }
  return;
}

void  TPhStopDisplay::DAngle_Phi(TPhEvent *event, TH1F *h0, TH1F *h1, TH1F *h2, TH1F *h3, TH1F *h4, TH2F *h)
{
  TPhMCTrack  *track;
  TPhMCHit    *hit;
  Int_t        ok,i;
  Float_t      stop_index;
  Float_t      phiprev,theta,phi;
  Float_t da1,da2;
  if(fVerbose==1)printf("DAngle: \n");
  
  TPhObjectContainer *datMC  = (TPhObjectContainer *) event->GetObject("MCTracks");
  
  TIter NextTrack(datMC->GetObjectList());  
  while((track = (TPhMCTrack *) NextTrack()))
    {
      if((track->GetNHits()-1<=kNLayersStop && track->GetNHits()-1>=kNLayersStart) )
	{
	  i  = 0;
	  ok = 1;
	  TIter NextHit(track->GetHitList());
	  while((hit = (TPhMCHit *) NextHit()))
	    {
	      if(fVerbose==1)printf("DAngle: %d %f %d \n",i,hit->GetDe(),hit->GetLayer() );
	      if( i!=hit->GetLayer() || hit->GetX()<0.0 || hit->GetDe() < kdE )ok=0;
	      stop_index= hit->GetDt()*1000000000.;
	      if( i == 4 &&  stop_index < 0.5 )ok=0;
	      i++;
	    }
	  if(fVerbose==1)printf("DAngle: %d %f \n",ok,stop_index);
	  if(ok)
	    {
	      i  = 0;
	      TIter NextHit(track->GetHitList());
	      while((hit = (TPhMCHit *) NextHit()))
		{
		  fStop->GetThetaPhi(hit,&theta,&phi);
		  if(i>0)if(fVerbose==1)printf("DAngle: %f %f %f \n",
					       phiprev-phi,phi,r2d*atan(track->GetPy()/track->GetPx()));
		  if(i==0)h0->Fill(fabs(r2d*atan(track->GetPy()/track->GetPx()) - phi));
		  if(i==1){h1->Fill(fabs(phiprev - phi));da1=phiprev - phi;}
		  if(i==2){h2->Fill(fabs(phiprev - phi));da2=phiprev - phi;}
		  if(i==3)h3->Fill(fabs(phiprev - phi));
		  if(i==4)h4->Fill(fabs(phiprev - phi));
		  i++;
		  phiprev=phi;
		}
	      h->Fill(da1,da2);
	    }
 	}
    }
  return;
}
TPhMCTrack *TPhStopDisplay::GetMCTrack(Int_t TrackNo)
{
  TPhObjectContainer *datMC  = (TPhObjectContainer *) fEvent->GetObject("MCTracks");
  TPhMCTrack         *track;
  TIter NextTrack(datMC->GetObjectList());  
  while((track = (TPhMCTrack *) NextTrack()))
    {
      printf("TPhStopDisplay::GetMCTrack: TrackNo=%d , %d \n",TrackNo,track->GetTrackNo());
      if(TrackNo==track->GetTrackNo())return track;
    }
  return 0;
}
