      SUBROUTINE DETGEOM(IDET, IDETSHP, NDETPAR, DETPAR, DETPOS, DETROT)
*************************************************************************
*   Extracts from GEANT banks information on the geometry of active
*   detector IDET that are not available from RHSIL common:
*    *IDETSHP  - GEANT shape number
*    *NDETPAR* - number of GEANT shape parameters
*     DETPAR*  - GEANT shape parameters (volume dimensions)
*     DETPOS*  - position of the detector
*     DETROT*  - effective rotation matrix
*
* History:
*  05-Nov-97   K.W.   Corrected translation vector calculations
*                     in the case of multiple rotations
*  05-Sep-97   K.W.   No additional rotation for matrix # 0
*  20-Aug-97   K.W.   Creation
*************************************************************************

      IMPLICIT NONE

      INTEGER IDET, IDETSHP, NDETPAR
      REAL DETPAR(40), DETPOS(3), DETROT(9)

*KEEP,GCBANK.
      INTEGER IQ,LQ,NZEBRA,IXSTOR,IXDIV,IXCONS,LMAIN,LR1,JCG
      INTEGER KWBANK,KWWORK,IWS
      REAL GVERSN,ZVERSN,FENDQ,WS,Q
C
      PARAMETER (KWBANK=69000,KWWORK=5200)
      COMMON/GCBANK/NZEBRA,GVERSN,ZVERSN,IXSTOR,IXDIV,IXCONS,FENDQ(16)
     +             ,LMAIN,LR1,WS(KWBANK)
      DIMENSION IQ(2),Q(2),LQ(8000),IWS(2)
      EQUIVALENCE (Q(1),IQ(1),LQ(9)),(LQ(1),LMAIN),(IWS(1),WS(1))
      EQUIVALENCE (JCG,JGSTAT)
      INTEGER       JDIGI ,JDRAW ,JHEAD ,JHITS ,JKINE ,JMATE ,JPART
     +      ,JROTM ,JRUNG ,JSET  ,JSTAK ,JGSTAT,JTMED ,JTRACK,JVERTX
     +      ,JVOLUM,JXYZ  ,JGPAR ,JGPAR2,JSKLT
C
      COMMON/GCLINK/JDIGI ,JDRAW ,JHEAD ,JHITS ,JKINE ,JMATE ,JPART
     +      ,JROTM ,JRUNG ,JSET  ,JSTAK ,JGSTAT,JTMED ,JTRACK,JVERTX
     +      ,JVOLUM,JXYZ  ,JGPAR ,JGPAR2,JSKLT
C
*KEEP,GCNUM.
      COMMON/GCNUM/NMATE ,NVOLUM,NROTM,NTMED,NTMULT,NTRACK,NPART
     +            ,NSTMAX,NVERTX,NHEAD,NBIT
      COMMON /GCNUMX/ NALIVE,NTMSTO
C
      INTEGER      NMATE ,NVOLUM,NROTM,NTMED,NTMULT,NTRACK,NPART
     +            ,NSTMAX,NVERTX,NHEAD,NBIT ,NALIVE,NTMSTO
C
*KEEP,RHSIL.
C RHSIL.CMN: PHOBOS detector plane dimensions, positions, and
c granularity; UGC parameters
c The actual and maximum numbers of detector planes and detector hit
c parameters.  Their default values are defined in RHSILD.INC.
c 12-Dec-97 K. W.       PADSOLD and PADSNEW from UGCSET moved to a common
c  4-Nov-97 K. W.       Increased number of PADS parameters to 10
c                       Increased NSLPM to 800
c  1-Jul-97 K. W.       Added data for GEANT pixelization (GSDVN)
c  1-May-97 R. V.       Increased NSLPM to 500
c  3-MAR-97 K. W.       Removed SPL, added PADS data
C  3-Jan-97 K. W.       Increased NSLPM to 180
c  3-Jul-96 K. W.       Geometry version number added
c  5-Apr-96 D. McL.     Moved data value of UgcpMax to RHSILD
c  ...
c    Mar-92 D.McLeod    Creation
c Storage limit for number of silicon planes:
      INTEGER NSLPM
      PARAMETER (NSLPM=800)
c Storage limit for number of parameters for each hit:
      integer NSipMaxp
      parameter (NSipMaxp = 12)
c Safety limit for number of parameter values that may be entered in
c a UGC text input record:
      integer UgcpMaxp
      parameter (UgcpMaxp = 10)
c Number of silicon planes in use:
      integer NSLP
c Additional information on detectors - pad sizes:
C  DETNAME  - name of the detector volume
C  DIVXNAME - name for division in X direction
C  DIVYNAME - name for division in Y direction
C  DIVZNAME - name for division in Z direction
C  NDIVX    - number of divisions in X direction
C  NDIVY    - number of divisions in Y direction
C  NDIVZ    - number of divisions in Z direction
C  IPADFL   - pad type flag
C  PADn   - four pad parameters
C             (pad size in X, Y, Z direction for IPADFL=1 for example)
      CHARACTER*4 DETNAME(NSLPM), DIVXNAME(NSLPM),
     +             DIVYNAME(NSLPM), DIVZNAME(NSLPM)
      INTEGER NDIVX(NSLPM), NDIVY(NSLPM), NDIVZ(NSLPM)
      REAL PAD1(NSLPM),PAD2(NSLPM),PAD3(NSLPM),PAD4(NSLPM),PAD5(NSLPM)
      REAL PAD6(NSLPM),PAD7(NSLPM),PAD8(NSLPM),PAD9(NSLPM),PAD10(NSLPM)
      INTEGER NDETS, IPADFL(NSLPM)
      LOGICAL PADSOLD, PADSNEW
      COMMON /RHPADS/ NDETS, PADSOLD, PADSNEW,
     +       DETNAME, DIVXNAME, DIVYNAME, DIVZNAME,
     +       NDIVX, NDIVY, NDIVZ,
     +       IPADFL, PAD1, PAD2, PAD3, PAD4, PAD5,
     +               PAD6, PAD7, PAD8, PAD9, PAD10
c Number of silicon planes - compared with final value of NDETS
      COMMON /RHSIL/ NSLP
c UGC parameter information:
      integer UgcpMax
      real UGCpars(UgcpMaxp)
c Declare silicon plane parameters; their default values are specified
c in RHSILD.INC
      integer NSIP
c Names of parameters:
      CHARACTER*4 SINAMH(NSipMaxp)
c Mumber of bits stored for each parameter:
      INTEGER SIBITH(NSipMaxp)
c Multiplicative scale factors and origins, defined so that
c   Stored value = (Parameter value + SIORIG) * SIFACT:
      REAL SIFACT(NSipMaxp), SIORIG(NSipMaxp)
c Common for access to UGC parameters and hit parameter definitions:
      common /UGCPAR/ UgcpMax, UGCpars,
     1                NSIP, SINAMH, SIBITH, SIORIG, SIFACT
      real GEOV  !  geometry version number
      common /ugGEOV/ GEOV
*KEND.

      CHARACTER*4 CNAME
      INTEGER NR,JR,I, N,J,JJ, IV,JD,JDV,JDVV,KV
      INTEGER ISLVOL,ISLSHP,ISLJ,ISLNPAR
      INTEGER JDMAX
      PARAMETER (JDMAX=30)
      INTEGER JDLINK(JDMAX),JDNIN(JDMAX),JDIN(JDMAX), JDROT(JDMAX)
      REAL TRXJD(JDMAX), TRYJD(JDMAX), TRZJD(JDMAX)
      REAL*8 TRX, TRY, TRZ, TRXS, TRYS, TRZS
      REAL*8 R1,R2,R3,R4,R5,R6,R7,R8,R9, ROT(9)

      INTEGER NPARMAX
      PARAMETER (NPARMAX=40)
      REAL PAR(NPARMAX), POS(3)

      SAVE N, ISLSHP, ISLNPAR, PAR, POS, ROT


      IF(IDET .EQ. N)   GO TO 700   !  detector requested previously

c
c  new detector - parameters have to be calculated
c
      N = IDET
      ISLVOL = 0
      DO  IV=1,NVOLUM    !  search for the detector volume
         KV = IQ(JVOLUM+IV)
         CALL UHTOC(KV, 4, CNAME, 4)
         IF(CNAME .EQ. DETNAME(N))   THEN
            ISLVOL = IV
            GO TO 110
         ENDIF
      ENDDO
  110 CONTINUE
      IF(ISLVOL .EQ. 0)   THEN
         WRITE(*,*) ' *** ERROR IN DETGEOM - DETECTOR:  ',
     +                DETNAME(N), '   NOT DEFINED IN THE GEOMETRY'
         GO TO 900
      ENDIF
c
C      find parameters of the volume
c
      ISLJ = LQ(JVOLUM-ISLVOL)
      ISLSHP = Q(ISLJ+2)
      ISLNPAR = Q(ISLJ+5)
      IF(ISLNPAR .GT. NPARMAX .OR. ISLNPAR .GT. NDETPAR)  THEN
           I = NPARMAX
           IF(I .GT. NDETPAR)   I = NDETPAR
           WRITE(*,*) ' *** WARNING - DETGEOM - TOO MANY ',
     +       'SHAPE PARAMETERS ', ISLNPAR, '    IN VOLUME ',
     +         DETNAME(N), '   TRUNCATED TO ', I
           ISLNPAR = I
      ENDIF
      DO  I=1,ISLNPAR
         PAR(I) = Q(ISLJ+6+I)
      ENDDO

C      find the position of the volume in the volumes tree
C      calculate effective translation and
C      find the numbers of rotation matrices for this volume
      JD = 1    ! depth of the volume in the tree
      JDLINK(1) = LQ(JVOLUM-1)
      JDNIN(1) = Q(JDLINK(1)+3)
      JDIN(1) = 1
  120 CONTINUE
        JDV = LQ(JDLINK(JD)-JDIN(JD))   ! link to the lower level volume
        IV = Q(JDV+2)
        JDROT(JD) = Q(JDV+4)
        TRXJD(JD) = Q(JDV+5)
        TRYJD(JD) = Q(JDV+6)
        TRZJD(JD) = Q(JDV+7)
        IF(IV .EQ. ISLVOL)  GO TO 150  ! volume found

        JDVV = LQ(JVOLUM-IV)
        IF(Q(JDVV+3) .GT. 0)   THEN   ! there are volumes deeper
             JD = JD + 1
             JDLINK(JD) = JDVV
             JDNIN(JD) = Q(JDVV+3)
             JDIN(JD) = 1
             GO TO 120
        ELSE    ! try next volume on the same level or upper
  125       CONTINUE
            IF(JDIN(JD) .LT. JDNIN(JD))   THEN
                JDIN(JD) = JDIN(JD) + 1    ! next volume on this level
                GO TO 120
            ELSE
                JD = JD -1   ! go one level upper
                IF(JD .LT. 0)  THEN
                   WRITE(*,*) ' *** ERROR IN DETGEOM - DETECTOR  ',
     +                DETNAME(N), '   NOT POSITIONED IN THE TREE'
                   GO TO 900
                ENDIF
                GO TO 125
            ENDIF
        ENDIF

  150 CONTINUE   !  detector found in the tree
      TRX = 0.0
      TRY = 0.0
      TRZ = 0.0

      ROT(1) = 1.0
      ROT(2) = 0.0
      ROT(3) = 0.0

      ROT(4) = 0.0
      ROT(5) = 1.0
      ROT(6) = 0.0

      ROT(7) = 0.0
      ROT(8) = 0.0
      ROT(9) = 1.0

      DO  J=1,JD
          JJ = JD - J + 1
          NR = JDROT(JJ)
          IF(NR .GT. 0)  THEN  !   add the actual translation vector and
             JR = LQ(JROTM-NR)  !  rotated previous vector
             IF(JR .GT. 0)  THEN   !  safety check only
                TRXS = DBLE(Q(JR+1)) * TRX +
     +                 DBLE(Q(JR+4)) * TRY +
     +                 DBLE(Q(JR+7)) * TRZ
                TRYS = DBLE(Q(JR+2)) * TRX +
     +                 DBLE(Q(JR+5)) * TRY +
     +                 DBLE(Q(JR+8)) * TRZ
                TRZS = DBLE(Q(JR+3)) * TRX +
     +                 DBLE(Q(JR+6)) * TRY +
     +                 DBLE(Q(JR+9)) * TRZ
                TRX = TRXS + TRXJD(JJ)
                TRY = TRYS + TRYJD(JJ)
                TRZ = TRZS + TRZJD(JJ)
             ENDIF    !  (JR .GT. 0)
          ELSE    !   .NOT. (NR .GT. 0)  ! simply add two vectors (no rotation)
             TRX = TRX + TRXJD(JJ)
             TRY = TRY + TRYJD(JJ)
             TRZ = TRZ + TRZJD(JJ)
          ENDIF   !   (NR .GT. 0)

          NR = JDROT(J)
          IF(NR .GT. 0) THEN  !  rotation matrix 0 = no additional rotation
             JR = LQ(JROTM-NR)
             R1 = Q(JR+1)*ROT(1) + Q(JR+2)*ROT(4) + Q(JR+3)*ROT(7)
             R2 = Q(JR+1)*ROT(2) + Q(JR+2)*ROT(5) + Q(JR+3)*ROT(8)
             R3 = Q(JR+1)*ROT(3) + Q(JR+2)*ROT(6) + Q(JR+3)*ROT(9)
             R4 = Q(JR+4)*ROT(1) + Q(JR+5)*ROT(4) + Q(JR+6)*ROT(7)
             R5 = Q(JR+4)*ROT(2) + Q(JR+5)*ROT(5) + Q(JR+6)*ROT(8)
             R6 = Q(JR+4)*ROT(3) + Q(JR+5)*ROT(6) + Q(JR+6)*ROT(9)
             R7 = Q(JR+7)*ROT(1) + Q(JR+8)*ROT(4) + Q(JR+9)*ROT(7)
             R8 = Q(JR+7)*ROT(2) + Q(JR+8)*ROT(5) + Q(JR+9)*ROT(8)
             R9 = Q(JR+7)*ROT(3) + Q(JR+8)*ROT(6) + Q(JR+9)*ROT(9)
             ROT(1) = R1
             ROT(2) = R2
             ROT(3) = R3
             ROT(4) = R4
             ROT(5) = R5
             ROT(6) = R6
             ROT(7) = R7
             ROT(8) = R8
             ROT(9) = R9
          ENDIF
      ENDDO
      POS(1) = TRX
      POS(2) = TRY
      POS(3) = TRZ

c
c  define output parameters using restored or saved information
c
  700 CONTINUE
      IDETSHP = ISLSHP
      IF(NDETPAR .GE. ISLNPAR)   THEN
         NDETPAR = ISLNPAR
      ELSE
         WRITE(*,*) ' *** WARNING - DETGEOM - TOO MANY ',
     +       'SHAPE PARAMETERS ', ISLNPAR, '    IN VOLUME ',
     +         DETNAME(N), '   TRUNCATED TO ', NDETPAR
      ENDIF
      DO  I = 1,NDETPAR
        DETPAR(I) = PAR(I)
      ENDDO
      DO  I = 1,3
        DETPOS(I) = POS(I)
      ENDDO
      DO  I = 1,9
        DETROT(I) = ROT(I)
      ENDDO

      RETURN

  900 CONTINUE
      CALL STOPER('DETGEOM', 'ERROR IN DETECTOR GEOMETRY', 1)

      RETURN
      END
