      PROGRAM GEPHOB
*Documentation_Block
************************************************************************
*
* Description:
*  This is the main program for the interactive version of the Phobos
*  Monte Carlo. It is copied from the GEANT interactive example program
*  with slight modifications.  Phobos-specific code is in the GUXXX
*  routines.
* File: pmc_src:GEPHOB.FOR
*
* Arguments: none
*
* Called by: system (main program)
*
* Calls:
*  GEANT/KUIP/HIGZ initialization routines KUARGS, GZEBRA, VZERO,
*  KUINIT, KUEXIT, KUTERM, GINTRI, IGINIT, IGWKTY, GEAMON, HPLINT,
*  HERMES, IGSA, UGINIT, GDINIT, TIMEST, TIMEL, KUEXEC, LNBLNK,
*  and UGCONS, and then passes control to KUWHAG or UGCONB.
*
* Implicit inputs, outputs, side effects:
*  Geometry definition file with logical name UGCDATA, read by UGCIN
*  Control file with logical name RHDATA, read by UGINIT
*  See phobos_root:[sim.doc]pmcuser.doc for specifications.

*  No conditions returned.
*
* History:
* Date       Name       Description
*  ----       ----       -----------
* 15-Jul-98  K.W.       Changed NWGEAN, 3.2->5.0M and NWPAW, 0.4->0.5M
*                       (for VMS old values are kept)
* 28-Feb-97  R.V.       Changed NWGEAN, 3.0->3.2M and NWPAW, .5->.4 M
* 23-Sep-96  K.W.       SIMVER initialization moved to UGINIT
* 14-Oct-95  DMcL       Added setup of SERVER data file, reading of
*                       other environment variables, UNIX signal
*                       monitor etc. with preprocessor switches on code,
*                       in routine UGSERV called below
* 21-Nov-93  RV         Removed obsolete GCFLAX include
* 02-Jun-93  RV         Added UGCONS and UGCONB calls to select batch
*                       or interactive mode if ModeSel = 0
* 01-Jan-93  RV         Increase GCBANK to 2.5M
* 02-Dec-92  RV         Changed GCFLAG and GCFLAX to includes; put in
*                       standard template with documentation block
* 03-Aug-92  R. Verdier Increased GCBANK size to 2.3M to run at B = 4.5 T
* 29-Jun-92  CGP        Added EZYLINK external statements to ease the
*                       link statement.
* 06-Jun-92  Chuck Parsons Creation from Geant example, with increased
*                       bank sizes: CHUCK@PIERRE.MIT.EDU
************************************************************************
*End_Documentation_Block
C.
C.    ******************************************************************
C.    *                                                                *
C.    *       The interactive version of GEANT3                        *
C.    *       based on the KUIP command processor                      *
C.    *                                                                *
C.    *       See  KUIP User Guide  CERN/I202                          *
C.    *            R.Brun, P.Zanarini                                  *
C.    *                                                                *
C.    *       GXINT is currently implemented on                        *
C.    *             APOLLO                                             *
C.    *             VAX/VMS                                            *
C.    *             IBM/VM                                             *
C.    *             SUN/SPARC station                                  *
C.    *             DEC station 3100                                   *
C.    *             Silicon Graphics                                   *
C.    *                                                                *
C.    *           =====> IN GEANTDOC   GXINT  = ZINT001 <=====         *
C.    *       Authors:   R.Brun      **********                        *
C.    *                  P.Zanarini  **********                        *
C.    *                                                                *
C.    ******************************************************************
C.
      PARAMETER (NWGEAN=5000000,NWPAW=500000,NWKUIP=60000)
      COMMON/GCBANK/GEANT(NWGEAN)
      COMMON/PAWC/PAW(NWPAW)

*KEEP,FLAG2.
C  PHOBOS flags, run control, operating modes, misc.   File FLAG2.INC
C  14-Nov-95  D. McLeod
*     Glossary:  IPSIG = identity of kill signal sent by user as interrupt
*                EXSERV = flag for existence of external server file
*                SERNAME = name part only of server file, also run name
*                ROOTPATH = program environment pathname (no trailing /)
*                ROOTVERS = version subdirectory e.g. /prod, /test, /dev
*                SIMVER  = version number for the PHOBOS Monte Carlo
      INTEGER IPSIG
      REAL SIMVER
      LOGICAL EXSERV
      CHARACTER SERNAME*20, ROOTPATH*60, ROOTVERS*10
      COMMON/RHFLG2/IPSIG, EXSERV, SIMVER, SERNAME, ROOTPATH, ROOTVERS
*KEEP,GCFLAG.
      COMMON/GCFLAG/IDEBUG,IDEMIN,IDEMAX,ITEST,IDRUN,IDEVT,IEORUN
     +        ,IEOTRI,IEVENT,ISWIT(10),IFINIT(20),NEVENT,NRNDM(2)
      COMMON/GCFLAX/BATCH, NOLOG
      LOGICAL BATCH, NOLOG
C
      INTEGER       IDEBUG,IDEMIN,IDEMAX,ITEST,IDRUN,IDEVT,IEORUN
     +        ,IEOTRI,IEVENT,ISWIT,IFINIT,NEVENT,NRNDM
C
*KEND.
c
      COMMON/GCTIME/TIMINT,TIMEND,ITIME,IGDATE,IGTIME
      INTEGER ITIME,IGDATE,IGTIME
      REAL TIMINT,TIMEND

      COMMON/GCOMIS/ICOMIS,JUINIT,JUGEOM,JUKINE,JUSTEP,JUOUT,JULAST

      COMMON/GCXLUN/LUNIT(128)

      COMMON/CWK/IWK

      EXTERNAL UGLAST,IGTERM

      CHARACTER*80 BATCHF, GTLOG, LOGFIL

c Define the control mechanism:
c If ModeSel = 0, the logical filename CONTROL sets the mode:
c   if CONTROL = "I", the program runs in interactive mode; the user
c     enters GEANT-KUIP commands, in particular TRIG n to run for n
c     events, from the keyboard.
c   if CONTROL = "B", the program runs in batch mode; the number of
c     events is taken from the GCDEFS file.
c   if CONTROL = "anything.KUMAC", the program runs in batch mode,
c     using GEANT-KUIP commands, including TRIG n, taken from the
c     text file specified by CONTROL.
c If ModeSel = 1, the standard interactive GEANT technique is used,
c   in which the name of batch file containing GEANT-KUIP commands
c   is read from the command line in the form MCX/BATCHF=<filename>.
c   This mechanism fails when one attempts to run a program linked
c   with debug information, when an extra debugger input file is
c   required.

      integer ModeSel /0/
C  Local variables:
      INTEGER IERR, NH
*
*----------------------------------------------------------------------
C  executable code:
*
*            Batch or Interactive version ?
*
      BATCHF = ' '
      GTLOG = 'glogon.kumac'
C       Gets command line arguments e.g. MCX/BATCHF=commandfile
      CALL KUARGS('GEPHOB',GTLOG,BATCHF,LOGFIL,IERR)
      IF (IERR .NE. 0) GOTO 999
      NOLOG=.FALSE.
      BATCH=.FALSE.
      IF (BATCHF.NE.' ') BATCH = .TRUE.
      IF (GTLOG.EQ.' ')  NOLOG = .TRUE.
c Reset mode indicators if ModeSel = 0.  UGCONS calls CERNLIB INTRAC
c to see if batch or interactive; UNIX => redirected input implies batch
      if (ModeSel .eq. 0) call UGCONS (BATCH, BATCHF, NOLOG)
*
*           Initialize Memory Manager (ZEBRA)
*
      CALL GZEBRA(NWGEAN)
      NH=-NWPAW
      CALL HLIMIT(NH)
*
      CALL VZERO(ICOMIS,7)
      CALL VZERO(LUNIT,128)
      LUNIT(5)=6
      LUNIT(6)=6
      LUNIT(7)=6
      LUNIT(10)=8
      DO 5 I=11,18
         LUNIT(I)=6
   5  CONTINUE
      LUNIT(19)=8
      LUNIT(81)=7
      LUNIT(82)=7
      LUNIT(83)=7
      LUNIT(84)=7
      LUNIT(89)=7
      LUNIT(91)=8
      LUNIT(97)=7
*
*           Initialize Command Processor (KUIP)
*
      CALL KUINIT(NWKUIP)
      CALL KUEXIT(UGLAST)
      CALL KUTERM(IGTERM)
*
*           Define Menus and Commands
*
      CALL GINTRI
*
*
*           Initialize Graphics (HIGZ with GKS-GRAL and HPLOT)
*
      CALL IGINIT(0)
*
*
*           Request workstation type
*
      IF(BATCH)THEN
         IWK=0
      ELSE
         CALL IGWKTY(IWK)
      ENDIF
*
*            Initialise monitoring
*
      CALL GEAMON(0,' ')
*
*
*           Initialize HPLOT
*
      CALL HPLINT(IWK)
      CALL HERMES(6)
      IF(.NOT.BATCH)CALL IGSA(0)
*
*           Define User Geometry
*
      CALL UGINIT
*
*           Initialize GEANT graphics unless already done
*
      CALL GDINIT
*
*           Keep starting time
*
      IEVENT=0
      CALL TIMEST(1.E10)
      CALL TIMEL(TIMINT)
      CALL KUEXEC('SET/PROMPT ''GEANT >''')
*
*           Execute LOGON macro
*
      IF (.NOT.NOLOG) THEN
          LG=LNBLNK(GTLOG)
          CALL KUEXEC('EXEC '//GTLOG(1:LG))
      ENDIF
*
*            Reset history
*
      CALL KUEXEC('LAST 0')
*
      IF (BATCH) THEN

c Do standard or KUIP-macro batch processing
        if (BATCHF(1:1) .eq. ' ') then
          call UGCONB
        else
          CALL KUEXEC('EXEC '//BATCHF)
        endif
      ELSE
         CALL KUWHAG
      ENDIF
 999  CONTINUE
*
*            End monitoring
*
      CALL GEAMON(2,'GXINT')
*
      STOP
      END
