      SUBROUTINE GUOUT
*Documentation_Block
************************************************************************
*
* Description:
*  User routine called at the end of each event.  This version saves
* specified zebra banks in FZ-format.
*
* Arguments: none
*
* Called by:
*  Geant
*
* Calls:
*  GSAVE, USOUT
*
* Implicit inputs, outputs, side effects:
*  Uses IUSRZEB in IO.CMN for file lun, assumed opened by UGINIT
*  Writes FZ-format banks
*
* Filename: GUOUT.FOR
*
* History:
* Date      Name       Description
* ----      ----       -----------
* 10-Mar-98 K. W.      corrected meaning of SWIT(6) to enable output
*                      at the end of event
* 13-Feb-98 K. W.      SWIT(6) used to control GUOUT statistics printing
*                      at the end of the path
*                       0 = not printed
*                       1 = printed if at least 10000 primary particles were
*                           simulated AND at least one event was completed
*                       2 = printed if at least 100 primary particles were
*                           simulated AND at least one event was completed
*                       3 = printed at the end of each event
*                       4 = printed also in the middle of large event
*                           (previous default)
* 21-Jul-96 R. V.      Removed unused FileName
* 18-Jul-94 K. Wozniak Increase statistics format width
*  1-Nov-93 R. V.      Move NtTot update to USSTEP in case STRA = 1
*  8-Jul-93 M. Baker   Fix output conversion error for large # of events.
*  9-Jun-93 R. V.      Update NtTot, reset IEVENT in multi-pass
* 23-May-93 R. V.      Test on IDEVT for multi-pass event processing
*  8-Feb-93 R. Verdier Added geometry bank save, std document block
* 17-Jun-92 C. Parsons Creation
*C DEC/CMS REPLACEMENT HISTORY, Element GUOUT.FOR
*C *1    21-JUL-1992 14:32:06 CHUCK "Initial version declaration"
************************************************************************
*End_Documentation_Block

      IMPLICIT NONE
*KEEP,GCFLAG.
      COMMON/GCFLAG/IDEBUG,IDEMIN,IDEMAX,ITEST,IDRUN,IDEVT,IEORUN
     +        ,IEOTRI,IEVENT,ISWIT(10),IFINIT(20),NEVENT,NRNDM(2)
      COMMON/GCFLAX/BATCH, NOLOG
      LOGICAL BATCH, NOLOG
C
      INTEGER       IDEBUG,IDEMIN,IDEMAX,ITEST,IDRUN,IDEVT,IEORUN
     +        ,IEOTRI,IEVENT,ISWIT,IFINIT,NEVENT,NRNDM
C
*KEEP,GCLIST.
      COMMON/GCLIST/NHSTA,NGET ,NSAVE,NSETS,NPRIN,NGEOM,NVIEW,NPLOT
     +       ,NSTAT,LHSTA(20),LGET (20),LSAVE(20),LSETS(20),LPRIN(20)
     +             ,LGEOM(20),LVIEW(20),LPLOT(20),LSTAT(20)
C
      INTEGER       NHSTA,NGET ,NSAVE,NSETS,NPRIN,NGEOM,NVIEW,NPLOT
     + ,NSTAT,LHSTA,LGET ,LSAVE,LSETS,LPRIN,LGEOM,LVIEW,LPLOT,LSTAT
C
*KEEP,GCNUM.
      COMMON/GCNUM/NMATE ,NVOLUM,NROTM,NTMED,NTMULT,NTRACK,NPART
     +            ,NSTMAX,NVERTX,NHEAD,NBIT
      COMMON /GCNUMX/ NALIVE,NTMSTO
C
      INTEGER      NMATE ,NVOLUM,NROTM,NTMED,NTMULT,NTRACK,NPART
     +            ,NSTMAX,NVERTX,NHEAD,NBIT ,NALIVE,NTMSTO
C
*KEEP,IO.
C Common block for GPH logical units etc.: file IO.CMN
c 13-Aug-96  R. V.       Added USRBATCHK for KUIP commands for UGCONS
c 21-Jul-96  R. V.       Remove unused record; note CARDDEF now obsolete
c 22-Feb-93  R. V.       Added USRMCNTU and IMCNTU for MC Ntuple
c 14-Nov-92  R. Verdier  Added UGCIN, IUGCIN, CARDDEF and ICARDDEF
c                        for UGC and EUCARD (obsolete) input units
C    Apr-92  C. Parsons  Replacement for original COMMON.CDT
      INTEGER USRGCIN, CARDDEF, USRIN, USROUT, USRMAP, USRNTU, USRZEB,
     *  USRMCNTU, USRBATKUMAC
      PARAMETER (USRIN = 4, USROUT = 16, USRMAP = 18)
      PARAMETER (USRNTU = 15, USRZEB = 17, USRGCIN = 19, CARDDEF = 20)
      PARAMETER (USRMCNTU = 21, USRBATKUMAC = 22)
      INTEGER ICARDDEF, IMCNTU, IUSRGCIN, IUSRIN, IUSROUT, IUSRMAP,
     *  IUSRNTU, IUSRZEB, IUSRAOU, IUSRBATKUMAC
      COMMON /IO/ IUSRIN, IUSROUT, IUSRMAP, IUSRNTU, IUSRZEB, IUSRGCIN,
     *  ICARDDEF, IMCNTU, IUSRAOU, IUSRBATKUMAC
*KEEP,FLAG.
C  PHOBOS flags, run control, operating modes, misc.   File FLAG.CMN
C   7-Jul-98  K. W.      Added  ITRIG flag (initial numer in TRIG command)
C  27-Nov-97  K. W.      Added IAOUF flag
C  31-Mar-95  R.V.       Change STRA to SECT to avoid GEANT 3.21 conflict
C  22-Nov-92  D. McLeod
C   These are set in input cards
      INTEGER ISASC,ISHBO,ISHDO,ISNTU, ISMEM,ISAOU,IAOUF, ISECT,IDRAW,
     1        IGEN,IANAL,ISCAT,IPIXL,ISEQ,NTRK,IZEB, ITRIG
      REAL WPIXL,WLOSS
      COMMON/RHFLG/ISASC,ISHBO,ISHDO,ISNTU,
     1  ISMEM,ISAOU,IAOUF, ISECT,IDRAW,
     2  IGEN,IANAL,ISCAT,IPIXL,ISEQ,NTRK,IZEB,WPIXL,WLOSS, ITRIG
*KEEP,MUPEP.
c MUPEP.CMN: PHOBOS MC multi-pass event processing variables
c 16-Mar-95 K. W.     NeSkip added
c  6-Jun-93 R. V.     Creation
c Multi-pass event processing breaks up each event into groups of
c tracks, in order to avoid overflowing Zebra track storage.
c Common for access to control variables:
      common /MUPEP/ EPState, NtConc, NtpE, NtPrim, NeSkip, NtSkip,
     1  MPind, NtPrev, NtTot, NtMax, NvPrev
c Parameters and data values are assigned in MUPEP.CDA.
c Event processing state: EPState = 0 for first pass,
c 1 for continuing pass, 2 for final pass
      integer EPState
c Current pass index:
      integer MPind
c Maximum number of tracks to process concurrently in a group:
      integer NtConc
c Maximum track number for this group:
      integer NtMax
c Maximum number of tracks per event:
      integer NtpE
c Number of primary and secondary tracks generated before this pass:
      integer NtPrev
c Number of primary tracks and vertices generated:
      integer NtPrim, NvPrev
c Number of input file events to skip initially:
      integer NeSkip
c Number of tracks to skip initially:
      integer NtSkip
c Total number of primary and secondary tracks generated:
      integer NtTot
*KEND.

      character*4 FBanks(5), FBsave(5), BankName, Bsave(20)
      integer banktype, ier,lout, Nbsave,Nfbanks,Nfbsave, mm,nn

c counters that are used to decide if to write stats at end of pass
      integer ireport, ioldprim
      data ioldprim / 0 /
      save ioldprim

      data lout /6/  ! standard output
      save Bsave, FBsave, Nbsave, Nfbsave

c Identify banks to be saved, if requested by SAVE, only on first event:
      data Nfbanks /5/,
     1     FBanks  / 'SETS', 'VOLU', 'ROTM', 'MATE', 'TMED' /

      IF(ISWIT(3) .GE. 1  .AND.  IDEBUG .EQ. 1)
     +                                 CALL GPRINT('HITS',0)
C
C Call the user output routine
C
      CALL USOUT

************************************************************
*   Output banks requested by SAVE card in Zebra FZ format *
************************************************************

c Skip if not switched on or if file open failed

      if (izeb.ne.0 .and. IusrZeb .gt. 0) then

c Store names of banks to be saved on first event only in FBsave,
c and those to be saved on every event in Bsave

        if (ievent .eq. 1) then

          nfbsave = 0
          nbsave = 0
          do nn = 1, Nsave
            call UHTOC (LSAVE(nn), 4, BankName, 4)
            banktype = 1
            do mm = 1, Nfbanks
              if (BankName .eq. FBanks(mm)) banktype = 2
            enddo
            if (banktype .eq. 2) then
              Nfbsave = Nfbsave + 1
              FBsave(Nfbsave) = BankName
            else
              Nbsave = Nbsave + 1
              Bsave(Nbsave) = BankName
            endif
          enddo

c Save first-event banks
          if (Nfbsave .gt. 0 .and. IDEVT .eq. 1)
     1      call GSAVE (IusrZeb, FBsave, -Nfbsave, 0, ier)

        endif

c Save all-event banks
        if (Nbsave .gt. 0)
     1    call GSAVE (IusrZeb, Bsave, Nbsave, ievent, ier)

      endif

c Report event processing statistics

      if (ISWIT(6) .gt. 0) then
        ireport = 0
        if(ISWIT(6) .ge. 4)  ireport = 1
        if(ISWIT(6) .ge. 3  .and. EPstate .eq. 2)
     +                             ireport = 1
        if(ISWIT(6) .ge. 2  .and.  EPstate .eq. 2  .and.
     +      (ioldprim+NtPrim) .ge. 100)     ireport = 1
        if(ISWIT(6) .ge. 1  .and.  EPstate .eq. 2  .and.
     +      (ioldprim+NtPrim) .ge. 10000)   ireport = 1
        if(ireport .eq. 0) then
          ioldprim = ioldprim + NtPrim
        else
          ioldprim = 0
          write (lout,'(a,i7,a,i7,a,i5)') ' GUOUT:',
     1      NtPrim, ' primary &', NtTot - NtPrim,
     2      ' secondary tracks processed so far in event', Ievent
        endif
      endif
c Reset the event number if not the final pass in this event.  This is
c done here because it is the last point in the event loop under user
c control.

      if (Epstate .eq. 1 .and. IEVENT .ge. 1) IEVENT = IEVENT - 1

      return

      END
