      SUBROUTINE PH_HIT
*Documentation_Block
************************************************************************
*                                                                      *
* Description:                                                         *
*  User routine called at the end of each tracking step to record      *
*  hits on the detector planes for PMC GEANT.  The HITS saved:         *
*    Word 1:  X      \  in the master coordinate system, unpixelled,   *
*         2:  Y       = at the average of the entry and exit positions *
*         3:  Z      /  for the silicon plane                          *
*         4:  DE     Energy deposit in the silicon (GeV/c)             *
*         5:  DX     X-component of vector from entry to exit point    *
*         6:  DY     Y   "    "    "    "      "      "    "     "     *
*         7:  DZ     Z   "    "    "    "      "      "    "     "     *
*         8:  EFIN   track energy at the exit of the plane             *
*         9:  TOF    Time of flight to this detector (in seconds)      *
*        10:  ITRK   track number for this hit                         *
*        11:  ISEQ   sequential (first = 1) hit number on this track   *
*        12:  TLNG   length of the track up to the hit (the middle of  *
*                    the particle trajectory inside the sensor)        *
*                                                                      *
* Arguments: none                                                      *
*                                                                      *
* Called by:                                                           *
*  USSTEP                                                              *
*                                                                      *
* Calls:                                                               *
*  GDTOM, GMTOD, GSAHIT, UZERO, UHTOC                                  *
*                                                                      *
*  Implicit inputs, outputs, side effects:                             *
*    Commons included below                                            *
*                                                                      *
*  Filename: PH_HIT.FOR                                                *
*                                                                      *
*  History:                                                            *
*  Date      Name       Description                                    *
*  ----      ----       -----------                                    *
*   7-Jul-98 K.W.       Track length added to the list of hit          *
*                       parameters (the size of HITS bank is now 12)   *
*  24-Feb-98 K.W.       Remove IVOL from 11th position in hits bank    *
*                       it now stores only ISEQ - sequential hit number*
*   4-Mar-97 K.W.       Remove pixelization code and UHITSOUT call     *
*  21-Jul-96 R. V.      Remove unused jku, jk                          *
*  24-Mar-95 K.W.       Store time in place of IVOL, IVOL combined     *
*                       with ISEQ (stored 1000*ISEQ+IVOL)              *
*  18-Jul-94 R.V.       Get sequential hit number from common /UJKB/   *
*  22-Jun-94 R.V.       Store hit number (temporarily) in 11th word of *
*                       user buffer, replacing NSEQN storage           *
*  15-Jun-94 R.V.       Store mean hit position and exit-entry vector  *
*                       instead of entry position and direction cosines*
*  07-May-94 R.V.       Reordered SEQ's & doc. block, restored IUSROUT *
*  30-Apr-94 DMcL       Merged with MIT current version this date      *
*                       Note Wozniak printout removed; not in MIT vers.*
*  22-Jun-93 DMcL       Added array bound check on NSEQN               *
*  27-May-93 DMcL       Changed cosx cosy to 3 system dir. cosines     *
*  12-May-93 DMcL       Major revisions.. new HITS structure           *
*   5-Feb-93 R.V.       Added HitsOut + mode arg to UHITSOUT call      *
*  27-Oct-92 R.V.       Added call to UHITSOUT                         *
*  23-Jul-92 R. Verdier Moved diagnostic print from GUSTEP             *
*   ?-May-92 C. Parsons Separated from GUSTEP                          *
*  28-Mar-92 D. Mcleod  Creation as part of GUSTEP in GPH              *
************************************************************************
*End_Documentation_Block

      IMPLICIT NONE

c For Ipixl:
*KEEP,FLAG.
C  PHOBOS flags, run control, operating modes, misc.   File FLAG.CMN
C   7-Jul-98  K. W.      Added  ITRIG flag (initial numer in TRIG command)
C  27-Nov-97  K. W.      Added IAOUF flag
C  31-Mar-95  R.V.       Change STRA to SECT to avoid GEANT 3.21 conflict
C  22-Nov-92  D. McLeod
C   These are set in input cards
      INTEGER ISASC,ISHBO,ISHDO,ISNTU, ISMEM,ISAOU,IAOUF, ISECT,IDRAW,
     1        IGEN,IANAL,ISCAT,IPIXL,ISEQ,NTRK,IZEB, ITRIG
      REAL WPIXL,WLOSS
      COMMON/RHFLG/ISASC,ISHBO,ISHDO,ISNTU,
     1  ISMEM,ISAOU,IAOUF, ISECT,IDRAW,
     2  IGEN,IANAL,ISCAT,IPIXL,ISEQ,NTRK,IZEB,WPIXL,WLOSS, ITRIG
*KEND.
c For JKINE:
*KEEP,GCBANK.
      INTEGER IQ,LQ,NZEBRA,IXSTOR,IXDIV,IXCONS,LMAIN,LR1,JCG
      INTEGER KWBANK,KWWORK,IWS
      REAL GVERSN,ZVERSN,FENDQ,WS,Q
C
      PARAMETER (KWBANK=69000,KWWORK=5200)
      COMMON/GCBANK/NZEBRA,GVERSN,ZVERSN,IXSTOR,IXDIV,IXCONS,FENDQ(16)
     +             ,LMAIN,LR1,WS(KWBANK)
      DIMENSION IQ(2),Q(2),LQ(8000),IWS(2)
      EQUIVALENCE (Q(1),IQ(1),LQ(9)),(LQ(1),LMAIN),(IWS(1),WS(1))
      EQUIVALENCE (JCG,JGSTAT)
      INTEGER       JDIGI ,JDRAW ,JHEAD ,JHITS ,JKINE ,JMATE ,JPART
     +      ,JROTM ,JRUNG ,JSET  ,JSTAK ,JGSTAT,JTMED ,JTRACK,JVERTX
     +      ,JVOLUM,JXYZ  ,JGPAR ,JGPAR2,JSKLT
C
      COMMON/GCLINK/JDIGI ,JDRAW ,JHEAD ,JHITS ,JKINE ,JMATE ,JPART
     +      ,JROTM ,JRUNG ,JSET  ,JSTAK ,JGSTAT,JTMED ,JTRACK,JVERTX
     +      ,JVOLUM,JXYZ  ,JGPAR ,JGPAR2,JSKLT
C
*KEND.
c For Idebug, Iswit:
*KEEP,GCFLAG.
      COMMON/GCFLAG/IDEBUG,IDEMIN,IDEMAX,ITEST,IDRUN,IDEVT,IEORUN
     +        ,IEOTRI,IEVENT,ISWIT(10),IFINIT(20),NEVENT,NRNDM(2)
      COMMON/GCFLAX/BATCH, NOLOG
      LOGICAL BATCH, NOLOG
C
      INTEGER       IDEBUG,IDEMIN,IDEMAX,ITEST,IDRUN,IDEVT,IEORUN
     +        ,IEOTRI,IEVENT,ISWIT,IFINIT,NEVENT,NRNDM
C
*KEND.
c For Charge, Ipart, Itra:
*KEEP,GCKINE.
      COMMON/GCKINE/IKINE,PKINE(10),ITRA,ISTAK,IVERT,IPART,ITRTYP
     +      ,NAPART(5),AMASS,CHARGE,TLIFE,VERT(3),PVERT(4),IPAOLD
C
      INTEGER       IKINE,ITRA,ISTAK,IVERT,IPART,ITRTYP,NAPART,IPAOLD
      REAL          PKINE,AMASS,CHARGE,TLIFE,VERT,PVERT
C
*KEEP,GCSETS.
      COMMON/GCSETS/IHSET,IHDET,ISET,IDET,IDTYPE,NVNAME,NUMBV(20)
C
      INTEGER       IHSET,IHDET,ISET,IDET,IDTYPE,NVNAME,NUMBV
C
*KEEP,GCTRAK.
      INTEGER NMEC,LMEC,NAMEC,NSTEP ,MAXNST,IGNEXT,INWVOL,ISTOP,MAXMEC
     + ,IGAUTO,IEKBIN,ILOSL, IMULL,INGOTO,NLDOWN,NLEVIN,NLVSAV,ISTORY
     + ,MAXME1,NAMEC1
      REAL  VECT,GETOT,GEKIN,VOUT,DESTEP,DESTEL,SAFETY,SLENG ,STEP
     + ,SNEXT,SFIELD,TOFG  ,GEKRAT,UPWGHT
      REAL POLAR
      PARAMETER (MAXMEC=30)
      COMMON/GCTRAK/VECT(7),GETOT,GEKIN,VOUT(7),NMEC,LMEC(MAXMEC)
     + ,NAMEC(MAXMEC),NSTEP ,MAXNST,DESTEP,DESTEL,SAFETY,SLENG
     + ,STEP  ,SNEXT ,SFIELD,TOFG  ,GEKRAT,UPWGHT,IGNEXT,INWVOL
     + ,ISTOP ,IGAUTO,IEKBIN, ILOSL, IMULL,INGOTO,NLDOWN,NLEVIN
     + ,NLVSAV,ISTORY
      PARAMETER (MAXME1=30)
      COMMON/GCTPOL/POLAR(3), NAMEC1(MAXME1)
C
*KEND.
c For system volume number: (part of 4/30/94 update)
*KEEP,GCVOLU.
      COMMON/GCVOLU/NLEVEL,NAMES(15),NUMBER(15),
     +LVOLUM(15),LINDEX(15),INFROM,NLEVMX,NLDEV(15),LINMX(15),
     +GTRAN(3,15),GRMAT(10,15),GONLY(15),GLX(3)
C
      INTEGER NLEVEL,NAMES,NUMBER,LVOLUM,LINDEX,INFROM,NLEVMX,
     +        NLDEV,LINMX
      REAL GTRAN,GRMAT,GONLY,GLX
*KEND.
c For Iusrout:
*KEEP,IO.
C Common block for GPH logical units etc.: file IO.CMN
c 13-Aug-96  R. V.       Added USRBATCHK for KUIP commands for UGCONS
c 21-Jul-96  R. V.       Remove unused record; note CARDDEF now obsolete
c 22-Feb-93  R. V.       Added USRMCNTU and IMCNTU for MC Ntuple
c 14-Nov-92  R. Verdier  Added UGCIN, IUGCIN, CARDDEF and ICARDDEF
c                        for UGC and EUCARD (obsolete) input units
C    Apr-92  C. Parsons  Replacement for original COMMON.CDT
      INTEGER USRGCIN, CARDDEF, USRIN, USROUT, USRMAP, USRNTU, USRZEB,
     *  USRMCNTU, USRBATKUMAC
      PARAMETER (USRIN = 4, USROUT = 16, USRMAP = 18)
      PARAMETER (USRNTU = 15, USRZEB = 17, USRGCIN = 19, CARDDEF = 20)
      PARAMETER (USRMCNTU = 21, USRBATKUMAC = 22)
      INTEGER ICARDDEF, IMCNTU, IUSRGCIN, IUSRIN, IUSROUT, IUSRMAP,
     *  IUSRNTU, IUSRZEB, IUSRAOU, IUSRBATKUMAC
      COMMON /IO/ IUSRIN, IUSROUT, IUSRMAP, IUSRNTU, IUSRZEB, IUSRGCIN,
     *  ICARDDEF, IMCNTU, IUSRAOU, IUSRBATKUMAC
*KEND.
c For detector plane characteristics (updated RHSIL 4/30/94):
*KEEP,RHSIL.
C RHSIL.CMN: PHOBOS detector plane dimensions, positions, and
c granularity; UGC parameters
c The actual and maximum numbers of detector planes and detector hit
c parameters.  Their default values are defined in RHSILD.INC.
c 12-Dec-97 K. W.       PADSOLD and PADSNEW from UGCSET moved to a common
c  4-Nov-97 K. W.       Increased number of PADS parameters to 10
c                       Increased NSLPM to 800
c  1-Jul-97 K. W.       Added data for GEANT pixelization (GSDVN)
c  1-May-97 R. V.       Increased NSLPM to 500
c  3-MAR-97 K. W.       Removed SPL, added PADS data
C  3-Jan-97 K. W.       Increased NSLPM to 180
c  3-Jul-96 K. W.       Geometry version number added
c  5-Apr-96 D. McL.     Moved data value of UgcpMax to RHSILD
c  ...
c    Mar-92 D.McLeod    Creation
c Storage limit for number of silicon planes:
      INTEGER NSLPM
      PARAMETER (NSLPM=800)
c Storage limit for number of parameters for each hit:
      integer NSipMaxp
      parameter (NSipMaxp = 12)
c Safety limit for number of parameter values that may be entered in
c a UGC text input record:
      integer UgcpMaxp
      parameter (UgcpMaxp = 10)
c Number of silicon planes in use:
      integer NSLP
c Additional information on detectors - pad sizes:
C  DETNAME  - name of the detector volume
C  DIVXNAME - name for division in X direction
C  DIVYNAME - name for division in Y direction
C  DIVZNAME - name for division in Z direction
C  NDIVX    - number of divisions in X direction
C  NDIVY    - number of divisions in Y direction
C  NDIVZ    - number of divisions in Z direction
C  IPADFL   - pad type flag
C  PADn   - four pad parameters
C             (pad size in X, Y, Z direction for IPADFL=1 for example)
      CHARACTER*4 DETNAME(NSLPM), DIVXNAME(NSLPM),
     +             DIVYNAME(NSLPM), DIVZNAME(NSLPM)
      INTEGER NDIVX(NSLPM), NDIVY(NSLPM), NDIVZ(NSLPM)
      REAL PAD1(NSLPM),PAD2(NSLPM),PAD3(NSLPM),PAD4(NSLPM),PAD5(NSLPM)
      REAL PAD6(NSLPM),PAD7(NSLPM),PAD8(NSLPM),PAD9(NSLPM),PAD10(NSLPM)
      INTEGER NDETS, IPADFL(NSLPM)
      LOGICAL PADSOLD, PADSNEW
      COMMON /RHPADS/ NDETS, PADSOLD, PADSNEW,
     +       DETNAME, DIVXNAME, DIVYNAME, DIVZNAME,
     +       NDIVX, NDIVY, NDIVZ,
     +       IPADFL, PAD1, PAD2, PAD3, PAD4, PAD5,
     +               PAD6, PAD7, PAD8, PAD9, PAD10
c Number of silicon planes - compared with final value of NDETS
      COMMON /RHSIL/ NSLP
c UGC parameter information:
      integer UgcpMax
      real UGCpars(UgcpMaxp)
c Declare silicon plane parameters; their default values are specified
c in RHSILD.INC
      integer NSIP
c Names of parameters:
      CHARACTER*4 SINAMH(NSipMaxp)
c Mumber of bits stored for each parameter:
      INTEGER SIBITH(NSipMaxp)
c Multiplicative scale factors and origins, defined so that
c   Stored value = (Parameter value + SIORIG) * SIFACT:
      REAL SIFACT(NSipMaxp), SIORIG(NSipMaxp)
c Common for access to UGC parameters and hit parameter definitions:
      common /UGCPAR/ UgcpMax, UGCpars,
     1                NSIP, SINAMH, SIBITH, SIORIG, SIFACT
      real GEOV  !  geometry version number
      common /ugGEOV/ GEOV
*KEND.
c Access to control variables HitsOut and draw_hits:
*KEEP,UHITS.
c UHITS.CMN: control variables for UHITSOUT.FOR
c  5-Feb-93  R. Verdier     Creation
      integer draw_mode, HitsOut
      logical draw_hits
      common /Hitsocon/ HitsOut, draw_hits, draw_mode
*KEND.
c Access to number of hits on active track:
*KEEP,UJKBUF.
C  PHOBOS JKINE user buffer definitions.          File: UJKBUF.INC
c 18-Jul-94  R. V.  Added NHitsAct
	integer Nwubuf, Nwubmax, NHitsAct
	parameter (Nwubmax = 11)
	common /UJKB/ Nwubuf, Ubuf(Nwubmax), NHitsAct
	real Ubuf
	integer IUBUF(Nwubmax)
	equivalence (IUBUF, UBUF)
c NHitsAct:   The number of hits on the track being propagated
c The user words at present are:
c UBUF(1):    Process in which particle was created (DCAY, BREM etc.)
c     (2):    Parent track number, negative is parent not stored
c             (possible in SECT=1 mode)
c     (3):    Volume number at origin, (4 characters in one integer word)
c             not definded for primaries and undefined for all tracks
c             in SECT=1 mode (integer value 0)
c     (4-6):  X, Y, Z at termination
c     (7-10): Px, Py, Pz, E at termination
c     (11):   Istop at track termination, positive when particle stopped
c             in a sensitive volume, negative otherwize
*KEND.

C Local:  NOTE: NHitPar should be gotten dynamically from the bank
c storage for each detector; the following is a stopgap.
      integer NHitPar, nn
      parameter (NHitPar = 12)
      REAL HITS(NHitPar)
      INTEGER IHIT, I
      SAVE HITS
C
C Code:
C
      IF(CHARGE.EQ.0) GOTO 5     !We don't see these
      IF(IHSET.EQ.0) GOTO 5     !not a detector

******************************************************
*  Record GEANT bank HITS at detector planes only    *
******************************************************

      IF(ISET.GE.1) THEN

         IF(INWVOL.EQ.1) THEN

c At a silicon plane entrance, save position and initialize the rest
c of the hits array.

            do nn = 1, 3
              HITS(nn) = VECT(nn)
            enddo
            call UZERO(HITS(4), 1, NHitPar - 3)
C Track number kept in HITS for external use:
            HITS(10) = FLOAT(ITRA)
C Store the time (units: seconds)
            HITS(9) = TOFG
C Store the length of the track up to the entry point
            HITS(12) = SLENG

         ELSE IF((INWVOL.EQ.0.OR.INWVOL.EQ.2).AND.STEP.GT.0.0) THEN

c Within the silicon or at exit from it, increment the energy
c deposition and store the system volume number from /GCVOLU/

            HITS(4) = HITS(4) + DESTEP

         ENDIF

         IF(INWVOL.EQ.2.OR.ISTOP.GT.0) THEN

c At exit from the silicon or end of track, store the vector from
c entry to exit, the mean hit position, the final kinetic entry,
c track number, and hit sequence number, for writing out in PH_OUT.
c NOTE THIS FAILS IF A SECONDARY IS PRODUCED IN THE SILICON; THIS
c MUST BE DEALT WITH LATER.

            if (HITS(10) .ne. FLOAT(ITRA)) print *, ' PH_HIT: *****',
     1        ' track number ', ITRA, ' changed in silicon.'
            do nn = 1, 3
              HITS(nn+4) = VECT(nn) - HITS(nn)
              HITS(nn) = HITS(NN) + 0.5 * HITS(nn+4)
            enddo

            HITS(8) = GEKIN
C Save sequential number of hit on this track: hits(11) = ISEQ
            HITS(11) = NHitsAct
C Save the track length up to the middle of the hit
            HITS(12) = HITS(12) +
     +        SQRT(HITS(5)**2+HITS(6)**2+HITS(7)**2) / 2.0

            CALL GSAHIT(ISET,IDET,ITRA,NUMBV,HITS,IHIT)
            draw_hits = .false.

c If IDEBUG = 1 and ISWIT(4) >= 1, write diagnostic hits output

            IF(IDEBUG .EQ. 1  .AND.  ISWIT(4) .GE. 1) THEN
               WRITE(IUSROUT,1000)INWVOL,IHSET,IHDET,
     1         IDTYPE,(HITS(I),I=1,NHitPar)
1000           FORMAT(' PH_HIT: INWVOL,IHSET,IHDET,IDTYPE = ',
     1         I2,'|',A4,'|',A4,'|',I5,/,
     2         ' HITS SAVED = ',5(' | ',G10.4),/,
     3         7('| ',G10.4))
            ENDIF
         ENDIF
      ENDIF

5     RETURN
      END
