       SUBROUTINE RDIVISION(X0, Y0, X1, Y1, R, X, Y)
*Documentation_Block
************************************************************************
*
*  Description:
*  Division of the track in a ring detector
*  (X0,Y0)   - starting point
*  (X1,Y1)   - exit point
*   R        - radius at which division should occur
*  (X,Y)     - point at radius R - to be found
*              (equal to (X0,Y0) if division is not possible)
*
*  Called by:
*  PIXEL
*
*  History:
*  Date       Name       Description
*  ----       ----       -----------
*   4-Nov-97  K.W.       Creation
************************************************************************
*End_Documentation_Block

      IMPLICIT NONE

      REAL*8 X0,Y0, X1,Y1, R, X, Y

C     Local definitions:
C     ==================

      REAL*8 A, B, C, DEL, DELS, T


C  X = X0 + (X1-X0) * T
C  Y = Y0 + (Y1-Y0) * T
C  calculate T:   X**2 + Y**2 = R**2
C  T**2 * ((X1-X0)**2+(Y1-Y0)**2)  +  T * 2*(X0*(X1-X0)+Y0*(Y1-Y0))
C                                    +  X0**2+Y0**2 - R**2  =  0

      A = (X1-X0)**2 + (Y1-Y0)**2
      B = 2.0 * ( X0*(X1-X0) + Y0*(Y1-Y0) )
      C = X0**2 + Y0**2 - R**2
      DEL = B * B  - 4.0 * A * C
      X = X0
      Y = Y0
      IF(DEL .LT. 0.0  .OR.  A . LT. 0.1E-10)  RETURN

      DELS = DSQRT(DEL)
      T = 0.5 * (-B - DELS) / A
      IF(T .LT. 0.0  .OR.  T .GT. 1.0)   T = 0.5 * (-B +DELS) / A

      IF(T .LT. 0.0  .OR.  T .GT. 1.0)   RETURN  !  (X,Y) not between
c                                                !  (X0,Y0)  and  (X1,Y1)

      X = X0 + (X1-X0) * T
      Y = Y0 + (Y1-Y0) * T

      RETURN
      END
