      SUBROUTINE SETPMCPAR(NAME, NVALUES, VALUES)
*Documentation_Block
************************************************************************
*
*  Description:
*  Modify PMC parameters of the simulations
*  NOTE: the supported parameters list should be identical with
*        those in  SETPMCPAR  and  GETPMCPNAME
*
*   Some most obvious errors are detected and signalled by
*    NVALUES  reset to 0  (parameter is not changed)
*
*  Arguments:
*  NAME    - parameter keyword
*  NVALUES - number of values for this parameter
*  VALUES  - table of new parameter values
*
*  Called by:
*  Phat
*
*  Calls:
*
*  Implicit inputs, outputs, side effects:
*  Reads information from standard input - or from a common /CGETKINE/
*
*  History:
*  Date       Name       Description
*  ----       ----       -----------
*   17-Dec-98  K.W.    Added almost all control file parameters
*    7-Jul-98  K.W.    Enable modification of MAGT
*                      If GEN is changed close GENEVS if EPSTATE > 0
*                      to enable restart of simulations with a new file
*                      modify ITRIG by parameter TRIG
*   25-Jun-98  K.W.    Included part of GEANT routine GXPHYSI to
*                      enable correect modification of parameters
*                      describing physics in the simulations
*   27-Apr-98  K.W.    Creation
************************************************************************
*End_Documentation_Block

      IMPLICIT NONE

      CHARACTER*4 NAME
      INTEGER  NVALUES
      REAL VALUES(10)

*KEEP,GCBANK.
      INTEGER IQ,LQ,NZEBRA,IXSTOR,IXDIV,IXCONS,LMAIN,LR1,JCG
      INTEGER KWBANK,KWWORK,IWS
      REAL GVERSN,ZVERSN,FENDQ,WS,Q
C
      PARAMETER (KWBANK=69000,KWWORK=5200)
      COMMON/GCBANK/NZEBRA,GVERSN,ZVERSN,IXSTOR,IXDIV,IXCONS,FENDQ(16)
     +             ,LMAIN,LR1,WS(KWBANK)
      DIMENSION IQ(2),Q(2),LQ(8000),IWS(2)
      EQUIVALENCE (Q(1),IQ(1),LQ(9)),(LQ(1),LMAIN),(IWS(1),WS(1))
      EQUIVALENCE (JCG,JGSTAT)
      INTEGER       JDIGI ,JDRAW ,JHEAD ,JHITS ,JKINE ,JMATE ,JPART
     +      ,JROTM ,JRUNG ,JSET  ,JSTAK ,JGSTAT,JTMED ,JTRACK,JVERTX
     +      ,JVOLUM,JXYZ  ,JGPAR ,JGPAR2,JSKLT
C
      COMMON/GCLINK/JDIGI ,JDRAW ,JHEAD ,JHITS ,JKINE ,JMATE ,JPART
     +      ,JROTM ,JRUNG ,JSET  ,JSTAK ,JGSTAT,JTMED ,JTRACK,JVERTX
     +      ,JVOLUM,JXYZ  ,JGPAR ,JGPAR2,JSKLT
C
*KEEP,GCPHYS.
      COMMON/GCPHYS/IPAIR,SPAIR,SLPAIR,ZINTPA,STEPPA
     +             ,ICOMP,SCOMP,SLCOMP,ZINTCO,STEPCO
     +             ,IPHOT,SPHOT,SLPHOT,ZINTPH,STEPPH
     +             ,IPFIS,SPFIS,SLPFIS,ZINTPF,STEPPF
     +             ,IDRAY,SDRAY,SLDRAY,ZINTDR,STEPDR
     +             ,IANNI,SANNI,SLANNI,ZINTAN,STEPAN
     +             ,IBREM,SBREM,SLBREM,ZINTBR,STEPBR
     +             ,IHADR,SHADR,SLHADR,ZINTHA,STEPHA
     +             ,IMUNU,SMUNU,SLMUNU,ZINTMU,STEPMU
     +             ,IDCAY,SDCAY,SLIFE ,SUMLIF,DPHYS1
     +             ,ILOSS,SLOSS,SOLOSS,STLOSS,DPHYS2
     +             ,IMULS,SMULS,SOMULS,STMULS,DPHYS3
     +             ,IRAYL,SRAYL,SLRAYL,ZINTRA,STEPRA
      COMMON/GCPHLT/ILABS,SLABS,SLLABS,ZINTLA,STEPLA
     +             ,ISYNC
     +             ,ISTRA
*
      INTEGER IPAIR,ICOMP,IPHOT,IPFIS,IDRAY,IANNI,IBREM,IHADR,IMUNU
     +       ,IDCAY,ILOSS,IMULS,IRAYL,ILABS,ISYNC,ISTRA
      REAL    SPAIR,SLPAIR,ZINTPA,STEPPA,SCOMP,SLCOMP,ZINTCO,STEPCO
     +       ,SPHOT,SLPHOT,ZINTPH,STEPPH,SPFIS,SLPFIS,ZINTPF,STEPPF
     +       ,SDRAY,SLDRAY,ZINTDR,STEPDR,SANNI,SLANNI,ZINTAN,STEPAN
     +       ,SBREM,SLBREM,ZINTBR,STEPBR,SHADR,SLHADR,ZINTHA,STEPHA
     +       ,SMUNU,SLMUNU,ZINTMU,STEPMU,SDCAY,SLIFE ,SUMLIF,DPHYS1
     +       ,SLOSS,SOLOSS,STLOSS,DPHYS2,SMULS,SOMULS,STMULS,DPHYS3
     +       ,SRAYL,SLRAYL,ZINTRA,STEPRA,SLABS,SLLABS,ZINTLA,STEPLA
C
*KEEP,GCCUTS.
      COMMON/GCCUTS/CUTGAM,CUTELE,CUTNEU,CUTHAD,CUTMUO,BCUTE,BCUTM
     +             ,DCUTE ,DCUTM ,PPCUTM,TOFMAX,GCUTS(5)
C
      REAL          CUTGAM,CUTELE,CUTNEU,CUTHAD,CUTMUO,BCUTE,BCUTM
     +             ,DCUTE ,DCUTM ,PPCUTM,TOFMAX,GCUTS
C
*KEEP,GCONSP,IF=-SINGLE.
      DOUBLE PRECISION PI,TWOPI,PIBY2,DEGRAD,RADDEG,CLIGHT,BIG,EMASS
      DOUBLE PRECISION EMMU,PMASS,AVO
*
      PARAMETER (PI=3.14159265358979324D0)
      PARAMETER (TWOPI=6.28318530717958648D0)
      PARAMETER (PIBY2=1.57079632679489662D0)
      PARAMETER (DEGRAD=0.0174532925199432958D0)
      PARAMETER (RADDEG=57.2957795130823209D0)
      PARAMETER (CLIGHT=29979245800.D0)
      PARAMETER (BIG=10000000000.D0)
      PARAMETER (EMASS=0.0005109990615D0)
      PARAMETER (EMMU=0.105658387D0)
      PARAMETER (PMASS=0.9382723128D0)
      PARAMETER (AVO=0.60221367D0)
*
*KEEP,GCUNIT.
      COMMON/GCUNIT/LIN,LOUT,NUNITS,LUNITS(5)
      INTEGER LIN,LOUT,NUNITS,LUNITS
      COMMON/GCMAIL/CHMAIL
      CHARACTER*132 CHMAIL
C
*KEEP,GCFLAG.
      COMMON/GCFLAG/IDEBUG,IDEMIN,IDEMAX,ITEST,IDRUN,IDEVT,IEORUN
     +        ,IEOTRI,IEVENT,ISWIT(10),IFINIT(20),NEVENT,NRNDM(2)
      COMMON/GCFLAX/BATCH, NOLOG
      LOGICAL BATCH, NOLOG
C
      INTEGER       IDEBUG,IDEMIN,IDEMAX,ITEST,IDRUN,IDEVT,IEORUN
     +        ,IEOTRI,IEVENT,ISWIT,IFINIT,NEVENT,NRNDM
C
*KEEP,GCMULO.
      COMMON/GCMULO/SINMUL(101),COSMUL(101),SQRMUL(101),OMCMOL,CHCMOL
     +  ,EKMIN,EKMAX,NEKBIN,NEK1,EKINV,GEKA,GEKB,EKBIN(200),ELOW(200)
C
      REAL SINMUL,COSMUL,SQRMUL,OMCMOL,CHCMOL,EKMIN,EKMAX,ELOW,EKINV
      REAL GEKA,GEKB,EKBIN
      INTEGER NEKBIN,NEK1
C
*KEEP,BANGC.
C Event generator parameters                 File: BANGC.CMN
C 20-Sep-96  K. Wozniak Added new parameters to control BANG mode = 2
C                       RSPX, RSPZ, RSPR (removed RMAG)
C 10-Mar-95  K. Wozniak Added new parameters to control track generation
c                       and selection (ETAMIN,ETAMAX, IDMIN,IDMAX ..)
c 22-Jun-94  R. V.      Remove NSEQN storage (see PH_HIT)
c 10-May-94  D. McLeod  Increased MXMUL to 13000 for HIJET events
c 17-Dec-92  R. Verdier Changed name from BANG to BANGC for CMS
c 22-Nov-92  D. Mcleod  Added EXF and NSEQN
      INTEGER MXMUL
      PARAMETER (MXMUL=13000)  ! maximum multiplicity for BANG etc.
      INTEGER IRMUL         !  multiplicity in random particle generation
      INTEGER IRARM         !  particles going to 1 or 2 arms selected
      INTEGER IRPID(2)      !  particle id range: min, max
      REAL RMOM(3)          !  momentum of particles:  min, max and step
                            !  (first step if 1/p is changed)
      REAL REXP             !  mean transv. mom. - for momentum generation
      REAL RETA(2)          !  ETA range: min, max
      REAL RANG(3)          !  starting theta angle and step
      REAL RPHI(2)          !  range of emission phi angle: min, max
      REAL RROT(2)          !  phi initial and additional rotation angle (GEN=0)
      REAL RBXX,RBYY,RBZZ   !  central position of the vertex
      REAL RBXY             !  width of the beam intersection in x-y
      REAL RBDX,RBDY,RBDZ   !  the range of positions of the vertex
C                           !
      REAL RSPX,RSPZ,RSPR   !  position and radius of the circle describing
C                           !  area covered by spectrometer
      REAL PHIR,CZ,ZC,RS    !  working variables for BANG
      COMMON/RHBNG/IRMUL, IRARM, IRPID, RMOM, REXP, RETA, RANG, RPHI,
     1             RROT,
     2             RBXX,RBYY,RBZZ, RBDX, RBDY, RBDZ, RBXY,
     3             RSPX,RSPZ,RSPR, PHIR,CZ,ZC,RS
*KEEP,FLAG.
C  PHOBOS flags, run control, operating modes, misc.   File FLAG.CMN
C   7-Jul-98  K. W.      Added  ITRIG flag (initial numer in TRIG command)
C  27-Nov-97  K. W.      Added IAOUF flag
C  31-Mar-95  R.V.       Change STRA to SECT to avoid GEANT 3.21 conflict
C  22-Nov-92  D. McLeod
C   These are set in input cards
      INTEGER ISASC,ISHBO,ISHDO,ISNTU, ISMEM,ISAOU,IAOUF, ISECT,IDRAW,
     1        IGEN,IANAL,ISCAT,IPIXL,ISEQ,NTRK,IZEB, ITRIG
      REAL WPIXL,WLOSS
      COMMON/RHFLG/ISASC,ISHBO,ISHDO,ISNTU,
     1  ISMEM,ISAOU,IAOUF, ISECT,IDRAW,
     2  IGEN,IANAL,ISCAT,IPIXL,ISEQ,NTRK,IZEB,WPIXL,WLOSS, ITRIG
*KEEP,RHSYS.
C  Common blocks for GPH PHOBOS simulation:  FILE RHSYS.CMN
C  General geometric layout of PHOBOS detector exclusive of detectors
C  These values are on input cards or data statements, except *MAX are
C  calculated to encompass all elements of the system.
C  20-Sep-96  K.W       Removed obsolete BMTBRAD, BERTHIK
C                       Removed FANGL - now local variable in BANG
C  12-Jul-96  K.W       Position of the magnet pole center MAGX, MAGZ
C                       (previously XOFF,ZOFF) separated from the magnet
C                       offset (now MOFF - 3-D vector)
C  14 Dec-92  R.V.      TMAG redefined and changed to integer
C  22-Nov-92 D. McLeod  Renamed from COMMON.SYS; TMAG, ZOFF, XOFF
C                       are added from the original GPH version
      REAL   BFLD         ! Magnetic field strength
     &      ,MAGX,MAGZ    ! Coordinates of field center
     &      ,MOFF(3)      ! offset of the field
     &      ,RFLD         ! Radius of field (perfect dipole only)
     1   ,XMAX,YMAX,ZMAX,ZMIN,XMMAX,ZMMAX
      INTEGER MAGT, TMAG  ! Field type: 0 Zebra bank, 1 = dipole,
                          ! 2 = ASCII map
      COMMON/RHSYS/ BFLD,MAGT,MAGX,MAGZ,MOFF
     1  ,RFLD,XMAX,YMAX,ZMAX,ZMIN,XMMAX,ZMMAX
      EQUIVALENCE (TMAG, MAGT)
*KEEP,MUPEP.
c MUPEP.CMN: PHOBOS MC multi-pass event processing variables
c 16-Mar-95 K. W.     NeSkip added
c  6-Jun-93 R. V.     Creation
c Multi-pass event processing breaks up each event into groups of
c tracks, in order to avoid overflowing Zebra track storage.
c Common for access to control variables:
      common /MUPEP/ EPState, NtConc, NtpE, NtPrim, NeSkip, NtSkip,
     1  MPind, NtPrev, NtTot, NtMax, NvPrev
c Parameters and data values are assigned in MUPEP.CDA.
c Event processing state: EPState = 0 for first pass,
c 1 for continuing pass, 2 for final pass
      integer EPState
c Current pass index:
      integer MPind
c Maximum number of tracks to process concurrently in a group:
      integer NtConc
c Maximum track number for this group:
      integer NtMax
c Maximum number of tracks per event:
      integer NtpE
c Number of primary and secondary tracks generated before this pass:
      integer NtPrev
c Number of primary tracks and vertices generated:
      integer NtPrim, NvPrev
c Number of input file events to skip initially:
      integer NeSkip
c Number of tracks to skip initially:
      integer NtSkip
c Total number of primary and secondary tracks generated:
      integer NtTot
*KEEP,FIRSTC.
C  PHOBOS "first call" flags,   File FIRSTC.CMN
C  The flags denoting the very first call are put in one common
C  to enable easy restart of simulations in PHAT
C  11-Feb-98  K. W.      Creation
C
      LOGICAL FCGUFLD, FCGUSTEP, FCPHOUT
      COMMON /CFIRSTC/ FCGUFLD, FCGUSTEP, FCPHOUT
*KEND.

      INTEGER MECA, I, J, JM, JMA, JTM, JTMI
      DIMENSION MECA(5,13)
      EQUIVALENCE (MECA(1,1),IPAIR)
      REAL VDUM(3), BDUM(3)
      CHARACTER*80 FILENAME

C
C     Executable Statements
C     =====================
C

C    Physics control
C
      IF(NAME .EQ. 'CUTS')  THEN
         IF(NVALUES .NE. 5)  GO TO 999
         CUTGAM = VALUES(1)
         CUTELE = VALUES(2)
         CUTNEU = VALUES(3)
         CUTHAD = VALUES(4)
         CUTMUO = VALUES(5)
          GO TO 100
      ELSE IF(NAME .EQ. 'MULS')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         IMULS = INT(VALUES(1)+0.0001)
          GO TO 100
      ELSE IF(NAME .EQ. 'DCAY')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         IDCAY = INT(VALUES(1)+0.0001)
          GO TO 100
      ELSE IF(NAME .EQ. 'HADR')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         IHADR = INT(VALUES(1)+0.0001)
          GO TO 100
      ELSE IF(NAME .EQ. 'LOSS')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         ILOSS = INT(VALUES(1)+0.0001)
         IF (ILOSS.EQ.2.OR.ILOSS.EQ.0) THEN
            IDRAY=0
         ELSE
            IDRAY=1
         ENDIF
          GO TO 100
      ELSE IF(NAME .EQ. 'PAIR')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         IPAIR = INT(VALUES(1)+0.0001)
          GO TO 100
      ELSE IF(NAME .EQ. 'BREM')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         IBREM = INT(VALUES(1)+0.0001)
          GO TO 100
      ELSE IF(NAME .EQ. 'COMP')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         ICOMP = INT(VALUES(1)+0.0001)
          GO TO 100
      ELSE IF(NAME .EQ. 'PHOT')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         IPHOT = INT(VALUES(1)+0.0001)
          GO TO 100
      ELSE IF(NAME .EQ. 'DRAY')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         IDRAY = INT(VALUES(1)+0.0001)
         IF (ILOSS.EQ.2.OR.ILOSS.EQ.0)     IDRAY=0
          GO TO 100
      ELSE IF(NAME .EQ. 'ANNI')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         IANNI = INT(VALUES(1)+0.0001)
          GO TO 100

      ELSE IF(NAME .EQ. 'SAOU')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         IF(VALUES(1) .LT. -0.000001  .OR.
     +        VALUES(1) .GT. 4.000001) GO TO 999
         ISAOU = INT(VALUES(1)+0.0001)
      ELSE IF(NAME .EQ. 'SMEM')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         IF(VALUES(1) .LT. -0.000001 .OR.
     +        VALUES(1) .GT. 4.000001) GO TO 999
         ISMEM = INT(VALUES(1)+0.0001)

C   PMC control
C
      ELSE IF(NAME .EQ. 'GEN ')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         IF(VALUES(1) .LT. -0.000001 .OR.
     +        VALUES(1) .GT. 100.0) GO TO 999
         IGEN = INT(VALUES(1)+0.0001)
         IF(EPSTATE .NE. 0)  THEN
            CALL UFILE(3, 'GENEVS', I, FILENAME)
            EPSTATE = 0
         ENDIF

      ELSE IF(NAME .EQ. 'TRIG')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         IF(VALUES(1) .LT. 0.99999 .OR.
     +        VALUES(1) .GT. 10000.0) GO TO 999
         ITRIG = INT(VALUES(1)+0.0001)

      ELSE IF(NAME .EQ. 'MAGT')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         IF(VALUES(1) .LT. -0.000001 .OR.
     +        VALUES(1) .GT. 3.000001) GO TO 999
         MAGT = INT(VALUES(1)+0.0001)
         IF(.NOT. FCGUFLD)  THEN
            FCGUFLD = .TRUE.  !  call GUFLD to properly initialize it
            VDUM(1) = 0.0
            VDUM(2) = 0.0
            VDUM(3) = 0.0
            CALL GUFLD(VDUM, BDUM)
         ENDIF
      ELSE IF(NAME .EQ. 'PIXL')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         IF(VALUES(1) .LT. -0.000001 .OR.
     +        VALUES(1) .GT. 2.000001) GO TO 999
         IPIXL = INT(VALUES(1)+0.0001)
      ELSE IF(NAME .EQ. 'SECT')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         IF(VALUES(1) .LT. -0.000001  .OR.
     +        VALUES(1) .GT. 2.000001) GO TO 999
         ISECT = INT(VALUES(1)+0.0001)
      ELSE IF(NAME .EQ. 'RBXX')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         RBXX = VALUES(1)
      ELSE IF(NAME .EQ. 'RBYY')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         RBYY = VALUES(1)
      ELSE IF(NAME .EQ. 'RBZZ')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         RBZZ = VALUES(1)
      ELSE IF(NAME .EQ. 'RMOM')  THEN
         IF(NVALUES .NE. 3)  GO TO 999
         RMOM(1) = VALUES(1)
         RMOM(2) = VALUES(2)
         RMOM(3) = VALUES(3)
      ELSE IF(NAME .EQ. 'RPID')  THEN
         IF(NVALUES .NE. 2)  GO TO 999
         IF(VALUES(1) .LT. -0.000001) GO TO 999
         IF(VALUES(2) .LT. -0.000001) GO TO 999
         IRPID(1) = INT(VALUES(1)+0.0001)
         IRPID(2) = INT(VALUES(2)+0.0001)
      ELSE IF(NAME .EQ. 'RETA')  THEN
         IF(NVALUES .NE. 2)  GO TO 999
         RETA(1) = VALUES(1)
         RETA(2) = VALUES(2)
      ELSE IF(NAME .EQ. 'RPHI')  THEN
         IF(NVALUES .NE. 2)  GO TO 999
         RPHI(1) = VALUES(1)
         RPHI(2) = VALUES(2)
      ELSE IF(NAME .EQ. 'RARM')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         IF(VALUES(1) .LT. 0.999999  .OR.
     +        VALUES(1) .GT. 2.000001) GO TO 999
         IRARM = INT(VALUES(1)+0.0001)
      ELSE IF(NAME .EQ. 'RMUL')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         IF(VALUES(1) .LT. 0.999999 .OR.
     +         VALUES(1) .GT. 10000.0) GO TO 999
         IRMUL = INT(VALUES(1)+0.0001)
         IF(IRMUL .LT. 1)  IRMUL = 1
      ELSE IF(NAME .EQ. 'RROT')  THEN
         IF(NVALUES .NE. 2)  GO TO 999
         RROT(1) = VALUES(1)
         RROT(2) = VALUES(2)
      ELSE IF(NAME .EQ. 'REXP')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         REXP = VALUES(1)
      ELSE IF(NAME .EQ. 'RANG')  THEN
         IF(NVALUES .NE. 3)  GO TO 999
         RANG(1) = VALUES(1)
         RANG(2) = VALUES(2)
         RANG(3) = VALUES(3)
      ELSE IF(NAME .EQ. 'RSPX')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         RSPX = VALUES(1)
      ELSE IF(NAME .EQ. 'RSPZ')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         RSPZ = VALUES(1)
      ELSE IF(NAME .EQ. 'RSPR')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         RSPR = VALUES(1)
      ELSE IF(NAME .EQ. 'RBXY')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         RBXY = VALUES(1)
      ELSE IF(NAME .EQ. 'RBDX')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         RBDX = VALUES(1)
      ELSE IF(NAME .EQ. 'RBDY')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         RBDY = VALUES(1)
      ELSE IF(NAME .EQ. 'RBDZ')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         RBDZ = VALUES(1)
      ELSE IF(NAME .EQ. 'RNDM')  THEN
         IF(NVALUES .NE. 2)  GO TO 999
         IF(VALUES(1) .LT. 1.0  .OR.
     +                VALUES(2) .LT. 1.0)   GO TO 999
         NRNDM(1) = INT(VALUES(1)+0.0001)
         NRNDM(2) = INT(VALUES(2)+0.0001)
      ELSE IF(NAME .EQ. 'RUNG')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         IF(VALUES(1) .LT. 0)  GO TO 999
         IDRUN = INT(VALUES(1)+0.0001)
      ELSE IF(NAME .EQ. 'ANAL')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         IANAL = INT(VALUES(1)+0.0001)
      ELSE IF(NAME .EQ. 'NESK')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         IF(VALUES(1) .LT. 0.0)   GO TO 999
         NESKIP = INT(VALUES(1)+0.0001)
      ELSE IF(NAME .EQ. 'NTSK')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         IF(VALUES(1) .LT. 0.0)  GO TO 999
         NTSKIP = INT(VALUES(1)+0.0001)
      ELSE IF(NAME .EQ. 'NTPE')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         IF(VALUES(1) .LT. 1.0)  GO TO 999
         NTPE = INT(VALUES(1)+0.0001)
      ELSE IF(NAME .EQ. 'NTCO')  THEN
         IF(NVALUES .NE. 1)  GO TO 999
         IF(VALUES(1) .LT. 1.0)  GO TO 999
         NTCONC = INT(VALUES(1)+0.0001)
      ELSE IF(NAME .EQ. 'SWIT')  THEN
         IF(NVALUES .NE. 10)  GO TO 999
         DO  I=1,10
            IF(VALUES(I) .LT. 0)  GO TO 999
         ENDDO
         DO  I=1,10
            ISWIT(I) = INT(VALUES(I)+0.0001)
         ENDDO
      ELSE IF(NAME .EQ. 'DEBU')  THEN
         IF(NVALUES .NE. 3)  GO TO 999
         IF(VALUES(1) .LT. 0.0)  GO TO 999
         IF(VALUES(2) .LT. 0.0)  GO TO 999
         IF(VALUES(3) .LT. 0.0)  GO TO 999
         IDEMIN = INT(VALUES(1)+0.0001)
         IDEMAX = INT(VALUES(2)+0.0001)
         ITEST  = INT(VALUES(3)+0.0001)
      ENDIF

      RETURN

  100 CONTINUE
         IF(JTMED .GT. 0)  THEN
            DO  130  I=1,IQ(JTMED-2)
               JTM = LQ(JTMED-I)
               IF(JTM .LE. 0)  GO TO 130
               IF(IQ(JTM-2) .EQ. 0)  THEN
                  CALL MZPUSH(IXCONS, JTM, 10, 0, 'I')
                  GO TO 130
               ENDIF
               DO  120  J=1,10
                  JTMI = LQ(JTM-J)
                  IF(JTMI .GT. 0)  THEN
                     CALL MZDROP(IXCONS, JTMI, ' ')
                  ENDIF
  120          CONTINUE
  130       CONTINUE
            CALL UCOPY(CUTGAM, Q(JTMED+1), 10)
            DO  140  I=1,13
               Q(JTMED+10+I) = MECA(1,I)
  140       CONTINUE
         ENDIF
         IF(JMATE .LE. 0)  GO TO 990
         DO  160  I=1,IQ(JMATE-2)
            JMA = LQ(JMATE-I)
            IF(JMA .LE. 0)  GO TO 160
            DO  150  J=1,IQ(JMA-2)
               IF(J .EQ. 4  .OR. J .EQ. 5)  GO TO 160
               JM = LQ(JMA-J)
               IF(JM .LE. 0)  GO TO 150
               CALL MZDROP(IXCONS, JM, 'L')
  150       CONTINUE
  160    CONTINUE
         CALL MZGARB (IXCONS, 0)
         CALL GPHYSI

c
      RETURN

  990 CONTINUE
      RETURN


  999 CONTINUE   !   error in the parameter values
      NVALUES = 0

CC      WRITE(*,*) ' ***** ERROR IN SETPMCPAR: ',
CC     +   NAME, NVALUES, VALUES(1), '  ..... '
      RETURN

      END
