*CMZ :          08/07/98  13.39.58  by  Unknown
*CMZU:  3.00/00 03/12/97  11.24.07  by  K. Wozniak
*CMZU:  2.04/01 22/09/97  13.41.52  by  Phobos (R. Verdier)
*CMZU:  2.04/00 28/08/97  13.14.40  by  Phobos (K. Wozniak)
*CMZU:  2.03/02 21/08/97  13.57.17  by  Phobos (R. Verdier)
*CMZU:  2.03/01 25/07/97  14.35.29  by  Phobos (D. McLeod)
*-- Author :
      subroutine UFILE(Mode, LogName, LogUnit, FileName)
*Documentation_Block
************************************************************************
*
* Description:
*  Assigns Fortran logical unit numbers for, and optionally opens or
*  closes, a file for the Phobos MC.
*
*  OSSPEC - Operating System SPECific routine
*
*  Arguments:
*  Mode (integer; input): specifies actions to be preformed by UFILE;
*   = 0: Assign a logical unit number to the file, and, if it is not
*        in the list of files already assigned, open it.
*   = 1: Same action as mode = 0, but do not open the file.
*   = 2: Close the file and open next file with modified
*        file name (increased file index number) for example:
*         1-st call:   UFILE(0, 'FLDASC', ...)
*                      opens file  FLDASC
*         2-nd call:   UFILE(2, 'FLDASC', ...)
*                      closes FLDASC and opens FLDASC01
*         3-rd call:   UFILE(2, 'FLDASC', ...)
*                      closes FLDASC01 and opens FLDASC02
*         etc. until one of files FLDASCxx does not exist
*   = 3:  Close the file, so that it can be once more opened
*         (starting from the file without appended 01, 02 ... etc.)
*         1-st call:  UFILE(0, 'GENEVS', ...)
*                     opens file GENEVS
*         2-nd call:  UFILE(3, 'GENEVS', ...)
*                     closes file GENEVS
*         3-rd call:  UFILE(0, 'GENEVS', ...)
*                     opens file GENEVS (not GENEVS01) once more
*   = 4:  Close all assigned files and delete all assignments.
*        operation intended to be executed at the end of program
*  LogName (character*(*), input): specifies the logical file name,
*   presumed to have been assigned to an actual file by DCL statements.
*   If the name contains a period (.), DCL treats it as an actual
*   (not logical) file name.
*   If the name contains no  period, and no logical assignment was made,
*   Fortran will take FILENAME.DAT as the actual file name.
*  LogUnit (integer, output) is the returned Fortran Logical Unit
*   Number; if an error occurred, LogUnit will be 0 or negative.
*  FileName (character*(*), output): the actual filename assigned
*   to the file.  This uses VAX-specific system calls, but a KUIP
*   alternative is available for platform independence.
*
*  Called by:
*  UGINIT
*
*  Calls:
*    LIB$SYS_TRNLOG or GETENV, LENOCC
*
*  Implicit inputs: IO.CMN for parameterized unit #s
*
*  Implicit outputs: opened files; unit numbers in common IO
*
*  Filename: pmc_src:UFILE.FOR
*
*  History:
*  Date       Name       Description
*  ----       ----       -----------
*   7-Jul-98  K. W.      changed meaning of mode 3 - it is now closing
*                        the file specified by LogName
*                        mode = 4 closes all files as previously mode = 3 did
*  13-Feb-98  K. W.      ireport = SWIT(5), two standard options:
*                          SWIT(5) = 1   - report all opened files
*                          SWIT(5) = 0   - report errors opening files only
*                         (SWIT(5) = -1  - no output, not recomended)
*  13-Feb-98  R. V.      Add file-not-found errors 1018 for SunOS and 2 for
*                        IRIX
*  03-Dec-97  K. W.      Add comment with text indicating platform specific
*                        status of the routine
*  22-Sep-97  R. V.      Add file-not-found error # = 6 for AIX
*  10-Sep-97  R. V.      Set platform-specific file-not-found Fortran
*                        error numbers; set report level to 1 + ISWIT(5)
*                        in common GCFLAG
*  25-Aug-97  K. W.      rewritten to enable reading from several
*                        files as from one logical input (new version
*                        of mode=2)
*  20-Aug-97  RV         Remove READONLY and ACTION=READ for Linux
*  20-Jul-97  DMcL       report level, AIX vs. non-AIX now set by
*                        preprocessor switches REP2, AIX
*  15-Jul-97  DMcL       GETENV call in place of LIB$SYS_TRNLOG in UNIX
*                        environment, to obtain (setenv) file name.
*                        OPENs altered to use full file names.
*  25-Mar-97  R. V.      Version for DEC osf1, status 'new' -> 'unknown'
*                        if CMZ selects OSF1; added reporting options;
*                        list alternate selections as comments for
*                        testing without CMZ
*  13-Aug-96  R. V.      Change READONLY to ACTION = READ if CMZ selects
*                          IBM; replace FLDZBR by BATKUMAC
*  21-Jul-96  R. V.      Removed unused nn
*  08-Jul-96  R. V.      Use lib$sys_trnlog if sel VMS, else KUQUINF
*  18-Jul-94  K. Wozniak Increase NFILES to 10
*  06-Jun-93  R. V.      Add GENEVS
*  10-Jan-93  R. V.      Add VAX-specific code to get actual filename.
*                        There is also a KUIP non-specific alternative
*  10-Dec-92  R. V.      Changed name to UFILE; restructured to allow
*                        programs to call for individual files to be
*                        located and/or opened
*   9-Dec-92  C. Conner  Add field map in pre-sorted Zebra bank
*  15-Nov-92  R. Verdier Save unit values in IO common to flag
*                        results of file opens, add gcdefs
*   6-Jun-92  C. Parsons Separated from package, added cards$def
*     Apr-92  D. Mcleod  Creation in GPH package as UFILES
************************************************************************
*End_Documentation_Block

C     Global specifictions:

      IMPLICIT NONE

c     Arguments:

      integer LogUnit, Mode
      character*(*) LogName, FileName

C     External specifications:

*KEEP,IO.
C Common block for GPH logical units etc.: file IO.CMN
c 13-Aug-96  R. V.       Added USRBATCHK for KUIP commands for UGCONS
c 21-Jul-96  R. V.       Remove unused record; note CARDDEF now obsolete
c 22-Feb-93  R. V.       Added USRMCNTU and IMCNTU for MC Ntuple
c 14-Nov-92  R. Verdier  Added UGCIN, IUGCIN, CARDDEF and ICARDDEF
c                        for UGC and EUCARD (obsolete) input units
C    Apr-92  C. Parsons  Replacement for original COMMON.CDT
      INTEGER USRGCIN, CARDDEF, USRIN, USROUT, USRMAP, USRNTU, USRZEB,
     *  USRMCNTU, USRBATKUMAC
      PARAMETER (USRIN = 4, USROUT = 16, USRMAP = 18)
      PARAMETER (USRNTU = 15, USRZEB = 17, USRGCIN = 19, CARDDEF = 20)
      PARAMETER (USRMCNTU = 21, USRBATKUMAC = 22)
      INTEGER ICARDDEF, IMCNTU, IUSRGCIN, IUSRIN, IUSROUT, IUSRMAP,
     *  IUSRNTU, IUSRZEB, IUSRAOU, IUSRBATKUMAC
      COMMON /IO/ IUSRIN, IUSROUT, IUSRMAP, IUSRNTU, IUSRZEB, IUSRGCIN,
     *  ICARDDEF, IMCNTU, IUSRAOU, IUSRBATKUMAC
*KEEP,GCFLAG.
      COMMON/GCFLAG/IDEBUG,IDEMIN,IDEMAX,ITEST,IDRUN,IDEVT,IEORUN
     +        ,IEOTRI,IEVENT,ISWIT(10),IFINIT(20),NEVENT,NRNDM(2)
      COMMON/GCFLAX/BATCH, NOLOG
      LOGICAL BATCH, NOLOG
C
      INTEGER       IDEBUG,IDEMIN,IDEMAX,ITEST,IDRUN,IDEVT,IEORUN
     +        ,IEOTRI,IEVENT,ISWIT,IFINIT,NEVENT,NRNDM
C
*KEEP,FILES.
C Common block for UFILE routine
c 22-Aug-97  K. W.       Creation

      integer MaxFiles
      parameter (MaxFiles = 12)

c Preassigned files:
c RHDATA  is for FFREAD and STPARS control input
c GCDEFS  is for UGC system geometry and control input
c CARDS$DEF is for interactive input of FFREAD and STPARS data
c RHASC is for standard debug output
c BATKUMAC is for a KUIP batch command file
c FLDASC is for ascii-format magnetic field data
c RHZEB is for Zebra output
c RHNTU is for Ntuple output for tracks containing hits only
c MCNTU is for Ntuple output for all tracks
c GENEVS is for the ascii track input file
c The corresponding standard logical unit numbers usrin, ... are
c defined in IO.CMN now, but eventually should be defined directly by
c the definition for Luns below.
c Additional numbers 101, ... are pre-set for formatted ascii output
c files; for other file types, the user should call with mode = 1 and
c do his own OPEN.

      integer NFiles, NFilesPre
      character*32 LogNames(MaxFiles)    !  logical names of files
      character*63 FileNames(MaxFiles)   !  actual names of files
      integer Luns(MaxFiles)             !  FORTRAN logical units
      character*2 LogIndex(MaxFiles)     !  actual index of LogName
c                                        !  (excluding first file)

      integer Iform(MaxFiles)            !  FORMATTED/UNFORMATTED switch
      integer Irw(MaxFiles)              !  READONLY switch
      integer Istat(MaxFiles)            !  NEW/OLD/UNKNOWN switch

      common /cfiles/ NFiles, NfilesPre, LogNames, FileNames, Luns,
     + LogIndex, Iform, Irw,  Istat
*KEND.
      integer LENOCC

c Local definitions:

      integer IFile, ios,  i, i0, i1
      character*11 Form, Forms(3) /'formatted', 'unformatted',
     * 'unspecified'/
      character*7 Stat, Status(3) /'old', 'new', 'unknown'/
      character*80 LLogName

c Fortran File-not-found error number = 29 except = 2 for Linux G77
c and SGI IRIX, 6 for IBM AIX, and 1018 for Pentium SunOS
      integer FILENOTFOUND / 2 /

c report level: -1 = no output, 0 = errors only, 1 = always
      integer ireport / 0 /

c Executable Statements:

      ireport = ISWIT(5)

************************************************************************
*  Mode = 0, 1, 2, 3    Find logical unit number assigned to the file  *
************************************************************************
      if (Mode .ne. 4) then
        LogUnit = 0
        IFile = 0
        do while (LogUnit .eq. 0 .and. IFile .lt. NFiles)
          IFile = IFile + 1
          if (LogNames(IFile) .eq. LogName) LogUnit = Luns(IFile)
        enddo
      endif   !  Mode .ne. 4

*************************************************
*   Mode = 0, 1    assign new Lun if necessary  *
*************************************************
      if(Mode .eq. 0  .or.  Mode .eq. 1)  then
        if(LogUnit .eq. 0)   then     !  assign new Lun
          if(NFiles .lt. MaxFiles)  then
             NFiles = NFiles + 1
             IFile = NFiles
             LogNames(IFile) = LogName
             LogIndex(IFile) = '00'
             LogUnit = Luns(IFile)
          else
             write(*,'(2A/1x,A)')
     +                  ' *** ERROR IN UFILE: too many additional',
     +                  ' files already opened, file to open: ',
     +                  Logname
          endif   !  (NFiles .lt. MaxFiles)
        else
           LogIndex(IFile) = '00'
        endif   !  (LogUnit .eq. 0)
        LLogName = LogName
      endif   !  (Mode .eq. 0  .or.  Mode .eq. 1)

******************************************************************
*  Mode = 2   Close old file and generate new logical file name  *
*             (increase index at the end of the name)            *
******************************************************************
      if(Mode .eq. 2)   then
         if(LogUnit .gt. 0)   then
            if(LogIndex(IFile) .eq. '?')  then
               LLogName = LogName     !  first open (open with mode=0
               LogIndex(IFile) = '00' !  missing)
               write(*,'(/3A)') ' *** WARNING IN UFILE:  file ',
     +               LogName(1:LENOCC(LogName)),
     +               '  now opened for the first time in MODE=2'
            else
               close(LogUnit)
               i0 = ichar(LogIndex(IFile)(2:2))-ichar('0')
               i1 = ichar(LogIndex(IFile)(1:1))-ichar('0')
               i = 10*i1 + i0 + 1
               if(i .gt. 99)  i = 99
               i1 = i / 10
               i0 = i - 10*i1
               LogIndex(IFile)(1:1) = char(i1 + ichar('0'))
               LogIndex(IFile)(2:2) = char(i0 + ichar('0'))
               i0 = LENOCC(LogName)
               do  i=1,LENOCC(LogName)
                 if(LogName(i:i) .ne. ' ' .and. i .lt. i0)  then
                    i0 = i
                 endif
               enddo
               i1 = LENOCC(LogName)
               do  i=1,LENOCC(LogName)
                 if(LogName(i:i) .eq. ' ' .and. i .lt. i1)  then
                    i1 = i-1
                 endif
               enddo
               LLogName = LogName(i0:i1) // LogIndex(IFile)
            endif   !  (LogIndex(IFile) .eq. '?')  then
         else
            write(*,*) ' *** ERROR IN UFILE: (MODE=2), ',
     +                 'can not close unknown file: ', LogName
         endif   !  (LogUnit .gt. 0)
      endif   !  (Mode .eq. 2)

************************************************************
*  Mode = 0, 1, 2   Get actual file name from system call. *
*                   system dependent                       *
************************************************************
      if(Mode .ne. 3  .and.  LogUnit .ne. 0) then
          FileNames(IFile) = ' '
C  Similarly (7/15/97) get actual file name in UNIX environment,
C  assuming set by setenv call.  Otherwise use logical name & link to it.
          call GETENV(LLogName(1:LENOCC(LLogName)),FileNames(IFile))

          if( FileNames(IFile).eq. ' ') FileNames(IFile) = LLogName
          FileName = FileNames(IFile)(1:LENOCC(FileNames(IFile)))

      endif   !  (Mode .ne. 3  .and.  IFile .gt. 0)

***********************************************************************
*  Mode = 0, 2   Open the file if a Lun was assigned.                 *
*                The form of the statement has to be different        *
*                for different platforms because the Fortran standard *
*                prevents file characteristics like READONLY,         *
*                essential for reading data files that may be open    *
*                concurrently for other jobs, from being entered as   *
*                character strings or flag words.                     *
***********************************************************************
      if((Mode .eq. 0 .or. Mode .eq. 2) .and. LogUnit .gt. 0) then
         Form = Forms(Iform(IFile))
         Stat = Status(Istat(IFile))

         if(Irw(IFile) .eq. 1) then
c Open existing files with ACTION=READ for IBM AIX, nothing for Linux,
c READONLY for other o.s.'s
            OPEN (UNIT=LogUnit, FILE=FileName, FORM=Form, STATUS=Stat,
     1      IOSTAT=ios)
         else

c Open output file as status new, formatted/unformatted normally,
c status unknown under DEC OSF1 Unix
            OPEN(UNIT=LogUnit, FILE=FileName,
     *           FORM=Form, STATUS=Stat, IOSTAT=ios)
         endif   !  (Irw(IFile) .eq. 1)

c report results
         if(ireport .ge. 0) then

c          report each opened file:  ireport = 1
            if (ios .eq. 0 .and. ireport .ge. 1)
     1         print '(/2a,i1,2a/a,i4,5a/2a/)', ' UFILE ',
     2         '(mode=',  Mode,   '): opened ',
     3         LLogName(1:LENOCC(LLogName)),
     4         ' on unit', LogUnit, ', format = ', Form, ', status = ',
     5          Stat, ',', ' file ', FileName(1:LENOCC(FileName))

            if (ios .ne. 0)  then
               if (mode .eq. 2  .and. ios .eq. FILENOTFOUND) then
                  if(ireport .ge. 1) print '(/2a,i1,3a/3a,i4,a/)',
     1               ' UFILE ', '(mode=',  Mode,  '): ',
     2               LLogName(1:LENOCC(LLogName)),
     3               ' not found,', ' reading from ',
     4               LogName(1:LENOCC(LogName)),
     5               ' on unit', LogUnit, ' now complete.'
               else
c               report serious errors: also when   ireport = 0
                  print '(/2a,i1,2a/a,i4,5a,i6,a/2a/)',
     1             ' *** ERROR IN UFILE ',
     2             '(mode=', Mode, '): opening ',
     3             LLogName(1:LENOCC(LLogName)),
     4             ' on unit', LogUnit, ', format = ', Form,
     5             ', status = ', Stat, ', IOSTAT =', ios, ',',
     6             ' file ', FileName(1:LENOCC(FileName))
               endif   !  (mode .eq. 2  .and. ios .eq. 29)
            endif   !  (ios .ne. 0)
         endif   !  (ireport .ge. 0)

c Return the negative of the i/o error code if the open failed
         if(ios .ne. 0)   LogUnit = -abs(ios)

      endif   !  ((Mode .eq. 0 .or. Mode .eq. 2) .and. LogUnit .gt. 0)


****************************************************
*  Mode = 3    close assigned file                 *
****************************************************
      if(Mode .eq. 3) then
         if(LogUnit .gt. 0)   then
            LogIndex(IFile) = '?'
            close(LogUnit)
         else
            write(*,*) ' *** ERROR IN UFILE: (MODE=3), ',
     +                 'can not close unknown file: ', LogName
         endif   !  (LogUnit .gt. 0)
      endif   !  (Mode .eq. 3)


****************************************************
*  Mode = 4    close all assigned files            *
****************************************************
      if(Mode .eq. 4) then
         do   IFile=1,NFiles
            close(Luns(IFile))
         end do
         NFiles = NFilesPre
      endif   !  (Mode .eq. 3)

      return
      end
