      subroutine UGCVAL (token, lent, ivtype, rvalue, ivalue, index)
*Documentation_Block
************************************************************************
*
*  Description:
*  UGCVAL classifies and evaluates a token on the basis of its content.
*  The token is first assumed to be an integer; if it contains an "e" or
*  a decimal point, it is called real; if it fails either case, or if it
*  is embedded in apostrophes (', not "), it is called a string.
*  If the token contains left and right parentheses, UGCVAL converts the
*  characters between them to an integer and returns the result in
*  index; otherwise index = 0.
*
*  Arguments:
*  *token:  character string to be evaluated;
*  *lent*:  on input, the length of the token;
*           on output, the length up to a left parenthesis, if any
*  ivtype*: the returned classification of the token:
*    = 1, ivalue = integer value of token if token is integer
*    = 2, value = real value of token if token is real
*    = 3, if token is neither integer nor real
*    < 0, if error converting value
*  index*: the returned vector index value
*
*  Called by:
*  UGCIN, after receiving a token from UGCGET
*
*  Calls:
*  none
*
*  Implicit inputs, outputs, side effects:
*  none
*
*  History:
*  Date       Name       Description
*  ----       ----       -----------
*  12-Dec-97  K. W.      Removed comment suggesting apostrophes stripping
*                        in UGCGET
*                        Such stripping has to be done after UGCVAL recognizes
*                        the type of token to enable text (volume names)
*                        that look like a number
*  17-Aug-97  R. V.      Change ichar('0') and init ios to 0 for linux
*  25-Jul-96  R. V.      correct (i) read format
*  23-Apr-93  R. V.      Add lent and index arguments for vectors
*  02-Nov-92  R. Verdier Creation
************************************************************************
*End_Documentation_Block

      implicit none

c Argument declarations:

      character*(*) token
      integer index, ivalue, ivtype, lent
      real rvalue

c Local declarations:

c Linux g77 does not support ichar in a parameter declaration
      integer mindig / 256 /, maxdig / 256 /
      character cch*1, fmt*7, lpar*1 /'('/, rpar*1 /')'/
      integer ich, idebug /1/, ios, lc, lenind, llpar, lrpar
c End declarations

      ios = 0
      if (mindig .gt. 255) then
        mindig = ichar('0')
        maxdig = ichar('9')
      endif
      lc = 0
      llpar = 0
      lrpar = 0
      index = 0
c Determine the token type: assume integer, promote to real if
c decimal point or e is found, else treat it as a string.
      ivtype = 1
      do while (lc .lt. lent)
        lc = lc + 1
        cch = token(lc:lc)
        ich = ichar(cch)
        if (ivtype .lt. 3) then
          if (ich .lt. mindig .or. ich .gt. maxdig) then
            if (cch .eq. 'e' .or. cch .eq. 'E' .or. cch .eq. '.') then
              ivtype = 2
            else if (cch .ne. '-' .and. cch .ne. '+') then
              ivtype = 3
            endif
          endif
        endif
        if (ivtype .eq. 3) then
c If a string, check for presence of a vector index.  Note that an
c erroneous expression like 123(5) will be identified as a vector, and,
c if not found as a keyword, will be ignored by UGCSET.
          if (llpar .eq. 0) then
            if (cch .eq. lpar) llpar = lc
          else
            if (cch .eq. rpar) lrpar = lc
          endif
        endif
      enddo
c Convert the value according to the assigned type.  We could return
c values in both variables (with suitable limits on real->integer) if
c that turned out to be useful.
      if (ivtype .eq. 1) then
        write (fmt,'(a,i2,a)') '(i', lent, ')  '
        read (token, fmt, iostat=ios) ivalue
      else if (ivtype .eq. 2) then
        write (fmt,'(a,i2,a)') '(e', lent, '.0)'
        read (token,fmt,iostat=ios) rvalue
c Convert the index, if any
      else if (llpar .ge. 2) then
        lenind = lrpar - llpar - 1
        if (lenind .ge. 1) then
          write (fmt,'(a,i2,a)') '(i', lenind, ')  '
          read (token(llpar+1:lrpar-1), fmt, iostat=ios) index
        endif
        lent = llpar - 1
      endif
c Return ivtype = -|io error code| if the conversion failed.
      if (ios .ne. 0) ivtype = iabs(ios)
c Display error message only in debug mode, pending standard facility
      if (idebug .ge. 1 .and. ios .ne. 0) print '(a,i3,2a)',
     *  ' UGCVAL: Error ', ios, ' converting token ', token
c Display results only in debug mode
      if (idebug .ge. 3 .and. ivtype .ge. 1) then
        if (ivtype .eq. 1) print '(3a,i3,a,i8)', ' UGCVAL: token ',
     *    token, ': type ', ivtype, ', value =', ivalue
        if (ivtype .eq. 2) print '(3a,i3,a,e12.4)', ' UGCVAL: token ',
     *    token, ': type ', ivtype, ', value =', rvalue
        if (ivtype .eq. 3) print '(3a,i3    )', ' UGCVAL: token ',
     *    token, ': type ', ivtype
      endif
      return
      end
