#include "TROOT.h"
#include "TClass.h"
#include "Getline.h"
#include "TPhInteract.h"

ClassImp(TPhInteract)

/////////////////////////////////////////////////////////////////////////////
//                                                                         //
//   TPhInteract                                                           //
//                                                                         //
//   Phobos user interaction class                                         //
//                                                                         //
//   TPhInteract provides interface to the Getline package used in         //
//   the ROOT TRint class.                                                 //
//   This package provides Emacs style input line editing and history.     //
//   The Getline package is a set of global functions that use only one    //
//   copy of memory storage.                                               //
//   The Ask() function is used to ask the question, and if used without   //
//   the second parameter the history feature is not activated.            //
//                                                                         //
/////////////////////////////////////////////////////////////////////////////


TPhInteract::TPhInteract()
{
  //
   
   strcpy(fPrompt,"");
   strcpy(fHist,"");
}

TPhInteract::~TPhInteract()
{
    Getlinem(kCleanUp, NULL); 
}

char *TPhInteract::Ask(Char_t *prompt, Char_t *hist)
{
   // Set prompt and take answer

   Char_t *p;
   Bool_t isHist = kTRUE;;

   // Set prompt and history file name for this interaction
   strcpy(fPrompt,prompt); 

   // If empty string for history file, then no history of the interaction is kept
   if( !strcmp(hist,"") ) isHist = kFALSE;
   if( isHist ) {
     // Set an interaction specific history file
     strcpy(fHist,hist);
     Gl_histinit(fHist);
   }

   p = Getlinem(kLine1,fPrompt);
   if( isHist ) {
      Gl_histadd(p);

      // Back to TRint history file
      Gl_histinit(".root_hist");
   }

   //convert \n ended Getline string to the \0 ended
   p[strlen(p)-1] = '\0';

   strcpy(fAns,p);
   return fAns;
}


