#ifndef _TPhTrackFinder_
#define _TPhTrackFinder_
//
// TPhTrackFinder.h
//
// 19981015.1738 Inkyu.Park@bnl.gov
// 19981203. 
//
//
//
#include "TObject.h"
#include "TObjArray.h"
#include "TPolyLine3D.h"

#include "TPhHough.h"
class TPhEvent;
class TPhTrack;
class TPhRecTrack;
class TPhHit;
class TPhMagnet;
class TPhSensor;
class TPhSiSensor;
class TPhDetector;
class TPhTrackTemplate;
class TPhStuff;
class TPhTrackSeedFinder;
class TPhHough;
class TPhHoughHit;
class TPhHoughRoad;
class TPhMerging;
class TPhMulguisin;

const int kNLayer = 16; // number of layers
const int kNumHits = 10; // maximum number of hits compatible with a track template
const int kNPairs = 4;
const int k0Pairs[kNPairs] = { 8, 9,10,12};
const int k1Pairs[kNPairs] = { 9,10,12,14};

class TPhTrackFinder : public TObject {

private:

  Bool_t        fVerbose;           //! Control debugging output
  int           fOuterLayer;        //! first layer of outer layers 
  Int_t         fMinHits;           //! Minimum number of hits for track candidates
  Float_t       fMinProb;           //! Minimum chi^2 probability for track candidates
  Float_t       fMaxCompDist;       //! maximum distance between hit and template
  Float_t       fMinCompEnergy;     //! For selection of hits compatible with template
  int           fMaxSharedHits;     //! maximum allowed shared hits for tracks
  
  TPhMerging   *fMerge;             //! hit merge
  TPhStuff     *fStuff;             //! Routines for chi^2 probabilities etc
  TPhDetector  *fDetector;          //! PHOBOS Detector Object
  TObjArray    *fTemplateList;      //! list of track templates
  TObjArray    *fCandidateList;     //! list of Track candidates
  TObjArray    *fTrackList;     	   //! list of final reconstructed track  
  TPhHit       *fHitArray[kNLayer][kNumHits]; //! Array of hits compatible with template
  Int_t         fHitCnt[kNLayer]; //! Number of hits compatible with template per layer
 
  float         fErrorQP[kNPairs];	//! mo
  float         fErrorTH[kNPairs];	//! mo
  TPhHough     *fHough;			//! ho
  TObjArray    *fHoughHitA[kNLayer];	//! hh
  TObjArray    *fHoughRoadA[kNPairs];	//! 
  TObjArray    *fCurveList;     //! list of Track candidates
  TObjArray    *fTrack[16]; //! temporary
  TObjArray    *fSeedList;         //! TPhTrackSeedFinder

  float         fSeedResol;
  
  virtual void  DrawCurves();
  
public:
  
                       TPhTrackFinder();
  virtual             ~TPhTrackFinder();
  
  virtual void         SetVerbose(Int_t i){fVerbose=i;}
  virtual void         SetOuterLayer(int i){fOuterLayer=i;}
  virtual void         SetMinHits(int i){fMinHits=i;}
  virtual void         SetMinProb(float x){fMinProb=x;}
  virtual void         SetMaxCompDist(Float_t x){fMaxCompDist=x;}
  virtual void         SetMinCompEnergy(Float_t x){fMinCompEnergy=x;}
  virtual void         SetMaxSharedHits(Int_t n){fMaxSharedHits=n;}
  virtual void         SetHoughTable(TPhHough *hough){fHough=hough;}
  virtual void         SetSeedList(TObjArray *seeds){fSeedList=seeds;}
  virtual void         SetSeedResol(float resol){fSeedResol=resol;}
  virtual Bool_t       ReadTemplateList(Char_t *TemplName);
  virtual void         ScanTemplates(){ScanTemplates(NULL);}
  virtual void         ScanTemplates(TPhTrackSeedFinder *tsf);
  virtual Int_t        GetCompatibleHits(TPhTrackTemplate *t);
  virtual void         SelectTracks(TObjArray *list);
  virtual Bool_t       DoCompete(TPhRecTrack *t1, TPhRecTrack *t2);

  virtual void         SetErrorQP(int i, float x){fErrorQP[i]=x;}
  virtual void         SetErrorTH(int i, float x){fErrorTH[i]=x;}
  virtual void         FillHit();
  virtual void         DoHough(int,float,float,float,float);
  virtual void         RunMulguisin();
  virtual void         FindCurve(int charge, int direction);
  virtual void         FindTrackCandidate(TPhTrack *seed, int direction);
  virtual void         ResetCurveList(){fCurveList->Clear();}
  virtual TObjArray   *GetCurveList(){ return fCurveList;}
  
  virtual TObjArray   *GetHoughRoadList(int i){return fHoughRoadA[i];}
  
  virtual TPhDetector *GetDetector()     { return fDetector; }
  virtual TObjArray   *GetTemplateList() { return fTemplateList; }
  virtual TObjArray   *GetCandidateList(){ return fCandidateList;}
  virtual TObjArray   *GetTrackList(){ return fTrackList;}
  
  ClassDef(TPhTrackFinder,1) // Manages the pre-generated templates.

};

#endif
