#ifndef _PhTrackSelector_INCLUDED_
#define _PhTrackSelector_INCLUDED_

///////////////////////////////////////////////////////////////////////
//                                                                   //
//    TPhTrackSelector                                               //
//                                                                   //
//    PHOBOS track selection class                                   //
//                                                                   //
//    TPhTrackSelector selects non-conflicting tracks from a list    //
//    of candidate tracks                                            //
//                                                                   //
//    Author  : Gunther Roland (rolandg@vxcern.cern.ch)              //
//    Created : 15/03/97                                             //
//    Version : 1.0                                                  //
//    Changed :                                                      //
//                                                                   //
///////////////////////////////////////////////////////////////////////

// ROOT classes

#include "TObject.h"
#include "TObjArray.h"

// Phobos classes

class TPhRecTrack;

class TPhTrackSelector : public TObject {

public:
    TPhTrackSelector();

    virtual ~TPhTrackSelector() {};


    virtual void              SetVerbose(Int_t n)  { fVerbose = n; }

    virtual TObjArray        *GetCandidateList()   { return fCandidateList; }
    virtual TObjArray        *GetTrackList()       { return fTrackList; }
    virtual void              SelectTracks(TObjArray *CandList);
    virtual Bool_t            DoCompete(TPhRecTrack *t1, TPhRecTrack *t2);
    virtual void              ChooseTrack(TPhRecTrack *t1, TPhRecTrack *t2);

private:

    Int_t             fMinHits;          //  Minimum number of hits for track candidates
    Float_t           fMinProb;          //  Minimum chi^2 probability for track candidates
    Float_t           fMaxSharedHits;    //  Maximum number of shared hits between 2 tracks
    TObjArray        *fCandidateList;    //! List of track candidates
    TObjArray        *fTrackList;        //! List of selected output tracks
    Bool_t            fVerbose;          //! Control debugging output

public:

    ClassDef(TPhTrackSelector,1) // Select non-confilicting tracks from a list of cadidate tracks. 

};

#endif



