//
//
// TPhHough
//
//
//
#include "TFile.h"

#include "TPhHough.h"
#include "TPhMCTrack.h"
#include "TPhMCHit.h"
#include "TPhTrack.h"
#include "TPhHit.h"
double a_min[kNPair] = { 0.40, 0.40, 0.30, 0.25};
double a_max[kNPair] = { 1.20, 1.20, 1.30, 1.35};
double c_min[kNPair] = {-0.60,-1.20,-1.80,-2.40};
double c_max[kNPair] = { 0.60, 1.20, 1.80, 2.40};
char *HistQP[kNPair] = {"HistQP_IJ","HistQP_JK","HistQP_KM","HistQP_MO"};
char *HistTH[kNPair] = {"HistTH_IJ","HistTH_JK","HistTH_KM","HistTH_MO"};

ClassImp(TPhHough)

TPhHough::TPhHough()
{
  fDebug = 0;
  for(int i=0;i<kNPair;i++)
  {
    fHistQP[i]=new TH2F(HistQP[i],HistQP[i],
	A_BINS,a_min[i],a_max[i],C_BINS,c_min[i], c_max[i]);
    fHistTH[i]=new TH2F(HistTH[i],HistTH[i],          
	A_BINS,a_min[i],a_max[i],C_BINS,c_min[i], c_max[i]);
  }
}

TPhHough::~TPhHough()
{
  if (fDebug) printf("~TPhHough");
}

Bool_t TPhHough::GetAngleCurve(double z0,double x0,double z1,double x1,double *angle,double *curve)
{
  //
  // alpha: angle to h0
  // beta : angle to h1
  // gamma: relative angle
  //

  *angle=0;
  *curve=0;  

  double dz=z1-z0;
  double dx=x1-x0;
  
  if (dz==0)
  {
    if (fDebug) printf("Really z0=z1! (%5.3f=%5.3f)\n",z0,z1);
    return 0;
  }
// Gunter's function 
//  double tan0=x0/z0;
//  double tan1=dx/dz;
//  *angle = atan(x0/z0);
//  *curve = atan((tan1-tan0)/(1+tan1*tan0));
//  return 1;
// My first try*  
//  double alpha= atan(x0/z0);
//  double beta = atan(dx/dz);
//  *angle = alpha;
//  *curve = beta-alpha;  
  
  double Ur = sqrt(x0*x0+z0*z0);
  double Ux = x0/Ur;
  double Uz = z0/Ur;
  
  double Dr = sqrt(dx*dx+dz*dz);
  double Dx = dx/Dr;  
  double Dz = dz/Dr;
  
  double UoD = Uz*Dz + Ux*Dx;
  double UxD = Uz*Dx - Ux*Dz;

  *angle = atan(x0/z0); 
  *curve = (asin(UxD)>0)?acos(UoD):-acos(UoD);
  
  if (fDebug)
    printf("\t(z,x)=(%5.3f,%5.3f)(%5.3f,%5.3f) : angle=%5.3f curve=%5.3f\n",
	  z0,x0,z1,x1,*angle,*curve);
  return 1;
}

Bool_t TPhHough::AngleCurveToBin(int l,double angle,double curve,int *angle_bin,int *curve_bin)
{// Get bins in Hough table for matchstick parameters (curve,angle)

  //
  // check whether angle & curve are in the limits
  //
  
  *angle_bin=-1;
  *curve_bin=-1;
  if (angle<a_min[l]||angle>a_max[l]||curve<c_min[l]||curve>c_max[l]) return 0;

  //
  // now calculate!
  //
  
  *angle_bin=(int)((angle-a_min[l])/(a_max[l]-a_min[l])*A_BINS);
  *curve_bin=(int)((curve-c_min[l])/(c_max[l]-c_min[l])*C_BINS);
  
  if (fDebug)
    printf("\tangle_bin=%d (%g), curve_bin=%d (%g)\n",
      *angle_bin,angle,*curve_bin,curve);

  return 1;

}

Bool_t TPhHough::BinToAngleCurve(int l, int angle_bin,int curve_bin,double *angle,double *curve)
{// Translate bins in table into matchstick parameters

  //
  // check 
  //
  *angle = 0;
  *curve = 0;
  if (curve_bin<0||curve_bin>=C_BINS||angle_bin<0||angle_bin>=A_BINS) return 0;
    
  //
  //
  //

  *angle=(double)(angle_bin+0.5)/(double)A_BINS*(a_max[l]-a_min[l])+a_min[l];
  *curve=(double)(curve_bin+0.5)/(double)C_BINS*(c_max[l]-c_min[l])+c_min[l];

  return 1;

}

void TPhHough::Normalize()
{
  for (int i=0;i<kNPair; i++)
  for (int ia=0;ia<A_BINS; ia++)
  for (int ic=0;ic<C_BINS; ic++)
  {
    if (fHoughNB[i][ia][ic]>0)
    {
      fHoughQP[i][ia][ic] /= (double) fHoughNB[i][ia][ic];
      fHoughTH[i][ia][ic] /= (double) fHoughNB[i][ia][ic];
      fHoughNB[i][ia][ic]  = 1;
    }
  }
}

void TPhHough::FillHistograms()
{
  double angle,curve;
  for (int i=0;i<kNPair; i++)
  for (int ia=0;ia<A_BINS; ia++)
  for (int ic=0;ic<C_BINS; ic++)
  {
    if (fHoughNB[i][ia][ic]>0)
    {
      BinToAngleCurve(i,ia,ic,&angle,&curve);
      fHistQP[i]->Fill(angle,curve,fHoughQP[i][ia][ic]);
      fHistTH[i]->Fill(angle,curve,fHoughTH[i][ia][ic]);
    }
  }
}


void TPhHough::SmoothTable()
{
//
// Filling missing bins by 
//  
  for (int ip=0;ip<kNPair; ip++)
  {// ---- loop over pairs 0 ----
    if (fDebug) printf("Smoothing Table %d...\n",ip);
    for (int ic=0;ic<C_BINS; ic++)
    {// ---- loop over curves 0 ----
      if (fDebug) printf("%3d:",ic);
      int ia=0;
      while (ia<A_BINS)
      {
        int ix=ia+1;
        while (ix<A_BINS && fHoughNB[ip][ix][ic]==0) ix++; 
        if (fDebug) printf("%d-%d,",ia,ix);
	if (ia!=0 && ix!=A_BINS)
	{ 
	  int   dnum=ix-ia;
	  double doop=fHoughQP[ip][ix][ic]-fHoughQP[ip][ia][ic];
	  double deloop=doop/(double)dnum;
	  double dthe=fHoughTH[ip][ix][ic]-fHoughTH[ip][ia][ic];
 	  double delthe=dthe/(double)dnum;
	  for (int i=1; i<dnum; i++)
          {
            fHoughQP[ip][i+ia][ic]=fHoughQP[ip][ia][ic]+deloop*i;
            fHoughTH[ip][i+ia][ic]=fHoughTH[ip][ia][ic]+delthe*i;
            fHoughNB[ip][i+ia][ic]=1;
	  }
	}
        ia=ix;
      }
      if (fDebug && ia!=0) printf("\n");
    }// ---- loop over curves 1 ----
  }// ---- loop over pairs 1 ----
}

void TPhHough::WriteTable()
{// Write hough table to file
  this->SetObject("Hough","test version");
  TFile *f=new TFile("hough.root","RECREATE");
  this->Write(); 
  f->Close();
}

void TPhHough::ReadTable(int ip,int ic)
{
  //TFile *f = new TFile("hough.root"); 
  //f->ls();
  //TPhHough *this=(TPhHough*)f->Get("Hough");
  //:&this=hough;
  //f->Close();
  
  printf("Number of pairs = %d\n",kNPair);
  printf("Number of A BINS= %d\n",A_BINS);
  printf("Number of C BINS= %d\n",C_BINS);

  for (int ia=0; ia<A_BINS; ia++)
    printf("%d -> %5.3f %5.3f\n",ia,fHoughQP[ip][ia][ic],fHoughTH[ip][ia][ic]);
    
  
}

void TPhHough::FillTable(TPhMCTrack *track)
{
  
  double z[16],x[16];
  double za[16][20],xa[16][20];
  int    na[16];
  
  //
  // minimum momentum
  //
  
  double p  = track->GetP();
  double px = track->GetPx();
  double py = track->GetPy();
  double pz = track->GetPz();
  if (p<0.05) return;
  
  double theta = acos(pz/p);
  if (theta<0.35) return;

  theta = atan(px/pz); // recalculate

  if (fDebug)
    printf("(Px,Py,Pz)=(%f,%f,%f) : theta=%f, oop=%f\n",
      px,py,pz,theta,1/p);

  if (theta<0.0) printf("Crazy...%f",theta);
  
  //
  // initialization 
  //
  
  for (int i=0; i<16; i++)
  {
    for (int j=0; j<20; j++)
    {
      za[i][j]=0;
      xa[i][j]=0; 
    }
    na[i]=0;
    z[i]=0;
    x[i]=0;
  }
  
  //
  // build hit array
  //

  TObjArray *hits=track->GetHitList();
  if (!hits) return;
  
  int nhits = hits->GetEntries();
  for (int ih=0; ih<nhits; ih++)
  {
    TPhHit *hit = (TPhHit *) hits->At(ih);
    int layer=hit->GetLayer();
    if (layer>15||layer<0) printf("Oh la la!\n");
    // if (fDebug) printf("%d",layer);
    za[layer][na[layer]]=hit->GetZ();
    xa[layer][na[layer]]=hit->GetX();  
    na[layer]++;
    if (na[layer]>3) return;
  //  if (na[layer]>=9) printf("$ %d (%d) $\n",layer,na[layer]);
  }
  //
  // hit merging
  //

  for (int il=0; il<16; il++)
  {
    if (na[il]!=0)
    {
      double zs=0;
      double xs=0;
      for (int in=0; in<na[il]; in++)
      {
        zs+=za[il][in];
        xs+=xa[il][in]; 
      }
      z[il]=zs/(double)na[il];    
      x[il]=xs/(double)na[il];    
    }
  }
  
  //
  //
  //

  Bool_t flag;
  double angle,curve;
  int   a_bin,c_bin;
  
  for(int l=0;l<kNPair;l++)
  {

    int l0 = k0Pair[l];
    int l1 = k1Pair[l];

    if (fDebug) printf("l0 = %d, l1 = %d\n",l0,l1);

    if(na[l0]!=0 && na[l1]!=0)
    {

      flag=GetAngleCurve(z[l0],x[l0],z[l1],x[l1],&angle,&curve);

      if (fDebug)
        if (angle<a_min[l]||angle>a_max[l]||curve<c_min[l]||curve>c_max[l])
          printf("should increase range for %d pair: %5.3f %5.3f\n",
            l,angle,curve);	    
	
      flag=AngleCurveToBin(l,angle,curve,&a_bin,&c_bin);
   
      if (flag)
      {	
        fHoughQP[l][a_bin][c_bin]+=1.0/p;
        fHoughTH[l][a_bin][c_bin]+=theta;
        fHoughNB[l][a_bin][c_bin]++;
      }
    }
  }
}

void TPhHough::Transform(int charge,int num,double z0,double x0,double z1,double x1,
                         double *theta_out,double *oop_out)
{
  if (fDebug) printf("\tTPhHough::Transform\n");
  int    a_bin, c_bin;
  double  angle_in, curve_in;
  *theta_out = 0;
  *oop_out   = 0;
  
  GetAngleCurve(z0,x0,z1,x1,&angle_in,&curve_in);

  if (curve_in*charge>0) return;

  if (AngleCurveToBin(num,angle_in,curve_in,&a_bin,&c_bin))
  {
    *theta_out = fHoughTH[num][a_bin][c_bin];
    *oop_out   = fHoughQP[num][a_bin][c_bin];
  }
  if (fDebug) printf("\ttheta=%5.3f, oop=%5.3f\n",*theta_out,*oop_out);
  
}
/*
void TPhHough::Transform(int num,double z0,double x0,double z1,double x1,
                         double *theta_out,double *oop_out)
{
  int    a_bin, c_bin;
  double  angle_in, curve_in;
  double  theta[2],oop[2];
  *theta_out = 0;
  *oop_out   = 0;
  
  GetAngleCurve(z0,x0,z1,x1,&angle_in,&curve_in);

  AngleCurveToBin(num,angle_in,curve_in,&a_bin,&c_bin);

  theta[0] = fHoughTH[num][a_bin][c_bin];
  oop[0]   = fHoughQP[num][a_bin][c_bin];

  *theta_out = theta[0];
  *oop_out = oop[0];

  if (fDebug) printf("\ttheta=%5.3f, oop=%5.3f\n",*theta_out,*oop_out);
  
}*/

