#ifndef _PhASCIIHijet_INCLUDED_
#define _PhASCIIHijet_INCLUDED_

///////////////////////////////////////////////////////////////////////
//                                                                   //
//    TPhASCIIHijet                                                  //
//                                                                   //
//    HIJET MC data handling class                                   //
//                                                                   //
//    Interface to Hijet format ASCII output files with (only)       //
//    particle id and momentum information for events generated      //
//    by a MC Event Generator.                                       //
//    It reads ASCII file and makes standard TPhRun and TPhEvent     //
//    objects, with track container called EGTracks                  //
//                                                                   //
//    Author  : A. Olszewski                                         //
//    Created : 25/05/97                                             //
//    Version : 1.0                                                  //
//    Changed : 15.06.98 A.Olszewski                                 //
//              Updated to create containers for tracks and hits     //
//              Run number added in the constructor.                 //
//    Changed : 10.01.99 A.Olszewski                                 //
//              Updated to process parameters accessed by name       //
//              Run object created                                   //
//                                                                   //
// $Id: TPhASCIIHijet.h,v 1.3 1999/01/08 08:47:18 olszewsk Exp $ 
//                                                                   //
/////////////////////////////////////////////////////////////////////// 

#include "TObject.h"
#include "stdio.h"

class TPhMCTrack;  
class TPhEvent;  
class TPhRun;  

class TPhASCIIHijet : public TObject {

public:
    TPhASCIIHijet(); 
    TPhASCIIHijet(Char_t *fname, Int_t nrun=1, Int_t startevno=0);

    virtual ~TPhASCIIHijet();

    Bool_t      Open(Char_t *fname);
    Bool_t      Close();

    TPhRun     *GetRun()                        { return fRun;          }

    TPhEvent   *GetNextEvent();
    Int_t       GetEventCounter()               { return fEventCounter; }
    Bool_t      GetEofStat()                    { return fleof;         }


private:

    void        SetCurrRun(TPhRun *run)         { fRun = run;           }
    void        SetCurrEvent(TPhEvent *event)   { fEvent = event;       }
    Bool_t      AddASCIIRInfo();
    Bool_t      AddASCIIEInfo();
    TPhMCTrack *GetNextTrack();

    Char_t    fFileName[256];           //! File name for ASCII HIJET file 
    FILE     *fFilePointer;             //! File pointer to ASCII HIJET file
    TPhRun   *fRun;                     //! Current run object
    TPhEvent *fEvent;                   //! Current event object
    Int_t     fNRun;                    //! Run number
    Int_t     fEventCounter;            //! Event counter     
    Char_t    fASCIIEGName[120];        //! MC event generator name
    Char_t    fReadBuffer[120];         //! Read buffer
    Bool_t    fleof;                    //! End of file flag 

public:
    ClassDef(TPhASCIIHijet,1)           // Interface to HIJET ASCII format

};

#endif // _PhASCIIHijet_INCLUDED_
