#include "TMath.h"

#include "TPhASCIIHijet.h"
#include "TPhObjectContainer.h"

#include "TPhMCHit.h"
#include "TPhMCTrack.h"
#include "TPhEvent.h"
#include "TPhRun.h"

#include "TPhParManager.h"

#undef DEBUG

ClassImp( TPhASCIIHijet )

//////////////////////////////////////////////////////////////////////////
//
// Interface to Hijet format ASCII output files with (only) particle id and
// momentum information for events generated by an MC Event Generator.
//
// $Id: TPhASCIIHijet.cxx,v 1.6 1999/01/08 08:47:18 olszewsk Exp $
// 
//////////////////////////////////////////////////////////////////////////


 TPhASCIIHijet::TPhASCIIHijet()
{
    fFilePointer  = NULL;
    fEventCounter = 0;
    fRun = NULL; 
    fEvent = NULL;  
    fNRun = 0;
    fEventCounter = 0;
    fleof = kFALSE;
}

 TPhASCIIHijet::TPhASCIIHijet( Char_t *fname, Int_t nrun, Int_t startevno )
{
    fFilePointer  = NULL;
    fEventCounter = startevno;
    fRun = NULL;
    fEvent = NULL;
    fNRun = nrun;
    fASCIIEGName[0] = '\0';
    fleof = kFALSE;

    Open( fname );
}

TPhASCIIHijet::~TPhASCIIHijet()
{ 
  //destructor does not touch event and run objects
  fRun=NULL;
  fEvent=NULL;
  if(fFilePointer) Close();
}


 Bool_t TPhASCIIHijet::Open(Char_t *fname)
{

    sprintf( fFileName,"%s",fname );
    if( !fFileName ) return kFALSE;
    fFilePointer = fopen( fFileName,"r" );
    if( !fFilePointer )
    {
        printf( "Can't open File %s\n",fFileName );
        return kFALSE;
    }
    else
    {
        fleof = kFALSE;
	if( !fgets(fReadBuffer, 120, fFilePointer) ) return kFALSE;
        while( AddASCIIRInfo() ) {
	  if( !fgets(fReadBuffer, 120, fFilePointer) ) {
	    fleof = kTRUE;
	    return kFALSE;
	  }
	}
    }
    return kTRUE;
}

 Bool_t TPhASCIIHijet::Close()
{
    if( fFilePointer )
    {
        fclose( fFilePointer );
        fFilePointer = NULL;
        fleof = kFALSE;
        return kTRUE;
    }
    else
    {
        return kFALSE;
    }
}

Bool_t TPhASCIIHijet::AddASCIIRInfo()
{
  //
#ifdef DEBUG
   printf("AddASCIIRInfo was called with:\n Run parameter:%s\n", runinfo);
#endif
   Char_t temp[120];
   Int_t  norec=0;
   Char_t ind[2], keyname[20], keyvalue[120];
   TPhParManager *parman = NULL;
   TPhParKey *parkey = NULL;
   Char_t sourceMC[]="MC";

   // Real generator name is given as a parameter
   // Only after this is known the proper source name is set
   // for other generator parameters 
   if(*fASCIIEGName=='\0') {
     if(!fRun) fRun = new TPhRun(fNRun);
     parman = fRun->GetParManager();
     if(parman) 
       if(parman->GetParTextValue(temp, "GENERATOR", sourceMC)) 
	 sscanf(temp,"%119s",fASCIIEGName);
   }

   sscanf(fReadBuffer,"%s %s %[ -~]", ind, keyname, keyvalue);
   // R indicates event generator run parameters
   if(!strcmp(ind,"R")) {
     norec++;
     if(*fASCIIEGName!='\0') 
          parkey = new TPhParKey(fASCIIEGName,keyname,keyvalue);
     else parkey = new TPhParKey(sourceMC,keyname,keyvalue);
   }
   // others are ignored
   else return kFALSE;

   fRun->AddParameter(parkey);
   return kTRUE;

}


Bool_t TPhASCIIHijet::AddASCIIEInfo()
{
  //
#ifdef DEBUG
   printf("AddASCIIEInfo was called with:\n Event parameter:%s\n", evinfo);
#endif
   Char_t ind[2], keyname[20], keyvalue[120];
   TPhParKey *parkey = NULL;
   Char_t sourceMC[]="EventGenerator";

   sscanf(fReadBuffer,"%s %s %[!-~]", ind, keyname, keyvalue);
   // only H is expected to be seen here
   if(!strcmp(ind,"H")) 
     if(*fASCIIEGName!='\0') 
          parkey = new TPhParKey(fASCIIEGName,keyname,keyvalue);
     else parkey = new TPhParKey(sourceMC,keyname,keyvalue);
   // end of event flag is understood
   else if(!strcmp(ind,"E")) return kTRUE; 
   // others are ignored
   else return kFALSE;

   fEvent->AddParameter(parkey);
   return kTRUE;
}


 TPhEvent *TPhASCIIHijet::GetNextEvent()
{
    Char_t name[64];

    TPhMCTrack  *track;
    fEvent = new TPhEvent(fNRun, fEventCounter);
    //    TPhEvent *event = new TPhEvent(fNRun, fEventCounter);
    //    SetCurrEvent(event);

    if(fleof) return NULL;

    // should come with line after run info in the buffer
    while( AddASCIIEInfo() ) {
      if( (fgets(fReadBuffer, 120, fFilePointer))==NULL ) {
	fleof = kTRUE;
	return NULL;
      }
    }

    sprintf(name,"event_%d_%d",fEventCounter,fNRun);
    fEvent->SetName(name);
    sprintf(name,"%s",fASCIIEGName);
    fEvent->SetTitle(name);

    TPhObjectContainer *TrackBuffer = new TPhObjectContainer("EGTracks");
    fEvent->AddObject(TrackBuffer);

    Int_t trno = 0;
    while( (track=GetNextTrack()) ) { 
       track->SetTrackNo( trno ); 
       TrackBuffer->Add( track ); 
       trno++;    
       if( (fgets(fReadBuffer, 120, fFilePointer))==NULL ) {
	 fleof = kTRUE;
	 break;
       }
    }

    if( !trno ) { delete fEvent; return NULL; }

    fEventCounter++;
    return fEvent;
}

TPhMCTrack *TPhASCIIHijet::GetNextTrack()
{
   Char_t control;
   Int_t gcharge[50]={ 0, 1,-1, 0, 1,-1, 0, 1,-1, 0,
                       1,-1, 0, 1,-1, 0, 0, 0, 1, 0,
                      -1, 0,-1,-1, 0, 0,-1, 0, 1, 0,
                       1, 1, 0, 0, 0, 0, 0, 0, 0, 0,
                       0, 0, 0, 0, 1, 1, 2, 0, 2, 0};
   Float_t gmass[50]={ 0, 0.00051099906, 0.00051099906, 0, 0.105658389, 
                       0.105658389, 0.1349764, 0.1395700, 0.1395700, 0.497672,
                       0.493677, 0.493677, 0.93956563, 0.83827231,  0.83827231, 
                       0.497672, 0.54745, 1.115684, 1.18937, 1.19255,
                       1.197436, 1.3149, 1.32132, 1.67245, 0.93956563, 
                       1.115684, 1.18937, 1.19255, 1.197436, 1.3149,
                       1.32132, 1.67245, 0, 0, 0, 
                       0, 0, 0, 0, 0,
                       0, 0, 0, 0, 1.875613, 
                       2.80925, 3.727417, 0, 2.80923, 0};
   Int_t pid;
   Float_t mom;
   Float_t theta;
   Float_t phi;
   Float_t px;
   Float_t py;
   Float_t pz;

#ifdef DEBUG
   printf( "Read track info\n" );
#endif

   sscanf(fReadBuffer,"%c", &control) ;
   if( control != 'P' ) return NULL; 

   sscanf( fReadBuffer,"%c %d %f %f %f\n", 
                        &control, &pid, &mom, &theta, &phi );

   if( pid>50 || pid<1 ) {
     printf( "Unknown GEANT pid = %d changed to Cerenkov (50)\n",pid );
     pid = 1;
   }
   px = mom * TMath::Sin( theta ) * TMath::Cos( phi ); 
   py = mom * TMath::Sin( theta ) * TMath::Sin( phi );
   pz = mom * TMath::Cos( theta );  

#ifdef DEBUG
   printf( "Found %5d %10g %10g %10g \n", 
                  pid, px,  py,  pz );
#endif

   TPhMCTrack *track = new TPhMCTrack();

   track->SetPx( px );
   track->SetPy( py );
   track->SetPz( pz );
   track->SetXProd( 0 );
   track->SetYProd( 0 );
   track->SetZProd( 0 );
   track->SetGPid( pid );
   track->SetCharge( gcharge[pid-1] );
   track->SetMass( gmass[pid-1] );

   return track;

}

