#include "stdio.h"
#include "math.h"
#include "TPhSwim.h"
#include "TPhMagnet.h"
#include "TPhDetector.h"
#include "TPhSpectSensor.h"
#include "TPhSubDetector.h"
#include "TPhObjectContainer.h"
#include "TPhMCHit.h"
#include "TPhMCTrack.h"
#include "TPhEvent.h"
#include "TPhLayer.h"
#include "TRandom.h"
#include "TSystem.h"
#include "TMath.h"

ClassImp(TPhSwim)
//////////////////////////////////////////////////////////////////////////////
// 
// TPhSwim 
//
// This class is used for PHOBOS simulation work in applications that 
// require a quick turn out around for changes in detector configuration,
// event type or sensor properties.
// The simulation routines are interfaced to the detector geometry with a 
// pointer to a TPhDetector object and to the magnetic field map with a 
// pointer to a TPhMagnet object. These two objects have to be created 
// independently from TPhSwim.
// TPhSwim can be called for TPhEvent or TPhMCTrack objects. The TPhMCHit 
// objects created by TPhSwim will be stored in the HitLists of the 
// tracks, events and the TPhSensor objects in the TPhDetector object.
//
// Important note: The TPhSwim object requires a parametrisation of 
// a Landau distribution stored in a file called landau.init that
// should be stored in the $PHATHOME/init directory
//
// 
///////////////////////////////////////////////////////////////////////////////

static int total_calls = 0;

TPhSwim::TPhSwim()
{
// TPhSwim constructor
// Initialize some of the flags and set pointers to 
// fMagnet and fDetector to NULL
// These pointers have to be initialized before TPhSwim 
// can be used
// fDoMS and fPixelize control the multiple scattering,
// which is handled by TPhSwim and Pixelisation, which
// is done in the TPhSensor class. 

    fDoMS       = kFALSE;
    fPixelize   = kFALSE;
    fVerbose    = kFALSE;
    fMagnet     = NULL;
    fDetector   = NULL;
    fSensorList = NULL;
    InitLandau();
}

Bool_t TPhSwim::SwimEvent(TPhEvent *event)
{
// Propagate one event through the PHOBOS setup. Creates
// TPhMCHit objects on the track that are stored in the event
// hitlist, the hitlists of the individual tracks and the 
// sensor hitlist.
//
// Return kFALSE if an error occured, kTRUE otherwise.

  //BUGGY CODE:
//     Int_t i, trkcntr=0;
//     TObjArray *HitList;
//     TPhTrack  *track;
//     TPhTrack  *newtrack;
//     THashTable *objlist;

//     if(!fMagnet)
//     {
//         Error("SwimEvent", "No TPhMagnet object connected to TPhSwim!\n");
// 	return kFALSE;
//     }
//     if(!fDetector)
//     {
//         Error("SwimEvent", "No TPhDetector object connected to TPhSwim!\n");
// 	return kFALSE;
//     }

//     TPhObjectContainer *swimTrackBuffer = new TPhObjectContainer("SwimTracks");
//     TPhObjectContainer *mcTrackBuffer;
//     mcTrackBuffer = (TPhObjectContainer *) event->GetObject("MCTracks");
//     if(!mcTrackBuffer)
//     {
//         fprintf(stderr,"Error in TPhSwim::SwimEvent(TPhEvent *event): \n");
//         fprintf(stderr,"Can't find TPhObjectContainer 'MCTracks'.\n");
//         return kFALSE;
//     }


//     printf("Swim event %d %d, %d tracks\n",
//              event->GetNRun(),event->GetNEvent(),mcTrackBuffer->GetObjectList()->GetEntries());

//     TPhObjectContainer *swimHitBuffer =  new TPhObjectContainer("SwimHits");
//     TPhObjectContainer *mcHitBuffer;
//     mcHitBuffer = (TPhObjectContainer *) event->GetObject("MCHits");
    
//     TIter NextTrack(mcTrackBuffer->GetObjectList());
//     while(track = (TPhTrack *) NextTrack())
//     {
//         if(fVerbose)
//         {
//             printf("Track no: %d - %d hits (before swimming) for P(x,y,z) %g %g %g\n", trkcntr,
//                        track->GetNHits(),
//                        track->GetPx(),
//                        track->GetPy(),
//                        track->GetPz());
//         }
//mpd this will not work if you don't provide a deep copy constructor for TPhTrack! newtrack = new TPhTrack(*track);
//         if( newtrack->GetHitList() ) newtrack->GetHitList()->Clear();
//         newtrack->ResetHitCounter();
//         if ( !SwimTrack(newtrack) ) {
//            delete newtrack;
//            return kFALSE;
// 	}
//         swimTrackBuffer->Add(newtrack);
//         trkcntr++;
//         if(fVerbose)
//         {
//             printf("Track no: %d - %d hits (after swimming)  for P(x,y,z) %g %g %g\n", trkcntr,
//                        newtrack->GetNHits(),
//                        newtrack->GetPx(),
//                        newtrack->GetPy(),
//                        newtrack->GetPz());
//         }
//         if(newtrack->GetNHits())
//         {
//             HitList = newtrack->GetHitList();
//             for(i=0;i<HitList->GetEntries();i++)
//             {
//                 swimHitBuffer->Add(HitList->At(i));
//             }
//         }
//     }
//     printf("total_calls = %d\n",total_calls);

//     // WE WILL NOT DELETE ANYTHING UNLESS THE USER SPECIFICALLY ASKS FOR IT!
//     //    if(mcTrackBuffer) event->RemoveObject(mcTrackBuffer);
//     //if(mcHitBuffer) event->RemoveObject(mcHitBuffer);
//     event->AddObject(swimTrackBuffer);
//     event->AddObject(swimHitBuffer);
//     return kTRUE;

    Int_t i, trkcntr=0;
    TObjArray *HitList;
    TPhMCTrack  *track;

    if(!fMagnet)
    {
        printf("To use TPhSwim::SwimEvent(), fMagnet has to be set to\n");
        printf("a valid TPhMagnet object\n"); 
        return kFALSE;
    }
    if(!fDetector)
    {
        printf("To use TPhSwim::SwimEvent(), fDetector has to be set to\n");
        printf("a valid TPhDetector object\n"); 
        return kFALSE;
    }

    TPhObjectContainer *TrackBuffer;
    TrackBuffer = (TPhObjectContainer *) event->GetObject("MCTracks");
    if(!TrackBuffer)
    {
        fprintf(stderr,"Error in TPhSwim::SwimEvent(TPhEvent *event): \n");
        fprintf(stderr,"Can't find TPhObjectContainer 'MCTracks'.\n");
        return kFALSE;
    }

    printf("Swim event %d %d, %d tracks\n",
             event->GetNRun(),event->GetNEvent(),TrackBuffer->GetObjectList()->GetEntries());

    TPhObjectContainer *HitBuffer   = new TPhObjectContainer("MCHits");
    event->AddObject(HitBuffer);

    TIter NextTrack(TrackBuffer->GetObjectList());
    while((track = (TPhMCTrack *) NextTrack()) != NULL)
    {
        SwimTrack(track);
        trkcntr++;
        if(fVerbose)
        {
            printf("Track no: %d - %d hits for P(x,y,z) %g %g %g\n", trkcntr,
                       track->GetNHits(),
                       track->GetPx(),
                       track->GetPy(),
                       track->GetPz());
        }
        if(track->GetNHits())
        {
            HitList = track->GetHitList();
            for(i=0;i<HitList->GetEntries();i++)
            {
                HitBuffer->Add(HitList->At(i));
            }
        }
    }
    printf("total_calls = %d\n",total_calls);
    return kTRUE;
}

extern "C" Double_t get_track_sensor_angle(Double_t psi, Double_t alpha);
extern "C" void MoveHitToSensor(TPhMCHit *hit, TPhSpectSensor *sens, Double_t *cos);
extern "C" Int_t    rkgen(Double_t  *xstart, Double_t *dxstrt,
                          Double_t se, Double_t hst, Double_t signp,
                          Float_t *xend, Double_t *dxend, TPhMagnet *magnet );

Bool_t TPhSwim::SwimTrack(TPhMCTrack *track)
{
//                                                                 
// The routine SwimTrack() propagates a TPhMCTrack object through 
// the PHOBOS detector setup. This routine uses the momentum, mass     
// and point of origin information from the TPhMCTrack object.
// So far multiple scattering in the Si layers is the only physics
// effect that is taken into account. This can be controlled via the
// SetMS() member function. Pixelisation is handled by the TPhSensor
// objects that are owned by the TPhDetector object pointed to by   
// fDetector.
// The swimming routine is extremely primitive, but at least           
// selfconsistent.                                                     
//                                                                     
// Return kFALSE if an error occured, kTRUE otherwise.

#define dEBUGSWIM
#define dRAW 
#define wRITE 

#define MSTEST

#define X0_SI	9.36 * 1.4
#define X0_AIR	30420.0 * 2.0
#define X0_BEAMPIPE	0.00025

#define MAX_LENGTH	120.0

    const Double_t klsemod=0.95;    //tracking length reduction factor
    const Double_t kHitDist=0.05; //maximum distance from sensor to regard it a hit
    const Double_t kStepSize=0.1;  //internal tracking step

    Float_t  ex[3];
    Float_t field[3] = {0, 0, 0};

    Double_t sx[3];
    Double_t scosines[3], ecosines[3];
    Double_t p, px, py, pz;
    Double_t stepsize, lsignp;     //signed momentum
    Double_t d = 0;
    Double_t x[3];
    Double_t dpsi;
    Double_t ms_psi;
    Double_t ms_dip;
    Double_t dist;
    Int_t steps;
    Int_t cnt;
    Double_t charge;
    Double_t psi_old;
    Double_t step_sigma;
    Double_t length;
    Double_t old_length;
    Double_t psi;
    Double_t beta;
    Double_t sigma;
    Double_t pxz;
    Double_t dip;
    Double_t rel_rise;
    Double_t min_dist;
    Double_t max_path;

    Int_t old_layer = -1;
    TPhSensor *BaseSensor;
    TPhSpectSensor *sensor;

    TPhSubDetector *SubDetector;
    TPhLayer  *layer;
    TPhMCHit    *hit;
    int flVerbose;
    char stopch;

    if(!fMagnet)
    {
        Error("SwimEvent", "No TPhMagnet object connected to TPhSwim!\n");
	return kFALSE;
    }
    if(!fDetector)
    {
        Error("SwimEvent", "No TPhDetector object connected to TPhSwim!\n");
	return kFALSE;
    }

    if(!fSensorList)
    {
//mpd 980212 trying to make this fit into new TPhSubDetector framework. 
//          fDetector->CalcMaxSensorHeight();

//          if(fVerbose)
//              printf("Create fSensorList\n");

//          fSensorList = new TObjArray(30);

//          TIter NextLayer(fDetector->GetLayerList());
//          while(layer = (TPhLayer *) NextLayer())
//          {
//              if(fVerbose)
//                  printf("Now at layer %d\n",layer->GetLabel());
//              TIter NextSensorX(layer->GetSensorList());
//              while(BaseSensor  = (TPhSensor *) NextSensorX())
//              {
//                  if(fVerbose)
//                  {
//                       printf("Now at sensor %d\n",BaseSensor->GetLabel());
//                       BaseSensor->SetVerbose(1);
//                  }
//                  if(strstr(BaseSensor->GetChLabel(),"S"))
//                  {
// 		     sensor = (TPhSpectSensor*) BaseSensor;
//                      fSensorList->Add(sensor);
//                      sensor->CalcDistVar();
//                      if(fVerbose)
//                           printf("Add sensor %s %g %g %d\n",
//                                       sensor->GetName(),
//                                       sensor->GetSensorHeight()/2,
//                                       sensor->GetPxlHeight(), sensor->GetRows());
//                  }
//              }
//          }

         if(fVerbose)
             printf("Create fSensorList\n");

         fSensorList = new TObjArray(30);

         TIter NextSubDetector(fDetector->GetSubDetectorList());
         while((SubDetector = (TPhSubDetector *) NextSubDetector()) != NULL) {
	   if(fVerbose)
	     printf("At subdetector %s\n", SubDetector->GetName());

	   TIter NextLayer(SubDetector->GetLayerList());
	   while((layer = (TPhLayer *) NextLayer()) != NULL) {

	     TIter NextSensorX(layer->GetSensorList());
	     while((BaseSensor  = (TPhSensor *) NextSensorX()) != NULL) {
	       if(fVerbose) {
		 printf("Now at sensor %s\n", BaseSensor->GetName());
		 BaseSensor->SetVerbose(1);
	       }
	       //	       fSensorList->Add(BaseSensor);
	       // Is this the spectrometer? Only spectrometer currently works...
	       if(strstr(SubDetector->GetName(),"Spect")) {
		 sensor = (TPhSpectSensor*) BaseSensor;
		 fSensorList->Add(BaseSensor);
		 sensor->CalcDistVar();
		 if(fVerbose)
		   printf("At sensor %s %g %g %d\n",
			  sensor->GetName(),
			  sensor->GetSensorHeight()/2,
			  sensor->GetPxlHeight(), sensor->GetRows());
	       }
	     }
	   }
	 }     
	 if(fVerbose)
	   printf("Found %d sensors\n",fSensorList->GetEntries());
    }

    if(fVerbose) {
        printf("\nStarting SwimTrack(): P(x,y,z,mass) %g %g %g %g Charge: %d\n",
                  track->GetPx(),
                  track->GetPy(),
                  track->GetPz(),
                  track->GetMass(),
                  track->GetCharge());
	gSystem->Sleep(1000);
    }

    if(track->GetHitList())
        track->GetHitList()->Clear();
    else
       track->MakeHitList();

// Get momentum components and calculate some numbers for 
// later use.
    px = track->GetPx();
    py = track->GetPy();
//ao include tracing into left arm by mirror reflection of x,y momenta
    Bool_t reversed;
    reversed = kFALSE;
    if (px<0) 
	{ px = -px;
          reversed = kTRUE;
        }
    pz = track->GetPz(); 
    charge = track->GetCharge();
    p = TMath::Sqrt(px*px + py*py + pz*pz);
    pxz = TMath::Sqrt(px*px + pz*pz);
    dip = TMath::ATan(py/pxz);
    psi = TMath::ATan(pz/px);
    if(!px)
    {
        px = 0.001 * (gRandom->Rndm() - 0.5);
        fprintf(stderr,"px = 0, set to %g\n",px);
    }
    scosines[0] = px/p;
    scosines[1] = py/p;
    scosines[2] = pz/p;
    lsignp = p*charge;
    rel_rise = GetRelRise(p,track->GetMass());

// We are not interested in things going towards negative z
// and p < 0.05 GeV particles don't make it through the beampipe
// anyways (?!?)
// Also throw away stuff going to the left arm and particles
// with large dip angles.

//ao    if(pz < 0.0 || p < 0.05 || TMath::Abs(dip)>0.1 || px < 0)
//ao include tracing into left arm by mirror reflection of x momenta
     if(pz < 0.0 || p < 0.05 || TMath::Abs(dip)>0.1 || charge==0)
     {
         return kFALSE;
     }
    length = 0.0;
    old_length = 0.0;

// Start tracking at production point of track

    x[0] = track->GetXProd();
    x[1] = track->GetYProd();
//ao include tracing into left arm by mirror reflection of x 
    if ( reversed ) 
	{ x[0] = -x[0];
        }
    x[2] = track->GetZProd();

// Multiple scattering in beam pipe and air.
    if(fDoMS)
    {
        beta = track->GetBeta();
        sigma = 0.014/(p*beta) * TMath::Sqrt(X0_BEAMPIPE);
        dpsi = gRandom->Gaus(0,sigma);
        psi += dpsi;
// assume pxz does not change
        pz = pxz * TMath::Sin(psi);
        px = pxz * TMath::Cos(psi);
        if(!px)
        {
            px = 0.001 * (gRandom->Rndm() - 0.5);
            fprintf(stderr,"px = 0, set to %g\n",px);
        }
        scosines[0]=px/p;
        scosines[2]=pz/p;
        step_sigma = 0.014/(p*beta) * TMath::Sqrt(1.0/X0_AIR);
#ifdef DEBUGSWIM
        printf("step_sigma = %g\n",step_sigma);
#endif
    }
    if(fVerbose)
    {
        printf("x,y,z = %g %g %g\n",x[0],x[1],x[2]);
	// mpd 9802102       printf("MaxLayers = %d\n",fDetector->GetNLayers());
    }
    steps=0;
    cnt  = 0;

// current_path counts the path length since distance to 
// sensors was checked for the last time. If this exceeds
// max_path, distances are checked again and max_path is 
// set according to shortest distance.

    max_path     = kStepSize;

// Here are some conditions for stopping the swimming routine
// Note that the cuts are set for only ONE tracking arm (x>0)
// Some cuts are hardwired here. This cuts have to be changed
// to make use of the full setup. This should be done after 
// moving to a proper Runge-Kutta integration of the field,
// which should allow bigger steps and therefore faster 
// tracking

    stopch = 'v';
    flVerbose = fVerbose;

    //mpd 980212: still experimenting with new setup with SubDetectors!
//     while(length < MAX_LENGTH &&  
//           x[2] >= 0 && x[0] >= 0 && 
//           x[2] < 100.0 && x[0] < 100 &&
//           (x[2] < 50 || x[0] > 5) &&
//           TMath::Abs(x[1]) < fDetector->GetMaxSensorHeight() &&
//           cnt < fDetector->GetNLayers())
//     {
    while(length < MAX_LENGTH &&  
          x[2] >= 0 && x[0] >= 0 && 
          x[2] < 100.0 && x[0] < 100 &&
          (x[2] < 50 || x[0] > 5)) {
 
// Calculate deflection and modify coordinates
        sx[0] = x[0]; sx[1] = x[1]; sx[2] = x[2];
        stepsize = kStepSize;

        rkgen( sx, scosines, max_path, stepsize, lsignp, ex, ecosines, fMagnet );

//mpd we need the field later on (is being stored in TPhMCHit), so i 
//mpd think that we should read the field here and pass it on to rkgen(),
//mpd so that we don't have to do it twice. 
	fMagnet->GetField(ex, field);

        x[0] = ex[0]; x[1] = ex[1]; x[2] = ex[2];
        scosines[0] = ecosines[0]; 
        scosines[1] = ecosines[1]; 
        scosines[2] = ecosines[2];

        px = p*scosines[0];
        py = p*scosines[1];
        pz = p*scosines[2];
        pxz = TMath::Sqrt(px*px + pz*pz);
        psi = TMath::ATan(scosines[2]/scosines[0]);

//mpd need to put psi in the right quadrant
	if(scosines[0] < 0)
	  psi += TMath::Pi();

        steps++;

	if(flVerbose)
        {
            printf("\nkStepSize = %g, length = %g, cnt = %d\n",
				kStepSize,length,cnt);
            printf("x,y,z %g, %g, %g\n",x[0],x[1],x[2]);
            printf("Press n for the next track, or other for this track tracing:\n");
            if( stopch != 'n' ) scanf("%c",&stopch);
            if( stopch == 'n' ) flVerbose = 0;
	}
// Loop over all sensors and check whether particle
// is close enough to one of them to call it a hit.
	TIter NextSensor(fSensorList);
        min_dist = 10.0;

        NextSensor.Reset();

        while((sensor = (TPhSpectSensor *) NextSensor()) != NULL)
        {
	    total_calls++;
            dist = TMath::Abs(sensor->DistToSensor(&x[0]));
	    if(flVerbose)
            {
                printf("Dist: %g Height:%g PHeight %g (%g %g %g %g) \n",
                        dist,TMath::Abs(x[1]),sensor->GetSensorHeight()/2,
                        sensor->GetX0(),sensor->GetZ0(),
                        sensor->GetX1(),sensor->GetZ1());
            }
            if(dist < kHitDist && 
               TMath::Abs(x[1]) < sensor->GetSensorHeight()/2 &&
               sensor->GetLayer() != old_layer)
	      {
		if( flVerbose ) 
		  {
		    printf("Found hit at %g %g %g (%g)\n",x[0],x[2],dist,length);
		    printf("Hit sensor %d (%g %g %d)\n",
			   sensor->GetLabel(),
			   TMath::Abs(x[1]),
			   sensor->GetSensorHeight()/2,
			   sensor->GetLayer());
		  }
// Check y-coordinate vs height of layer. Also we don't allow 
// consecutive hits in the same layer
		psi_old = psi;
		hit = new TPhMCHit();

// Simulate multiple scattering in layer
	        d = TMath::Abs(sensor->GetThickness()/TMath::Sin(get_track_sensor_angle(psi,sensor->GetAlpha())));
		if(fDoMS)
		{

//mpd need to cut it off above a rediculous value: 8cm for now...
		    if(d > 8) {
		      if(fVerbose)
			printf("d = %f, truncating it to 8cm\n", d);
		      d = 8.;
		    }

		    sigma = 0.0136/(p*beta)*TMath::Sqrt(d/X0_SI)*(1+0.038*TMath::Log(d/X0_SI));
#ifdef DEBUGSWIM
		    printf("p,d,beta,X0_SI,psi,alpha = %g %g %g %g %g %g\n",
			   p,d,beta,X0_SI,psi,sensor->GetAlpha());
#endif
		    ms_psi = gRandom->Gaus(0.0,sigma);
		    psi += ms_psi;
		    ms_dip = gRandom->Gaus(0.0,sigma);
		    dip += ms_dip;

// lets first change p
                    py = pxz * tan(dip);
		    pxz = TMath::Sqrt(p*p - py*py);
// now change px, pz
		    pz = pxz * TMath::Sin(psi);
		    px = pxz * TMath::Cos(psi);
                    if(!px)
                    {
                        px = 0.001 * (gRandom->Rndm() - 0.5);
                        fprintf(stderr,"px = 0, set to %g\n",px);
                    }
		    scosines[0]=px/p;
		    scosines[1]=py/p;
		    scosines[2]=pz/p;
		}

// Set hit parameters

		hit->SetX(x[0]);
		hit->SetY(x[1]);
		hit->SetZ(x[2]);
		hit->SetSensorLabel(sensor->GetLabel());
		hit->SetLayer(sensor->GetLayer());
		hit->SetPsi(psi_old);
		hit->SetLength(length);
		hit->SetField(field[1]);
		hit->SetDe(GetLandau()*d/sensor->GetThickness()*rel_rise);

// Make sure that hit coordinate lies on the sensor surface
		MoveHitToSensor(hit,sensor,scosines);

// Call pixelisation routine if fPixelize is true. Note that 
// the sensor may return a different pointer than the one in 
// the argument to Pixelize(), if there is already a hit in 
// this pixel.

		if(fPixelize)
                    hit = (TPhMCHit *) sensor->Pixelize(hit);
                else
                    sensor->AddHit(hit);

//ao include tracing into left arm by mirror reflection of x,y momenta
		if (reversed) 
		  { 
		    hit->SetX(-hit->GetX());
		  }

// Add the hit to the track list. 
		if(hit)
		  track->AddHit(hit); 
		old_layer = sensor->GetLayer();
		cnt++;
		if(flVerbose)
		  {
		    printf("Now %d hits\n",cnt);
		  }
	      }
            else if( (sensor->GetLayer() != old_layer) && 
                     (TMath::Abs(x[1]) < sensor->GetSensorHeight()/2) )
	      {
                if(dist < min_dist)
		  {
                    min_dist  = dist;
		  }
	      }
        }
        max_path = min_dist*klsemod;
        if(flVerbose)
	  {
	    printf("Set max_path to %g\n",max_path);
	    gSystem->Sleep(1000);
	  }
        length += max_path;
    }
    if(flVerbose)
       printf("Finished SwimTrack(): %d hits\n",track->GetNHits());
    return kTRUE;
}

void MoveHitToSensor(TPhMCHit *hit, TPhSpectSensor *sens, Double_t *cos)
{
// Move hit from to position after last Runge-Kutta
// step to position on the surface of the sensor.

    Double_t a;
    Double_t b;
    Double_t c;
    Double_t d;
    Double_t e;
    Double_t f;
    Double_t x;    
    Double_t y;    
    Double_t z;

    a = (sens->GetZ1() - sens->GetZ0())/(sens->GetX1() - sens->GetX0());
    b = sens->GetZ0() - sens->GetX0() * a;
    
#ifdef DEBUGMV
    printf("a,b = %g %g for det %d (%g %g %g %g)\n",a,b,det->det,det->x0,det->z0,det->x1,det->z1);
#endif

//    c = tan(hit->GetPsi());
    if(!cos[0])
    {
        fprintf(stderr,"TPhSwim::MoveHitToSensor(): cos[0] = %g\n",cos[0]);
        return;
    }
    c = cos[2]/cos[0];
    d = hit->GetZ() - hit->GetX() * c;

#ifdef DEBUGMV
    printf("c,d = %g %g for hit at %g %g\n",c,d,hit->GetX(),hit->GetZ());
#endif

    e = cos[1]/cos[0];
    f = hit->GetY() - hit->GetX() * e;

    if(a != c)
    {
        x = (d-b)/(a-c);
        z = a*x + b;
        y = e*x + f;
    }
    else
    {
        fprintf(stderr,"TPhSwim::MoveHitToSensor(): a = %g, c = %g, Hit not moved\n",a,c);
    }

    hit->SetX(x);
    hit->SetY(y);
    hit->SetZ(z);

#ifdef DEBUGMV
    printf("Intersection at x,z = %g %g \n",x,z);
#endif
}


void  TPhSwim::Draw()
{
// Call the drawing routine for the detector

    if(fDetector)
    {
        fDetector->Draw();
    }
}

Double_t get_track_sensor_angle(Double_t psi,Double_t alpha)
{
// return angle between track and sensor layer

    return TMath::Abs(psi - alpha);  
}



#define DEDXNORM 	78.0*0.96
#define DEDXSCALE	0.65


Double_t TPhSwim::GetRelRise(Double_t mom, Double_t mass)
{
// Parametrisation of Bethe-Bloch formula. This should be 
// replaced by something simpler

    Double_t epsilon;        
    Double_t zeta, K, Q, delta;
    Double_t gamma, beta;
    Double_t p1, p2;          
    Double_t a, m, X1, X0, XA;
    Double_t epsmin, logbg, X;

    m = 3.0;              
    Q = 1.0;
    p1 = 4.0;
    p2 = 1.0;
    epsmin = 30.0;

    zeta = 0.42;
    K = 13.85;
    XA = 2.28;
    a = 0.26;


    zeta = zeta * (p2/p1);
    K = K + TMath::Log(p2/p1);
    XA = XA - 0.5*log10(p2/p1);

    X0 = 1.771087313;
    X1 = 4.200915361;


// Defines unnormalized dE/dx as function of beta*gamma or mom/mass

        X = mom/mass;
        beta = TMath::Sqrt((X*X)/(1+X*X));
        gamma = TMath::Sqrt(1 + X*X);

        if(beta*gamma > 0.0)
        {
        logbg = log10(beta*gamma);
        if(logbg < X0)
        {
            delta = 0;
        }
        else if(X0 < logbg && logbg < X1)
        {
            delta = 2.0*TMath::Log(10.0)*(logbg-XA) + a*(pow(X1-logbg,m));
        }
        else if(X1 < logbg)
        {
            delta = 2.0*TMath::Log(10.0) * (logbg-XA);
        }

        epsilon = zeta * (Q*Q/(beta*beta))
                   * ( K + TMath::Log(Q*Q)
                   + TMath::Log(gamma*gamma) 
                   - beta*beta - delta);
        }
        else
            epsilon = 0.0;
        
        if(beta*gamma >= 3.8)
            epsilon = 1.0;
        else
            epsilon *= DEDXSCALE;
        return(epsilon * DEDXNORM);
}


void TPhSwim::InitLandau()
{
// Read landau distribution from file $PHATHOME/init/landau.init

    Char_t filename[256];
    fLandau = new TH1F("landau","Landau distribution",200,0,1);

    FILE *fp;
    Float_t x;

    const Char_t *DirName = gSystem->Getenv("PHATHOME");
    
    if(!DirName)
    {
        fprintf(stderr,"$PHATHOME undefined. Can't load landau distribution\n");
        return;
    }
    sprintf(filename,"%s/init/landau.init",DirName);
    fp = fopen(filename,"r");

    if(fp)
    {
        for( int i=0;i<200;i++)
        {
            fscanf(fp,"%f",&x);
            x/=1.5603e+05;
            fLandau->SetBinContent(i,x);
        }
    }
    else
    {
        printf("Can't find %s\n",filename);
        return;
    }
}

Double_t TPhSwim::GetLandau()
{
// Return random value distributed according to a Landau distribution

    Double_t x;

    x = 0;
    while(gRandom->Rndm() > fLandau->GetBinContent((Int_t) (200*x)))
    {
        x = gRandom->Rndm();
    }
    return x;
}

/* Subroutine */ 
 Int_t rkgen(Double_t  xstart[3], Double_t dxstrt[3],
                  Double_t se, Double_t hst, Double_t signp,
                  Float_t xend[3], Double_t dxend[3], TPhMagnet *magnet )
{
    /* Initialized data */

    static Double_t thrd = .333333333333333;

    /* System generated locals */
    Int_t i__1;
    Double_t r__1, r__2, r__3;

    /* Local variables */
    static Double_t pinv, a, b, c__, h__, x, y, z__, anorm, secxs[4], 
                   secys[4], seczs[4];
    static Int_t nstep;
    static Double_t h2, h4, at, bt, ct, ph;
    static Int_t mm;
    static Double_t xt, yt, zt, ph2;
    Float_t vec[3];
    Float_t f[3];


/* .        RUNGE-KUTTA METHOD FOR TRACKING A PARTICLE THROUGH A MAGNETIC */
/* .        FIELD. USES NYSTROEM ALGORITHM (SEE HANDBOOK NAT.BUR.OF */
/* .        STANDARDS, PROCEDURE 25.5.20) */
/* .        OPTIMISED FOR SPEED, ALLOWING MAX. STEP SIZE AND ANY */
/* .        ORIENTATION IN SPACE. STEP SIZE FIXED. */
/* .            ORIGIN = F.LOUIS '75, STATUS = TESTED. */

/*         INPUT PARAMETERS */
/*             XSTART    COORDINATES AT START */
/*             DXSTRT    DIRECTION COSINES AT START */
/*             SE        TOTAL CURVED TRACK LENGTH (+ OR -) */
/*             HST       STEP SIZE */
/*             SIGNP     MOMENTUM WITH SIGN INDICATING TURNING SENSE */
/*                       OF TRACK, IF +VE, TURNS ANTICLOCK WHEN LOOKING */
/*                       ALONG FIELD. IF DIRECTION = PARTICLE MOTION */
/*                       AND FIELD DEFINED SO THAT DI/DS=E*CONST*(I X H) 
*/
/*                       THEN SIGN IS THAT OF PARTICLE CHARGE. */
/*                       SPEED OF LIGHT IS .0003,ASSUMING CM,GEV/C,KGAUSS 
*/

/*         OUTPUT PARAMETERS */
/*             XEND      END POINT COORDINATES */
/*             DXEND     DIRECTION COSINES AT END */
/*                        (BOTH MAY OVERLAP STARTING VALUES) */

/*          USER ROUTINE CALLED */
/*             CALL MAGF(FIELD(1...3),X,Y,Z) */


    x = xstart[0];
    y = xstart[1];
    z__ = xstart[2];
    a = dxstrt[0];
    b = dxstrt[1];
    c__ = dxstrt[2];
    pinv = 2.997925e-4 / signp;

/* get field and translate Tesla to kGauss */
    vec[0] = x; vec[1] = y; vec[2] = z__; 
    magnet->GetField( vec,f );

    f[0] *= 10.0; f[1] *= 10.0; f[2] *= 10.0;
    nstep = (Int_t) (se / hst + .99);
    h__ = se /  nstep;
    h2 = h__ * .5;
    h4 = h__ * .25;
    ph = pinv * h__;
    ph2 = ph * .5;
/*         LOOP OVER NUMBER OF (EQUAL) STEPS */
    i__1 = nstep;
    for (mm = 1; mm <= i__1; ++mm) {
	secxs[0] = (b * f[2] - c__ * f[1]) * ph2;
	secys[0] = (c__ * f[0] - a * f[2]) * ph2;
	seczs[0] = (a * f[1] - b * f[0]) * ph2;
	xt = x + h2 * a + h4 * secxs[0];
	yt = y + h2 * b + h4 * secys[0];
	zt = z__ + h2 * c__ + h4 * seczs[0];
	at = a + secxs[0];
	bt = b + secys[0];
	ct = c__ + seczs[0];
/* get field and translate Tesla to kGauss */
        vec[0] = xt; vec[1] = yt; vec[2] = zt; 
        magnet->GetField( vec,f );
        f[0] *= 10.0; f[1] *= 10.0; f[2] *= 10.0;
	secxs[1] = (bt * f[2] - ct * f[1]) * ph2;
	secys[1] = (ct * f[0] - at * f[2]) * ph2;
	seczs[1] = (at * f[1] - bt * f[0]) * ph2;
	at = a + secxs[1];
	bt = b + secys[1];
	ct = c__ + seczs[1];
	secxs[2] = (bt * f[2] - ct * f[1]) * ph2;
	secys[2] = (ct * f[0] - at * f[2]) * ph2;
	seczs[2] = (at * f[1] - bt * f[0]) * ph2;
	xt = x + h__ * a + h__ * secxs[2];
	yt = y + h__ * b + h__ * secys[2];
	zt = z__ + h__ * c__ + h__ * seczs[2];
	at = a + secxs[2] + secxs[2];
	bt = b + secys[2] + secys[2];
	ct = c__ + seczs[2] + seczs[2];
/* get field and translate Tesla to kGauss */
        vec[0] = xt; vec[1] = yt; vec[2] = zt; 
        magnet->GetField( vec,f );
        f[0] *= 10.0; f[1] *= 10.0; f[2] *= 10.0;
	secxs[3] = (bt * f[2] - ct * f[1]) * ph2;
	secys[3] = (ct * f[0] - at * f[2]) * ph2;
	seczs[3] = (at * f[1] - bt * f[0]) * ph2;
	z__ += (c__ + (seczs[0] + seczs[1] + seczs[2]) * thrd) * h__;
	y += (b + (secys[0] + secys[1] + secys[2]) * thrd) * h__;
	x += (a + (secxs[0] + secxs[1] + secxs[2]) * thrd) * h__;
	a += (secxs[0] + secxs[3] + (secxs[1] + secxs[2]) * 2.) * thrd;
	b += (secys[0] + secys[3] + (secys[1] + secys[2]) * 2.) * thrd;
	c__ += (seczs[0] + seczs[3] + (seczs[1] + seczs[2]) * 2.) * 
		thrd;
/* L10: */
    }
/*         TRANSMIT RESULT */
    xend[0] = x;
    xend[1] = y;
    xend[2] = z__;
/* Computing 2nd power */
    r__1 = a;
/* Computing 2nd power */
    r__2 = b;
/* Computing 2nd power */
    r__3 = c__;
    anorm = 1.5 - (r__1 * r__1 + r__2 * r__2 + r__3 * r__3) * 
            .5;
    dxend[0] = anorm * a;
    dxend[1] = anorm * b;
    dxend[2] = anorm * c__;
    return 0;

} /* rkgen_ */



